# -*- coding: utf-8
conversation={
    "testFlow":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DBSCHEMA_CATALOGS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="ROLES" name="ROLES" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DATE_MODIFIED" name="DATE_MODIFIED" type="xsd:dateTime" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <DESCRIPTION>A Unified Dimensional Model that encompasses the Adventure Works data warehouse.</DESCRIPTION>
            <ROLES>*,admin</ROLES>
            <DATE_MODIFIED>2013-07-05T16:05:56.07</DATE_MODIFIED>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_CUBES</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>Adventure Works DW 2008R2</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_TYPE" name="CUBE_TYPE" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_GUID" name="CUBE_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="CREATED_ON" name="CREATED_ON" type="xsd:dateTime" minOccurs="0"/>
                <xsd:element sql:field="LAST_SCHEMA_UPDATE" name="LAST_SCHEMA_UPDATE" type="xsd:dateTime" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_UPDATED_BY" name="SCHEMA_UPDATED_BY" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LAST_DATA_UPDATE" name="LAST_DATA_UPDATE" type="xsd:dateTime" minOccurs="0"/>
                <xsd:element sql:field="DATA_UPDATED_BY" name="DATA_UPDATED_BY" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="IS_DRILLTHROUGH_ENABLED" name="IS_DRILLTHROUGH_ENABLED" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_LINKABLE" name="IS_LINKABLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_WRITE_ENABLED" name="IS_WRITE_ENABLED" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_SQL_ENABLED" name="IS_SQL_ENABLED" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="CUBE_CAPTION" name="CUBE_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="BASE_CUBE_NAME" name="BASE_CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_SOURCE" name="CUBE_SOURCE" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="PREFERRED_QUERY_PATTERNS" name="PREFERRED_QUERY_PATTERNS" type="xsd:unsignedShort" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <CUBE_TYPE>CUBE</CUBE_TYPE>
            <LAST_SCHEMA_UPDATE>2011-06-23T23:01:05.196667</LAST_SCHEMA_UPDATE>
            <LAST_DATA_UPDATE>2011-06-24T11:57:43.523333</LAST_DATA_UPDATE>
            <DESCRIPTION/>
            <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
            <IS_LINKABLE>true</IS_LINKABLE>
            <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
            <IS_SQL_ENABLED>true</IS_SQL_ENABLED>
            <CUBE_CAPTION>Adventure Works</CUBE_CAPTION>
            <CUBE_SOURCE>1</CUBE_SOURCE>
            <PREFERRED_QUERY_PATTERNS>0</PREFERRED_QUERY_PATTERNS>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_HIERARCHIES</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
          <HIERARCHY_UNIQUE_NAME>[Product].[Category]</HIERARCHY_UNIQUE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>Adventure Works DW 2008R2</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_NAME" name="HIERARCHY_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_GUID" name="HIERARCHY_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_CAPTION" name="HIERARCHY_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_TYPE" name="DIMENSION_TYPE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_CARDINALITY" name="HIERARCHY_CARDINALITY" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="DEFAULT_MEMBER" name="DEFAULT_MEMBER" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="ALL_MEMBER" name="ALL_MEMBER" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="STRUCTURE" name="STRUCTURE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="IS_VIRTUAL" name="IS_VIRTUAL" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_READWRITE" name="IS_READWRITE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_UNIQUE_SETTINGS" name="DIMENSION_UNIQUE_SETTINGS" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_MASTER_UNIQUE_NAME" name="DIMENSION_MASTER_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_IS_VISIBLE" name="DIMENSION_IS_VISIBLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_ORDINAL" name="HIERARCHY_ORDINAL" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_IS_SHARED" name="DIMENSION_IS_SHARED" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_IS_VISIBLE" name="HIERARCHY_IS_VISIBLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_ORIGIN" name="HIERARCHY_ORIGIN" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_DISPLAY_FOLDER" name="HIERARCHY_DISPLAY_FOLDER" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="INSTANCE_SELECTION" name="INSTANCE_SELECTION" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="GROUPING_BEHAVIOR" name="GROUPING_BEHAVIOR" type="xsd:unsignedShort" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Category</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Category]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Category</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Category].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Category].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>6</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_LEVELS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
          <HIERARCHY_UNIQUE_NAME>[Product].[Category]</HIERARCHY_UNIQUE_NAME>
          <LEVEL_UNIQUE_NAME>[Product].[Category].[Category]</LEVEL_UNIQUE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>Adventure Works DW 2008R2</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_NAME" name="LEVEL_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_UNIQUE_NAME" name="LEVEL_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_GUID" name="LEVEL_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_CAPTION" name="LEVEL_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_NUMBER" name="LEVEL_NUMBER" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_CARDINALITY" name="LEVEL_CARDINALITY" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_TYPE" name="LEVEL_TYPE" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUSTOM_ROLLUP_SETTINGS" name="CUSTOM_ROLLUP_SETTINGS" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_UNIQUE_SETTINGS" name="LEVEL_UNIQUE_SETTINGS" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_IS_VISIBLE" name="LEVEL_IS_VISIBLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_ORDERING_PROPERTY" name="LEVEL_ORDERING_PROPERTY" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_DBTYPE" name="LEVEL_DBTYPE" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_MASTER_UNIQUE_NAME" name="LEVEL_MASTER_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_NAME_SQL_COLUMN_NAME" name="LEVEL_NAME_SQL_COLUMN_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_KEY_SQL_COLUMN_NAME" name="LEVEL_KEY_SQL_COLUMN_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME" name="LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_ATTRIBUTE_HIERARCHY_NAME" name="LEVEL_ATTRIBUTE_HIERARCHY_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_KEY_CARDINALITY" name="LEVEL_KEY_CARDINALITY" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_ORIGIN" name="LEVEL_ORIGIN" type="xsd:unsignedShort" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Category]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_NAME>Category</LEVEL_NAME>
            <LEVEL_UNIQUE_NAME>[Product].[Category].[Category]</LEVEL_UNIQUE_NAME>
            <LEVEL_CAPTION>Category</LEVEL_CAPTION>
            <LEVEL_NUMBER>1</LEVEL_NUMBER>
            <LEVEL_CARDINALITY>5</LEVEL_CARDINALITY>
            <LEVEL_TYPE>0</LEVEL_TYPE>
            <DESCRIPTION/>
            <CUSTOM_ROLLUP_SETTINGS>0</CUSTOM_ROLLUP_SETTINGS>
            <LEVEL_UNIQUE_SETTINGS>0</LEVEL_UNIQUE_SETTINGS>
            <LEVEL_IS_VISIBLE>true</LEVEL_IS_VISIBLE>
            <LEVEL_ORDERING_PROPERTY>Category</LEVEL_ORDERING_PROPERTY>
            <LEVEL_DBTYPE>3</LEVEL_DBTYPE>
            <LEVEL_NAME_SQL_COLUMN_NAME>NAME( [$Product].[Category] )</LEVEL_NAME_SQL_COLUMN_NAME>
            <LEVEL_KEY_SQL_COLUMN_NAME>KEY( [$Product].[Category] )</LEVEL_KEY_SQL_COLUMN_NAME>
            <LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME>UNIQUENAME( [$Product].[Category] )</LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME>
            <LEVEL_ATTRIBUTE_HIERARCHY_NAME>Category</LEVEL_ATTRIBUTE_HIERARCHY_NAME>
            <LEVEL_KEY_CARDINALITY>1</LEVEL_KEY_CARDINALITY>
            <LEVEL_ORIGIN>2</LEVEL_ORIGIN>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_MEMBERS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
          <HIERARCHY_UNIQUE_NAME>[Product].[Category]</HIERARCHY_UNIQUE_NAME>
          <LEVEL_UNIQUE_NAME>[Product].[Category].[Category]</LEVEL_UNIQUE_NAME>
          <MEMBER_UNIQUE_NAME>[Product].[Category].&amp;[3]</MEMBER_UNIQUE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>Adventure Works DW 2008R2</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_UNIQUE_NAME" name="LEVEL_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_NUMBER" name="LEVEL_NUMBER" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_ORDINAL" name="MEMBER_ORDINAL" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_NAME" name="MEMBER_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_UNIQUE_NAME" name="MEMBER_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_TYPE" name="MEMBER_TYPE" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_GUID" name="MEMBER_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_CAPTION" name="MEMBER_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CHILDREN_CARDINALITY" name="CHILDREN_CARDINALITY" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="PARENT_LEVEL" name="PARENT_LEVEL" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="PARENT_UNIQUE_NAME" name="PARENT_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="PARENT_COUNT" name="PARENT_COUNT" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="EXPRESSION" name="EXPRESSION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_KEY" name="MEMBER_KEY" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="IS_PLACEHOLDERMEMBER" name="IS_PLACEHOLDERMEMBER" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_DATAMEMBER" name="IS_DATAMEMBER" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="SCOPE" name="SCOPE" type="xsd:int" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Category]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_UNIQUE_NAME>[Product].[Category].[Category]</LEVEL_UNIQUE_NAME>
            <LEVEL_NUMBER>1</LEVEL_NUMBER>
            <MEMBER_ORDINAL>3</MEMBER_ORDINAL>
            <MEMBER_NAME>Clothing</MEMBER_NAME>
            <MEMBER_UNIQUE_NAME>[Product].[Category].&amp;[3]</MEMBER_UNIQUE_NAME>
            <MEMBER_TYPE>1</MEMBER_TYPE>
            <MEMBER_CAPTION>Clothing</MEMBER_CAPTION>
            <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
            <PARENT_LEVEL>0</PARENT_LEVEL>
            <PARENT_UNIQUE_NAME>[Product].[Category].[All Products]</PARENT_UNIQUE_NAME>
            <PARENT_COUNT>1</PARENT_COUNT>
            <MEMBER_KEY>3</MEMBER_KEY>
            <IS_PLACEHOLDERMEMBER>false</IS_PLACEHOLDERMEMBER>
            <IS_DATAMEMBER>false</IS_DATAMEMBER>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetDBSchemaCatalogs":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DBSCHEMA_CATALOGS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="ROLES" name="ROLES" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DATE_MODIFIED" name="DATE_MODIFIED" type="xsd:dateTime" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>4PLAN HR UDM</CATALOG_NAME>
            <DESCRIPTION/>
            <DATE_MODIFIED>2017-03-01T14:24:31.29</DATE_MODIFIED>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <DESCRIPTION>A Unified Dimensional Model that encompasses the Adventure Works data warehouse.</DESCRIPTION>
            <ROLES>*,admin</ROLES>
            <DATE_MODIFIED>2013-07-05T16:05:56.07</DATE_MODIFIED>
          </row>
          <row>
            <CATALOG_NAME>bi2</CATALOG_NAME>
            <DESCRIPTION/>
            <DATE_MODIFIED>2019-04-10T05:22:01.156667</DATE_MODIFIED>
          </row>
          <row>
            <CATALOG_NAME>DWH</CATALOG_NAME>
            <DESCRIPTION/>
            <DATE_MODIFIED>2017-02-01T14:55:41.26</DATE_MODIFIED>
          </row>
          <row>
            <CATALOG_NAME>hr2</CATALOG_NAME>
            <DESCRIPTION/>
            <DATE_MODIFIED>2019-04-10T06:45:15.883333</DATE_MODIFIED>
          </row>
          <row>
            <CATALOG_NAME>hr4</CATALOG_NAME>
            <DESCRIPTION/>
            <DATE_MODIFIED>2019-04-10T06:44:36.793333</DATE_MODIFIED>
          </row>
          <row>
            <CATALOG_NAME>MDX Step-by-Step</CATALOG_NAME>
            <DESCRIPTION/>
            <DATE_MODIFIED>2015-07-01T10:27:45.18</DATE_MODIFIED>
          </row>
          <row>
            <CATALOG_NAME>onstat</CATALOG_NAME>
            <DESCRIPTION/>
            <DATE_MODIFIED>2019-04-10T05:22:19.623333</DATE_MODIFIED>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetDBSchemaColumns":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DBSCHEMA_COLUMNS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="TABLE_CATALOG" name="TABLE_CATALOG" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="TABLE_SCHEMA" name="TABLE_SCHEMA" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="TABLE_NAME" name="TABLE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="COLUMN_NAME" name="COLUMN_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="COLUMN_GUID" name="COLUMN_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="COLUMN_PROPID" name="COLUMN_PROPID" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="ORDINAL_POSITION" name="ORDINAL_POSITION" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="COLUMN_HAS_DEFAULT" name="COLUMN_HAS_DEFAULT" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="COLUMN_DEFAULT" name="COLUMN_DEFAULT" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="COLUMN_FLAGS" name="COLUMN_FLAGS" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="IS_NULLABLE" name="IS_NULLABLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="DATA_TYPE" name="DATA_TYPE" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="TYPE_GUID" name="TYPE_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="CHARACTER_MAXIMUM_LENGTH" name="CHARACTER_MAXIMUM_LENGTH" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="CHARACTER_OCTET_LENGTH" name="CHARACTER_OCTET_LENGTH" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="NUMERIC_PRECISION" name="NUMERIC_PRECISION" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="NUMERIC_SCALE" name="NUMERIC_SCALE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="DATETIME_PRECISION" name="DATETIME_PRECISION" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="CHARACTER_SET_CATALOG" name="CHARACTER_SET_CATALOG" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CHARACTER_SET_SCHEMA" name="CHARACTER_SET_SCHEMA" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CHARACTER_SET_NAME" name="CHARACTER_SET_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="COLLATION_CATALOG" name="COLLATION_CATALOG" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="COLLATION_SCHEMA" name="COLLATION_SCHEMA" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="COLLATION_NAME" name="COLLATION_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DOMAIN_CATALOG" name="DOMAIN_CATALOG" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DOMAIN_SCHEMA" name="DOMAIN_SCHEMA" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DOMAIN_NAME" name="DOMAIN_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="COLUMN_OLAP_TYPE" name="COLUMN_OLAP_TYPE" type="xsd:string" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Account</TABLE_SCHEMA>
            <TABLE_NAME>Dim AccountMG</TABLE_NAME>
            <COLUMN_NAME>Account</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Account</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <COLUMN_NAME>Accounts</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Account</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <COLUMN_NAME>Account</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Account</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <COLUMN_NAME>Account Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Account</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <COLUMN_NAME>Account Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Clustered Customers</TABLE_SCHEMA>
            <TABLE_NAME>Clustered CustomersMG</TABLE_NAME>
            <COLUMN_NAME>Clustered Customers</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Clustered Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Clustered Customers</TABLE_NAME>
            <COLUMN_NAME>Attribute Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Clustered Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Clustered Customers</TABLE_NAME>
            <COLUMN_NAME>Customer Clusters</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Clustered Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Clustered Customers</TABLE_NAME>
            <COLUMN_NAME>Node Unique Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>Dim CustomerMG</TABLE_NAME>
            <COLUMN_NAME>Customer</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Customer</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Postal Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>State-Province</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Birth Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>City</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Date of First Purchase</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Email Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Yearly Income</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Total Children</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Number of Cars Owned</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Number of Children At Home</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Education</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Occupation</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Marital Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Gender</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Home Owner</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Commute Distance</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Commute Distance Sort</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>Dim TimeMG</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Department</TABLE_SCHEMA>
            <TABLE_NAME>Dim Department GroupMG</TABLE_NAME>
            <COLUMN_NAME>Department</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Department</TABLE_SCHEMA>
            <TABLE_NAME>$Department</TABLE_NAME>
            <COLUMN_NAME>Departments</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Department</TABLE_SCHEMA>
            <TABLE_NAME>$Department</TABLE_NAME>
            <COLUMN_NAME>Department</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Destination Currency</TABLE_SCHEMA>
            <TABLE_NAME>Dim Destination CurrencyMG</TABLE_NAME>
            <COLUMN_NAME>Destination Currency</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Destination Currency</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Destination Currency</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Destination Currency</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Locale</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>Dim EmployeeMG</TABLE_NAME>
            <COLUMN_NAME>Employee</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Employee</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Department Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Sales Person Flag</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Title</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Hire Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Sick Leave Hours</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Birth Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Vacation Hours</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Login ID</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Base Rate</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Email Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Pay Frequency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Salaried Flag</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Emergency Contact Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Emergency Contact Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Gender</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Marital Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Key</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>SSN</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Manager SSN</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Employees</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Hire Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Geography</TABLE_SCHEMA>
            <TABLE_NAME>Dim GeographyMG</TABLE_NAME>
            <COLUMN_NAME>Geography</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Geography</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>City</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Geography</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>State-Province</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Geography</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Geography</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>Postal Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Geography</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>Geography Key</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Internet Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>Fact Internet SalesMG</TABLE_NAME>
            <COLUMN_NAME>Internet Sales Order Details</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Internet Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Internet Sales Order</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Internet Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Internet Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Organization</TABLE_SCHEMA>
            <TABLE_NAME>Dim OrganizationMG</TABLE_NAME>
            <COLUMN_NAME>Organization</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Organization</TABLE_SCHEMA>
            <TABLE_NAME>$Organization</TABLE_NAME>
            <COLUMN_NAME>Organizations</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Organization</TABLE_SCHEMA>
            <TABLE_NAME>$Organization</TABLE_NAME>
            <COLUMN_NAME>Organization</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Organization</TABLE_SCHEMA>
            <TABLE_NAME>$Organization</TABLE_NAME>
            <COLUMN_NAME>Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>Dim ProductMG</TABLE_NAME>
            <COLUMN_NAME>Product</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Standard Cost</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Category</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Color</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Safety Stock Level</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Reorder Point</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>List Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size Range</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Weight</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Days to Manufacture</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Dealer Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Class</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Style</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Model Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Subcategory</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Large Photo</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Promotion</TABLE_SCHEMA>
            <TABLE_NAME>Dim PromotionMG</TABLE_NAME>
            <COLUMN_NAME>Promotion</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Promotion</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Promotion</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Discount Percent</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Promotion</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Max Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Promotion</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Promotion</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Min Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Promotion</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion Category</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Promotion</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Promotion</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>Dim ResellerMG</TABLE_NAME>
            <COLUMN_NAME>Reseller</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Reseller</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Product Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Last Order Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Business Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>First Order Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Number of Employees</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Year Opened</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Annual Sales</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Annual Revenue</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Bank Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Min Payment Amount</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Min Payment Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Order Frequency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Order Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Geography Key</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>Fact Reseller SalesMG</TABLE_NAME>
            <COLUMN_NAME>Reseller Sales Order Details</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Reseller Sales Order</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Carrier Tracking Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Customer PO Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Channel</TABLE_SCHEMA>
            <TABLE_NAME>Fact Sales SummaryMG</TABLE_NAME>
            <COLUMN_NAME>Sales Channel</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Channel</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Channel</TABLE_NAME>
            <COLUMN_NAME>Sales Channel</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Reason</TABLE_SCHEMA>
            <TABLE_NAME>Dim Sales ReasonMG</TABLE_NAME>
            <COLUMN_NAME>Sales Reason</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Reason</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Reason</TABLE_NAME>
            <COLUMN_NAME>Sales Reason</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Reason</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Reason</TABLE_NAME>
            <COLUMN_NAME>Sales Reason Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Summary Order Details</TABLE_SCHEMA>
            <TABLE_NAME>Fact Sales Summary 1MG</TABLE_NAME>
            <COLUMN_NAME>Sales Summary Order Details</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Summary Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Summary Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Carrier Tracking Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Summary Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Customer PO Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Summary Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Summary Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Territory</TABLE_SCHEMA>
            <TABLE_NAME>Dim Sales TerritoryMG</TABLE_NAME>
            <COLUMN_NAME>Sales Territory</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Territory</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Region</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Territory</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Territory</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Group</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Scenario</TABLE_SCHEMA>
            <TABLE_NAME>Dim ScenarioMG</TABLE_NAME>
            <COLUMN_NAME>Scenario</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Scenario</TABLE_SCHEMA>
            <TABLE_NAME>$Scenario</TABLE_NAME>
            <COLUMN_NAME>Scenario</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Source Currency</TABLE_SCHEMA>
            <TABLE_NAME>Dim CurrencyMG</TABLE_NAME>
            <COLUMN_NAME>Source Currency</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Source Currency</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <COLUMN_NAME>Source Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Source Currency</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <COLUMN_NAME>Source Currency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Subcategory Basket Analysis</TABLE_SCHEMA>
            <TABLE_NAME>Subcategory Basket AnalysisMG</TABLE_NAME>
            <COLUMN_NAME>Subcategory Basket Analysis</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Subcategory Basket Analysis</TABLE_SCHEMA>
            <TABLE_NAME>$Subcategory Basket Analysis</TABLE_NAME>
            <COLUMN_NAME>Attribute Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Subcategory Basket Analysis</TABLE_SCHEMA>
            <TABLE_NAME>$Subcategory Basket Analysis</TABLE_NAME>
            <COLUMN_NAME>Subcategory Baskets</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Subcategory Basket Analysis</TABLE_SCHEMA>
            <TABLE_NAME>$Subcategory Basket Analysis</TABLE_NAME>
            <COLUMN_NAME>Node Unique Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>Average Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>End of Day Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Financial Reporting</TABLE_NAME>
            <COLUMN_NAME>Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <COLUMN_NAME>Customer Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <COLUMN_NAME>Internet Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Orders</TABLE_NAME>
            <COLUMN_NAME>Reseller Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Discount Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Unit Price Discount Percent</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Orders</TABLE_NAME>
            <COLUMN_NAME>Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <COLUMN_NAME>Sales Reason Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Targets</TABLE_NAME>
            <COLUMN_NAME>Sales Amount Quota</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <COLUMN_NAME>Accounts</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <COLUMN_NAME>Account</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <COLUMN_NAME>Account Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <COLUMN_NAME>Account Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Customer</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Postal Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>State-Province</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Birth Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>City</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Date of First Purchase</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Email Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Yearly Income</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Total Children</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Number of Cars Owned</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Number of Children At Home</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Education</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Occupation</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Marital Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Gender</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Home Owner</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Commute Distance</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Commute Distance Sort</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Department</TABLE_NAME>
            <COLUMN_NAME>Departments</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Department</TABLE_NAME>
            <COLUMN_NAME>Department</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Locale</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Employee</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Department Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Sales Person Flag</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Title</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Hire Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Sick Leave Hours</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Birth Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Vacation Hours</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Login ID</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Base Rate</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Email Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Pay Frequency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Salaried Flag</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Emergency Contact Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Emergency Contact Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Gender</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Marital Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Key</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>SSN</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Manager SSN</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Employees</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Hire Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>City</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>State-Province</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>Postal Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>Geography Key</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Internet Sales Order</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Organization</TABLE_NAME>
            <COLUMN_NAME>Organizations</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Organization</TABLE_NAME>
            <COLUMN_NAME>Organization</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Organization</TABLE_NAME>
            <COLUMN_NAME>Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Standard Cost</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Category</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Color</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Safety Stock Level</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Reorder Point</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>List Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size Range</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Weight</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Days to Manufacture</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Dealer Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Class</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Style</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Model Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Subcategory</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Large Photo</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Discount Percent</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Max Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Min Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion Category</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Reseller</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Product Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Last Order Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Business Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>First Order Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Number of Employees</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Year Opened</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Annual Sales</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Annual Revenue</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Bank Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Min Payment Amount</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Min Payment Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Order Frequency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Order Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Geography Key</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Reseller Sales Order</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Carrier Tracking Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Customer PO Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Channel</TABLE_NAME>
            <COLUMN_NAME>Sales Channel</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Reason</TABLE_NAME>
            <COLUMN_NAME>Sales Reason</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Reason</TABLE_NAME>
            <COLUMN_NAME>Sales Reason Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Carrier Tracking Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Customer PO Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Region</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Group</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Scenario</TABLE_NAME>
            <COLUMN_NAME>Scenario</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <COLUMN_NAME>Source Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <COLUMN_NAME>Source Currency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>Average Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>End of Day Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Financial Reporting</TABLE_NAME>
            <COLUMN_NAME>Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <COLUMN_NAME>Customer Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <COLUMN_NAME>Internet Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Orders</TABLE_NAME>
            <COLUMN_NAME>Reseller Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Discount Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Unit Price Discount Percent</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Orders</TABLE_NAME>
            <COLUMN_NAME>Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <COLUMN_NAME>Sales Reason Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Targets</TABLE_NAME>
            <COLUMN_NAME>Sales Amount Quota</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Locale</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Employee</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Department Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Sales Person Flag</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Title</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Hire Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Sick Leave Hours</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Birth Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Vacation Hours</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Login ID</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Base Rate</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Email Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Pay Frequency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Salaried Flag</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Emergency Contact Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Emergency Contact Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Gender</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Marital Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Key</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>SSN</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Manager SSN</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Employees</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Hire Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>City</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>State-Province</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>Postal Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <COLUMN_NAME>Geography Key</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Standard Cost</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Category</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Color</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Safety Stock Level</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Reorder Point</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>List Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size Range</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Weight</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Days to Manufacture</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Dealer Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Class</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Style</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Model Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Subcategory</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Large Photo</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Discount Percent</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Max Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Min Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion Category</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Reseller</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Product Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Last Order Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Business Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>First Order Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Number of Employees</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Year Opened</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Annual Sales</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Annual Revenue</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Bank Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Min Payment Amount</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Min Payment Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Order Frequency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Order Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Geography Key</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <COLUMN_NAME>Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Reseller Sales Order</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Carrier Tracking Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Customer PO Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Region</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Group</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <COLUMN_NAME>Source Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <COLUMN_NAME>Source Currency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>Average Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>End of Day Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Financial Reporting</TABLE_NAME>
            <COLUMN_NAME>Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <COLUMN_NAME>Customer Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <COLUMN_NAME>Internet Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Orders</TABLE_NAME>
            <COLUMN_NAME>Reseller Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Discount Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Unit Price Discount Percent</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Orders</TABLE_NAME>
            <COLUMN_NAME>Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <COLUMN_NAME>Sales Reason Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Targets</TABLE_NAME>
            <COLUMN_NAME>Sales Amount Quota</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Customer</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Postal Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>State-Province</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Birth Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>City</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Date of First Purchase</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Email Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Yearly Income</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Total Children</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Number of Cars Owned</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Number of Children At Home</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Education</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Occupation</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Marital Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Gender</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Home Owner</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Commute Distance</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Commute Distance Sort</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Locale</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Internet Sales Order</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Standard Cost</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Category</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Color</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Safety Stock Level</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Reorder Point</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>List Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size Range</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Weight</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Days to Manufacture</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Dealer Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Class</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Style</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Model Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Subcategory</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Large Photo</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Discount Percent</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Max Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Min Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion Category</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Reason</TABLE_NAME>
            <COLUMN_NAME>Sales Reason</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Reason</TABLE_NAME>
            <COLUMN_NAME>Sales Reason Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Region</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Group</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <COLUMN_NAME>Source Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <COLUMN_NAME>Source Currency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>Average Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>End of Day Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Financial Reporting</TABLE_NAME>
            <COLUMN_NAME>Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <COLUMN_NAME>Customer Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <COLUMN_NAME>Internet Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Orders</TABLE_NAME>
            <COLUMN_NAME>Reseller Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Discount Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Unit Price Discount Percent</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Orders</TABLE_NAME>
            <COLUMN_NAME>Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <COLUMN_NAME>Sales Reason Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Targets</TABLE_NAME>
            <COLUMN_NAME>Sales Amount Quota</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <COLUMN_NAME>Accounts</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <COLUMN_NAME>Account</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <COLUMN_NAME>Account Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <COLUMN_NAME>Account Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Department</TABLE_NAME>
            <COLUMN_NAME>Departments</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Department</TABLE_NAME>
            <COLUMN_NAME>Department</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Locale</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Organization</TABLE_NAME>
            <COLUMN_NAME>Organizations</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Organization</TABLE_NAME>
            <COLUMN_NAME>Organization</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Organization</TABLE_NAME>
            <COLUMN_NAME>Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Scenario</TABLE_NAME>
            <COLUMN_NAME>Scenario</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>Average Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>End of Day Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <COLUMN_NAME>Customer Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <COLUMN_NAME>Internet Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <COLUMN_NAME>Sales Reason Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Clustered Customers</TABLE_NAME>
            <COLUMN_NAME>Attribute Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Clustered Customers</TABLE_NAME>
            <COLUMN_NAME>Customer Clusters</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Clustered Customers</TABLE_NAME>
            <COLUMN_NAME>Node Unique Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Customer</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Postal Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>State-Province</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Birth Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>City</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Date of First Purchase</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Email Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Yearly Income</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Total Children</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Number of Cars Owned</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Number of Children At Home</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Education</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Occupation</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Marital Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Gender</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Home Owner</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Commute Distance</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Commute Distance Sort</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <COLUMN_NAME>Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Locale</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Internet Sales Order</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Standard Cost</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Category</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Color</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Safety Stock Level</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Reorder Point</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>List Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size Range</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Weight</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Days to Manufacture</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Dealer Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Class</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Style</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Model Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Subcategory</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Large Photo</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Discount Percent</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Max Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Min Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion Category</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Reason</TABLE_NAME>
            <COLUMN_NAME>Sales Reason</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Reason</TABLE_NAME>
            <COLUMN_NAME>Sales Reason Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Region</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Group</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <COLUMN_NAME>Source Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <COLUMN_NAME>Source Currency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Subcategory Basket Analysis</TABLE_NAME>
            <COLUMN_NAME>Attribute Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Subcategory Basket Analysis</TABLE_NAME>
            <COLUMN_NAME>Subcategory Baskets</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Subcategory Basket Analysis</TABLE_NAME>
            <COLUMN_NAME>Node Unique Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>Average Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>End of Day Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Financial Reporting</TABLE_NAME>
            <COLUMN_NAME>Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <COLUMN_NAME>Customer Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <COLUMN_NAME>Internet Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Orders</TABLE_NAME>
            <COLUMN_NAME>Reseller Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Discount Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Unit Price Discount Percent</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Orders</TABLE_NAME>
            <COLUMN_NAME>Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <COLUMN_NAME>Sales Reason Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Targets</TABLE_NAME>
            <COLUMN_NAME>Sales Amount Quota</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Destination Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <COLUMN_NAME>Locale</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Standard Cost</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Category</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Color</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Safety Stock Level</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Reorder Point</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>List Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size Range</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Weight</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Days to Manufacture</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Dealer Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Class</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Style</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Model Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Subcategory</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Large Photo</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Discount Percent</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Max Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion Type</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Min Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Promotion Category</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Channel</TABLE_NAME>
            <COLUMN_NAME>Sales Channel</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Carrier Tracking Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Customer PO Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Number</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <COLUMN_NAME>Sales Order Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Region</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Group</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <COLUMN_NAME>Source Currency Code</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <COLUMN_NAME>Source Currency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>Average Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <COLUMN_NAME>End of Day Rate</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Financial Reporting</TABLE_NAME>
            <COLUMN_NAME>Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <COLUMN_NAME>Customer Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <COLUMN_NAME>Internet Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <COLUMN_NAME>Internet Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Orders</TABLE_NAME>
            <COLUMN_NAME>Reseller Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Discount Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Unit Price Discount Percent</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <COLUMN_NAME>Reseller Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Orders</TABLE_NAME>
            <COLUMN_NAME>Order Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <COLUMN_NAME>Sales Reason Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Order Quantity</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Unit Price</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Extended Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Standard Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Total Product Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Sales Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Tax Amount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Freight Cost</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <COLUMN_NAME>Transaction Count</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Targets</TABLE_NAME>
            <COLUMN_NAME>Sales Amount Quota</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_OLAP_TYPE>MEASURE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Month</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Day of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Semester of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Quarter of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Month of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Calendar Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <COLUMN_NAME>Fiscal Week of Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Employee</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Department Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Sales Person Flag</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Title</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Hire Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Sick Leave Hours</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Birth Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Vacation Hours</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Login ID</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Base Rate</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Email Address</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Pay Frequency</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Salaried Flag</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Emergency Contact Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Emergency Contact Phone</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Gender</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Marital Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Key</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>SSN</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Manager SSN</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Employees</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <COLUMN_NAME>Hire Year</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Standard Cost</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Category</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Color</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Safety Stock Level</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Reorder Point</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>List Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Size Range</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Weight</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Days to Manufacture</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Dealer Price</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Class</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Style</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Model Name</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Product Line</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Subcategory</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Status</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Start Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>End Date</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <COLUMN_NAME>Large Photo</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Region</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Country</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <COLUMN_NAME>Sales Territory Group</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>254</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>508</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>ATTRIBUTE</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_CATALOGS</TABLE_NAME>
            <COLUMN_NAME>CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>127</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>255</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_CATALOGS</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_CATALOGS</TABLE_NAME>
            <COLUMN_NAME>ROLES</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_CATALOGS</TABLE_NAME>
            <COLUMN_NAME>DATE_MODIFIED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_TABLES</TABLE_NAME>
            <COLUMN_NAME>TABLE_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>127</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>255</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_TABLES</TABLE_NAME>
            <COLUMN_NAME>TABLE_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>127</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>255</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_TABLES</TABLE_NAME>
            <COLUMN_NAME>TABLE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <CHARACTER_MAXIMUM_LENGTH>127</CHARACTER_MAXIMUM_LENGTH>
            <CHARACTER_OCTET_LENGTH>255</CHARACTER_OCTET_LENGTH>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_TABLES</TABLE_NAME>
            <COLUMN_NAME>TABLE_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_TABLES</TABLE_NAME>
            <COLUMN_NAME>TABLE_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_TABLES</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_TABLES</TABLE_NAME>
            <COLUMN_NAME>TABLE_PROPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_TABLES</TABLE_NAME>
            <COLUMN_NAME>DATE_CREATED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_TABLES</TABLE_NAME>
            <COLUMN_NAME>DATE_MODIFIED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_TABLES</TABLE_NAME>
            <COLUMN_NAME>TABLE_OLAP_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>TABLE_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>TABLE_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>TABLE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_PROPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>ORDINAL_POSITION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_HAS_DEFAULT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_DEFAULT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_FLAGS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>IS_NULLABLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DATA_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>TYPE_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_MAXIMUM_LENGTH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_OCTET_LENGTH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>NUMERIC_PRECISION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>NUMERIC_SCALE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>2</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DATETIME_PRECISION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_SET_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_SET_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_SET_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLLATION_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLLATION_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLLATION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DOMAIN_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DOMAIN_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DOMAIN_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_OLAP_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>TYPE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>DATA_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>COLUMN_SIZE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>LITERAL_PREFIX</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>LITERAL_SUFFIX</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>CREATE_PARAMS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>IS_NULLABLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>CASE_SENSITIVE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>SEARCHABLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>UNSIGNED_ATTRIBUTE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>FIXED_PREC_SCALE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>AUTO_UNIQUE_VALUE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>LOCAL_TYPE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>MINIMUM_SCALE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>2</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>MAXIMUM_SCALE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>2</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>TYPELIB</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>VERSION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>IS_LONG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>BEST_MATCH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <COLUMN_NAME>IS_FIXEDLENGTH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>SCHEMA_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>CUBE_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>CUBE_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>CREATED_ON</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>LAST_SCHEMA_UPDATE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>SCHEMA_UPDATED_BY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>LAST_DATA_UPDATE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>DATA_UPDATED_BY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>IS_DRILLTHROUGH_ENABLED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>IS_LINKABLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>IS_WRITE_ENABLED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>IS_SQL_ENABLED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>CUBE_CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>BASE_CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>CUBE_SOURCE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <COLUMN_NAME>PREFERRED_QUERY_PATTERNS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>SCHEMA_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_ORDINAL</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>2</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_CARDINALITY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DEFAULT_HIERARCHY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>IS_VIRTUAL</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>IS_READWRITE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_UNIQUE_SETTINGS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_MASTER_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_IS_VISIBLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>SCHEMA_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>HIERARCHY_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>HIERARCHY_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>HIERARCHY_CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>2</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>HIERARCHY_CARDINALITY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>DEFAULT_MEMBER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>ALL_MEMBER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>STRUCTURE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>2</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>IS_VIRTUAL</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>IS_READWRITE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_UNIQUE_SETTINGS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_MASTER_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_IS_VISIBLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>HIERARCHY_ORDINAL</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_IS_SHARED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>HIERARCHY_IS_VISIBLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>HIERARCHY_ORIGIN</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>HIERARCHY_DISPLAY_FOLDER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>INSTANCE_SELECTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <COLUMN_NAME>GROUPING_BEHAVIOR</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>SCHEMA_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_NUMBER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_CARDINALITY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>CUSTOM_ROLLUP_SETTINGS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_UNIQUE_SETTINGS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_IS_VISIBLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_ORDERING_PROPERTY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_DBTYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_MASTER_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_NAME_SQL_COLUMN_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_KEY_SQL_COLUMN_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_ATTRIBUTE_HIERARCHY_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_KEY_CARDINALITY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_ORIGIN</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>SCHEMA_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>MEASURE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>MEASURE_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>MEASURE_CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>MEASURE_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>MEASURE_AGGREGATOR</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>DATA_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>NUMERIC_PRECISION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>NUMERIC_SCALE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>2</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>MEASURE_UNITS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>EXPRESSION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>MEASURE_IS_VISIBLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>LEVELS_LIST</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>MEASURE_NAME_SQL_COLUMN_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>MEASURE_UNQUALIFIED_CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>MEASUREGROUP_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>MEASURE_DISPLAY_FOLDER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <COLUMN_NAME>DEFAULT_FORMAT_STRING</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>SCHEMA_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>LEVEL_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>MEMBER_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>PROPERTY_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>2</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>PROPERTY_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>PROPERTY_CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>DATA_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_MAXIMUM_LENGTH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_OCTET_LENGTH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>NUMERIC_PRECISION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>NUMERIC_SCALE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>2</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>PROPERTY_CONTENT_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>2</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>SQL_COLUMN_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>LANGUAGE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>PROPERTY_ORIGIN</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>PROPERTY_ATTRIBUTE_HIERARCHY_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>PROPERTY_CARDINALITY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>MIME_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>PROPERTY_IS_VISIBLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>SCHEMA_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>LEVEL_NUMBER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>MEMBER_ORDINAL</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>MEMBER_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>MEMBER_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>MEMBER_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>MEMBER_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>MEMBER_CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>CHILDREN_CARDINALITY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>PARENT_LEVEL</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>PARENT_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>PARENT_COUNT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>EXPRESSION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>MEMBER_KEY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>IS_PLACEHOLDERMEMBER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>IS_DATAMEMBER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <COLUMN_NAME>SCOPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>FUNCTION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>PARAMETER_LIST</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>RETURN_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>ORIGIN</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>INTERFACE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>LIBRARY_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>DLL_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>HELP_FILE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>HELP_CONTEXT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>OBJECT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>PARAMETERINFO</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>136</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_SETS</TABLE_NAME>
            <COLUMN_NAME>CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_SETS</TABLE_NAME>
            <COLUMN_NAME>SCHEMA_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_SETS</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_SETS</TABLE_NAME>
            <COLUMN_NAME>SET_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_SETS</TABLE_NAME>
            <COLUMN_NAME>SCOPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_SETS</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_SETS</TABLE_NAME>
            <COLUMN_NAME>EXPRESSION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_SETS</TABLE_NAME>
            <COLUMN_NAME>DIMENSIONS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_SETS</TABLE_NAME>
            <COLUMN_NAME>SET_CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_SETS</TABLE_NAME>
            <COLUMN_NAME>SET_DISPLAY_FOLDER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_SETS</TABLE_NAME>
            <COLUMN_NAME>SET_EVALUATION_CONTEXT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_INSTANCES</TABLE_NAME>
            <COLUMN_NAME>INSTANCE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_INSTANCES</TABLE_NAME>
            <COLUMN_NAME>INSTANCE_PORT_NUMBER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_INSTANCES</TABLE_NAME>
            <COLUMN_NAME>INSTANCE_STATE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>SCHEMA_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>MEASUREGROUP_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>KPI_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>KPI_CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>KPI_DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>KPI_DISPLAY_FOLDER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>KPI_VALUE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>KPI_GOAL</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>KPI_STATUS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>KPI_TREND</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>KPI_STATUS_GRAPHIC</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>KPI_TREND_GRAPHIC</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>KPI_WEIGHT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>KPI_CURRENT_TIME_MEMBER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>KPI_PARENT_KPI_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>ANNOTATIONS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <COLUMN_NAME>SCOPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUPS</TABLE_NAME>
            <COLUMN_NAME>CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUPS</TABLE_NAME>
            <COLUMN_NAME>SCHEMA_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUPS</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUPS</TABLE_NAME>
            <COLUMN_NAME>MEASUREGROUP_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUPS</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUPS</TABLE_NAME>
            <COLUMN_NAME>IS_WRITE_ENABLED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUPS</TABLE_NAME>
            <COLUMN_NAME>MEASUREGROUP_CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUP_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUP_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>SCHEMA_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUP_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUP_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>MEASUREGROUP_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUP_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>MEASUREGROUP_CARDINALITY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUP_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUP_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_CARDINALITY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUP_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_IS_VISIBLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUP_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_IS_FACT_DIMENSION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUP_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_PATH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>136</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUP_DIMENSIONS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_GRANULARITY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_INPUT_DATASOURCES</TABLE_NAME>
            <COLUMN_NAME>CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_INPUT_DATASOURCES</TABLE_NAME>
            <COLUMN_NAME>SCHEMA_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_INPUT_DATASOURCES</TABLE_NAME>
            <COLUMN_NAME>DATASOURCE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_INPUT_DATASOURCES</TABLE_NAME>
            <COLUMN_NAME>DATASOURCE_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_INPUT_DATASOURCES</TABLE_NAME>
            <COLUMN_NAME>CREATED_ON</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_INPUT_DATASOURCES</TABLE_NAME>
            <COLUMN_NAME>LAST_SCHEMA_UPDATE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_INPUT_DATASOURCES</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_INPUT_DATASOURCES</TABLE_NAME>
            <COLUMN_NAME>TIMEOUT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_INPUT_DATASOURCES</TABLE_NAME>
            <COLUMN_NAME>DBMS_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_INPUT_DATASOURCES</TABLE_NAME>
            <COLUMN_NAME>DBMS_VERSION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>SERVICE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>SERVICE_TYPE_ID</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>SERVICE_DISPLAY_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>SERVICE_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>PREDICTION_LIMIT</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>SUPPORTED_DISTRIBUTION_FLAGS</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>SUPPORTED_INPUT_CONTENT_TYPES</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>SUPPORTED_PREDICTION_CONTENT_TYPES</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>SUPPORTED_MODELING_FLAGS</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>SUPPORTED_SOURCE_QUERY</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>TRAINING_COMPLEXITY</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>PREDICTION_COMPLEXITY</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>EXPECTED_QUALITY</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>SCALING</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>ALLOW_INCREMENTAL_INSERT</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>ALLOW_PMML_INITIALIZATION</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>CONTROL</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>ALLOW_DUPLICATE_KEY</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>VIEWER_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>HELP_FILE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>HELP_CONTEXT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>MSOLAP_SUPPORTS_ANALYSIS_SERVICES_DDL</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>MSOLAP_SUPPORTS_OLAP_MINING_MODELS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>MSOLAP_SUPPORTS_DATA_MINING_DIMENSIONS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <COLUMN_NAME>MSOLAP_SUPPORTS_DRILLTHROUGH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICE_PARAMETERS</TABLE_NAME>
            <COLUMN_NAME>SERVICE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICE_PARAMETERS</TABLE_NAME>
            <COLUMN_NAME>PARAMETER_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICE_PARAMETERS</TABLE_NAME>
            <COLUMN_NAME>PARAMETER_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICE_PARAMETERS</TABLE_NAME>
            <COLUMN_NAME>IS_REQUIRED</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICE_PARAMETERS</TABLE_NAME>
            <COLUMN_NAME>PARAMETER_FLAGS</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICE_PARAMETERS</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICE_PARAMETERS</TABLE_NAME>
            <COLUMN_NAME>DEFAULT_VALUE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICE_PARAMETERS</TABLE_NAME>
            <COLUMN_NAME>VALUE_ENUMERATION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICE_PARAMETERS</TABLE_NAME>
            <COLUMN_NAME>HELP_FILE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICE_PARAMETERS</TABLE_NAME>
            <COLUMN_NAME>HELP_CONTEXT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>SERVICE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>FUNCTION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>FUNCTION_SIGNATURE</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>RETURNS_TABLE</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>HELP_FILE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_FUNCTIONS</TABLE_NAME>
            <COLUMN_NAME>HELP_CONTEXT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>MODEL_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>MODEL_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>MODEL_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>ATTRIBUTE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>NODE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>NODE_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>NODE_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>NODE_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>NODE_CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>CHILDREN_CARDINALITY</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>PARENT_UNIQUE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>NODE_DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>NODE_RULE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>MARGINAL_RULE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>NODE_PROBABILITY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>5</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>MARGINAL_PROBABILITY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>5</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>NODE_DISTRIBUTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>136</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>NODE_SUPPORT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>5</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>MSOLAP_MODEL_COLUMN</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>MSOLAP_NODE_SCORE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>5</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <COLUMN_NAME>MSOLAP_NODE_SHORT_CAPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_XML</TABLE_NAME>
            <COLUMN_NAME>MODEL_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_XML</TABLE_NAME>
            <COLUMN_NAME>MODEL_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_XML</TABLE_NAME>
            <COLUMN_NAME>MODEL_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_XML</TABLE_NAME>
            <COLUMN_NAME>MODEL_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_XML</TABLE_NAME>
            <COLUMN_NAME>MODEL_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_XML</TABLE_NAME>
            <COLUMN_NAME>MODEL_PMML</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_XML</TABLE_NAME>
            <COLUMN_NAME>SIZE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_XML</TABLE_NAME>
            <COLUMN_NAME>LOCATION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT_PMML</TABLE_NAME>
            <COLUMN_NAME>MODEL_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT_PMML</TABLE_NAME>
            <COLUMN_NAME>MODEL_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT_PMML</TABLE_NAME>
            <COLUMN_NAME>MODEL_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT_PMML</TABLE_NAME>
            <COLUMN_NAME>MODEL_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT_PMML</TABLE_NAME>
            <COLUMN_NAME>MODEL_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT_PMML</TABLE_NAME>
            <COLUMN_NAME>MODEL_PMML</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT_PMML</TABLE_NAME>
            <COLUMN_NAME>SIZE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT_PMML</TABLE_NAME>
            <COLUMN_NAME>LOCATION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>MODEL_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>MODEL_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>MODEL_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>MODEL_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>MODEL_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>MODEL_PROPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>DATE_CREATED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>DATE_MODIFIED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>SERVICE_TYPE_ID</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>SERVICE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>CREATION_STATEMENT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>PREDICTION_ENTITY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>IS_POPULATED</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>MINING_PARAMETERS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>MINING_STRUCTURE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>LAST_PROCESSED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>MSOLAP_IS_DRILLTHROUGH_ENABLED</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>FILTER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <COLUMN_NAME>TRAINING_SET_SIZE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>MODEL_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>MODEL_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>MODEL_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_PROPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>ORDINAL_POSITION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_HAS_DEFAULT</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_DEFAULT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_FLAGS</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>IS_NULLABLE</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DATA_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>TYPE_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_MAXIMUM_LENGTH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_OCTET_LENGTH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>NUMERIC_PRECISION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>NUMERIC_SCALE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>2</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DATETIME_PRECISION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_SET_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_SET_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_SET_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLLATION_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLLATION_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLLATION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DOMAIN_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DOMAIN_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DOMAIN_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DISTRIBUTION_FLAG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CONTENT_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>MODELING_FLAG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>IS_RELATED_TO_KEY</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>RELATED_ATTRIBUTE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>IS_INPUT</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>IS_PREDICTABLE</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CONTAINING_COLUMN</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>PREDICTION_SCALAR_FUNCTIONS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>PREDICTION_TABLE_FUNCTIONS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>IS_POPULATED</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>PREDICTION_SCORE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>5</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>SOURCE_COLUMN</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>FILTER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>STRUCTURE_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>STRUCTURE_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>STRUCTURE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>STRUCTURE_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>STRUCTURE_PROPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>DATE_CREATED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>DATE_MODIFIED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>CREATION_STATEMENT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>IS_POPULATED</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>LAST_PROCESSED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>HOLDOUT_MAXPERCENT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>17</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>HOLDOUT_MAXCASES</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>HOLDOUT_SEED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <COLUMN_NAME>HOLDOUT_ACTUAL_SIZE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>STRUCTURE_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>STRUCTURE_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>STRUCTURE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_PROPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>ORDINAL_POSITION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_HASDEFAULT</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_DEFAULT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_FLAGS</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>IS_NULLABLE</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DATA_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>TYPE_GUID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_MAXIMUM_LENGTH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_OCTET_LENGTH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>NUMERIC_PRECISION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>NUMERIC_SCALE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>2</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DATETIME_PRECISION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_SET_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_SET_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CHARACTER_SET_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLLATION_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLLATION_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLLATION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DOMAIN_CATALOG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DOMAIN_SCHEMA</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DOMAIN_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DISTRIBUTION_FLAG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CONTENT_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>MODELING_FLAG</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>IS_RELATED_TO_KEY</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>RELATED_ATTRIBUTE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CONTAINING_COLUMN</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>IS_POPULATED</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>PropertyName</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>PropertyDescription</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>PropertyType</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>PropertyAccessType</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>IsRequired</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PROPERTIES</TABLE_NAME>
            <COLUMN_NAME>Value</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SCHEMA_ROWSETS</TABLE_NAME>
            <COLUMN_NAME>SchemaName</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SCHEMA_ROWSETS</TABLE_NAME>
            <COLUMN_NAME>SchemaGuid</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SCHEMA_ROWSETS</TABLE_NAME>
            <COLUMN_NAME>Restrictions</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>136</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SCHEMA_ROWSETS</TABLE_NAME>
            <COLUMN_NAME>Description</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SCHEMA_ROWSETS</TABLE_NAME>
            <COLUMN_NAME>RestrictionsMask</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_ENUMERATORS</TABLE_NAME>
            <COLUMN_NAME>EnumName</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_ENUMERATORS</TABLE_NAME>
            <COLUMN_NAME>EnumDescription</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_ENUMERATORS</TABLE_NAME>
            <COLUMN_NAME>EnumType</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_ENUMERATORS</TABLE_NAME>
            <COLUMN_NAME>ElementName</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_ENUMERATORS</TABLE_NAME>
            <COLUMN_NAME>ElementDescription</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_ENUMERATORS</TABLE_NAME>
            <COLUMN_NAME>ElementValue</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_KEYWORDS</TABLE_NAME>
            <COLUMN_NAME>Keyword</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LITERALS</TABLE_NAME>
            <COLUMN_NAME>LiteralName</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LITERALS</TABLE_NAME>
            <COLUMN_NAME>LiteralValue</COLUMN_NAME>
            <COLUMN_FLAGS>0</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LITERALS</TABLE_NAME>
            <COLUMN_NAME>LiteralInvalidChars</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LITERALS</TABLE_NAME>
            <COLUMN_NAME>LiteralInvalidStartingChars</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LITERALS</TABLE_NAME>
            <COLUMN_NAME>LiteralMaxLength</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LITERALS</TABLE_NAME>
            <COLUMN_NAME>LiteralNameEnumValue</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACES</TABLE_NAME>
            <COLUMN_NAME>TraceID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACES</TABLE_NAME>
            <COLUMN_NAME>TraceName</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACES</TABLE_NAME>
            <COLUMN_NAME>LogFileName</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACES</TABLE_NAME>
            <COLUMN_NAME>LogFileSize</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACES</TABLE_NAME>
            <COLUMN_NAME>LogFileRollover</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACES</TABLE_NAME>
            <COLUMN_NAME>AutoRestart</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACES</TABLE_NAME>
            <COLUMN_NAME>CreationTime</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACES</TABLE_NAME>
            <COLUMN_NAME>StopTime</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</TABLE_NAME>
            <COLUMN_NAME>Data</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>Data</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACE_EVENT_CATEGORIES</TABLE_NAME>
            <COLUMN_NAME>Data</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <COLUMN_NAME>MemoryID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <COLUMN_NAME>MemoryName</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <COLUMN_NAME>SPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <COLUMN_NAME>CreationTime</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <COLUMN_NAME>BaseObjectType</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <COLUMN_NAME>MemoryUsed</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <COLUMN_NAME>MemoryAllocated</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <COLUMN_NAME>MemoryAllocBase</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <COLUMN_NAME>MemoryAllocFromAlloc</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <COLUMN_NAME>ElementCount</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <COLUMN_NAME>Shrinkable</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <COLUMN_NAME>ObjectParentPath</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <COLUMN_NAME>ObjectId</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYGRANT</TABLE_NAME>
            <COLUMN_NAME>MemoryID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYGRANT</TABLE_NAME>
            <COLUMN_NAME>SPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYGRANT</TABLE_NAME>
            <COLUMN_NAME>CreationTime</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYGRANT</TABLE_NAME>
            <COLUMN_NAME>LastRequestTime</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYGRANT</TABLE_NAME>
            <COLUMN_NAME>MemoryUsed</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYGRANT</TABLE_NAME>
            <COLUMN_NAME>MemoryGranted</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYGRANT</TABLE_NAME>
            <COLUMN_NAME>Blocked</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LOCKS</TABLE_NAME>
            <COLUMN_NAME>SPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LOCKS</TABLE_NAME>
            <COLUMN_NAME>LOCK_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LOCKS</TABLE_NAME>
            <COLUMN_NAME>LOCK_TRANSACTION_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>72</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LOCKS</TABLE_NAME>
            <COLUMN_NAME>LOCK_OBJECT_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LOCKS</TABLE_NAME>
            <COLUMN_NAME>LOCK_STATUS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LOCKS</TABLE_NAME>
            <COLUMN_NAME>LOCK_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LOCKS</TABLE_NAME>
            <COLUMN_NAME>LOCK_CREATION_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LOCKS</TABLE_NAME>
            <COLUMN_NAME>LOCK_GRANT_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_USER_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_IMPERSONATED_USER_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_HOST_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_HOST_APPLICATION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_START_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_ELAPSED_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_LAST_COMMAND_START_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_LAST_COMMAND_END_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_IDLE_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_BYTES_SENT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_DATA_BYTES_SENT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_BYTES_RECEIVED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_DATA_BYTES_RECEIVED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_SPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_CONNECTION_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_USER_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_CURRENT_DATABASE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_USED_MEMORY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_PROPERTIES</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_START_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_ELAPSED_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_LAST_COMMAND_START_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_LAST_COMMAND_END_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_LAST_COMMAND_ELAPSED_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_IDLE_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_CPU_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_LAST_COMMAND</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_LAST_COMMAND_CPU_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_STATUS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_READS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_WRITES</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_READ_KB</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_WRITE_KB</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <COLUMN_NAME>SESSION_COMMAND_COUNT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_JOBS</TABLE_NAME>
            <COLUMN_NAME>SPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_JOBS</TABLE_NAME>
            <COLUMN_NAME>JOB_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_JOBS</TABLE_NAME>
            <COLUMN_NAME>JOB_DESCRIPTION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_JOBS</TABLE_NAME>
            <COLUMN_NAME>JOB_CREATION_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_JOBS</TABLE_NAME>
            <COLUMN_NAME>JOB_TOTAL_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_JOBS</TABLE_NAME>
            <COLUMN_NAME>JOB_START_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_JOBS</TABLE_NAME>
            <COLUMN_NAME>JOB_EXECUTION_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_JOBS</TABLE_NAME>
            <COLUMN_NAME>JOB_THREADPOOL_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRANSACTIONS</TABLE_NAME>
            <COLUMN_NAME>TRANSACTION_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRANSACTIONS</TABLE_NAME>
            <COLUMN_NAME>TRANSACTION_SESSION_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRANSACTIONS</TABLE_NAME>
            <COLUMN_NAME>TRANSACTION_START_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRANSACTIONS</TABLE_NAME>
            <COLUMN_NAME>TRANSACTION_ELAPSED_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRANSACTIONS</TABLE_NAME>
            <COLUMN_NAME>TRANSACTION_CPU_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DB_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DB_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_START_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DB_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_LAST_COMMAND_START_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DB_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_LAST_COMMAND_END_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DB_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_IDLE_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DB_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_USAGE_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DB_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_IN_USE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DB_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_SERVER_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DB_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_CATALOG_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DB_CONNECTIONS</TABLE_NAME>
            <COLUMN_NAME>CONNECTION_SPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MASTER_KEY</TABLE_NAME>
            <COLUMN_NAME>KEY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PERFORMANCE_COUNTERS</TABLE_NAME>
            <COLUMN_NAME>PERF_COUNTER_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PERFORMANCE_COUNTERS</TABLE_NAME>
            <COLUMN_NAME>PERF_COUNTER_VALUE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>5</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_DIMENSION_STAT</TABLE_NAME>
            <COLUMN_NAME>DATABASE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_DIMENSION_STAT</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_DIMENSION_STAT</TABLE_NAME>
            <COLUMN_NAME>MEASURE_GROUP_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_DIMENSION_STAT</TABLE_NAME>
            <COLUMN_NAME>PARTITION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_DIMENSION_STAT</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_DIMENSION_STAT</TABLE_NAME>
            <COLUMN_NAME>ATTRIBUTE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_DIMENSION_STAT</TABLE_NAME>
            <COLUMN_NAME>ATTRIBUTE_INDEXED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_DIMENSION_STAT</TABLE_NAME>
            <COLUMN_NAME>ATTRIBUTE_COUNT_MIN</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_DIMENSION_STAT</TABLE_NAME>
            <COLUMN_NAME>ATTRIBUTE_COUNT_MAX</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_STAT</TABLE_NAME>
            <COLUMN_NAME>DATABASE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_STAT</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_STAT</TABLE_NAME>
            <COLUMN_NAME>MEASURE_GROUP_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_STAT</TABLE_NAME>
            <COLUMN_NAME>PARTITION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_STAT</TABLE_NAME>
            <COLUMN_NAME>AGGREGATION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_STAT</TABLE_NAME>
            <COLUMN_NAME>AGGREGATION_SIZE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DIMENSION_STAT</TABLE_NAME>
            <COLUMN_NAME>DATABASE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DIMENSION_STAT</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DIMENSION_STAT</TABLE_NAME>
            <COLUMN_NAME>ATTRIBUTE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DIMENSION_STAT</TABLE_NAME>
            <COLUMN_NAME>ATTRIBUTE_COUNT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMANDS</TABLE_NAME>
            <COLUMN_NAME>SESSION_SPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMANDS</TABLE_NAME>
            <COLUMN_NAME>SESSION_COMMAND_COUNT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMANDS</TABLE_NAME>
            <COLUMN_NAME>COMMAND_START_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMANDS</TABLE_NAME>
            <COLUMN_NAME>COMMAND_ELAPSED_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMANDS</TABLE_NAME>
            <COLUMN_NAME>COMMAND_CPU_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMANDS</TABLE_NAME>
            <COLUMN_NAME>COMMAND_READS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMANDS</TABLE_NAME>
            <COLUMN_NAME>COMMAND_READ_KB</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMANDS</TABLE_NAME>
            <COLUMN_NAME>COMMAND_WRITES</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMANDS</TABLE_NAME>
            <COLUMN_NAME>COMMAND_WRITE_KB</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMANDS</TABLE_NAME>
            <COLUMN_NAME>COMMAND_TEXT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMANDS</TABLE_NAME>
            <COLUMN_NAME>COMMAND_END_TIME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>SESSION_SPID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>SESSION_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>SESSION_COMMAND_COUNT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>OBJECT_PARENT_PATH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>OBJECT_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>OBJECT_VERSION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>OBJECT_DATA_VERSION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>OBJECT_CPU_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>OBJECT_READS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>OBJECT_READ_KB</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>OBJECT_WRITES</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>OBJECT_WRITE_KB</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>OBJECT_ROWS_SCANNED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <COLUMN_NAME>OBJECT_ROWS_RETURNED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_PARENT_PATH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_CPU_TIME_MS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_READS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_READ_KB</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_WRITES</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_WRITE_KB</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_AGGREGATION_HIT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_AGGREGATION_MISS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_HIT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_MISS</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_VERSION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_DATA_VERSION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_ROWS_SCANNED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <COLUMN_NAME>OBJECT_ROWS_RETURNED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_MEMORY_USAGE</TABLE_NAME>
            <COLUMN_NAME>OBJECT_PARENT_PATH</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_MEMORY_USAGE</TABLE_NAME>
            <COLUMN_NAME>OBJECT_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_MEMORY_USAGE</TABLE_NAME>
            <COLUMN_NAME>OBJECT_MEMORY_SHRINKABLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_MEMORY_USAGE</TABLE_NAME>
            <COLUMN_NAME>OBJECT_MEMORY_NONSHRINKABLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_MEMORY_USAGE</TABLE_NAME>
            <COLUMN_NAME>OBJECT_VERSION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_MEMORY_USAGE</TABLE_NAME>
            <COLUMN_NAME>OBJECT_DATA_VERSION</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_MEMORY_USAGE</TABLE_NAME>
            <COLUMN_NAME>OBJECT_TYPE_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_MEMORY_USAGE</TABLE_NAME>
            <COLUMN_NAME>OBJECT_TIME_CREATED</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>135</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLES</TABLE_NAME>
            <COLUMN_NAME>DATABASE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLES</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLES</TABLE_NAME>
            <COLUMN_NAME>MEASURE_GROUP_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLES</TABLE_NAME>
            <COLUMN_NAME>PARTITION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLES</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLES</TABLE_NAME>
            <COLUMN_NAME>TABLE_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLES</TABLE_NAME>
            <COLUMN_NAME>TABLE_PARTITIONS_COUNT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLES</TABLE_NAME>
            <COLUMN_NAME>HINT_TABLE_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLES</TABLE_NAME>
            <COLUMN_NAME>ROWS_COUNT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLES</TABLE_NAME>
            <COLUMN_NAME>RIVIOLATION_COUNT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DATABASE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>MEASURE_GROUP_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>PARTITION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>ATTRIBUTE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>TABLE_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_ENCODING</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>DATATYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>ISKEY</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>ISUNIQUE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>ISNULLABLE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <COLUMN_NAME>ISROWNUMBER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>11</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>DATABASE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>CUBE_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>MEASURE_GROUP_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>PARTITION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>DIMENSION_NAME</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>TABLE_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>COLUMN_ID</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>SEGMENT_NUMBER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>TABLE_PARTITION_NUMBER</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>RECORDS_COUNT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>ALLOCATED_SIZE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>USED_SIZE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>21</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>COMPRESSION_TYPE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>BITS_COUNT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>BOOKMARK_BITS_COUNT</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>20</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <COLUMN_NAME>VERTIPAQ_STATE</COLUMN_NAME>
            <COLUMN_FLAGS>64</COLUMN_FLAGS>
            <IS_NULLABLE>false</IS_NULLABLE>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_OLAP_TYPE>SCHEMA</COLUMN_OLAP_TYPE>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetDBSchemaProviderTypes":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DBSCHEMA_PROVIDER_TYPES</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="TYPE_NAME" name="TYPE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DATA_TYPE" name="DATA_TYPE" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="COLUMN_SIZE" name="COLUMN_SIZE" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="LITERAL_PREFIX" name="LITERAL_PREFIX" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LITERAL_SUFFIX" name="LITERAL_SUFFIX" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CREATE_PARAMS" name="CREATE_PARAMS" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="IS_NULLABLE" name="IS_NULLABLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="CASE_SENSITIVE" name="CASE_SENSITIVE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="SEARCHABLE" name="SEARCHABLE" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="UNSIGNED_ATTRIBUTE" name="UNSIGNED_ATTRIBUTE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="FIXED_PREC_SCALE" name="FIXED_PREC_SCALE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="AUTO_UNIQUE_VALUE" name="AUTO_UNIQUE_VALUE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="LOCAL_TYPE_NAME" name="LOCAL_TYPE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MINIMUM_SCALE" name="MINIMUM_SCALE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="MAXIMUM_SCALE" name="MAXIMUM_SCALE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="GUID" name="GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="TYPELIB" name="TYPELIB" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="VERSION" name="VERSION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="IS_LONG" name="IS_LONG" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="BEST_MATCH" name="BEST_MATCH" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_FIXEDLENGTH" name="IS_FIXEDLENGTH" type="xsd:boolean" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <TYPE_NAME>SHORT</TYPE_NAME>
            <DATA_TYPE>2</DATA_TYPE>
            <COLUMN_SIZE>2</COLUMN_SIZE>
            <IS_NULLABLE>true</IS_NULLABLE>
            <SEARCHABLE>3</SEARCHABLE>
            <UNSIGNED_ATTRIBUTE>false</UNSIGNED_ATTRIBUTE>
            <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
            <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
            <IS_LONG>false</IS_LONG>
            <BEST_MATCH>true</BEST_MATCH>
            <IS_FIXEDLENGTH>true</IS_FIXEDLENGTH>
          </row>
          <row>
            <TYPE_NAME>LONG</TYPE_NAME>
            <DATA_TYPE>3</DATA_TYPE>
            <COLUMN_SIZE>4</COLUMN_SIZE>
            <IS_NULLABLE>true</IS_NULLABLE>
            <SEARCHABLE>3</SEARCHABLE>
            <UNSIGNED_ATTRIBUTE>false</UNSIGNED_ATTRIBUTE>
            <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
            <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
            <IS_LONG>false</IS_LONG>
            <BEST_MATCH>true</BEST_MATCH>
            <IS_FIXEDLENGTH>true</IS_FIXEDLENGTH>
          </row>
          <row>
            <TYPE_NAME>FLOAT</TYPE_NAME>
            <DATA_TYPE>4</DATA_TYPE>
            <COLUMN_SIZE>4</COLUMN_SIZE>
            <IS_NULLABLE>true</IS_NULLABLE>
            <SEARCHABLE>3</SEARCHABLE>
            <UNSIGNED_ATTRIBUTE>false</UNSIGNED_ATTRIBUTE>
            <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
            <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
            <IS_LONG>false</IS_LONG>
            <BEST_MATCH>true</BEST_MATCH>
            <IS_FIXEDLENGTH>true</IS_FIXEDLENGTH>
          </row>
          <row>
            <TYPE_NAME>DOUBLE</TYPE_NAME>
            <DATA_TYPE>5</DATA_TYPE>
            <COLUMN_SIZE>8</COLUMN_SIZE>
            <IS_NULLABLE>true</IS_NULLABLE>
            <SEARCHABLE>3</SEARCHABLE>
            <UNSIGNED_ATTRIBUTE>false</UNSIGNED_ATTRIBUTE>
            <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
            <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
            <IS_LONG>false</IS_LONG>
            <BEST_MATCH>true</BEST_MATCH>
            <IS_FIXEDLENGTH>true</IS_FIXEDLENGTH>
          </row>
          <row>
            <TYPE_NAME>CURRENCY</TYPE_NAME>
            <DATA_TYPE>6</DATA_TYPE>
            <COLUMN_SIZE>8</COLUMN_SIZE>
            <IS_NULLABLE>true</IS_NULLABLE>
            <SEARCHABLE>3</SEARCHABLE>
            <UNSIGNED_ATTRIBUTE>false</UNSIGNED_ATTRIBUTE>
            <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
            <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
            <IS_LONG>false</IS_LONG>
            <BEST_MATCH>true</BEST_MATCH>
            <IS_FIXEDLENGTH>true</IS_FIXEDLENGTH>
          </row>
          <row>
            <TYPE_NAME>DATE</TYPE_NAME>
            <DATA_TYPE>7</DATA_TYPE>
            <COLUMN_SIZE>4</COLUMN_SIZE>
            <IS_NULLABLE>true</IS_NULLABLE>
            <SEARCHABLE>3</SEARCHABLE>
            <UNSIGNED_ATTRIBUTE>false</UNSIGNED_ATTRIBUTE>
            <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
            <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
            <IS_LONG>false</IS_LONG>
            <BEST_MATCH>true</BEST_MATCH>
            <IS_FIXEDLENGTH>true</IS_FIXEDLENGTH>
          </row>
          <row>
            <TYPE_NAME>BSTR</TYPE_NAME>
            <DATA_TYPE>8</DATA_TYPE>
            <COLUMN_SIZE>256</COLUMN_SIZE>
            <LITERAL_PREFIX>"</LITERAL_PREFIX>
            <LITERAL_SUFFIX>"</LITERAL_SUFFIX>
            <IS_NULLABLE>true</IS_NULLABLE>
            <CASE_SENSITIVE>false</CASE_SENSITIVE>
            <SEARCHABLE>3</SEARCHABLE>
            <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
            <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
            <IS_LONG>false</IS_LONG>
            <BEST_MATCH>true</BEST_MATCH>
            <IS_FIXEDLENGTH>false</IS_FIXEDLENGTH>
          </row>
          <row>
            <TYPE_NAME>USHORT</TYPE_NAME>
            <DATA_TYPE>18</DATA_TYPE>
            <COLUMN_SIZE>2</COLUMN_SIZE>
            <IS_NULLABLE>true</IS_NULLABLE>
            <SEARCHABLE>3</SEARCHABLE>
            <UNSIGNED_ATTRIBUTE>true</UNSIGNED_ATTRIBUTE>
            <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
            <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
            <IS_LONG>false</IS_LONG>
            <BEST_MATCH>true</BEST_MATCH>
            <IS_FIXEDLENGTH>true</IS_FIXEDLENGTH>
          </row>
          <row>
            <TYPE_NAME>ULONG</TYPE_NAME>
            <DATA_TYPE>19</DATA_TYPE>
            <COLUMN_SIZE>4</COLUMN_SIZE>
            <IS_NULLABLE>true</IS_NULLABLE>
            <SEARCHABLE>3</SEARCHABLE>
            <UNSIGNED_ATTRIBUTE>true</UNSIGNED_ATTRIBUTE>
            <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
            <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
            <IS_LONG>false</IS_LONG>
            <BEST_MATCH>true</BEST_MATCH>
            <IS_FIXEDLENGTH>true</IS_FIXEDLENGTH>
          </row>
          <row>
            <TYPE_NAME>CHAR</TYPE_NAME>
            <DATA_TYPE>129</DATA_TYPE>
            <COLUMN_SIZE>256</COLUMN_SIZE>
            <LITERAL_PREFIX>"</LITERAL_PREFIX>
            <LITERAL_SUFFIX>"</LITERAL_SUFFIX>
            <IS_NULLABLE>true</IS_NULLABLE>
            <CASE_SENSITIVE>false</CASE_SENSITIVE>
            <SEARCHABLE>3</SEARCHABLE>
            <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
            <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
            <IS_LONG>false</IS_LONG>
            <BEST_MATCH>true</BEST_MATCH>
            <IS_FIXEDLENGTH>false</IS_FIXEDLENGTH>
          </row>
          <row>
            <TYPE_NAME>WCHAR</TYPE_NAME>
            <DATA_TYPE>130</DATA_TYPE>
            <COLUMN_SIZE>256</COLUMN_SIZE>
            <LITERAL_PREFIX>"</LITERAL_PREFIX>
            <LITERAL_SUFFIX>"</LITERAL_SUFFIX>
            <IS_NULLABLE>true</IS_NULLABLE>
            <CASE_SENSITIVE>false</CASE_SENSITIVE>
            <SEARCHABLE>3</SEARCHABLE>
            <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
            <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
            <IS_LONG>false</IS_LONG>
            <BEST_MATCH>true</BEST_MATCH>
            <IS_FIXEDLENGTH>false</IS_FIXEDLENGTH>
          </row>
          <row>
            <TYPE_NAME>VARIANT</TYPE_NAME>
            <DATA_TYPE>12</DATA_TYPE>
            <COLUMN_SIZE>16</COLUMN_SIZE>
            <IS_NULLABLE>true</IS_NULLABLE>
            <CASE_SENSITIVE>false</CASE_SENSITIVE>
            <SEARCHABLE>3</SEARCHABLE>
            <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
            <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
            <IS_LONG>false</IS_LONG>
            <BEST_MATCH>true</BEST_MATCH>
            <IS_FIXEDLENGTH>true</IS_FIXEDLENGTH>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetDBSchemaSchemata":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetDBSchemaTables":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DBSCHEMA_TABLES</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="TABLE_CATALOG" name="TABLE_CATALOG" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="TABLE_SCHEMA" name="TABLE_SCHEMA" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="TABLE_NAME" name="TABLE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="TABLE_TYPE" name="TABLE_TYPE" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="TABLE_GUID" name="TABLE_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="TABLE_PROPID" name="TABLE_PROPID" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="DATE_CREATED" name="DATE_CREATED" type="xsd:dateTime" minOccurs="0"/>
                <xsd:element sql:field="DATE_MODIFIED" name="DATE_MODIFIED" type="xsd:dateTime" minOccurs="0"/>
                <xsd:element sql:field="TABLE_OLAP_TYPE" name="TABLE_OLAP_TYPE" type="xsd:string" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Account</TABLE_SCHEMA>
            <TABLE_NAME>Dim AccountMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.01</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.01</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Account</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.01</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.01</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Clustered Customers</TABLE_SCHEMA>
            <TABLE_NAME>Clustered CustomersMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.11</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.11</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Clustered Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Clustered Customers</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.11</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.11</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>Dim CustomerMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.88</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.88</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Customer</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.88</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.88</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>Dim TimeMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.036667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.036667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Date</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.036667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.036667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Department</TABLE_SCHEMA>
            <TABLE_NAME>Dim Department GroupMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.983333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.983333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Department</TABLE_SCHEMA>
            <TABLE_NAME>$Department</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.983333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.983333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Destination Currency</TABLE_SCHEMA>
            <TABLE_NAME>Dim Destination CurrencyMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.146667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.146667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Destination Currency</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.146667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.146667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>Dim EmployeeMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.95</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.95</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Employee</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.95</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.95</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Geography</TABLE_SCHEMA>
            <TABLE_NAME>Dim GeographyMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.9</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.9</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Geography</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.9</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.9</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Internet Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>Fact Internet SalesMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.096667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.096667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Internet Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.096667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.096667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Organization</TABLE_SCHEMA>
            <TABLE_NAME>Dim OrganizationMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.996667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.996667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Organization</TABLE_SCHEMA>
            <TABLE_NAME>$Organization</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.996667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.996667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>Dim ProductMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.856667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.856667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Product</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.856667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.856667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Promotion</TABLE_SCHEMA>
            <TABLE_NAME>Dim PromotionMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.833333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.833333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Promotion</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.833333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.833333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>Dim ResellerMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.916667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.916667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.916667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.916667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>Fact Reseller SalesMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.083333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.083333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Reseller Sales Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.083333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.083333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Channel</TABLE_SCHEMA>
            <TABLE_NAME>Fact Sales SummaryMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.133333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.133333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Channel</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Channel</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.133333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.133333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Reason</TABLE_SCHEMA>
            <TABLE_NAME>Dim Sales ReasonMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.066667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.066667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Reason</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Reason</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.066667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.066667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Summary Order Details</TABLE_SCHEMA>
            <TABLE_NAME>Fact Sales Summary 1MG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.16</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.16</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Summary Order Details</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.16</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.16</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Territory</TABLE_SCHEMA>
            <TABLE_NAME>Dim Sales TerritoryMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.933333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.933333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Sales Territory</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.933333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.933333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Scenario</TABLE_SCHEMA>
            <TABLE_NAME>Dim ScenarioMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.97</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.97</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Scenario</TABLE_SCHEMA>
            <TABLE_NAME>$Scenario</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:04.97</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:04.97</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Source Currency</TABLE_SCHEMA>
            <TABLE_NAME>Dim CurrencyMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.056667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.056667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Source Currency</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.056667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.056667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Subcategory Basket Analysis</TABLE_SCHEMA>
            <TABLE_NAME>Subcategory Basket AnalysisMG</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.123333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.123333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>$Subcategory Basket Analysis</TABLE_SCHEMA>
            <TABLE_NAME>$Subcategory Basket Analysis</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.123333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.123333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Financial Reporting</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>Sales Targets</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Department</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Organization</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Channel</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Reason</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Scenario</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Adventure Works</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.196667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.196667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Financial Reporting</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Targets</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Geography</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Reseller Sales Order Details</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Channel Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.356667</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.356667</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Financial Reporting</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>Sales Targets</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Reason</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Direct Sales</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.293333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.293333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Financial Reporting</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>Sales Targets</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Account</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Department</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Organization</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Finance</TABLE_SCHEMA>
            <TABLE_NAME>$Scenario</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.453333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.453333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Clustered Customers</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Customer</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Internet Sales Order Details</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Reason</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Mined Customers</TABLE_SCHEMA>
            <TABLE_NAME>$Subcategory Basket Analysis</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:08.363333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:08.363333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Financial Reporting</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>Sales Targets</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Delivery Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Destination Currency</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Promotion</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Channel</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Summary Order Details</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Ship Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Summary</TABLE_SCHEMA>
            <TABLE_NAME>$Source Currency</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.413333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.413333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Exchange Rates</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Financial Reporting</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Customers</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Internet Sales</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Reseller Sales</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Orders</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Reasons</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Summary</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>Sales Targets</TABLE_NAME>
            <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>MEASURE_GROUP</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Date</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Employee</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Product</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_CATALOG>Adventure Works DW 2008R2</TABLE_CATALOG>
            <TABLE_SCHEMA>Sales Targets</TABLE_SCHEMA>
            <TABLE_NAME>$Sales Territory</TABLE_NAME>
            <TABLE_TYPE>TABLE</TABLE_TYPE>
            <DESCRIPTION/>
            <DATE_CREATED>2011-06-23T23:01:05.513333</DATE_CREATED>
            <DATE_MODIFIED>2011-06-23T23:01:05.513333</DATE_MODIFIED>
            <TABLE_OLAP_TYPE>CUBE_DIMENSION</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_CATALOGS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>C8B52211-5CF3-11CE-ADE5-00AA0044773D</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_TABLES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>C8B52229-5CF3-11CE-ADE5-00AA0044773D</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_COLUMNS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>C8B52214-5CF3-11CE-ADE5-00AA0044773D</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DBSCHEMA_PROVIDER_TYPES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_CUBES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_DIMENSIONS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_HIERARCHIES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_LEVELS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASURES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_PROPERTIES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEMBERS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_FUNCTIONS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD07-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_SETS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD0B-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_INSTANCES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>20518699-2474-4C15-9885-0E947EC7A7E3</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_KPIS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUPS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_MEASUREGROUP_DIMENSIONS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD33-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>MDSCHEMA_INPUT_DATASOURCES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD32-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_SERVICE_PARAMETERS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_FUNCTIONS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_XML</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODEL_CONTENT_PMML</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_MODELS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_COLUMNS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>883269F3-0CAD-462F-B6F5-E88A72418C4B</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DMSCHEMA_MINING_STRUCTURE_COLUMNS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PROPERTIES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SCHEMA_ROWSETS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>EEA0302B-7922-4992-8991-0E605D0E5593</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_ENUMERATORS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>55A9E78B-ACCB-45B4-95A6-94C5065617A7</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_KEYWORDS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LITERALS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>C3EF5ECB-0A07-4665-A140-B075722DBDC2</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD1A-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD1B-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACE_COLUMNS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD18-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRACE_EVENT_CATEGORIES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD19-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYUSAGE</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD21-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MEMORYGRANT</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD23-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_LOCKS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD24-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_CONNECTIONS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD25-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_SESSIONS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD26-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_JOBS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD27-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_TRANSACTIONS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD28-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DB_CONNECTIONS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD2A-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_MASTER_KEY</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD29-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PERFORMANCE_COUNTERS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD2E-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_DIMENSION_STAT</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD8E-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_PARTITION_STAT</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD8F-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_DIMENSION_STAT</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD90-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMANDS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD34-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_COMMAND_OBJECTS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD35-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_ACTIVITY</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD36-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_OBJECT_MEMORY_USAGE</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD37-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLES</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD43-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMNS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD44-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
          <row>
            <TABLE_SCHEMA>$SYSTEM</TABLE_SCHEMA>
            <TABLE_NAME>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</TABLE_NAME>
            <TABLE_TYPE>SCHEMA</TABLE_TYPE>
            <TABLE_GUID>A07CCD45-8148-11D0-87BB-00C04FC33942</TABLE_GUID>
            <TABLE_OLAP_TYPE>SCHEMA</TABLE_OLAP_TYPE>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetDBSchemaTablesInfo":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetDatasources":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_DATASOURCES</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="DataSourceName" name="DataSourceName" type="xsd:string"/>
                <xsd:element sql:field="DataSourceDescription" name="DataSourceDescription" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="URL" name="URL" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DataSourceInfo" name="DataSourceInfo" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="ProviderName" name="ProviderName" type="xsd:string"/>
                <xsd:element sql:field="ProviderType" name="ProviderType" type="xsd:string" minOccurs="0" maxOccurs="unbounded"/>
                <xsd:element sql:field="AuthenticationMode" name="AuthenticationMode" type="xsd:string" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <DataSourceName>DWH-BI</DataSourceName>
            <DataSourceDescription/>
            <URL/>
            <DataSourceInfo/>
            <ProviderName>Microsoft Analysis Services</ProviderName>
            <ProviderType>MDP</ProviderType>
            <ProviderType>TDP</ProviderType>
            <ProviderType>DMP</ProviderType>
            <AuthenticationMode>Authenticated</AuthenticationMode>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetEnumerators":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_ENUMERATORS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="EnumName" name="EnumName" type="xsd:string"/>
                <xsd:element sql:field="EnumDescription" name="EnumDescription" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="EnumType" name="EnumType" type="xsd:string"/>
                <xsd:element sql:field="ElementName" name="ElementName" type="xsd:string"/>
                <xsd:element sql:field="ElementDescription" name="ElementDescription" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="ElementValue" name="ElementValue" type="xsd:string" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <EnumName>ProviderType</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>TDP</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>1</ElementValue>
          </row>
          <row>
            <EnumName>ProviderType</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>MDP</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>2</ElementValue>
          </row>
          <row>
            <EnumName>ProviderType</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>DMP</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>3</ElementValue>
          </row>
          <row>
            <EnumName>ProviderType</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>DOCSOURCE</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>4</ElementValue>
          </row>
          <row>
            <EnumName>AuthenticationMode</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>Unauthenticated</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>11</ElementValue>
          </row>
          <row>
            <EnumName>AuthenticationMode</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>Authenticated</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>12</ElementValue>
          </row>
          <row>
            <EnumName>AuthenticationMode</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>Integrated</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>13</ElementValue>
          </row>
          <row>
            <EnumName>PropertyAccessType</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>Read</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>21</ElementValue>
          </row>
          <row>
            <EnumName>PropertyAccessType</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>Write</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>22</ElementValue>
          </row>
          <row>
            <EnumName>PropertyAccessType</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>ReadWrite</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>23</ElementValue>
          </row>
          <row>
            <EnumName>StateSupport</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>None</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>31</ElementValue>
          </row>
          <row>
            <EnumName>StateSupport</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>Sessions</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>32</ElementValue>
          </row>
          <row>
            <EnumName>StateActionVerb</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>BeginSession</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>41</ElementValue>
          </row>
          <row>
            <EnumName>StateActionVerb</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>EndSession</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>42</ElementValue>
          </row>
          <row>
            <EnumName>StateActionVerb</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>Session</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>43</ElementValue>
          </row>
          <row>
            <EnumName>ResultsetFormat</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>Tabular</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>51</ElementValue>
          </row>
          <row>
            <EnumName>ResultsetFormat</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>Multidimensional</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>52</ElementValue>
          </row>
          <row>
            <EnumName>ResultsetAxisFormat</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>TupleFormat</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>70</ElementValue>
          </row>
          <row>
            <EnumName>ResultsetAxisFormat</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>ClusterFormat</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>71</ElementValue>
          </row>
          <row>
            <EnumName>ResultsetAxisFormat</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>CustomFormat</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>72</ElementValue>
          </row>
          <row>
            <EnumName>ResultsetContents</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>None</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>61</ElementValue>
          </row>
          <row>
            <EnumName>ResultsetContents</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>Schema</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>62</ElementValue>
          </row>
          <row>
            <EnumName>ResultsetContents</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>Data</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>63</ElementValue>
          </row>
          <row>
            <EnumName>ResultsetContents</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>SchemaData</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>64</ElementValue>
          </row>
          <row>
            <EnumName>MDXSupportLevel</EnumName>
            <EnumDescription> </EnumDescription>
            <EnumType>string</EnumType>
            <ElementName>Core</ElementName>
            <ElementDescription> </ElementDescription>
            <ElementValue>80</ElementValue>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetKeywords":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_KEYWORDS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="Keyword" name="Keyword" type="xsd:string"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <Keyword>BOOLEAN</Keyword>
          </row>
          <row>
            <Keyword>COLUMN</Keyword>
          </row>
          <row>
            <Keyword>COUNT</Keyword>
          </row>
          <row>
            <Keyword>IF</Keyword>
          </row>
          <row>
            <Keyword>UNKNOWNMEMBER</Keyword>
          </row>
          <row>
            <Keyword>DATE</Keyword>
          </row>
          <row>
            <Keyword>DOUBLE</Keyword>
          </row>
          <row>
            <Keyword>FORMAT</Keyword>
          </row>
          <row>
            <Keyword>GROUPING</Keyword>
          </row>
          <row>
            <Keyword>HIDDEN</Keyword>
          </row>
          <row>
            <Keyword>ISDESCENDANT</Keyword>
          </row>
          <row>
            <Keyword>LONG</Keyword>
          </row>
          <row>
            <Keyword>MODEL_EXISTENCE_ONLY</Keyword>
          </row>
          <row>
            <Keyword>NEST</Keyword>
          </row>
          <row>
            <Keyword>NO_PROPERTIES</Keyword>
          </row>
          <row>
            <Keyword>NOT_RELATED_TO_FACTS</Keyword>
          </row>
          <row>
            <Keyword>PREDICTIONSCORE</Keyword>
          </row>
          <row>
            <Keyword>PREDICTSTDDEV</Keyword>
          </row>
          <row>
            <Keyword>STORAGE</Keyword>
          </row>
          <row>
            <Keyword>TEXT</Keyword>
          </row>
          <row>
            <Keyword>UNIQUE</Keyword>
          </row>
          <row>
            <Keyword>UNIQUE_NAME</Keyword>
          </row>
          <row>
            <Keyword>ABSOLUTE</Keyword>
          </row>
          <row>
            <Keyword>$ADJUSTEDPROBABILITY</Keyword>
          </row>
          <row>
            <Keyword>$DISTANCE</Keyword>
          </row>
          <row>
            <Keyword>$PROBABILITY</Keyword>
          </row>
          <row>
            <Keyword>$STDEV</Keyword>
          </row>
          <row>
            <Keyword>$SUPPORT</Keyword>
          </row>
          <row>
            <Keyword>$VARIANCE</Keyword>
          </row>
          <row>
            <Keyword>ACTION</Keyword>
          </row>
          <row>
            <Keyword>BATCH</Keyword>
          </row>
          <row>
            <Keyword>INTERACTIVE</Keyword>
          </row>
          <row>
            <Keyword>ON_OPEN</Keyword>
          </row>
          <row>
            <Keyword>COMMANDLINE</Keyword>
          </row>
          <row>
            <Keyword>DATASET</Keyword>
          </row>
          <row>
            <Keyword>HTML</Keyword>
          </row>
          <row>
            <Keyword>PROPRIETARY</Keyword>
          </row>
          <row>
            <Keyword>ROWSET</Keyword>
          </row>
          <row>
            <Keyword>STATEMENT</Keyword>
          </row>
          <row>
            <Keyword>URL</Keyword>
          </row>
          <row>
            <Keyword>CHAPTERS</Keyword>
          </row>
          <row>
            <Keyword>COLUMNS</Keyword>
          </row>
          <row>
            <Keyword>PAGES</Keyword>
          </row>
          <row>
            <Keyword>ROWS</Keyword>
          </row>
          <row>
            <Keyword>SECTIONS</Keyword>
          </row>
          <row>
            <Keyword>FALSE</Keyword>
          </row>
          <row>
            <Keyword>TRUE</Keyword>
          </row>
          <row>
            <Keyword>RELATIVE</Keyword>
          </row>
          <row>
            <Keyword>BACK_COLOR</Keyword>
          </row>
          <row>
            <Keyword>CELL_ORDINAL</Keyword>
          </row>
          <row>
            <Keyword>FONT_FLAGS</Keyword>
          </row>
          <row>
            <Keyword>FONT_NAME</Keyword>
          </row>
          <row>
            <Keyword>FONT_SIZE</Keyword>
          </row>
          <row>
            <Keyword>FORE_COLOR</Keyword>
          </row>
          <row>
            <Keyword>FORMAT_STRING</Keyword>
          </row>
          <row>
            <Keyword>FORMATTED_VALUE</Keyword>
          </row>
          <row>
            <Keyword>READ</Keyword>
          </row>
          <row>
            <Keyword>WRITE</Keyword>
          </row>
          <row>
            <Keyword>EXCLUDEEMPTY</Keyword>
          </row>
          <row>
            <Keyword>INCLUDEEMPTY</Keyword>
          </row>
          <row>
            <Keyword>AFTER</Keyword>
          </row>
          <row>
            <Keyword>BEFORE</Keyword>
          </row>
          <row>
            <Keyword>BEFORE_AND_AFTER</Keyword>
          </row>
          <row>
            <Keyword>LEAVES</Keyword>
          </row>
          <row>
            <Keyword>SELF</Keyword>
          </row>
          <row>
            <Keyword>SELF_AND_AFTER</Keyword>
          </row>
          <row>
            <Keyword>SELF_AND_BEFORE</Keyword>
          </row>
          <row>
            <Keyword>SELF_BEFORE_AFTER</Keyword>
          </row>
          <row>
            <Keyword>USE_EQUAL_ALLOCATION</Keyword>
          </row>
          <row>
            <Keyword>USE_EQUAL_INCREMENT</Keyword>
          </row>
          <row>
            <Keyword>PASSWORD</Keyword>
          </row>
          <row>
            <Keyword>ADDRESS</Keyword>
          </row>
          <row>
            <Keyword>ADDRESS_BUILDING</Keyword>
          </row>
          <row>
            <Keyword>ADDRESS_CITY</Keyword>
          </row>
          <row>
            <Keyword>ADDRESS_COUNTRY</Keyword>
          </row>
          <row>
            <Keyword>ADDRESS_FAX</Keyword>
          </row>
          <row>
            <Keyword>ADDRESS_FLOOR</Keyword>
          </row>
          <row>
            <Keyword>ADDRESS_HOUSE</Keyword>
          </row>
          <row>
            <Keyword>ADDRESS_PHONE</Keyword>
          </row>
          <row>
            <Keyword>ADDRESS_QUARTER</Keyword>
          </row>
          <row>
            <Keyword>ADDRESS_ROOM</Keyword>
          </row>
          <row>
            <Keyword>ADDRESS_STATE_OR_PROVINCE</Keyword>
          </row>
          <row>
            <Keyword>ADDRESS_STREET</Keyword>
          </row>
          <row>
            <Keyword>ADDRESS_ZIP</Keyword>
          </row>
          <row>
            <Keyword>CAPTION_ABBREVIATION</Keyword>
          </row>
          <row>
            <Keyword>CAPTION_DESCRIPTION</Keyword>
          </row>
          <row>
            <Keyword>CAPTION_SHORT</Keyword>
          </row>
          <row>
            <Keyword>DATE_CANCELED</Keyword>
          </row>
          <row>
            <Keyword>DATE_DURATION</Keyword>
          </row>
          <row>
            <Keyword>DATE_ENDED</Keyword>
          </row>
          <row>
            <Keyword>DATE_MODIFIED</Keyword>
          </row>
          <row>
            <Keyword>DATE_START</Keyword>
          </row>
          <row>
            <Keyword>FORMATTING_COLOR</Keyword>
          </row>
          <row>
            <Keyword>FORMATTING_FONT</Keyword>
          </row>
          <row>
            <Keyword>FORMATTING_FONT_EFFECTS</Keyword>
          </row>
          <row>
            <Keyword>FORMATTING_FONT_SIZE</Keyword>
          </row>
          <row>
            <Keyword>FORMATTING_ORDER</Keyword>
          </row>
          <row>
            <Keyword>FORMATTING_SUB_TOTAL</Keyword>
          </row>
          <row>
            <Keyword>GEO_BOUNDARY_BOTTOM</Keyword>
          </row>
          <row>
            <Keyword>GEO_BOUNDARY_FRONT</Keyword>
          </row>
          <row>
            <Keyword>GEO_BOUNDARY_LEFT</Keyword>
          </row>
          <row>
            <Keyword>GEO_BOUNDARY_POLIGON</Keyword>
          </row>
          <row>
            <Keyword>GEO_BOUNDARY_READ</Keyword>
          </row>
          <row>
            <Keyword>GEO_BOUNDARY_RIGHT</Keyword>
          </row>
          <row>
            <Keyword>GEO_BOUNDARY_TOP</Keyword>
          </row>
          <row>
            <Keyword>GEO_CENTROID_X</Keyword>
          </row>
          <row>
            <Keyword>GEO_CENTROID_Y</Keyword>
          </row>
          <row>
            <Keyword>GEO_CENTROID_Z</Keyword>
          </row>
          <row>
            <Keyword>ID</Keyword>
          </row>
          <row>
            <Keyword>ORG_TITLE</Keyword>
          </row>
          <row>
            <Keyword>PERSON_CONTACT</Keyword>
          </row>
          <row>
            <Keyword>PERSON_DEMOGRAPHIC</Keyword>
          </row>
          <row>
            <Keyword>PERSON_FIRST_NAME</Keyword>
          </row>
          <row>
            <Keyword>PERSON_FULL_NAME</Keyword>
          </row>
          <row>
            <Keyword>PERSON_LAST_NAME</Keyword>
          </row>
          <row>
            <Keyword>PERSON_MIDDLE_NAME</Keyword>
          </row>
          <row>
            <Keyword>PHYSICAL_COLOR</Keyword>
          </row>
          <row>
            <Keyword>PHYSICAL_DENSITY</Keyword>
          </row>
          <row>
            <Keyword>PHYSICAL_DEPTH</Keyword>
          </row>
          <row>
            <Keyword>PHYSICAL_HEIGHT</Keyword>
          </row>
          <row>
            <Keyword>PHYSICAL_SIZE</Keyword>
          </row>
          <row>
            <Keyword>PHYSICAL_VOLUME</Keyword>
          </row>
          <row>
            <Keyword>PHYSICAL_WEIGHT</Keyword>
          </row>
          <row>
            <Keyword>PHYSICAL_WIDTH</Keyword>
          </row>
          <row>
            <Keyword>QTY_RANGE_HIGH</Keyword>
          </row>
          <row>
            <Keyword>QTY_RANGE_LOW</Keyword>
          </row>
          <row>
            <Keyword>REGULAR</Keyword>
          </row>
          <row>
            <Keyword>RELATION_TO_PARENT</Keyword>
          </row>
          <row>
            <Keyword>VERSION</Keyword>
          </row>
          <row>
            <Keyword>WEB_HTML</Keyword>
          </row>
          <row>
            <Keyword>WEB_MAIL_ALIAS</Keyword>
          </row>
          <row>
            <Keyword>WEB_URL</Keyword>
          </row>
          <row>
            <Keyword>WEB_XML_OR_XSL</Keyword>
          </row>
          <row>
            <Keyword>SOLVE_ORDER</Keyword>
          </row>
          <row>
            <Keyword>VISIBLE</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_CY</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_DATE</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_DECIMAL</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_I1</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_I2</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_I4</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_I8</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_NUMERIC</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_R4</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_R8</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_UI1</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_UI2</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_UI4</Keyword>
          </row>
          <row>
            <Keyword>DBTYPE_UI8</Keyword>
          </row>
          <row>
            <Keyword>EXCLUDE_NULL</Keyword>
          </row>
          <row>
            <Keyword>EXCLUSIVE</Keyword>
          </row>
          <row>
            <Keyword>EXCLUSIVE_ASSOCIATION</Keyword>
          </row>
          <row>
            <Keyword>INCLUDE_NULL</Keyword>
          </row>
          <row>
            <Keyword>INCLUSIVE</Keyword>
          </row>
          <row>
            <Keyword>INPUT_ONLY</Keyword>
          </row>
          <row>
            <Keyword>SKIP</Keyword>
          </row>
          <row>
            <Keyword>GLOBAL</Keyword>
          </row>
          <row>
            <Keyword>SESSION</Keyword>
          </row>
          <row>
            <Keyword>ASC</Keyword>
          </row>
          <row>
            <Keyword>BASC</Keyword>
          </row>
          <row>
            <Keyword>BDESC</Keyword>
          </row>
          <row>
            <Keyword>DESC</Keyword>
          </row>
          <row>
            <Keyword>USE_WEIGHTED_ALLOCATION</Keyword>
          </row>
          <row>
            <Keyword>USE_WEIGHTED_INCREMENT</Keyword>
          </row>
          <row>
            <Keyword>ALL</Keyword>
          </row>
          <row>
            <Keyword>ALLEXCEPT</Keyword>
          </row>
          <row>
            <Keyword>ALLNOBLANKROW</Keyword>
          </row>
          <row>
            <Keyword>ALTER</Keyword>
          </row>
          <row>
            <Keyword>AND</Keyword>
          </row>
          <row>
            <Keyword>APPEND</Keyword>
          </row>
          <row>
            <Keyword>APPLICATION</Keyword>
          </row>
          <row>
            <Keyword>AS</Keyword>
          </row>
          <row>
            <Keyword>AUTOMATIC</Keyword>
          </row>
          <row>
            <Keyword>BEGIN</Keyword>
          </row>
          <row>
            <Keyword>BINARY</Keyword>
          </row>
          <row>
            <Keyword>BY</Keyword>
          </row>
          <row>
            <Keyword>CACHE</Keyword>
          </row>
          <row>
            <Keyword>CALCULATED</Keyword>
          </row>
          <row>
            <Keyword>CALCULATION</Keyword>
          </row>
          <row>
            <Keyword>CALCULATION_PASS_NUMBER</Keyword>
          </row>
          <row>
            <Keyword>CALCULATION_PASS_DEPTH</Keyword>
          </row>
          <row>
            <Keyword>CALL</Keyword>
          </row>
          <row>
            <Keyword>CAPTION</Keyword>
          </row>
          <row>
            <Keyword>CASE</Keyword>
          </row>
          <row>
            <Keyword>CATALOG</Keyword>
          </row>
          <row>
            <Keyword>CELL</Keyword>
          </row>
          <row>
            <Keyword>CELLS</Keyword>
          </row>
          <row>
            <Keyword>CLUSTERS</Keyword>
          </row>
          <row>
            <Keyword>COLUMN_VALUES</Keyword>
          </row>
          <row>
            <Keyword>COMMIT</Keyword>
          </row>
          <row>
            <Keyword>CONDITION</Keyword>
          </row>
          <row>
            <Keyword>CONTENT</Keyword>
          </row>
          <row>
            <Keyword>CONTINUOUS</Keyword>
          </row>
          <row>
            <Keyword>CREATE</Keyword>
          </row>
          <row>
            <Keyword>CUBE</Keyword>
          </row>
          <row>
            <Keyword>CURRENTCUBE</Keyword>
          </row>
          <row>
            <Keyword>CUSTOM</Keyword>
          </row>
          <row>
            <Keyword>CYCLICAL</Keyword>
          </row>
          <row>
            <Keyword>DEFAULT_MEMBER</Keyword>
          </row>
          <row>
            <Keyword>DELETE</Keyword>
          </row>
          <row>
            <Keyword>DESCRIPTION</Keyword>
          </row>
          <row>
            <Keyword>DISABLED</Keyword>
          </row>
          <row>
            <Keyword>DISCRETE</Keyword>
          </row>
          <row>
            <Keyword>DISCRETIZED</Keyword>
          </row>
          <row>
            <Keyword>DISTINCT</Keyword>
          </row>
          <row>
            <Keyword>DRILLTHROUGH</Keyword>
          </row>
          <row>
            <Keyword>DROP</Keyword>
          </row>
          <row>
            <Keyword>ELSE</Keyword>
          </row>
          <row>
            <Keyword>EMPTY</Keyword>
          </row>
          <row>
            <Keyword>END</Keyword>
          </row>
          <row>
            <Keyword>EQUAL_AREAS</Keyword>
          </row>
          <row>
            <Keyword>ERROR</Keyword>
          </row>
          <row>
            <Keyword>FIRSTROWSET</Keyword>
          </row>
          <row>
            <Keyword>FLATTENED</Keyword>
          </row>
          <row>
            <Keyword>FN</Keyword>
          </row>
          <row>
            <Keyword>FOR</Keyword>
          </row>
          <row>
            <Keyword>FROM</Keyword>
          </row>
          <row>
            <Keyword>GROUP</Keyword>
          </row>
          <row>
            <Keyword>HAVING</Keyword>
          </row>
          <row>
            <Keyword>INCLUDE_STATISTICS</Keyword>
          </row>
          <row>
            <Keyword>INSERT</Keyword>
          </row>
          <row>
            <Keyword>INTO</Keyword>
          </row>
          <row>
            <Keyword>INVOCATION</Keyword>
          </row>
          <row>
            <Keyword>IS</Keyword>
          </row>
          <row>
            <Keyword>JOIN</Keyword>
          </row>
          <row>
            <Keyword>KEY</Keyword>
          </row>
          <row>
            <Keyword>LIBRARY</Keyword>
          </row>
          <row>
            <Keyword>MAXROWS</Keyword>
          </row>
          <row>
            <Keyword>MEASURE</Keyword>
          </row>
          <row>
            <Keyword>MEMBER</Keyword>
          </row>
          <row>
            <Keyword>MICROSOFT_CLUSTERING</Keyword>
          </row>
          <row>
            <Keyword>MICROSOFT_DECISION_TREES</Keyword>
          </row>
          <row>
            <Keyword>MINING</Keyword>
          </row>
          <row>
            <Keyword>MODEL</Keyword>
          </row>
          <row>
            <Keyword>MODELS</Keyword>
          </row>
          <row>
            <Keyword>MOVE</Keyword>
          </row>
          <row>
            <Keyword>NATURAL</Keyword>
          </row>
          <row>
            <Keyword>NON</Keyword>
          </row>
          <row>
            <Keyword>NORMAL</Keyword>
          </row>
          <row>
            <Keyword>NOT</Keyword>
          </row>
          <row>
            <Keyword>NULL</Keyword>
          </row>
          <row>
            <Keyword>OF</Keyword>
          </row>
          <row>
            <Keyword>OLAP</Keyword>
          </row>
          <row>
            <Keyword>ON</Keyword>
          </row>
          <row>
            <Keyword>OPENROWSET</Keyword>
          </row>
          <row>
            <Keyword>OR</Keyword>
          </row>
          <row>
            <Keyword>ORDERED</Keyword>
          </row>
          <row>
            <Keyword>PMML</Keyword>
          </row>
          <row>
            <Keyword>POST</Keyword>
          </row>
          <row>
            <Keyword>PREDICT_ONLY</Keyword>
          </row>
          <row>
            <Keyword>PREDICTION</Keyword>
          </row>
          <row>
            <Keyword>PROBABILITY</Keyword>
          </row>
          <row>
            <Keyword>PROBABILITY_STDDEV</Keyword>
          </row>
          <row>
            <Keyword>PROBABILITY_STDEV</Keyword>
          </row>
          <row>
            <Keyword>PROBABILITY_VARIANCE</Keyword>
          </row>
          <row>
            <Keyword>PROPERTY</Keyword>
          </row>
          <row>
            <Keyword>RECURSIVE</Keyword>
          </row>
          <row>
            <Keyword>REFRESH</Keyword>
          </row>
          <row>
            <Keyword>RELATE</Keyword>
          </row>
          <row>
            <Keyword>RELATED</Keyword>
          </row>
          <row>
            <Keyword>RELATEDTABLE</Keyword>
          </row>
          <row>
            <Keyword>RENAME</Keyword>
          </row>
          <row>
            <Keyword>ROLLBACK</Keyword>
          </row>
          <row>
            <Keyword>ROLLUP</Keyword>
          </row>
          <row>
            <Keyword>SELECT</Keyword>
          </row>
          <row>
            <Keyword>SEQUENCE_TIME</Keyword>
          </row>
          <row>
            <Keyword>SERVER</Keyword>
          </row>
          <row>
            <Keyword>SET</Keyword>
          </row>
          <row>
            <Keyword>SHAPE</Keyword>
          </row>
          <row>
            <Keyword>SKIPPED_LEVELS</Keyword>
          </row>
          <row>
            <Keyword>SUPPORT</Keyword>
          </row>
          <row>
            <Keyword>TABLE</Keyword>
          </row>
          <row>
            <Keyword>THEN</Keyword>
          </row>
          <row>
            <Keyword>THRESHOLDS</Keyword>
          </row>
          <row>
            <Keyword>TO</Keyword>
          </row>
          <row>
            <Keyword>TOTALS</Keyword>
          </row>
          <row>
            <Keyword>TRAN</Keyword>
          </row>
          <row>
            <Keyword>TRANSACTION</Keyword>
          </row>
          <row>
            <Keyword>TYPE</Keyword>
          </row>
          <row>
            <Keyword>UNDER</Keyword>
          </row>
          <row>
            <Keyword>UNIFORM</Keyword>
          </row>
          <row>
            <Keyword>UPDATE</Keyword>
          </row>
          <row>
            <Keyword>USE</Keyword>
          </row>
          <row>
            <Keyword>USING</Keyword>
          </row>
          <row>
            <Keyword>VISUAL</Keyword>
          </row>
          <row>
            <Keyword>WHEN</Keyword>
          </row>
          <row>
            <Keyword>WHERE</Keyword>
          </row>
          <row>
            <Keyword>WITH</Keyword>
          </row>
          <row>
            <Keyword>WORK</Keyword>
          </row>
          <row>
            <Keyword>XOR</Keyword>
          </row>
          <row>
            <Keyword>BOTTOMCOUNT</Keyword>
          </row>
          <row>
            <Keyword>BOTTOMPERCENT</Keyword>
          </row>
          <row>
            <Keyword>BOTTOMSUM</Keyword>
          </row>
          <row>
            <Keyword>CLUSTER</Keyword>
          </row>
          <row>
            <Keyword>CLUSTERDISTANCE</Keyword>
          </row>
          <row>
            <Keyword>CLUSTERPROBABILITY</Keyword>
          </row>
          <row>
            <Keyword>PREDICT</Keyword>
          </row>
          <row>
            <Keyword>PREDICTADJUSTEDPROBABILITY</Keyword>
          </row>
          <row>
            <Keyword>PREDICTHISTOGRAM</Keyword>
          </row>
          <row>
            <Keyword>PREDICTPROBABILITY</Keyword>
          </row>
          <row>
            <Keyword>PREDICTSTDEV</Keyword>
          </row>
          <row>
            <Keyword>PREDICTSUPPORT</Keyword>
          </row>
          <row>
            <Keyword>PREDICTVARIANCE</Keyword>
          </row>
          <row>
            <Keyword>RANGEMAX</Keyword>
          </row>
          <row>
            <Keyword>RANGEMID</Keyword>
          </row>
          <row>
            <Keyword>RANGEMIN</Keyword>
          </row>
          <row>
            <Keyword>TOPCOUNT</Keyword>
          </row>
          <row>
            <Keyword>TOPPERCENT</Keyword>
          </row>
          <row>
            <Keyword>TOPSUM</Keyword>
          </row>
          <row>
            <Keyword>ADDCALCULATEDMEMBERS</Keyword>
          </row>
          <row>
            <Keyword>AGGREGATE</Keyword>
          </row>
          <row>
            <Keyword>ANCESTOR</Keyword>
          </row>
          <row>
            <Keyword>ANCESTORS</Keyword>
          </row>
          <row>
            <Keyword>ASCENDANTS</Keyword>
          </row>
          <row>
            <Keyword>AVG</Keyword>
          </row>
          <row>
            <Keyword>AXIS</Keyword>
          </row>
          <row>
            <Keyword>CALCULATIONCURRENTPASS</Keyword>
          </row>
          <row>
            <Keyword>CALCULATIONPASSVALUE</Keyword>
          </row>
          <row>
            <Keyword>CLOSINGPERIOD</Keyword>
          </row>
          <row>
            <Keyword>COALESCEEMPTY</Keyword>
          </row>
          <row>
            <Keyword>CORRELATION</Keyword>
          </row>
          <row>
            <Keyword>COUSIN</Keyword>
          </row>
          <row>
            <Keyword>COVARIANCE</Keyword>
          </row>
          <row>
            <Keyword>COVARIANCEN</Keyword>
          </row>
          <row>
            <Keyword>CROSSJOIN</Keyword>
          </row>
          <row>
            <Keyword>DESCENDANTS</Keyword>
          </row>
          <row>
            <Keyword>DIMENSIONS</Keyword>
          </row>
          <row>
            <Keyword>DISTINCTCOUNT</Keyword>
          </row>
          <row>
            <Keyword>DRILLDOWNLEVEL</Keyword>
          </row>
          <row>
            <Keyword>DRILLDOWNLEVELBOTTOM</Keyword>
          </row>
          <row>
            <Keyword>DRILLDOWNLEVELTOP</Keyword>
          </row>
          <row>
            <Keyword>DRILLDOWNMEMBER</Keyword>
          </row>
          <row>
            <Keyword>DRILLDOWNMEMBERBOTTOM</Keyword>
          </row>
          <row>
            <Keyword>DRILLDOWNMEMBERTOP</Keyword>
          </row>
          <row>
            <Keyword>DRILLUPLEVEL</Keyword>
          </row>
          <row>
            <Keyword>DRILLUPMEMBER</Keyword>
          </row>
          <row>
            <Keyword>EXCEPT</Keyword>
          </row>
          <row>
            <Keyword>EXTRACT</Keyword>
          </row>
          <row>
            <Keyword>FILTER</Keyword>
          </row>
          <row>
            <Keyword>GENERATE</Keyword>
          </row>
          <row>
            <Keyword>HEAD</Keyword>
          </row>
          <row>
            <Keyword>HIERARCHIZE</Keyword>
          </row>
          <row>
            <Keyword>IGNORE</Keyword>
          </row>
          <row>
            <Keyword>IIF</Keyword>
          </row>
          <row>
            <Keyword>INTERSECT</Keyword>
          </row>
          <row>
            <Keyword>ISANCESTOR</Keyword>
          </row>
          <row>
            <Keyword>ISEMPTY</Keyword>
          </row>
          <row>
            <Keyword>ISGENERATION</Keyword>
          </row>
          <row>
            <Keyword>ISLEAF</Keyword>
          </row>
          <row>
            <Keyword>ISSIBLING</Keyword>
          </row>
          <row>
            <Keyword>LASTPERIODS</Keyword>
          </row>
          <row>
            <Keyword>LINKMEMBER</Keyword>
          </row>
          <row>
            <Keyword>LINREGINTERCEPT</Keyword>
          </row>
          <row>
            <Keyword>LINREGPOINT</Keyword>
          </row>
          <row>
            <Keyword>LINREGR2</Keyword>
          </row>
          <row>
            <Keyword>LINREGSLOPE</Keyword>
          </row>
          <row>
            <Keyword>LINREGVARIANCE</Keyword>
          </row>
          <row>
            <Keyword>LOOKUPCUBE</Keyword>
          </row>
          <row>
            <Keyword>MAX</Keyword>
          </row>
          <row>
            <Keyword>MEDIAN</Keyword>
          </row>
          <row>
            <Keyword>MEMBERTOSTR</Keyword>
          </row>
          <row>
            <Keyword>MIN</Keyword>
          </row>
          <row>
            <Keyword>MTD</Keyword>
          </row>
          <row>
            <Keyword>NAMETOSET</Keyword>
          </row>
          <row>
            <Keyword>NONEMPTYCROSSJOIN</Keyword>
          </row>
          <row>
            <Keyword>OPENINGPERIOD</Keyword>
          </row>
          <row>
            <Keyword>ORDER</Keyword>
          </row>
          <row>
            <Keyword>PARALLELPERIOD</Keyword>
          </row>
          <row>
            <Keyword>PERIODSTODATE</Keyword>
          </row>
          <row>
            <Keyword>QTD</Keyword>
          </row>
          <row>
            <Keyword>RANK</Keyword>
          </row>
          <row>
            <Keyword>ROLLUPCHILDREN</Keyword>
          </row>
          <row>
            <Keyword>SETTOARRAY</Keyword>
          </row>
          <row>
            <Keyword>SETTOSTR</Keyword>
          </row>
          <row>
            <Keyword>STDDEV</Keyword>
          </row>
          <row>
            <Keyword>STDDEVP</Keyword>
          </row>
          <row>
            <Keyword>STDEV</Keyword>
          </row>
          <row>
            <Keyword>STDEVP</Keyword>
          </row>
          <row>
            <Keyword>STRIPCALCULATEDMEMBERS</Keyword>
          </row>
          <row>
            <Keyword>STRTOMEMBER</Keyword>
          </row>
          <row>
            <Keyword>STRTOSET</Keyword>
          </row>
          <row>
            <Keyword>STRTOTUPLE</Keyword>
          </row>
          <row>
            <Keyword>STRTOVALUE</Keyword>
          </row>
          <row>
            <Keyword>SUBSET</Keyword>
          </row>
          <row>
            <Keyword>SUM</Keyword>
          </row>
          <row>
            <Keyword>TAIL</Keyword>
          </row>
          <row>
            <Keyword>TOGGLEDRILLSTATE</Keyword>
          </row>
          <row>
            <Keyword>TUPLETOSTR</Keyword>
          </row>
          <row>
            <Keyword>UNION</Keyword>
          </row>
          <row>
            <Keyword>USERNAME</Keyword>
          </row>
          <row>
            <Keyword>VALIDMEASURE</Keyword>
          </row>
          <row>
            <Keyword>VAR</Keyword>
          </row>
          <row>
            <Keyword>VARIANCE</Keyword>
          </row>
          <row>
            <Keyword>VARIANCEP</Keyword>
          </row>
          <row>
            <Keyword>VARP</Keyword>
          </row>
          <row>
            <Keyword>VISUALTOTALS</Keyword>
          </row>
          <row>
            <Keyword>WTD</Keyword>
          </row>
          <row>
            <Keyword>YTD</Keyword>
          </row>
          <row>
            <Keyword>ITEM</Keyword>
          </row>
          <row>
            <Keyword>LAG</Keyword>
          </row>
          <row>
            <Keyword>LEAD</Keyword>
          </row>
          <row>
            <Keyword>LEVELS</Keyword>
          </row>
          <row>
            <Keyword>PROPERTIES</Keyword>
          </row>
          <row>
            <Keyword>ALLMEMBERS</Keyword>
          </row>
          <row>
            <Keyword>CHILDREN</Keyword>
          </row>
          <row>
            <Keyword>CURRENT</Keyword>
          </row>
          <row>
            <Keyword>CURRENTMEMBER</Keyword>
          </row>
          <row>
            <Keyword>DATAMEMBER</Keyword>
          </row>
          <row>
            <Keyword>DEFAULTMEMBER</Keyword>
          </row>
          <row>
            <Keyword>DIMENSION</Keyword>
          </row>
          <row>
            <Keyword>FIRSTCHILD</Keyword>
          </row>
          <row>
            <Keyword>FIRSTSIBLING</Keyword>
          </row>
          <row>
            <Keyword>HIERARCHY</Keyword>
          </row>
          <row>
            <Keyword>LASTCHILD</Keyword>
          </row>
          <row>
            <Keyword>LASTSIBLING</Keyword>
          </row>
          <row>
            <Keyword>LEVEL</Keyword>
          </row>
          <row>
            <Keyword>MEMBERS</Keyword>
          </row>
          <row>
            <Keyword>NAME</Keyword>
          </row>
          <row>
            <Keyword>NEXTMEMBER</Keyword>
          </row>
          <row>
            <Keyword>ORDINAL</Keyword>
          </row>
          <row>
            <Keyword>PARENT</Keyword>
          </row>
          <row>
            <Keyword>PREVMEMBER</Keyword>
          </row>
          <row>
            <Keyword>SIBLINGS</Keyword>
          </row>
          <row>
            <Keyword>UNIQUENAME</Keyword>
          </row>
          <row>
            <Keyword>VALUE</Keyword>
          </row>
          <row>
            <Keyword>CHILDREN_CARDINALITY</Keyword>
          </row>
          <row>
            <Keyword>CUBE_NAME</Keyword>
          </row>
          <row>
            <Keyword>DIMENSION_UNIQUE_NAME</Keyword>
          </row>
          <row>
            <Keyword>HIERARCHY_UNIQUE_NAME</Keyword>
          </row>
          <row>
            <Keyword>IS_DATAMEMBER</Keyword>
          </row>
          <row>
            <Keyword>LEVEL_NUMBER</Keyword>
          </row>
          <row>
            <Keyword>LEVEL_UNIQUE_NAME</Keyword>
          </row>
          <row>
            <Keyword>MEMBER_CAPTION</Keyword>
          </row>
          <row>
            <Keyword>MEMBER_NAME</Keyword>
          </row>
          <row>
            <Keyword>MEMBER_ORDINAL</Keyword>
          </row>
          <row>
            <Keyword>MEMBER_TYPE</Keyword>
          </row>
          <row>
            <Keyword>MEMBER_UNIQUE_NAME</Keyword>
          </row>
          <row>
            <Keyword>PARENT_COUNT</Keyword>
          </row>
          <row>
            <Keyword>PARENT_UNIQUE_NAME</Keyword>
          </row>
          <row>
            <Keyword>UNARY_OPERATOR</Keyword>
          </row>
          <row>
            <Keyword>UPDATEABLE</Keyword>
          </row>
          <row>
            <Keyword>NON_EMPTY_BEHAVIOR</Keyword>
          </row>
          <row>
            <Keyword>CELL_EVALUATION_LIST</Keyword>
          </row>
          <row>
            <Keyword>$CLUSTER</Keyword>
          </row>
          <row>
            <Keyword>SUBCUBE</Keyword>
          </row>
          <row>
            <Keyword>SUBCUBESET</Keyword>
          </row>
          <row>
            <Keyword>AS_FORMULA</Keyword>
          </row>
          <row>
            <Keyword>AS_VALUE</Keyword>
          </row>
          <row>
            <Keyword>SAMPLE_CASES</Keyword>
          </row>
          <row>
            <Keyword>$NODEID</Keyword>
          </row>
          <row>
            <Keyword>$NODENAME</Keyword>
          </row>
          <row>
            <Keyword>$NODECAPTION</Keyword>
          </row>
          <row>
            <Keyword>CLEAR</Keyword>
          </row>
          <row>
            <Keyword>UPDATES</Keyword>
          </row>
          <row>
            <Keyword>SOLVEORDER</Keyword>
          </row>
          <row>
            <Keyword>EXISTS</Keyword>
          </row>
          <row>
            <Keyword>ROLLUPCUBE</Keyword>
          </row>
          <row>
            <Keyword>PREDICTSEQUENCE</Keyword>
          </row>
          <row>
            <Keyword>$SEQUENCE</Keyword>
          </row>
          <row>
            <Keyword>EXCLUDE</Keyword>
          </row>
          <row>
            <Keyword>CELL_BY_ALLOCATION</Keyword>
          </row>
          <row>
            <Keyword>PASS</Keyword>
          </row>
          <row>
            <Keyword>DIMENSION_CONTENT</Keyword>
          </row>
          <row>
            <Keyword>INCLUDE_NODE_ID</Keyword>
          </row>
          <row>
            <Keyword>PREDICTNODEID</Keyword>
          </row>
          <row>
            <Keyword>PREDICTTIMESERIES</Keyword>
          </row>
          <row>
            <Keyword>SKIPPEDLEVELS</Keyword>
          </row>
          <row>
            <Keyword>CUSTOMROLLUP</Keyword>
          </row>
          <row>
            <Keyword>CASES</Keyword>
          </row>
          <row>
            <Keyword>ISINNODE</Keyword>
          </row>
          <row>
            <Keyword>$TIME</Keyword>
          </row>
          <row>
            <Keyword>RETURN</Keyword>
          </row>
          <row>
            <Keyword>CALCULATIONS</Keyword>
          </row>
          <row>
            <Keyword>CUSTOMROLLUPPROPERTIES</Keyword>
          </row>
          <row>
            <Keyword>UNARYOPERATOR</Keyword>
          </row>
          <row>
            <Keyword>MDXFILTER</Keyword>
          </row>
          <row>
            <Keyword>PREDICTASSOCIATION</Keyword>
          </row>
          <row>
            <Keyword>ACTION_TYPE</Keyword>
          </row>
          <row>
            <Keyword>SCOPE</Keyword>
          </row>
          <row>
            <Keyword>THIS</Keyword>
          </row>
          <row>
            <Keyword>FREEZE</Keyword>
          </row>
          <row>
            <Keyword>CALCULATE</Keyword>
          </row>
          <row>
            <Keyword>CALCULATETABLE</Keyword>
          </row>
          <row>
            <Keyword>ROOT</Keyword>
          </row>
          <row>
            <Keyword>MICROSOFT_NAIVE_BAYES</Keyword>
          </row>
          <row>
            <Keyword>MICROSOFT_SEQUENCE_CLUSTERING</Keyword>
          </row>
          <row>
            <Keyword>MICROSOFT_ASSOCIATION_RULES</Keyword>
          </row>
          <row>
            <Keyword>MICROSOFT_TIME_SERIES</Keyword>
          </row>
          <row>
            <Keyword>MICROSOFT_NEURAL_NETWORK</Keyword>
          </row>
          <row>
            <Keyword>SEQUENCE</Keyword>
          </row>
          <row>
            <Keyword>DATAID</Keyword>
          </row>
          <row>
            <Keyword>NONLEAVES</Keyword>
          </row>
          <row>
            <Keyword>UNORDER</Keyword>
          </row>
          <row>
            <Keyword>OPEN</Keyword>
          </row>
          <row>
            <Keyword>CLOSE</Keyword>
          </row>
          <row>
            <Keyword>PREDICTCASELIKELIHOOD</Keyword>
          </row>
          <row>
            <Keyword>REGRESSOR</Keyword>
          </row>
          <row>
            <Keyword>KPIVALUE</Keyword>
          </row>
          <row>
            <Keyword>KPIGOAL</Keyword>
          </row>
          <row>
            <Keyword>KPISTATUS</Keyword>
          </row>
          <row>
            <Keyword>KPITREND</Keyword>
          </row>
          <row>
            <Keyword>KPIWEIGHT</Keyword>
          </row>
          <row>
            <Keyword>KPICURRENTTIMEMEMBER</Keyword>
          </row>
          <row>
            <Keyword>BLOB</Keyword>
          </row>
          <row>
            <Keyword>EXISTING</Keyword>
          </row>
          <row>
            <Keyword>CALCULATEDMEASURE</Keyword>
          </row>
          <row>
            <Keyword>IMPORT</Keyword>
          </row>
          <row>
            <Keyword>EXPORT</Keyword>
          </row>
          <row>
            <Keyword>DEPENDENCIES</Keyword>
          </row>
          <row>
            <Keyword>STRUCTURE</Keyword>
          </row>
          <row>
            <Keyword>OPENQUERY</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMOPENSCHEMA</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETLOGICALDRIVES</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETSUBDIRS</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETFILEEXISTS</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETFILES</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETALLOWEDFOLDERS</Keyword>
          </row>
          <row>
            <Keyword>CONSTRAINED</Keyword>
          </row>
          <row>
            <Keyword>NORMALIZED</Keyword>
          </row>
          <row>
            <Keyword>NONNORMALIZED</Keyword>
          </row>
          <row>
            <Keyword>MARGINALNORMALIZED</Keyword>
          </row>
          <row>
            <Keyword>DISTANCENORMALIZED</Keyword>
          </row>
          <row>
            <Keyword>PARENT_LEVEL</Keyword>
          </row>
          <row>
            <Keyword>LCID</Keyword>
          </row>
          <row>
            <Keyword>TYPED</Keyword>
          </row>
          <row>
            <Keyword>TOP</Keyword>
          </row>
          <row>
            <Keyword>MEASUREGROUPMEASURES</Keyword>
          </row>
          <row>
            <Keyword>SLICE_EXPRESSION</Keyword>
          </row>
          <row>
            <Keyword>ADD</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMOPENQUERY</Keyword>
          </row>
          <row>
            <Keyword>CUSTOM_ROLLUP</Keyword>
          </row>
          <row>
            <Keyword>CUSTOM_ROLLUP_PROPERTIES</Keyword>
          </row>
          <row>
            <Keyword>STRTOVAL</Keyword>
          </row>
          <row>
            <Keyword>MEMBER_VALUE</Keyword>
          </row>
          <row>
            <Keyword>MEMBERVALUE</Keyword>
          </row>
          <row>
            <Keyword>NONEMPTY</Keyword>
          </row>
          <row>
            <Keyword>LANGUAGE</Keyword>
          </row>
          <row>
            <Keyword>LOG</Keyword>
          </row>
          <row>
            <Keyword>MICROSOFT_LINEAR_REGRESSION</Keyword>
          </row>
          <row>
            <Keyword>MICROSOFT_LOGISTIC_REGRESSION</Keyword>
          </row>
          <row>
            <Keyword>CUSTOMDATA</Keyword>
          </row>
          <row>
            <Keyword>CURRENTORDINAL</Keyword>
          </row>
          <row>
            <Keyword>MEMBER_KEY</Keyword>
          </row>
          <row>
            <Keyword>CATALOG_NAME</Keyword>
          </row>
          <row>
            <Keyword>URLESCAPEFRAGMENT</Keyword>
          </row>
          <row>
            <Keyword>IS_PLACEHOLDERMEMBER</Keyword>
          </row>
          <row>
            <Keyword>SCOPE_ISOLATION</Keyword>
          </row>
          <row>
            <Keyword>DISPLAY_FOLDER</Keyword>
          </row>
          <row>
            <Keyword>ASSOCIATED_MEASURE_GROUP</Keyword>
          </row>
          <row>
            <Keyword>KPI</Keyword>
          </row>
          <row>
            <Keyword>GOAL</Keyword>
          </row>
          <row>
            <Keyword>STATUS</Keyword>
          </row>
          <row>
            <Keyword>STATUS_GRAPHIC</Keyword>
          </row>
          <row>
            <Keyword>TREND</Keyword>
          </row>
          <row>
            <Keyword>TREND_GRAPHIC</Keyword>
          </row>
          <row>
            <Keyword>WEIGHT</Keyword>
          </row>
          <row>
            <Keyword>CURRENT_TIME_MEMBER</Keyword>
          </row>
          <row>
            <Keyword>PARENT_KPI</Keyword>
          </row>
          <row>
            <Keyword>STATIC</Keyword>
          </row>
          <row>
            <Keyword>DYNAMIC</Keyword>
          </row>
          <row>
            <Keyword>REPLACE_MODEL_CASES</Keyword>
          </row>
          <row>
            <Keyword>EXTEND_MODEL_CASES</Keyword>
          </row>
          <row>
            <Keyword>HOLDOUT</Keyword>
          </row>
          <row>
            <Keyword>REPEATABLE</Keyword>
          </row>
          <row>
            <Keyword>PERCENT</Keyword>
          </row>
          <row>
            <Keyword>ISTRAININGCASE</Keyword>
          </row>
          <row>
            <Keyword>ISTESTCASE</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETLIFTTABLE</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETSCATTERTABLE</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETCLASSIFICATIONMATRIX</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETSTRUCTURELIFTTABLE</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETSTRUCTURESCATTERTABLE</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETSTRUCTURECLASSIFICATIONMATRIX</Keyword>
          </row>
          <row>
            <Keyword>STRUCTURECOLUMN</Keyword>
          </row>
          <row>
            <Keyword>FOLDING</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETCROSSVALIDATIONRESULTS</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETACCURACYRESULTS</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETCLUSTERCROSSVALIDATIONRESULTS</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMGETCLUSTERACCURACYRESULTS</Keyword>
          </row>
          <row>
            <Keyword>HINT</Keyword>
          </row>
          <row>
            <Keyword>EAGER</Keyword>
          </row>
          <row>
            <Keyword>STRICT</Keyword>
          </row>
          <row>
            <Keyword>LAZY</Keyword>
          </row>
          <row>
            <Keyword>SYSTEMRESTRICTSCHEMA</Keyword>
          </row>
          <row>
            <Keyword>INCLUDE_CALC_MEMBERS</Keyword>
          </row>
          <row>
            <Keyword>AVERAGE</Keyword>
          </row>
          <row>
            <Keyword>AVERAGEX</Keyword>
          </row>
          <row>
            <Keyword>AVERAGEA</Keyword>
          </row>
          <row>
            <Keyword>COUNTA</Keyword>
          </row>
          <row>
            <Keyword>COUNTAX</Keyword>
          </row>
          <row>
            <Keyword>COUNTX</Keyword>
          </row>
          <row>
            <Keyword>COUNTROWS</Keyword>
          </row>
          <row>
            <Keyword>COUNTBLANK</Keyword>
          </row>
          <row>
            <Keyword>MAXA</Keyword>
          </row>
          <row>
            <Keyword>MAXX</Keyword>
          </row>
          <row>
            <Keyword>MINA</Keyword>
          </row>
          <row>
            <Keyword>MINX</Keyword>
          </row>
          <row>
            <Keyword>SUMX</Keyword>
          </row>
          <row>
            <Keyword>VALUES</Keyword>
          </row>
          <row>
            <Keyword>BLANK</Keyword>
          </row>
          <row>
            <Keyword>EARLIER</Keyword>
          </row>
          <row>
            <Keyword>EARLIEST</Keyword>
          </row>
          <row>
            <Keyword>FIRSTDATE</Keyword>
          </row>
          <row>
            <Keyword>LASTDATE</Keyword>
          </row>
          <row>
            <Keyword>FIRSTNONBLANK</Keyword>
          </row>
          <row>
            <Keyword>LASTNONBLANK</Keyword>
          </row>
          <row>
            <Keyword>STARTOFMONTH</Keyword>
          </row>
          <row>
            <Keyword>STARTOFQUARTER</Keyword>
          </row>
          <row>
            <Keyword>STARTOFYEAR</Keyword>
          </row>
          <row>
            <Keyword>ENDOFMONTH</Keyword>
          </row>
          <row>
            <Keyword>ENDOFQUARTER</Keyword>
          </row>
          <row>
            <Keyword>ENDOFYEAR</Keyword>
          </row>
          <row>
            <Keyword>DATESBETWEEN</Keyword>
          </row>
          <row>
            <Keyword>DATESINPERIOD</Keyword>
          </row>
          <row>
            <Keyword>PREVIOUSDAY</Keyword>
          </row>
          <row>
            <Keyword>PREVIOUSMONTH</Keyword>
          </row>
          <row>
            <Keyword>PREVIOUSQUARTER</Keyword>
          </row>
          <row>
            <Keyword>PREVIOUSYEAR</Keyword>
          </row>
          <row>
            <Keyword>NEXTDAY</Keyword>
          </row>
          <row>
            <Keyword>NEXTMONTH</Keyword>
          </row>
          <row>
            <Keyword>NEXTQUARTER</Keyword>
          </row>
          <row>
            <Keyword>NEXTYEAR</Keyword>
          </row>
          <row>
            <Keyword>DATESMTD</Keyword>
          </row>
          <row>
            <Keyword>DATESQTD</Keyword>
          </row>
          <row>
            <Keyword>DATESYTD</Keyword>
          </row>
          <row>
            <Keyword>SAMEPERIODLASTYEAR</Keyword>
          </row>
          <row>
            <Keyword>TOTALMTD</Keyword>
          </row>
          <row>
            <Keyword>TOTALQTD</Keyword>
          </row>
          <row>
            <Keyword>TOTALYTD</Keyword>
          </row>
          <row>
            <Keyword>OPENINGBALANCEMONTH</Keyword>
          </row>
          <row>
            <Keyword>OPENINGBALANCEQUARTER</Keyword>
          </row>
          <row>
            <Keyword>OPENINGBALANCEYEAR</Keyword>
          </row>
          <row>
            <Keyword>CLOSINGBALANCEMONTH</Keyword>
          </row>
          <row>
            <Keyword>CLOSINGBALANCEQUARTER</Keyword>
          </row>
          <row>
            <Keyword>CLOSINGBALANCEYEAR</Keyword>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetLiterals":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_LITERALS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="LiteralName" name="LiteralName" type="xsd:string"/>
                <xsd:element sql:field="LiteralValue" name="LiteralValue" type="xsd:string"/>
                <xsd:element sql:field="LiteralInvalidChars" name="LiteralInvalidChars" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LiteralInvalidStartingChars" name="LiteralInvalidStartingChars" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LiteralMaxLength" name="LiteralMaxLength" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="LiteralNameEnumValue" name="LiteralNameEnumValue" type="xsd:int" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <LiteralName>DBLITERAL_CATALOG_NAME</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars>.</LiteralInvalidChars>
            <LiteralInvalidStartingChars>0123456789 </LiteralInvalidStartingChars>
            <LiteralMaxLength>24</LiteralMaxLength>
            <LiteralNameEnumValue>2</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_CATALOG_SEPARATOR</LiteralName>
            <LiteralValue>.</LiteralValue>
            <LiteralInvalidChars/>
            <LiteralInvalidStartingChars/>
            <LiteralMaxLength>1</LiteralMaxLength>
            <LiteralNameEnumValue>3</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_COLUMN_ALIAS</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars>'"[]</LiteralInvalidChars>
            <LiteralInvalidStartingChars>0123456789 </LiteralInvalidStartingChars>
            <LiteralMaxLength>255</LiteralMaxLength>
            <LiteralNameEnumValue>5</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_COLUMN_NAME</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars>.</LiteralInvalidChars>
            <LiteralInvalidStartingChars>0123456789 </LiteralInvalidStartingChars>
            <LiteralMaxLength>14</LiteralMaxLength>
            <LiteralNameEnumValue>6</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_CORRELATION_NAME</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars>'"[]</LiteralInvalidChars>
            <LiteralInvalidStartingChars>0123456789 </LiteralInvalidStartingChars>
            <LiteralMaxLength>255</LiteralMaxLength>
            <LiteralNameEnumValue>7</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_PROCEDURE_NAME</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars>.</LiteralInvalidChars>
            <LiteralInvalidStartingChars>0123456789 </LiteralInvalidStartingChars>
            <LiteralMaxLength>255</LiteralMaxLength>
            <LiteralNameEnumValue>14</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_TABLE_NAME</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars>.</LiteralInvalidChars>
            <LiteralInvalidStartingChars>0123456789 </LiteralInvalidStartingChars>
            <LiteralMaxLength>24</LiteralMaxLength>
            <LiteralNameEnumValue>17</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_TEXT_COMMAND</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars/>
            <LiteralInvalidStartingChars/>
            <LiteralMaxLength>0</LiteralMaxLength>
            <LiteralNameEnumValue>18</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_USER_NAME</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars/>
            <LiteralInvalidStartingChars/>
            <LiteralMaxLength>0</LiteralMaxLength>
            <LiteralNameEnumValue>19</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_QUOTE_PREFIX</LiteralName>
            <LiteralValue>[</LiteralValue>
            <LiteralInvalidChars/>
            <LiteralInvalidStartingChars/>
            <LiteralMaxLength>1</LiteralMaxLength>
            <LiteralNameEnumValue>15</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_CUBE_NAME</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars>.</LiteralInvalidChars>
            <LiteralInvalidStartingChars>0123456789 </LiteralInvalidStartingChars>
            <LiteralMaxLength>24</LiteralMaxLength>
            <LiteralNameEnumValue>21</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_DIMENSION_NAME</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars>.</LiteralInvalidChars>
            <LiteralInvalidStartingChars>0123456789 </LiteralInvalidStartingChars>
            <LiteralMaxLength>14</LiteralMaxLength>
            <LiteralNameEnumValue>22</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_HIERARCHY_NAME</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars>.</LiteralInvalidChars>
            <LiteralInvalidStartingChars>0123456789 </LiteralInvalidStartingChars>
            <LiteralMaxLength>10</LiteralMaxLength>
            <LiteralNameEnumValue>23</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_LEVEL_NAME</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars>.</LiteralInvalidChars>
            <LiteralInvalidStartingChars>0123456789 </LiteralInvalidStartingChars>
            <LiteralMaxLength>255</LiteralMaxLength>
            <LiteralNameEnumValue>24</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_MEMBER_NAME</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars>.</LiteralInvalidChars>
            <LiteralInvalidStartingChars>0123456789 </LiteralInvalidStartingChars>
            <LiteralMaxLength>255</LiteralMaxLength>
            <LiteralNameEnumValue>25</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_PROPERTY_NAME</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars>.</LiteralInvalidChars>
            <LiteralInvalidStartingChars>0123456789 </LiteralInvalidStartingChars>
            <LiteralMaxLength>255</LiteralMaxLength>
            <LiteralNameEnumValue>26</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_QUOTE_SUFFIX</LiteralName>
            <LiteralValue>]</LiteralValue>
            <LiteralInvalidChars/>
            <LiteralInvalidStartingChars/>
            <LiteralMaxLength>1</LiteralMaxLength>
            <LiteralNameEnumValue>28</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_SCHEMA_NAME</LiteralName>
            <LiteralValue/>
            <LiteralInvalidChars>.</LiteralInvalidChars>
            <LiteralInvalidStartingChars>0123456789 </LiteralInvalidStartingChars>
            <LiteralMaxLength>24</LiteralMaxLength>
            <LiteralNameEnumValue>16</LiteralNameEnumValue>
          </row>
          <row>
            <LiteralName>DBLITERAL_SCHEMA_SEPARATOR</LiteralName>
            <LiteralValue>.</LiteralValue>
            <LiteralInvalidChars/>
            <LiteralInvalidStartingChars/>
            <LiteralMaxLength>1</LiteralMaxLength>
            <LiteralNameEnumValue>27</LiteralNameEnumValue>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetMDSchemaActions":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_ACTIONS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
          <COORDINATE>Adventure Works</COORDINATE>
          <COORDINATE_TYPE>1</COORDINATE_TYPE>
        </RestrictionList>
      </Restrictions>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="ACTION_NAME" name="ACTION_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="ACTION_TYPE" name="ACTION_TYPE" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="COORDINATE" name="COORDINATE" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="COORDINATE_TYPE" name="COORDINATE_TYPE" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="ACTION_CAPTION" name="ACTION_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CONTENT" name="CONTENT" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="APPLICATION" name="APPLICATION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="INVOCATION" name="INVOCATION" type="xsd:int" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetMDSchemaCubes":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_CUBES</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties>
        <PropertyList>
          <Catalog>Adventure Works DW 2008R2</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_TYPE" name="CUBE_TYPE" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_GUID" name="CUBE_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="CREATED_ON" name="CREATED_ON" type="xsd:dateTime" minOccurs="0"/>
                <xsd:element sql:field="LAST_SCHEMA_UPDATE" name="LAST_SCHEMA_UPDATE" type="xsd:dateTime" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_UPDATED_BY" name="SCHEMA_UPDATED_BY" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LAST_DATA_UPDATE" name="LAST_DATA_UPDATE" type="xsd:dateTime" minOccurs="0"/>
                <xsd:element sql:field="DATA_UPDATED_BY" name="DATA_UPDATED_BY" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="IS_DRILLTHROUGH_ENABLED" name="IS_DRILLTHROUGH_ENABLED" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_LINKABLE" name="IS_LINKABLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_WRITE_ENABLED" name="IS_WRITE_ENABLED" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_SQL_ENABLED" name="IS_SQL_ENABLED" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="CUBE_CAPTION" name="CUBE_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="BASE_CUBE_NAME" name="BASE_CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_SOURCE" name="CUBE_SOURCE" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="PREFERRED_QUERY_PATTERNS" name="PREFERRED_QUERY_PATTERNS" type="xsd:unsignedShort" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <CUBE_TYPE>CUBE</CUBE_TYPE>
            <LAST_SCHEMA_UPDATE>2011-06-23T23:01:05.196667</LAST_SCHEMA_UPDATE>
            <LAST_DATA_UPDATE>2011-06-24T11:57:43.523333</LAST_DATA_UPDATE>
            <DESCRIPTION/>
            <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
            <IS_LINKABLE>true</IS_LINKABLE>
            <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
            <IS_SQL_ENABLED>true</IS_SQL_ENABLED>
            <CUBE_CAPTION>Adventure Works</CUBE_CAPTION>
            <CUBE_SOURCE>1</CUBE_SOURCE>
            <PREFERRED_QUERY_PATTERNS>0</PREFERRED_QUERY_PATTERNS>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Channel Sales</CUBE_NAME>
            <CUBE_TYPE>CUBE</CUBE_TYPE>
            <LAST_SCHEMA_UPDATE>2011-06-23T23:01:05.196667</LAST_SCHEMA_UPDATE>
            <LAST_DATA_UPDATE>2011-06-24T11:57:43.523333</LAST_DATA_UPDATE>
            <DESCRIPTION/>
            <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
            <IS_LINKABLE>true</IS_LINKABLE>
            <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
            <IS_SQL_ENABLED>true</IS_SQL_ENABLED>
            <CUBE_CAPTION>Channel Sales</CUBE_CAPTION>
            <BASE_CUBE_NAME>Adventure Works</BASE_CUBE_NAME>
            <CUBE_SOURCE>1</CUBE_SOURCE>
            <PREFERRED_QUERY_PATTERNS>0</PREFERRED_QUERY_PATTERNS>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Direct Sales</CUBE_NAME>
            <CUBE_TYPE>CUBE</CUBE_TYPE>
            <LAST_SCHEMA_UPDATE>2011-06-23T23:01:05.196667</LAST_SCHEMA_UPDATE>
            <LAST_DATA_UPDATE>2011-06-24T11:57:43.523333</LAST_DATA_UPDATE>
            <DESCRIPTION/>
            <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
            <IS_LINKABLE>true</IS_LINKABLE>
            <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
            <IS_SQL_ENABLED>true</IS_SQL_ENABLED>
            <CUBE_CAPTION>Direct Sales</CUBE_CAPTION>
            <BASE_CUBE_NAME>Adventure Works</BASE_CUBE_NAME>
            <CUBE_SOURCE>1</CUBE_SOURCE>
            <PREFERRED_QUERY_PATTERNS>0</PREFERRED_QUERY_PATTERNS>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Finance</CUBE_NAME>
            <CUBE_TYPE>CUBE</CUBE_TYPE>
            <LAST_SCHEMA_UPDATE>2011-06-23T23:01:05.196667</LAST_SCHEMA_UPDATE>
            <LAST_DATA_UPDATE>2011-06-24T11:57:43.523333</LAST_DATA_UPDATE>
            <DESCRIPTION/>
            <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
            <IS_LINKABLE>true</IS_LINKABLE>
            <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
            <IS_SQL_ENABLED>true</IS_SQL_ENABLED>
            <CUBE_CAPTION>Finance</CUBE_CAPTION>
            <BASE_CUBE_NAME>Adventure Works</BASE_CUBE_NAME>
            <CUBE_SOURCE>1</CUBE_SOURCE>
            <PREFERRED_QUERY_PATTERNS>0</PREFERRED_QUERY_PATTERNS>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Mined Customers</CUBE_NAME>
            <CUBE_TYPE>CUBE</CUBE_TYPE>
            <LAST_SCHEMA_UPDATE>2011-06-23T23:01:08.363333</LAST_SCHEMA_UPDATE>
            <LAST_DATA_UPDATE>2011-06-24T11:58:13.386667</LAST_DATA_UPDATE>
            <DESCRIPTION/>
            <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
            <IS_LINKABLE>true</IS_LINKABLE>
            <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
            <IS_SQL_ENABLED>true</IS_SQL_ENABLED>
            <CUBE_CAPTION>Mined Customers</CUBE_CAPTION>
            <CUBE_SOURCE>1</CUBE_SOURCE>
            <PREFERRED_QUERY_PATTERNS>0</PREFERRED_QUERY_PATTERNS>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Sales Summary</CUBE_NAME>
            <CUBE_TYPE>CUBE</CUBE_TYPE>
            <LAST_SCHEMA_UPDATE>2011-06-23T23:01:05.196667</LAST_SCHEMA_UPDATE>
            <LAST_DATA_UPDATE>2011-06-24T11:57:43.523333</LAST_DATA_UPDATE>
            <DESCRIPTION/>
            <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
            <IS_LINKABLE>true</IS_LINKABLE>
            <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
            <IS_SQL_ENABLED>true</IS_SQL_ENABLED>
            <CUBE_CAPTION>Sales Summary</CUBE_CAPTION>
            <BASE_CUBE_NAME>Adventure Works</BASE_CUBE_NAME>
            <CUBE_SOURCE>1</CUBE_SOURCE>
            <PREFERRED_QUERY_PATTERNS>0</PREFERRED_QUERY_PATTERNS>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Sales Targets</CUBE_NAME>
            <CUBE_TYPE>CUBE</CUBE_TYPE>
            <LAST_SCHEMA_UPDATE>2011-06-23T23:01:05.196667</LAST_SCHEMA_UPDATE>
            <LAST_DATA_UPDATE>2011-06-24T11:57:43.523333</LAST_DATA_UPDATE>
            <DESCRIPTION/>
            <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
            <IS_LINKABLE>true</IS_LINKABLE>
            <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
            <IS_SQL_ENABLED>true</IS_SQL_ENABLED>
            <CUBE_CAPTION>Sales Targets</CUBE_CAPTION>
            <BASE_CUBE_NAME>Adventure Works</BASE_CUBE_NAME>
            <CUBE_SOURCE>1</CUBE_SOURCE>
            <PREFERRED_QUERY_PATTERNS>0</PREFERRED_QUERY_PATTERNS>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_CUBES</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>Adventure Works DW 2008R2</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_TYPE" name="CUBE_TYPE" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_GUID" name="CUBE_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="CREATED_ON" name="CREATED_ON" type="xsd:dateTime" minOccurs="0"/>
                <xsd:element sql:field="LAST_SCHEMA_UPDATE" name="LAST_SCHEMA_UPDATE" type="xsd:dateTime" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_UPDATED_BY" name="SCHEMA_UPDATED_BY" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LAST_DATA_UPDATE" name="LAST_DATA_UPDATE" type="xsd:dateTime" minOccurs="0"/>
                <xsd:element sql:field="DATA_UPDATED_BY" name="DATA_UPDATED_BY" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="IS_DRILLTHROUGH_ENABLED" name="IS_DRILLTHROUGH_ENABLED" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_LINKABLE" name="IS_LINKABLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_WRITE_ENABLED" name="IS_WRITE_ENABLED" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_SQL_ENABLED" name="IS_SQL_ENABLED" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="CUBE_CAPTION" name="CUBE_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="BASE_CUBE_NAME" name="BASE_CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_SOURCE" name="CUBE_SOURCE" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="PREFERRED_QUERY_PATTERNS" name="PREFERRED_QUERY_PATTERNS" type="xsd:unsignedShort" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <CUBE_TYPE>CUBE</CUBE_TYPE>
            <LAST_SCHEMA_UPDATE>2011-06-23T23:01:05.196667</LAST_SCHEMA_UPDATE>
            <LAST_DATA_UPDATE>2011-06-24T11:57:43.523333</LAST_DATA_UPDATE>
            <DESCRIPTION/>
            <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
            <IS_LINKABLE>true</IS_LINKABLE>
            <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
            <IS_SQL_ENABLED>true</IS_SQL_ENABLED>
            <CUBE_CAPTION>Adventure Works</CUBE_CAPTION>
            <CUBE_SOURCE>1</CUBE_SOURCE>
            <PREFERRED_QUERY_PATTERNS>0</PREFERRED_QUERY_PATTERNS>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetMDSchemaDimensions":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_DIMENSIONS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
          <DIMENSION_NAME>Account</DIMENSION_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>Adventure Works DW 2008R2</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_NAME" name="DIMENSION_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_GUID" name="DIMENSION_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_CAPTION" name="DIMENSION_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_ORDINAL" name="DIMENSION_ORDINAL" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_TYPE" name="DIMENSION_TYPE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_CARDINALITY" name="DIMENSION_CARDINALITY" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="DEFAULT_HIERARCHY" name="DEFAULT_HIERARCHY" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="IS_VIRTUAL" name="IS_VIRTUAL" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_READWRITE" name="IS_READWRITE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_UNIQUE_SETTINGS" name="DIMENSION_UNIQUE_SETTINGS" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_MASTER_NAME" name="DIMENSION_MASTER_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_IS_VISIBLE" name="DIMENSION_IS_VISIBLE" type="xsd:boolean" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_NAME>Account</DIMENSION_NAME>
            <DIMENSION_UNIQUE_NAME>[Account]</DIMENSION_UNIQUE_NAME>
            <DIMENSION_CAPTION>Account</DIMENSION_CAPTION>
            <DIMENSION_ORDINAL>21</DIMENSION_ORDINAL>
            <DIMENSION_TYPE>6</DIMENSION_TYPE>
            <DIMENSION_CARDINALITY>100</DIMENSION_CARDINALITY>
            <DEFAULT_HIERARCHY>[Account].[Account Number]</DEFAULT_HIERARCHY>
            <DESCRIPTION/>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_MASTER_NAME>Account</DIMENSION_MASTER_NAME>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetMDSchemaFunctions":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_FUNCTIONS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="FUNCTION_NAME" name="FUNCTION_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="PARAMETER_LIST" name="PARAMETER_LIST" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RETURN_TYPE" name="RETURN_TYPE" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="ORIGIN" name="ORIGIN" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="INTERFACE_NAME" name="INTERFACE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LIBRARY_NAME" name="LIBRARY_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DLL_NAME" name="DLL_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HELP_FILE" name="HELP_FILE" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HELP_CONTEXT" name="HELP_CONTEXT" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="OBJECT" name="OBJECT" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CAPTION" name="CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="PARAMETERINFO" name="PARAMETERINFO" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="NAME" name="NAME" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="OPTIONAL" name="OPTIONAL" type="xsd:boolean" minOccurs="0"/>
                      <xsd:element sql:field="REPEATABLE" name="REPEATABLE" type="xsd:boolean" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <FUNCTION_NAME>ADDCALCULATEDMEMBERS</FUNCTION_NAME>
            <DESCRIPTION>Returns a set generated by adding calculated members to a specified set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>ADDCALCULATEDMEMBERS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>AGGREGATE</FUNCTION_NAME>
            <DESCRIPTION>Returns a calculated value using the appropriate aggregate function, based on the aggregation type of the member.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>AGGREGATE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ALLMEMBERS</FUNCTION_NAME>
            <DESCRIPTION>Returns a set containing all members of the level, including calculated members.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT>&#171;Level&#187;</OBJECT>
            <CAPTION>ALLMEMBERS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ALLMEMBERS</FUNCTION_NAME>
            <DESCRIPTION>Returns a set containing all members of the hierarchy, including calculated members.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT>&#171;Hierarchy&#187;</OBJECT>
            <CAPTION>ALLMEMBERS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ANCESTOR</FUNCTION_NAME>
            <DESCRIPTION>Returns the ancestor of a member at a specified level.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member&#187;, &#171;Level&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>ANCESTOR</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ANCESTOR</FUNCTION_NAME>
            <DESCRIPTION>Returns the ancestor of a member at a specific distance away in the hierarchy.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member&#187;, &#171;Distance&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>ANCESTOR</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ANCESTORS</FUNCTION_NAME>
            <DESCRIPTION>Returns a set of all ancestors of a member at a specific distance above the member in the hierarchy.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member&#187;, &#171;Distance&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>ANCESTORS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ANCESTORS</FUNCTION_NAME>
            <DESCRIPTION>Returns a set of all ancestors of a member at a specified level.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member&#187;, &#171;Level&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>ANCESTORS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ASCENDANTS</FUNCTION_NAME>
            <DESCRIPTION>Returns the set of the ascendants of the member.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>ASCENDANTS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>AVG</FUNCTION_NAME>
            <DESCRIPTION>Returns the average value of a numeric expression evaluated over a set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>AVG</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>AXIS</FUNCTION_NAME>
            <DESCRIPTION>Returns a set defined in an axis.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Numeric Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>AXIS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>BOTTOMNCOUNT</FUNCTION_NAME>
            <DESCRIPTION>Returns a specified number of items from the bottom of a set, optionally sorting the set first.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Count&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>BOTTOMNCOUNT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>BOTTOMPERCENT</FUNCTION_NAME>
            <DESCRIPTION>Sorts a set and returns the specified number of bottommost elements whose cumulative total is at least a specified percentage.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Percentage&#187;, &#171;Numeric Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>BOTTOMPERCENT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>BOTTOMSUM</FUNCTION_NAME>
            <DESCRIPTION>Sorts a set and returns the specified number of bottommost elements whose cumulative total is at least a specified value.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Value&#187;, &#171;Numeric Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>BOTTOMSUM</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>CALCULATIONCURRENTPASS</FUNCTION_NAME>
            <DESCRIPTION>Returns the current calculation pass of a cube for the specified query context.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Other</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>CALCULATIONCURRENTPASS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>CALCULATIONPASSVALUE</FUNCTION_NAME>
            <DESCRIPTION>Returns the value of a numeric MDX expression evaluated over the specified calculation pass of a cube.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Numeric Expression&#187;, &#171;Pass Value&#187;[[, &#171;Access Flag&#187;], ALL]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Other</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>CALCULATIONPASSVALUE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>CHILDREN</FUNCTION_NAME>
            <DESCRIPTION>Returns the children of a member.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>CHILDREN</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>CLOSINGPERIOD</FUNCTION_NAME>
            <DESCRIPTION>Returns the last sibling among the descendants of a member at a specified level.</DESCRIPTION>
            <PARAMETER_LIST>[&#171;Level&#187;[, &#171;Member&#187;] ]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Time</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>CLOSINGPERIOD</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>COALESCEEMPTY</FUNCTION_NAME>
            <DESCRIPTION>Coalesces an empty cell value to a number.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Numeric Expression&#187;[, &#171;Numeric Expression&#187;...]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>COALESCEEMPTY</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>CORRELATION</FUNCTION_NAME>
            <DESCRIPTION>Returns the correlation of two series evaluated over a set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Numeric Expression&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>CORRELATION</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DIMENSIONS.COUNT</FUNCTION_NAME>
            <DESCRIPTION>Counts the number of hierarchies in the cube.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DIMENSIONS.COUNT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>COUNT</FUNCTION_NAME>
            <DESCRIPTION>Counts the number of members in the tuple.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT>&#171;Tuple&#187;</OBJECT>
            <CAPTION>COUNT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>COUNT</FUNCTION_NAME>
            <DESCRIPTION>Counts the number of tuples in the set.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT>&#171;Set&#187;</OBJECT>
            <CAPTION>COUNT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LEVELS.COUNT</FUNCTION_NAME>
            <DESCRIPTION>Counts the number of levels in the hierarchy.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT>&#171;Hierarchy&#187;</OBJECT>
            <CAPTION>LEVELS.COUNT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>COUNT</FUNCTION_NAME>
            <DESCRIPTION>Returns the number of tuples in a set, optionally including or excluding empty tuples.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, EXCLUDEEMPTY | INCLUDEEMPTY]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>COUNT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>COUSIN</FUNCTION_NAME>
            <DESCRIPTION>Returns the child member with the same relative position under a parent member as the specified child member.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member1&#187;, &#171;Member2&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>COUSIN</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>COVARIANCE</FUNCTION_NAME>
            <DESCRIPTION>Returns the covariance of two series evaluated over a set, using the biased population formula.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Numeric Expression&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>COVARIANCE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>COVARIANCEN</FUNCTION_NAME>
            <DESCRIPTION>Returns the covariance of two series evaluated over a set, using the unbiased population formula.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Numeric Expression&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>COVARIANCEN</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>CROSSJOIN</FUNCTION_NAME>
            <DESCRIPTION>Returns the cross product of two sets.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set1&#187;, &#171;Set2&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>CROSSJOIN</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>CURRENT</FUNCTION_NAME>
            <DESCRIPTION>Returns the current tuple from a set during an iteration.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Set&#187;</OBJECT>
            <CAPTION>CURRENT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>CURRENTMEMBER</FUNCTION_NAME>
            <DESCRIPTION>Returns the current member along a hierarchy</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Hierarchy&#187;</OBJECT>
            <CAPTION>CURRENTMEMBER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>CURRENTORDINAL</FUNCTION_NAME>
            <DESCRIPTION>Returns the current ordinal during an iteration over a set</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Set&#187;</OBJECT>
            <CAPTION>CURRENTORDINAL</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>CUSTOMDATA</FUNCTION_NAME>
            <DESCRIPTION>Returns the value of CustomData property</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Other</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>CUSTOMDATA</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DATAMEMBER</FUNCTION_NAME>
            <DESCRIPTION>Returns the system-generated data member associated with a nonleaf member.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>DATAMEMBER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DEFAULTMEMBER</FUNCTION_NAME>
            <DESCRIPTION>Returns the default member of a hierarchy.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Hierarchy&#187;</OBJECT>
            <CAPTION>DEFAULTMEMBER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DESCENDANTS</FUNCTION_NAME>
            <DESCRIPTION>Returns the set of descendants of a member at a specified level, optionally including or excluding descendants in other levels.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member&#187;[, &#171;Level&#187;[, &#171;Desc_flags&#187;]]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DESCENDANTS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DESCENDANTS</FUNCTION_NAME>
            <DESCRIPTION>Returns the set of descendants of a member at a specific distance away in the hierarchy, optionally including or excluding descendants in other levels.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member&#187;,&#171;Distance&#187;[, &#171;Desc_flags&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DESCENDANTS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DISTINCT</FUNCTION_NAME>
            <DESCRIPTION>Returns a set, removing duplicate tuples from a specified set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DISTINCT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DISTINCTCOUNT</FUNCTION_NAME>
            <DESCRIPTION>Returns the number of distinct tuples in a set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DISTINCTCOUNT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DRILLDOWNLEVEL</FUNCTION_NAME>
            <DESCRIPTION>Drills down the members of a set one level below the lowest level represented in the set, or to one level below an optional level of a member represented in the set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Level&#187; ]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>UI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DRILLDOWNLEVEL</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DRILLDOWNLEVEL</FUNCTION_NAME>
            <DESCRIPTION>Drills down the members of a set one level below the lowest level represented in the set, or to one level below a dimension optionally selected by its zero-based index of a member represented in the set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, , &#171;Index&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>UI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DRILLDOWNLEVEL</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DRILLDOWNLEVELBOTTOM</FUNCTION_NAME>
            <DESCRIPTION>Drills down the members of a specified count of bottom members of a set, at a specified level, to one level below.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Count&#187;[, [&#171;Level&#187;][, &#171;Numeric Expression&#187;] ]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>UI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DRILLDOWNLEVELBOTTOM</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DRILLDOWNLEVELTOP</FUNCTION_NAME>
            <DESCRIPTION>Drills down a specified count of top members of a set, at a specified level, to one level below.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Count&#187;[, [&#171;Level&#187;][, &#171;Numeric Expression&#187;] ]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>UI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DRILLDOWNLEVELTOP</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DRILLDOWNMEMBER</FUNCTION_NAME>
            <DESCRIPTION>Drills down the members in a specified set that are present in a second specified set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set1&#187;, &#171;Set2&#187;[, RECURSIVE]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>UI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DRILLDOWNMEMBER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DRILLDOWNMEMBERBOTTOM</FUNCTION_NAME>
            <DESCRIPTION>Drills down the members in a specified set that are present in a second specified set, limiting the result set to a specified number of bottommost members.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set1&#187;, &#171;Set2&#187;, &#171;Count&#187;[, [&#171;Numeric Expression&#187;] [, RECURSIVE] ]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>UI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DRILLDOWNMEMBERBOTTOM</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DRILLDOWNMEMBERTOP</FUNCTION_NAME>
            <DESCRIPTION>Drills down the members in a specified set that are present in a second specified set, limiting the result set to a specified number of topmost members.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set1&#187;, &#171;Set2&#187;, &#171;Count&#187;[, [&#171;Numeric Expression&#187;] [, RECURSIVE] ]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>UI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DRILLDOWNMEMBERTOP</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DRILLUPLEVEL</FUNCTION_NAME>
            <DESCRIPTION>Drills up the members of a set that are below a specified level.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Level&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>UI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DRILLUPLEVEL</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DRILLUPMEMBER</FUNCTION_NAME>
            <DESCRIPTION>Drills up the members in a specified set that are present in a second specified set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set1&#187;, &#171;Set2&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>UI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>DRILLUPMEMBER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>EXCEPT</FUNCTION_NAME>
            <DESCRIPTION>Finds the difference between two sets, optionally retaining duplicates.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set1&#187;, &#171;Set2&#187;[, ALL]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>EXCEPT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>EXISTING</FUNCTION_NAME>
            <DESCRIPTION/>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>EXISTING</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>EXISTS</FUNCTION_NAME>
            <DESCRIPTION/>
            <PARAMETER_LIST>&#171;Set1&#187;, &#171;Set2&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>EXISTS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>EXTRACT</FUNCTION_NAME>
            <DESCRIPTION>Returns a set of tuples from extracted dimension elements.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Dimension&#187;[, &#171;Dimension&#187;...]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>EXTRACT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>FILTER</FUNCTION_NAME>
            <DESCRIPTION>Returns the set resulting from filtering a set based on a search condition.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Search Condition&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>FILTER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>FIRSTCHILD</FUNCTION_NAME>
            <DESCRIPTION>Returns the first child of a specified member.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>FIRSTCHILD</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>FIRSTSIBLING</FUNCTION_NAME>
            <DESCRIPTION>Returns the first child of the parent of a specified member.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>FIRSTSIBLING</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>GENERATE</FUNCTION_NAME>
            <DESCRIPTION>Applies a set to each member of another set and joins the resulting sets by union.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set1&#187;, &#171;Set2&#187;[, ALL]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>GENERATE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>GENERATE</FUNCTION_NAME>
            <DESCRIPTION>Returns a concatenated string created by evaluating a string expression over a set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;String Expression&#187;[, &#171;Delimiter&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>String</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>GENERATE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>HEAD</FUNCTION_NAME>
            <DESCRIPTION>Returns the first specified number of elements in a set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>HEAD</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>HIERARCHIZE</FUNCTION_NAME>
            <DESCRIPTION>Orders the members of a specified set in a hierarchy in natural or, optionally, post-natural order.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, POST]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>HIERARCHIZE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>HIERARCHY</FUNCTION_NAME>
            <DESCRIPTION>Returns the hierarchy of a specified level.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT>&#171;Level&#187;</OBJECT>
            <CAPTION>HIERARCHY</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>HIERARCHY</FUNCTION_NAME>
            <DESCRIPTION>Returns the hierarchy of a specified dimension.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>HIERARCHY</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>IIF</FUNCTION_NAME>
            <DESCRIPTION>Returns one of values determined by a logical test.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Logical Expression&#187;, &#171;object&#187;,  &#171;object&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Value</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>IIF</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>INTERSECT</FUNCTION_NAME>
            <DESCRIPTION>Returns the intersection of two sets, optionally retaining duplicates.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set1&#187;, &#171;Set2&#187;[, ALL]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>INTERSECT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>IS</FUNCTION_NAME>
            <DESCRIPTION>Returns TRUE if two compared objects are equivalent, FALSE otherwise.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Value</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>IS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ISANCESTOR</FUNCTION_NAME>
            <DESCRIPTION>Returns TRUE if a specified member is an ancestor of another specified member, FALSE otherwise.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member1&#187;,&#171;Member2&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>ISANCESTOR</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ISEMPTY</FUNCTION_NAME>
            <DESCRIPTION>Returns TRUE if the evaluated expression is the empty cell value, FALSE otherwise.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Value Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Value</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>ISEMPTY</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ISGENERATION</FUNCTION_NAME>
            <DESCRIPTION>Returns TRUE if a specified member is in a specified generation, FALSE otherwise.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member&#187;,&#171;Numeric Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>ISGENERATION</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ISLEAF</FUNCTION_NAME>
            <DESCRIPTION>Returns TRUE if a specified member is a leaf member, FALSE otherwise.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>ISLEAF</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ISSIBLING</FUNCTION_NAME>
            <DESCRIPTION>Returns TRUE if a specified member is a sibling of another specified member, FALSE otherwise.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member1&#187;,&#171;Member2&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>ISSIBLING</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ITEM</FUNCTION_NAME>
            <DESCRIPTION>Returns a member from a specified tuple.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Numeric Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Other</INTERFACE_NAME>
            <OBJECT>&#171;Tuple&#187;</OBJECT>
            <CAPTION>ITEM</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ITEM</FUNCTION_NAME>
            <DESCRIPTION>Returns a tuple from a specified set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;String Expression&#187;[, &#171;String Expression&#187;...] | &#171;Index&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Other</INTERFACE_NAME>
            <OBJECT>&#171;Set&#187;</OBJECT>
            <CAPTION>ITEM</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>KPICURRENTTIMEMEMBER</FUNCTION_NAME>
            <DESCRIPTION>Returns the current time member of the KPI</DESCRIPTION>
            <PARAMETER_LIST>&#171;String Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>KPI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>KPICURRENTTIMEMEMBER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>KPIGOAL</FUNCTION_NAME>
            <DESCRIPTION>Returns the goal of the KPI.</DESCRIPTION>
            <PARAMETER_LIST>&#171;String Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>KPI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>KPIGOAL</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>KPISTATUS</FUNCTION_NAME>
            <DESCRIPTION>Returns the measure with normalized status between -1 and 1 of the KPI. </DESCRIPTION>
            <PARAMETER_LIST>&#171;String Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>KPI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>KPISTATUS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>KPITREND</FUNCTION_NAME>
            <DESCRIPTION>Returns the measure with normalized trend between -1 and 1 of the KPI</DESCRIPTION>
            <PARAMETER_LIST>&#171;String Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>KPI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>KPITREND</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>KPIVALUE</FUNCTION_NAME>
            <DESCRIPTION>Returns the measure with normalized value between -1 and 1 of the KPI</DESCRIPTION>
            <PARAMETER_LIST>&#171;String Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>KPI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>KPIVALUE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>KPIWEIGHT</FUNCTION_NAME>
            <DESCRIPTION>Returns the measure with weight of the KPI</DESCRIPTION>
            <PARAMETER_LIST>&#171;String Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>KPI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>KPIWEIGHT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LAG</FUNCTION_NAME>
            <DESCRIPTION>Returns the member that is a specified number of positions prior to a specified member along the dimension of the member.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Numeric Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>LAG</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LASTCHILD</FUNCTION_NAME>
            <DESCRIPTION>Returns the last child of a specified member.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>LASTCHILD</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LASTPERIODS</FUNCTION_NAME>
            <DESCRIPTION>Returns a set of members prior to and including a specified member.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Index&#187;[, &#171;Member&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Time</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>LASTPERIODS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LASTSIBLING</FUNCTION_NAME>
            <DESCRIPTION>Returns the last child of the parent of a specified member.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>LASTSIBLING</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LEAD</FUNCTION_NAME>
            <DESCRIPTION>Returns the member that is a specified number of positions following a specified member along the dimension of the member.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Numeric Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>LEAD</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LEVEL</FUNCTION_NAME>
            <DESCRIPTION>Returns the level of a member.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>LEVEL</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LEVELS</FUNCTION_NAME>
            <DESCRIPTION>Returns the level whose zero-based position in a dimension is specified by a numeric expression.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Numeric Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT>&#171;Hierarchy&#187;</OBJECT>
            <CAPTION>LEVELS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LINKMEMBER</FUNCTION_NAME>
            <DESCRIPTION>Returns the member equivalent to a specified member in a specified hierarchy.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member&gt;, &#171;Hierarchy&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>LINKMEMBER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LINREGINTERCEPT</FUNCTION_NAME>
            <DESCRIPTION>Calculates the linear regression of a set and returns the value of b in the regression line y = ax + b.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Numeric Expression&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>LINREGINTERCEPT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LINREGPOINT</FUNCTION_NAME>
            <DESCRIPTION>Calculates the linear regression of a set and returns the value of y in the regression line y = ax + b.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Numeric Expression&#187;, &#171;Set&#187;, &#171;Numeric Expression&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>LINREGPOINT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LINREGR2</FUNCTION_NAME>
            <DESCRIPTION>Calculates the linear regression of a set and returns R&#178; (the coefficient of determination).</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Numeric Expression&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>LINREGR2</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LINREGSLOPE</FUNCTION_NAME>
            <DESCRIPTION>Calculates the linear regression of a set and returns the value of a in the regression line y = ax + b.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Numeric Expression&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>LINREGSLOPE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LINREGVARIANCE</FUNCTION_NAME>
            <DESCRIPTION>Calculates the linear regression of a set and returns the variance associated with the regression line y = ax + b.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Numeric Expression&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>LINREGVARIANCE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>LOOKUPCUBE</FUNCTION_NAME>
            <DESCRIPTION>Returns the value of an MDX expression evaluated over another specified cube in the same database.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Cube Name&#187;, &#171;Numeric Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>LOOKUPCUBE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>MAX</FUNCTION_NAME>
            <DESCRIPTION>Returns the maximum value of a numeric expression evaluated over a set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>MAX</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>MEASUREGROUPMEASURES</FUNCTION_NAME>
            <DESCRIPTION>Returns the set of measures in the measure group.</DESCRIPTION>
            <PARAMETER_LIST>&#171;String Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>MEASUREGROUPMEASURES</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>MEDIAN</FUNCTION_NAME>
            <DESCRIPTION>Returns the median value of a numeric expression evaluated over a set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>MEDIAN</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>MEMBERS</FUNCTION_NAME>
            <DESCRIPTION>Returns the set of all members in a specified hierarchy.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT>&#171;Hierarchy&#187;</OBJECT>
            <CAPTION>MEMBERS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>MEMBERS</FUNCTION_NAME>
            <DESCRIPTION>Returns the set of all members at a specified level in a dimension.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT>&#171;Level&#187;</OBJECT>
            <CAPTION>MEMBERS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>MEMBERTOSTR</FUNCTION_NAME>
            <DESCRIPTION>Returns a string in Multidimensional Expressions (MDX) format from a member.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>String</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>MEMBERTOSTR</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>MEMBERVALUE</FUNCTION_NAME>
            <DESCRIPTION>Returns the value of a member with its original data type.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Value</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>MEMBERVALUE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>MIN</FUNCTION_NAME>
            <DESCRIPTION>Returns the minimum value of a numeric expression evaluated over a set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>MIN</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>MTD</FUNCTION_NAME>
            <DESCRIPTION>Returns a set of members from the Month level in a Time dimension starting with the first period and ending with a specified member.</DESCRIPTION>
            <PARAMETER_LIST>[&#171;Member&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Time</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>MTD</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>NAME</FUNCTION_NAME>
            <DESCRIPTION>Returns the name of a specified member.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>NAME</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>NAME</FUNCTION_NAME>
            <DESCRIPTION>Returns the name of a specified hierarchy.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT>&#171;Hierarchy&#187;</OBJECT>
            <CAPTION>NAME</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>NAME</FUNCTION_NAME>
            <DESCRIPTION>Returns the name of a specified level.</DESCRIPTION>
            <PARAMETER_LIST>Level</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT>&#171;Level&#187;</OBJECT>
            <CAPTION>NAME</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>NAMETOSET</FUNCTION_NAME>
            <DESCRIPTION>Returns a set containing a single member based on a string expression containing a member name.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member Name&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>String</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>NAMETOSET</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>NEXTMEMBER</FUNCTION_NAME>
            <DESCRIPTION>Returns the next member in the level that contains a specified member.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>NEXTMEMBER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>NONEMPTY</FUNCTION_NAME>
            <DESCRIPTION>Returns subset of first set with removed empty tuples based on the cross product with a second set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set1&#187;, &#171;Set2&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>NONEMPTY</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>NONEMPTYCROSSJOIN</FUNCTION_NAME>
            <DESCRIPTION>Returns the cross product of two or more sets as a set, excluding empty members.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set1&#187;, &#171;Set2&#187;[, &#171;Set3&#187;...][, &#171;Crossjoin Count&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>NONEMPTYCROSSJOIN</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>OPENINGPERIOD</FUNCTION_NAME>
            <DESCRIPTION>Returns the first sibling among the descendants of a specified level, optionally at a specified member.</DESCRIPTION>
            <PARAMETER_LIST>[&#171;Level&#187;[, &#171;Member&#187;] ]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Time</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>OPENINGPERIOD</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ORDER</FUNCTION_NAME>
            <DESCRIPTION>Arranges the members of a specified set, optionally preserving or breaking the hierarchy.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, {&#171;String Expression&#187; | &#171;Numeric Expression&#187;}[, ASC | DESC | BASC | BDESC]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>ORDER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ORDINAL</FUNCTION_NAME>
            <DESCRIPTION>Returns the zero-based ordinal value associated with a specified level.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT>&#171;Level&#187;</OBJECT>
            <CAPTION>ORDINAL</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>PARALLELPERIOD</FUNCTION_NAME>
            <DESCRIPTION>Returns a member from a prior period in the same relative position as a specified member.</DESCRIPTION>
            <PARAMETER_LIST>[&#171;Level&#187;[, &#171;Numeric Expression&#187;[, &#171;Member&#187;] ] ]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Time</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>PARALLELPERIOD</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>PARENT</FUNCTION_NAME>
            <DESCRIPTION>Returns the parent of a specified member.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>PARENT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>PERIODSTODATE</FUNCTION_NAME>
            <DESCRIPTION>Returns a set of members (periods) from a specified level starting with the first member and ending with a specified member.</DESCRIPTION>
            <PARAMETER_LIST>[&#171;Level&#187;[, &#171;Member&#187;] ]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Time</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>PERIODSTODATE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>PREDICT</FUNCTION_NAME>
            <DESCRIPTION>Returns a value of a numeric expression evaluated over a data mining model.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Mining Model Name&#187;, &#171;Numeric Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Other</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>PREDICT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>PREVMEMBER</FUNCTION_NAME>
            <DESCRIPTION>Returns the previous member in the level that contains a specified member.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>PREVMEMBER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>PROPERTIES</FUNCTION_NAME>
            <DESCRIPTION>Returns a string containing the value of the specified member property.</DESCRIPTION>
            <PARAMETER_LIST>&#171;String Expression&#187;[, TYPED]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>PROPERTIES</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>QTD</FUNCTION_NAME>
            <DESCRIPTION>Returns a set of members from the Quarter level in a Time dimension starting with the first period and ending with a specified member.</DESCRIPTION>
            <PARAMETER_LIST>[&#171;Member&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Time</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>QTD</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>RANK</FUNCTION_NAME>
            <DESCRIPTION>Returns the one-based rank of a specified tuple in a specified set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Tuple&#187;, &#171;Set&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>RANK</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>ROLLUPCHILDREN</FUNCTION_NAME>
            <DESCRIPTION>Returns a value generated by rolling up the values of the children of a specified member using the specified unary operator.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Member&#187;, &#171;String Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>ROLLUPCHILDREN</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>SETTOARRAY</FUNCTION_NAME>
            <DESCRIPTION>Converts one or more sets to an array for use in a user-defined function.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Set&#187;...][, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Other</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>SETTOARRAY</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>SETTOSTR</FUNCTION_NAME>
            <DESCRIPTION>Constructs a string in MDX format from a set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>String</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>SETTOSTR</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>SIBLINGS</FUNCTION_NAME>
            <DESCRIPTION>Returns the set of siblings of a specified member, including the member itself.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>SIBLINGS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>STDDEV</FUNCTION_NAME>
            <DESCRIPTION>Returns the standard deviation of a numeric expression evaluated over a set, using an unbiased population. (Alias for Stdev.)</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>STDDEV</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>STDDEVP</FUNCTION_NAME>
            <DESCRIPTION>Returns the standard deviation of a numeric expression evaluated over a set, using a biased population. (Alias for StdevP.)</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>STDDEVP</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>STDEVP</FUNCTION_NAME>
            <DESCRIPTION>Returns the standard deviation of a numeric expression evaluated over a set, using an unbiased population.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>STDEVP</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>STDEVP</FUNCTION_NAME>
            <DESCRIPTION>Returns the standard deviation of a numeric expression evaluated over a set, using a biased population.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>STDEVP</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>STRIPCALCULATEDMEMBERS</FUNCTION_NAME>
            <DESCRIPTION>Returns a set generated by removing calculated members from a specified set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>STRIPCALCULATEDMEMBERS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>STRTOMEMBER</FUNCTION_NAME>
            <DESCRIPTION>Returns a member from a string expression in MDX format.</DESCRIPTION>
            <PARAMETER_LIST>&#171;String Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>String</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>STRTOMEMBER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>STRTOSET</FUNCTION_NAME>
            <DESCRIPTION>Constructs a set from a specified string expression in MDX format.</DESCRIPTION>
            <PARAMETER_LIST>&#171;String Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>String</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>STRTOSET</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>STRTOTUPLE</FUNCTION_NAME>
            <DESCRIPTION>Constructs a tuple from a specified string expression in MDX format.</DESCRIPTION>
            <PARAMETER_LIST>&#171;String Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>String</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>STRTOTUPLE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>STRTOVALUE</FUNCTION_NAME>
            <DESCRIPTION>Returns a value from a string expression.</DESCRIPTION>
            <PARAMETER_LIST>&#171;String Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>String</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>STRTOVALUE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>SUBSET</FUNCTION_NAME>
            <DESCRIPTION>Returns a subset of members from a specified set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Start&#187;[, &#171;Count&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>SUBSET</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>SUM</FUNCTION_NAME>
            <DESCRIPTION>Returns the sum of a numeric expression evaluated over a specified set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>SUM</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>TAIL</FUNCTION_NAME>
            <DESCRIPTION>Returns a subset of members from the end of a specified set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Count&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>TAIL</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>TOGGLEDRILLSTATE</FUNCTION_NAME>
            <DESCRIPTION>Toggles the drill state of members.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set1&#187;, &#171;Set2&#187;[, RECURSIVE]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>UI</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>TOGGLEDRILLSTATE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>TOPCOUNT</FUNCTION_NAME>
            <DESCRIPTION>Returns a specified number of items from the topmost members of a specified set, optionally ordering the set first.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Count&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>TOPCOUNT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>TOPPERCENT</FUNCTION_NAME>
            <DESCRIPTION>Sorts a set and returns the topmost elements whose cumulative total is at least a specified percentage.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Percentage&#187;, &#171;Numeric Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>TOPPERCENT</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>TOPSUM</FUNCTION_NAME>
            <DESCRIPTION>Sorts a set and returns the topmost elements whose cumulative total is at least a specified value.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Value&#187;, &#171;Numeric Expression&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>TOPSUM</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>TUPLETOSTR</FUNCTION_NAME>
            <DESCRIPTION>Returns a string in MDX format from a specified tuple.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Tuple&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>String</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>TUPLETOSTR</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>UNION</FUNCTION_NAME>
            <DESCRIPTION>Returns a set generated by the union of two sets, optionally retaining duplicate members.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set1&#187;, &#171;Set2&#187;[, ALL]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>UNION</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>UNIQUENAME</FUNCTION_NAME>
            <DESCRIPTION>Returns the unique name of a specified hierarchy.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT>&#171;Hierarchy&#187;</OBJECT>
            <CAPTION>UNIQUENAME</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>UNIQUENAME</FUNCTION_NAME>
            <DESCRIPTION>Returns the unique name of a specified member.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT>&#171;Member&#187;</OBJECT>
            <CAPTION>UNIQUENAME</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>UNIQUENAME</FUNCTION_NAME>
            <DESCRIPTION>Returns the unique name of a specified level.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Metadata</INTERFACE_NAME>
            <OBJECT>&#171;Level&#187;</OBJECT>
            <CAPTION>UNIQUENAME</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>UNKNOWNMEMBER</FUNCTION_NAME>
            <DESCRIPTION>Returns the domain name and user name of the current connection.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Navigation</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>UNKNOWNMEMBER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>UNORDER</FUNCTION_NAME>
            <DESCRIPTION>Returns a set without ordering.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Set</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>UNORDER</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>VALIDMEASURE</FUNCTION_NAME>
            <DESCRIPTION>Returns a value computed at the granularity of the measure group without unrelated dimensions and/or attributes.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Tuple&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Value</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>VALIDMEASURE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>VALUE</FUNCTION_NAME>
            <DESCRIPTION>Returns the value of a specified member.</DESCRIPTION>
            <PARAMETER_LIST>(none)</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Value</INTERFACE_NAME>
            <OBJECT>&#171;Tuple&#187;</OBJECT>
            <CAPTION>VALUE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>VAR</FUNCTION_NAME>
            <DESCRIPTION>Returns the variance of a numeric expression evaluated over a set, using an unbiased population.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>VAR</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>VARIANCE</FUNCTION_NAME>
            <DESCRIPTION>Returns the variance of a numeric expression evaluated over a set, using an unbiased population. (Alias for Var function.)</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>VARIANCE</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>VARIANCEP</FUNCTION_NAME>
            <DESCRIPTION>Returns the variance of a numeric expression evaluated over a set, using a biased population. (Alias for VarP function.)</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>VARIANCEP</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>VARP</FUNCTION_NAME>
            <DESCRIPTION>Returns the variance of a numeric expression evaluated over a set, using a biased population.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;[, &#171;Numeric Expression&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>VARP</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>VISUALTOTALS</FUNCTION_NAME>
            <DESCRIPTION>Returns a set generated by dynamically totaling child members in a specified set, optionally using a pattern for the name of the parent member in the result set.</DESCRIPTION>
            <PARAMETER_LIST>&#171;Set&#187;, &#171;Pattern&#187;</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Statistical</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>VISUALTOTALS</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>WTD</FUNCTION_NAME>
            <DESCRIPTION>Returns a set of members from the Week level in a Time dimension starting with the first period and ending with a specified member.</DESCRIPTION>
            <PARAMETER_LIST>[&#171;Member&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Time</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>WTD</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>YTD</FUNCTION_NAME>
            <DESCRIPTION>Returns a set of members from the Year level in a Time dimension starting with the first period and ending with a specified member.</DESCRIPTION>
            <PARAMETER_LIST>[&#171;Member&#187;]</PARAMETER_LIST>
            <RETURN_TYPE>12</RETURN_TYPE>
            <ORIGIN>1</ORIGIN>
            <INTERFACE_NAME>Time</INTERFACE_NAME>
            <OBJECT/>
            <CAPTION>YTD</CAPTION>
          </row>
          <row>
            <FUNCTION_NAME>DATE</FUNCTION_NAME>
            <DESCRIPTION>Gibt das angegebene Datum im datetime-Format zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Jahr</NAME>
              <DESCRIPTION>Eine vierstellige Zahl, die das Jahr darstellt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Monat</NAME>
              <DESCRIPTION>Eine Zahl zwischen 1 und 12, die den Monat des Jahres darstellt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Tag</NAME>
              <DESCRIPTION>Eine Zahl zwischen 1 und 31, die den Tag des Monats darstellt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>DATEVALUE</FUNCTION_NAME>
            <DESCRIPTION>Konvertiert ein Datum im Textformat in ein Datum im datetime-Format.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Datumstext</NAME>
              <DESCRIPTION>Eine Textzeichenfolge, die ein Datum darstellt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>DAY</FUNCTION_NAME>
            <DESCRIPTION>Gibt eine Zahl zwischen 1 und 31 zur&#252;ck, die den Tag des Monats darstellt.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Datum</NAME>
              <DESCRIPTION>Ein Datum im datetime-Format.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>EDATE</FUNCTION_NAME>
            <DESCRIPTION>Gibt das Datum zur&#252;ck, das der angegebenen Anzahl von Monaten vor oder nach dem Ausgangsdatum entspricht.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Ausgangsdatum</NAME>
              <DESCRIPTION>Ein Datum im datetime-Format, das das Ausgangsdatum darstellt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Monate</NAME>
              <DESCRIPTION>Die Anzahl der Monate vor oder nach 'Ausgangsdatum'.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>EOMONTH</FUNCTION_NAME>
            <DESCRIPTION>Gibt das Datum des letzten Tags des Monats vor oder nach einer angegebenen Anzahl von Monaten im datetime-Format zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Ausgangsdatum</NAME>
              <DESCRIPTION>Das Ausgangsdatum im datetime-Format.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Monate</NAME>
              <DESCRIPTION>Die Anzahl der Monate vor oder nach 'Ausgangsdatum'.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>HOUR</FUNCTION_NAME>
            <DESCRIPTION>Gibt die Stunde als eine Zahl zwischen 0 (00:00 Uhr) und 23 (23:00 Uhr) zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>datetime</NAME>
              <DESCRIPTION>Ein datetime-Wert oder Text im Uhrzeitformat, z.B. 16:48:00 Uhr.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>MINUTE</FUNCTION_NAME>
            <DESCRIPTION>Gibt eine Zahl zwischen 0 und 59 zur&#252;ck, die die Minute darstellt.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>datetime</NAME>
              <DESCRIPTION>Ein datetime-Wert oder Text im Uhrzeitformat, z.B. 16:48:00 Uhr.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>MONTH</FUNCTION_NAME>
            <DESCRIPTION>Gibt eine Zahl zwischen 1 (Januar) und 12 (Dezember) zur&#252;ck, die den Monat darstellt.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Datum</NAME>
              <DESCRIPTION>Ein Datum im datetime-Format.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>NOW</FUNCTION_NAME>
            <DESCRIPTION>Gibt das aktuelle Datum und die aktuelle Uhrzeit im datetime-Format zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
          </row>
          <row>
            <FUNCTION_NAME>SECOND</FUNCTION_NAME>
            <DESCRIPTION>Gibt eine Zahl zwischen 0 und 59 zur&#252;ck, die die Sekunde darstellt.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Uhrzeit</NAME>
              <DESCRIPTION>Die Uhrzeit im datetime-Format oder Text im Uhrzeitformat, z.B. 16:48:23 Uhr.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>TIME</FUNCTION_NAME>
            <DESCRIPTION>Konvertiert als Stunden, Minuten und Sekunden angegebene Zahlen in eine Uhrzeit im datetime-Format.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Stunde</NAME>
              <DESCRIPTION>Eine Zahl zwischen 0 und 23, die die Stunde darstellt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Minute</NAME>
              <DESCRIPTION>Eine Zahl zwischen 0 und 59, die die Minute darstellt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Sekunde</NAME>
              <DESCRIPTION>Eine Zahl zwischen 0 und 59, die die Sekunde darstellt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>TIMEVALUE</FUNCTION_NAME>
            <DESCRIPTION>Konvertiert eine Uhrzeit im Textformat in eine Uhrzeit im datetime-Format.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zeit</NAME>
              <DESCRIPTION>Eine Textzeichenfolge, die eine Uhrzeit angibt; Datumsinformationen in der Zeichenfolge werden ignoriert.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>TODAY</FUNCTION_NAME>
            <DESCRIPTION>Gibt das aktuelle Datum im datetime-Format zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
          </row>
          <row>
            <FUNCTION_NAME>WEEKDAY</FUNCTION_NAME>
            <DESCRIPTION>Gibt eine Zahl zwischen 1 und 7 zur&#252;ck, die den Wochentag eines Datums angibt.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Datum</NAME>
              <DESCRIPTION>Ein Datum im datetime-Format.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Typ</NAME>
              <DESCRIPTION>Eine Zahl, die den R&#252;ckgabewert bestimmt: 1 f&#252;r Sonntag=1 bis Samstag=7; 2 f&#252;r Montag=1 bis Sonntag=7, 3 f&#252;r Montag=0 bis Sonntag=6</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>WEEKNUM</FUNCTION_NAME>
            <DESCRIPTION>Gibt die Wochenzahl f&#252;r das Jahr zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Datum</NAME>
              <DESCRIPTION>Ein Datum im datetime-Format.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Typ</NAME>
              <DESCRIPTION>Eine Zahl, die den R&#252;ckgabewert bestimmt: Verwenden Sie '1', wenn die Woche am Sonntag beginnt, oder '2', wenn sie am Montag beginnt.</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>YEAR</FUNCTION_NAME>
            <DESCRIPTION>Gibt die Jahresangabe eines Datums als vierstellige ganze Zahl zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Datum</NAME>
              <DESCRIPTION>Ein Datum im datetime-Format.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>YEARFRAC</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Bruchteil von Jahren zur&#252;ck, der die Anzahl der ganzen Tage zwischen 'Ausgangsdatum' und 'Enddatum' darstellt.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Ausgangsdatum</NAME>
              <DESCRIPTION>Das Ausgangsdatum im datetime-Format.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Enddatum</NAME>
              <DESCRIPTION>Das Enddatum im datetime-Format.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Basis</NAME>
              <DESCRIPTION>Die Basis, auf der die Zinstage gez&#228;hlt werden.</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ISBLANK</FUNCTION_NAME>
            <DESCRIPTION>&#220;berpr&#252;ft, ob ein Wert leer ist, und gibt TRUE oder FALSE zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>INFO</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Wert</NAME>
              <DESCRIPTION>Der Wert, den Sie testen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ISERROR</FUNCTION_NAME>
            <DESCRIPTION>&#220;berpr&#252;ft, ob ein Wert fehlerhaft ist, und gibt TRUE oder FALSE zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>INFO</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Wert</NAME>
              <DESCRIPTION>Der Wert, den Sie testen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ISLOGICAL</FUNCTION_NAME>
            <DESCRIPTION>&#220;berpr&#252;ft, ob ein Wert ein Wahrheitswert (TRUE oder FALSE) ist, und gibt TRUE oder FALSE zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>INFO</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Wert</NAME>
              <DESCRIPTION>Der Wert, den Sie testen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ISNONTEXT</FUNCTION_NAME>
            <DESCRIPTION>&#220;berpr&#252;ft, ob es sich bei einem Wert nicht um Text handelt (leere Zellen sind kein Text), und gibt TRUE oder FALSE zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>INFO</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Wert</NAME>
              <DESCRIPTION>Der Wert, den Sie testen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ISNUMBER</FUNCTION_NAME>
            <DESCRIPTION>&#220;berpr&#252;ft, ob ein Wert eine Zahl ist, und gibt TRUE oder FALSE zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>INFO</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Wert</NAME>
              <DESCRIPTION>Der Wert, den Sie testen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ISTEXT</FUNCTION_NAME>
            <DESCRIPTION>&#220;berpr&#252;ft, ob es sich bei einem Wert um Text handelt, und gibt TRUE oder FALSE zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>INFO</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Wert</NAME>
              <DESCRIPTION>Der Wert, den Sie testen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>AND</FUNCTION_NAME>
            <DESCRIPTION>&#220;berpr&#252;ft, ob alle Argumente TRUE sind, und gibt in diesem Fall TRUE zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>LOGICAL</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Logisch1</NAME>
              <DESCRIPTION>Die Wahrheitswerte, die Sie testen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Logisch2</NAME>
              <DESCRIPTION>Die Wahrheitswerte, die Sie testen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>FALSE</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Wahrheitswert FALSE zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>LOGICAL</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
          </row>
          <row>
            <FUNCTION_NAME>IF</FUNCTION_NAME>
            <DESCRIPTION>&#220;berpr&#252;ft, ob eine Bedingung erf&#252;llt ist, und gibt bei TRUE einen anderen Wert als bei FALSE zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>LOGICAL</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Wahrheitspr&#252;fung</NAME>
              <DESCRIPTION>Ein beliebiger Wert oder Ausdruck, der TRUE oder FALSE sein kann.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Wert_falls_true</NAME>
              <DESCRIPTION>Der Wert, der zur&#252;ckgegeben wird, wenn die Wahrheitspr&#252;fung TRUE ergibt; falls nicht angegeben, wird TRUE zur&#252;ckgegeben.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Wert_falls_false</NAME>
              <DESCRIPTION>Der Wert, der zur&#252;ckgegeben wird, wenn die Wahrheitspr&#252;fung FALSE ergibt; falls nicht angegeben, wird FALSE zur&#252;ckgegeben.</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>IFERROR</FUNCTION_NAME>
            <DESCRIPTION>Gibt 'Wert_falls_Fehler' zur&#252;ck, wenn der erste Ausdruck fehlerhaft ist, und andernfalls den Wert des Ausdrucks selbst. </DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>LOGICAL</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Wert</NAME>
              <DESCRIPTION>Beliebiger Wert oder Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Wert_falls_Fehler</NAME>
              <DESCRIPTION>Beliebiger Wert oder Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>NOT</FUNCTION_NAME>
            <DESCRIPTION>&#196;ndert FALSE in TRUE bzw. TRUE in FALSE.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>LOGICAL</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Logisch</NAME>
              <DESCRIPTION>Ein Wert oder Ausdruck, der TRUE oder FALSE annehmen kann.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>OR</FUNCTION_NAME>
            <DESCRIPTION>Gibt TRUE zur&#252;ck, wenn ein beliebiges Argument TRUE ist, und FALSE, wenn alle Argumente FALSE sind.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>LOGICAL</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Logisch1</NAME>
              <DESCRIPTION>Die Wahrheitswerte, die Sie testen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Logisch2</NAME>
              <DESCRIPTION>Die Wahrheitswerte, die Sie testen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>TRUE</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Wahrheitswert TRUE zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>LOGICAL</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
          </row>
          <row>
            <FUNCTION_NAME>ABS</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Absolutwert einer Zahl zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Die Zahl, deren Absolutwert Sie ermitteln m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>CEILING</FUNCTION_NAME>
            <DESCRIPTION>Rundet eine Zahl auf die n&#228;chste ganze Zahl oder die n&#228;chste Schritteinheit auf.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Der Wert, den Sie runden m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Schritt</NAME>
              <DESCRIPTION>Das Vielfache, auf das Sie runden m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>EXP</FUNCTION_NAME>
            <DESCRIPTION>Potenziert die Basis e mit der angegebenen Zahl.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Der Exponent zur Basis e. Die Konstante e entspricht 2.71828182845904, der Basis der nat&#252;rlichen Logarithmen.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>FACT</FUNCTION_NAME>
            <DESCRIPTION>Gibt die Fakult&#228;t einer Zahl zur&#252;ck (Fakult&#228;t n = 1*2*3...*n).</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Die nicht negative Zahl, deren Fakult&#228;t Sie berechnen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>FLOOR</FUNCTION_NAME>
            <DESCRIPTION>Rundet eine Zahl gegen 0 (null) auf das n&#228;chstliegende Vielfache von 'Schritt' ab.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Die Zahl, die Sie runden m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Schritt</NAME>
              <DESCRIPTION>Das Vielfache, auf das Sie runden m&#246;chten. 'Zahl' und 'Schritt' m&#252;ssen beide entweder positiv oder negativ sein.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>INT</FUNCTION_NAME>
            <DESCRIPTION>Rundet eine Zahl auf die n&#228;chstkleinere ganze Zahl ab.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Die Zahl, die Sie auf eine ganze Zahl abrunden m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ISO.CEILING</FUNCTION_NAME>
            <DESCRIPTION>Rundet eine Zahl auf die n&#228;chste ganze Zahl oder das n&#228;chste Vielfache von 'Schritt' auf.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Der Wert, den Sie runden m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Schritt</NAME>
              <DESCRIPTION>Das Vielfache, auf das Sie runden m&#246;chten.</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>LN</FUNCTION_NAME>
            <DESCRIPTION>Gibt den nat&#252;rlichen Logarithmus einer Zahl zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Die positive Zahl, f&#252;r die Sie den nat&#252;rlichen Logarithmus berechnen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>LOG</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Logarithmus einer Zahl zu der angegebenen Basis zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Die positive Zahl, f&#252;r die Sie den Logarithmus berechnen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Basis</NAME>
              <DESCRIPTION>Die Basis des Logarithmus; falls nicht angegeben, 10.</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>LOG10</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Logarithmus einer Zahl zur Basis 10 zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Die positive Zahl, f&#252;r die Sie den Logarithmus einer Zahl zur Basis 10 berechnen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>MOD</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Rest zur&#252;ck, der nach der Division einer Zahl durch einen Divisor &#252;brig bleibt.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Die Zahl, deren Rest aus einer Division Sie wissen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Divisor</NAME>
              <DESCRIPTION>Die Zahl, durch die dividiert werden soll.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>MROUND</FUNCTION_NAME>
            <DESCRIPTION>Gibt eine auf das gew&#252;nschte Vielfache gerundete Zahl zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Der zu rundende Wert</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Vielfaches</NAME>
              <DESCRIPTION>Das Vielfache, auf das Sie die Zahl runden m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>PI</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Wert Pi, 3.14159265358979, mit 15 Stellen Genauigkeit zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
          </row>
          <row>
            <FUNCTION_NAME>POWER</FUNCTION_NAME>
            <DESCRIPTION>Gibt als Ergebnis eine potenzierte Zahl zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Die Basiszahl</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Potenz</NAME>
              <DESCRIPTION>Der Exponent, auf den die Basiszahl potenziert wird.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>QUOTIENT</FUNCTION_NAME>
            <DESCRIPTION>Gibt den ganzzahligen Anteil einer Division zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Z&#228;hler</NAME>
              <DESCRIPTION>Der Dividend</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Nenner</NAME>
              <DESCRIPTION>Der Divisor</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>RAND</FUNCTION_NAME>
            <DESCRIPTION>Gibt eine gleichm&#228;&#223;ig verteilte Zufallszahl gr&#246;&#223;er oder gleich 0 und kleiner 1 zur&#252;ck. Zufallszahlen &#228;ndern sich bei der Neuberechnung.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
          </row>
          <row>
            <FUNCTION_NAME>RANDBETWEEN</FUNCTION_NAME>
            <DESCRIPTION>Gibt eine Zufallszahl zur&#252;ck, die zwischen den angegebenen Zahlen liegt.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Untere_Zahl</NAME>
              <DESCRIPTION>Die kleinste ganze Zahl, die von ZUFALLSBEREICH zur&#252;ckgegeben wird.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Obere_Zahl</NAME>
              <DESCRIPTION>Die gr&#246;&#223;te ganze Zahl, die von ZUFALLSBEREICH zur&#252;ckgegeben wird.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ROUND</FUNCTION_NAME>
            <DESCRIPTION>Rundet eine Zahl auf eine angegebene Anzahl von Stellen auf.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Die Zahl, die Sie runden m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Anzahl_Stellen</NAME>
              <DESCRIPTION>Die Anzahl der Dezimalstellen, auf die Sie runden m&#246;chten. Bei negativen Werten wird auf ganze Zehnerpotenzen und bei 0 auf die n&#228;chste ganze Zahl gerundet.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ROUNDDOWN</FUNCTION_NAME>
            <DESCRIPTION>Rundet eine Zahl gegen 0 (null) ab.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Eine reelle Zahl, die Sie abrunden m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Anzahl_Stellen</NAME>
              <DESCRIPTION>Die Anzahl der Dezimalstellen, auf die Sie runden m&#246;chten. Bei negativen Werten wird auf ganze Zehnerpotenzen und bei 0, oder wenn kein Wert angegeben wird, auf die n&#228;chste ganze Zahl gerundet.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ROUNDUP</FUNCTION_NAME>
            <DESCRIPTION>Rundet die Zahl auf 'Anzahl_Stellen' auf.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Eine reelle Zahl, die Sie aufrunden m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Anzahl_Stellen</NAME>
              <DESCRIPTION>Die Anzahl der Dezimalstellen, auf die Sie runden m&#246;chten. Bei negativen Werten wird auf ganze Zehnerpotenzen und bei 0, oder wenn kein Wert angegeben wird, auf die n&#228;chste ganze Zahl gerundet.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>SIGN</FUNCTION_NAME>
            <DESCRIPTION>Gibt das Vorzeichen einer Zahl zur&#252;ck: 1, wenn die Zahl positiv ist; 0, wenn die Zahl 0 ist; oder -1, wenn die Zahl negativ ist.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Eine beliebige reelle Zahl.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>SQRT</FUNCTION_NAME>
            <DESCRIPTION>Gibt die Quadratwurzel einer Zahl zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Die Zahl, deren Quadratwurzel Sie berechnen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>TRUNC</FUNCTION_NAME>
            <DESCRIPTION>Schneidet die Kommastellen der Zahl ab und gibt als Ergebnis eine ganze Zahl zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Die Zahl, deren Stellen Sie abschneiden m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Anzahl_Stellen</NAME>
              <DESCRIPTION>Eine Zahl, die angibt, wie viele Nachkommastellen erhalten bleiben sollen; wenn nicht angegeben, 0 (null).</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>BLANK</FUNCTION_NAME>
            <DESCRIPTION>Gibt ein Leerzeichen zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
          </row>
          <row>
            <FUNCTION_NAME>CONCATENATE</FUNCTION_NAME>
            <DESCRIPTION>Verbindet zwei Textzeichenfolgen zu einer Textzeichenfolge.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Text1</NAME>
              <DESCRIPTION>Die erste Textzeichenfolge, die zu einer einzelnen Textzeichenfolge verkn&#252;pft werden soll. Zeichenfolgen k&#246;nnen Text oder Zahlen enthalten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Text2</NAME>
              <DESCRIPTION>Die erste Textzeichenfolge, die zu einer einzelnen Textzeichenfolge verkn&#252;pft werden soll. Zeichenfolgen k&#246;nnen Text oder Zahlen enthalten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>EXACT</FUNCTION_NAME>
            <DESCRIPTION>&#220;berpr&#252;ft, ob zwei Textzeichenfolgen genau &#252;bereinstimmen und gibt TRUE oder FALSE zur&#252;ck. Bei EXACT wird Gro&#223;- und Kleinschreibung beachtet.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Text1</NAME>
              <DESCRIPTION>Die erste Textzeichenfolge</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Text2</NAME>
              <DESCRIPTION>Die zweite Textzeichenfolge</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>FIND</FUNCTION_NAME>
            <DESCRIPTION>Gibt die Ausgangsposition einer Textzeichenfolge innerhalb einer anderen Textzeichenfolge zur&#252;ck. Bei FIND wird Gro&#223;- und Kleinschreibung beachtet.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Suchtext</NAME>
              <DESCRIPTION>Der Text, den Sie suchen m&#246;chten. Verwenden Sie doppelte Anf&#252;hrungszeichen (leerer Text), um eine &#220;bereinstimmung mit dem ersten Zeichen in "In_Text" zu erzielen; Platzhalterzeichen sind nicht zul&#228;ssig.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>In_Text</NAME>
              <DESCRIPTION>Der Text, der den zu suchenden Text enth&#228;lt</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Start_Zahl</NAME>
              <DESCRIPTION>Der Zeichensatz, an dem die Suche beginnen soll. Wenn der Zeichensatz ausgelassen wird, gilt Start_Zahl = 1. Das erste Zeichen in "In_Text" ist die Zeichennummer 1.</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>FIXED</FUNCTION_NAME>
            <DESCRIPTION>Rundet eine Zahl auf die angegebene Anzahl von Dezimalstellen und gibt das Ergebnis als Text mit optionalen Kommas zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Zahl</NAME>
              <DESCRIPTION>Die Zahl, die Sie runden und in Text konvertieren m&#246;chten</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Dezimalstellen</NAME>
              <DESCRIPTION>Die Anzahl der Ziffern rechts neben der Dezimalstelle; bei Auslassung 2</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Keine_Kommas</NAME>
              <DESCRIPTION>Ein logischer Wert: Wenn der Wert TRUE ergibt, werden im zur&#252;ckgegebenen Text keine Kommas angezeigt; wenn der Wert FALSE ergibt oder ausgelassen wird, werden Kommas im zur&#252;ckgegebenen Text angezeigt.</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>FORMAT</FUNCTION_NAME>
            <DESCRIPTION>Konvertiert einen Wert in Text im angegebenen Zahlenformat.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Wert</NAME>
              <DESCRIPTION>Eine Zahl oder eine Formel, die einen numerischen Wert ergibt</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Format_Text</NAME>
              <DESCRIPTION>Ein angegebenes Zahlenformat</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>LEFT</FUNCTION_NAME>
            <DESCRIPTION>Gibt die angegebene Anzahl von Zeichen vom Anfang einer Textzeichenfolge zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Text</NAME>
              <DESCRIPTION>Die Textzeichenfolge, die die zu extrahierenden Zeichen enth&#228;lt</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Anzahl_Zeichen</NAME>
              <DESCRIPTION>Die Anzahl der Zeichen, die Sie mit LEFT extrahieren m&#246;chten; bei Auslassung wird 1 angenommen</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>LEN</FUNCTION_NAME>
            <DESCRIPTION>Gibt die Anzahl der Zeichen in einer Textzeichenfolge zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Text</NAME>
              <DESCRIPTION>Der Text, dessen L&#228;nge Sie suchen m&#246;chten. Leerzeichen werden als Zeichen gewertet.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>LOWER</FUNCTION_NAME>
            <DESCRIPTION>Konvertiert alle Buchstaben in einer Textzeichenfolge in Kleinbuchstaben.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Text</NAME>
              <DESCRIPTION>Der Text, der in Kleinbuchstaben konvertiert werden soll. Zeichen, bei denen es sich nicht um Buchstaben handelt, werden nicht ge&#228;ndert.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>MID</FUNCTION_NAME>
            <DESCRIPTION>Gibt eine Zeichenfolge von Zeichen aus der Mitte einer Textzeichenfolge zur&#252;ck, sofern Ausgangsposition und L&#228;nge angegeben wurden.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Text</NAME>
              <DESCRIPTION>Die Textzeichenfolge, aus der Sie die Zeichen extrahieren m&#246;chten</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Start_Zahl</NAME>
              <DESCRIPTION>Die Position des ersten zu extrahierenden Zeichens. Positionen beginnen bei 1.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Anzahl_Zeichen</NAME>
              <DESCRIPTION>Die Anzahl der zur&#252;ckzugebenden Zeichen</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>REPLACE</FUNCTION_NAME>
            <DESCRIPTION>Ersetzt einen Teil einer Textzeichenfolge durch eine andere Textzeichenfolge.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Alter_Text</NAME>
              <DESCRIPTION>Die Zeichenfolge des Texts, der die zu ersetzenden Zeichen enth&#228;lt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Start_Zahl</NAME>
              <DESCRIPTION>Die Position des Zeichens in "Alter_Text", den Sie durch "Neuer_Text" ersetzen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Anzahl_Zeichen</NAME>
              <DESCRIPTION>Die Anzahl der zu ersetzenden Zeichen</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Neuer_Text</NAME>
              <DESCRIPTION>Der Ersetzungstext</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>REPT</FUNCTION_NAME>
            <DESCRIPTION>Wiederholt Text mit einer angegebenen H&#228;ufigkeit. Verwenden Sie REPT, um eine Zelle mit einer Reihe von Instanzen einer Textzeichenfolge auszuf&#252;llen.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Text</NAME>
              <DESCRIPTION>Der zu wiederholende Text</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Anzahl_Wiederholungen</NAME>
              <DESCRIPTION>Eine positive Zahl, die die Anzahl der Textwiederholungen angibt</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>RIGHT</FUNCTION_NAME>
            <DESCRIPTION>Gibt die angegebene Anzahl von Zeichen vom Ende einer Textzeichenfolge zur&#252;ck.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Text</NAME>
              <DESCRIPTION>Die Textzeichenfolge, die die zu extrahierenden Zeichen enth&#228;lt</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Anzahl_Zeichen</NAME>
              <DESCRIPTION>Die Anzahl der Zeichen, die Sie extrahieren m&#246;chten; bei Auslassung 1</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>SEARCH</FUNCTION_NAME>
            <DESCRIPTION>Gibt die Zahl des Zeichens zur&#252;ck, bei der ein bestimmtes Zeichen oder eine Textzeichenfolge zuerst gefunden wird. Dabei wird von links nach rechts gelesen (keine Beachtung von Gro&#223;- und Kleinschreibung).</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Suchtext</NAME>
              <DESCRIPTION>Der Text, den Sie suchen m&#246;chten. Sie k&#246;nnen die folgenden Platzhalterzeichen verwenden: "?" und "*"; verwenden Sie "~?" und "~*", um die Zeichen "?" und "*" zu suchen.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>In_Text</NAME>
              <DESCRIPTION>Der Text, in dem Sie Suchtext suchen m&#246;chten</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Start_Zahl</NAME>
              <DESCRIPTION>Die Zeichenposition in "In_Text", an der der Suchvorgang beginnen soll. Bei Auslassung der Position wird 1 angenommen.</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>SUBSTITUTE</FUNCTION_NAME>
            <DESCRIPTION>Ersetzt vorhandenen Text durch neuen Text in einer Textzeichenfolge.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Text</NAME>
              <DESCRIPTION>Eine Textzeichenfolge oder ein Verweis auf eine Zelle mit Text, in der Sie Zeichen ersetzen m&#246;chten</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Alter_Text</NAME>
              <DESCRIPTION>Der vorhandene Text, der ersetzt werden soll. Wenn die Schreibweise von "Alter_Text" nicht der Schreibweise im vorhandenen Text entspricht, wird der Text durch SUBSTITUTE nicht ersetzt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Neuer_Text</NAME>
              <DESCRIPTION>Der Text, durch den "Alter_Text" ersetzt werden soll</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Instanz_Anzahl</NAME>
              <DESCRIPTION>Das Vorkommen von "Alter_Text", das Sie ersetzen m&#246;chten. Bei Auslassung des Vorkommens wird jede Instanz von "Alter_Text" ersetzt.</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>TRIM</FUNCTION_NAME>
            <DESCRIPTION>Entfernt alle Leerzeichen aus einer Textzeichenfolge mit Ausnahme einzelner Leerzeichen zwischen W&#246;rtern.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Text</NAME>
              <DESCRIPTION>Der Text, aus dem Sie Leerzeichen entfernen m&#246;chten</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>UPPER</FUNCTION_NAME>
            <DESCRIPTION>Konvertiert eine Textzeichenfolge in Gro&#223;buchstaben.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Text</NAME>
              <DESCRIPTION>Der Text, der in Gro&#223;buchstaben konvertiert werden soll, oder ein Verweis auf eine Zelle, die eine Textzeichenfolge enth&#228;lt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>VALUE</FUNCTION_NAME>
            <DESCRIPTION>Konvertiert eine Textzeichenfolge, die eine Zahl darstellt, in eine Zahl.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Text</NAME>
              <DESCRIPTION>Der zu konvertierende Text</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>CLOSINGBALANCEMONTH</FUNCTION_NAME>
            <DESCRIPTION>Wertet den angegebenen Ausdruck nach Anwenden der angegebenen Filter f&#252;r das Datum aus, das dem Ende des aktuellen Monats entspricht.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Filter</NAME>
              <DESCRIPTION>Ein boolescher Ausdruck oder ein Tabellenausdruck, der einen Filter definiert</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>CLOSINGBALANCEQUARTER</FUNCTION_NAME>
            <DESCRIPTION>Wertet den angegebenen Ausdruck nach Anwenden der angegebenen Filter f&#252;r das Datum aus, das dem Ende des aktuellen Quartals entspricht.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Filter</NAME>
              <DESCRIPTION>Ein boolescher Ausdruck oder ein Tabellenausdruck, der einen Filter definiert</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>CLOSINGBALANCEYEAR</FUNCTION_NAME>
            <DESCRIPTION>Wertet den angegebenen Ausdruck nach Anwenden der angegebenen Filter f&#252;r das Datum aus, das dem Ende des aktuellen Jahres entspricht.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Filter</NAME>
              <DESCRIPTION>Ein boolescher Ausdruck oder ein Tabellenausdruck, der einen Filter definiert</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Jahresenddatum</NAME>
              <DESCRIPTION>Jahresenddatum</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>DATEADD</FUNCTION_NAME>
            <DESCRIPTION>Verschiebt den angegebenen Satz von Datumsangaben um ein angegebenes Intervall.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Anzahl_der_Intervalle</NAME>
              <DESCRIPTION>Die Anzahl der Intervalle</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Intervall</NAME>
              <DESCRIPTION>Der Typ des Intervalls</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>DATESBETWEEN</FUNCTION_NAME>
            <DESCRIPTION>Gibt die Datumsangaben zwischen zwei angegebenen Datumsangaben zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Ausgangsdatum</NAME>
              <DESCRIPTION>Ausgangsdatum</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>End_datum</NAME>
              <DESCRIPTION>Enddatum</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>DATESINPERIOD</FUNCTION_NAME>
            <DESCRIPTION>Gibt die Datumsangaben in der angegebenen Periode zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Ausgangsdatum</NAME>
              <DESCRIPTION>Ausgangsdatum</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Anzahl_der_Intervalle</NAME>
              <DESCRIPTION>Die Anzahl der Intervalle</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Intervall</NAME>
              <DESCRIPTION>Der Typ des Intervalls</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>DATESMTD</FUNCTION_NAME>
            <DESCRIPTION>Gibt einen Satz mit Datumsangaben im Monat bis zum aktuellen Datum zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>DATESQTD</FUNCTION_NAME>
            <DESCRIPTION>Gibt einen Satz mit Datumsangaben im Quartal bis zum aktuellen Datum zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>DATESYTD</FUNCTION_NAME>
            <DESCRIPTION>Gibt einen Satz mit Datumsangaben im Jahr bis zum aktuellen Datum zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Jahresenddatum</NAME>
              <DESCRIPTION>Jahresenddatum</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ENDOFMONTH</FUNCTION_NAME>
            <DESCRIPTION>Gibt das Ende des Monats zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ENDOFQUARTER</FUNCTION_NAME>
            <DESCRIPTION>Gibt das Ende des Quartals zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ENDOFYEAR</FUNCTION_NAME>
            <DESCRIPTION>Gibt das Ende des Jahres zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Jahresenddatum</NAME>
              <DESCRIPTION>Jahresenddatum</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>FIRSTDATE</FUNCTION_NAME>
            <DESCRIPTION>Gibt das erste nicht leere Datum zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>FIRSTNONBLANK</FUNCTION_NAME>
            <DESCRIPTION>Gibt den ersten nicht leeren Wert zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Quellwerte</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der f&#252;r jeden Wert auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>LASTDATE</FUNCTION_NAME>
            <DESCRIPTION>Gibt das letzte nicht leere Datum zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>LASTNONBLANK</FUNCTION_NAME>
            <DESCRIPTION>Gibt den letzten nicht leeren Wert zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Quellwerte</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der f&#252;r jeden Wert auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>NEXTDAY</FUNCTION_NAME>
            <DESCRIPTION>Gibt einen darauf folgenden Tag an.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>NEXTMONTH</FUNCTION_NAME>
            <DESCRIPTION>Gibt einen darauf folgenden Monat an.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>NEXTQUARTER</FUNCTION_NAME>
            <DESCRIPTION>Gibt ein darauf folgendes Quartal zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>NEXTYEAR</FUNCTION_NAME>
            <DESCRIPTION>Gibt ein darauf folgendes Jahr an.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Jahresenddatum</NAME>
              <DESCRIPTION>Jahresenddatum</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>OPENINGBALANCEMONTH</FUNCTION_NAME>
            <DESCRIPTION>Wertet den angegebenen Ausdruck nach Anwenden der angegebenen Filter f&#252;r das Datum aus, das dem Ende des vorangegangenen Monats entspricht.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Filter</NAME>
              <DESCRIPTION>Ein boolescher Ausdruck oder ein Tabellenausdruck, der einen Filter definiert</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>OPENINGBALANCEQUARTER</FUNCTION_NAME>
            <DESCRIPTION>Wertet den angegebenen Ausdruck nach Anwenden der angegebenen Filter f&#252;r das Datum aus, das dem Ende des vorangegangenen Quartals entspricht.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Filter</NAME>
              <DESCRIPTION>Ein boolescher Ausdruck oder ein Tabellenausdruck, der einen Filter definiert</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>OPENINGBALANCEYEAR</FUNCTION_NAME>
            <DESCRIPTION>Wertet nach Anwenden der angegebenen Filter den angegebenen Ausdruck f&#252;r das Datum aus, das dem Ende des vorangegangenen Jahres entspricht.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Filter</NAME>
              <DESCRIPTION>Ein boolescher Ausdruck oder ein Tabellenausdruck, der einen Filter definiert</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Jahresenddatum</NAME>
              <DESCRIPTION>Jahresenddatum</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>PARALLELPERIOD</FUNCTION_NAME>
            <DESCRIPTION>Gibt eine parallele Datumsperiode nach dem angegebenen Satz von Datumsangaben und einem angegebenen Intervall zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Anzahl_der_Intervalle</NAME>
              <DESCRIPTION>Die Anzahl der Intervalle</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Intervall</NAME>
              <DESCRIPTION>Der Typ des Intervalls</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>PREVIOUSDAY</FUNCTION_NAME>
            <DESCRIPTION>Gibt einen vorangegangenen Tag zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>PREVIOUSMONTH</FUNCTION_NAME>
            <DESCRIPTION>Gibt einen vorangegangenen Tag zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>PREVIOUSQUARTER</FUNCTION_NAME>
            <DESCRIPTION>Gibt ein vorangegangenes Quartal zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>PREVIOUSYEAR</FUNCTION_NAME>
            <DESCRIPTION>Gibt ein vorangegangenes Jahr zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Jahresenddatum</NAME>
              <DESCRIPTION>Jahresenddatum</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>SAMEPERIODLASTYEAR</FUNCTION_NAME>
            <DESCRIPTION>Gibt einen Satz mit Datumsangaben in der aktuellen Auswahl aus dem vorangegangenen Jahr zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>STARTOFMONTH</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Beginn eines Monats zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>STARTOFQUARTER</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Beginn eines Quartals zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>STARTOFYEAR</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Beginn eines Jahres zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Jahresenddatum</NAME>
              <DESCRIPTION>Jahresenddatum</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>TOTALMTD</FUNCTION_NAME>
            <DESCRIPTION>Wertet den angegebenen Ausdruck nach Anwenden der angegebenen Filter anhand des Intervalls aus, das am ersten Tag des Monats beginnt und mit dem letzten Datum in der angegebenen Datumsspalte endet.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Filter</NAME>
              <DESCRIPTION>Ein boolescher Ausdruck oder ein Tabellenausdruck, der einen Filter definiert</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>TOTALQTD</FUNCTION_NAME>
            <DESCRIPTION>Wertet den angegebenen Ausdruck nach Anwenden der angegebenen Filter anhand des Intervalls aus, das am ersten Tag des Quartals beginnt und am letzten Datum in der angegebenen Datumsspalte endet.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Filter</NAME>
              <DESCRIPTION>Ein boolescher Ausdruck oder ein Tabellenausdruck, der einen Filter definiert</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>TOTALYTD</FUNCTION_NAME>
            <DESCRIPTION>Wertet den angegebenen Ausdruck nach Anwenden der angegebenen Filter anhand des Intervalls aus, das am ersten Tag des Jahres beginnt und mit dem letzten Datum in der angegebenen Datumsspalte endet.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>DATETIME</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Datumsangaben</NAME>
              <DESCRIPTION>Der Satz der Datumsangaben</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Filter</NAME>
              <DESCRIPTION>Ein boolescher Ausdruck oder ein Tabellenausdruck, der einen Filter definiert</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Jahresenddatum</NAME>
              <DESCRIPTION>Jahresenddatum</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ALL</FUNCTION_NAME>
            <DESCRIPTION>Gibt alle Zeilen in einer Tabelle oder alle Werte in einer Spalte zur&#252;ck, wobei alle m&#246;glicherweise angewendeten Filter ignoriert werden.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>FILTER</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Tabelle_oder_Spalte</NAME>
              <DESCRIPTION>Eine Tabelle oder Spalte</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Eine Spalte in der gleichen Basistabelle</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>true</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ALLEXCEPT</FUNCTION_NAME>
            <DESCRIPTION>Gibt alle Zeilen in einer Tabelle mit Ausnahme der Zeilen zur&#252;ck, die bei Anwendung der angegebenen Spaltenfilter gefunden werden.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>FILTER</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Tabelle</NAME>
              <DESCRIPTION>Eine Tabelle</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Eine Spalte, deren Filter f&#252;r die Tabelle &#252;bernommen werden soll</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>true</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>ALLNOBLANKROW</FUNCTION_NAME>
            <DESCRIPTION>Gibt alle Zeilen mit Ausnahme von Leerzeilen in einer Tabelle oder alle Werte in einer Spalte zur&#252;ck, wobei alle Filter ignoriert werden, die m&#246;glicherweise angewendet wurden.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>FILTER</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Tabelle_oder_Spalte</NAME>
              <DESCRIPTION>Eine Tabelle oder Spalte</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>CALCULATE</FUNCTION_NAME>
            <DESCRIPTION>Wertet einen Ausdruck in einem durch Filter ge&#228;nderten Kontext aus.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>FILTER</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Filter</NAME>
              <DESCRIPTION>Ein boolescher Ausdruck oder ein Tabellenausdruck, der einen Filter definiert</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>true</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>CALCULATETABLE</FUNCTION_NAME>
            <DESCRIPTION>Wertet einen Tabellenausdruck in einem durch Filter ge&#228;nderten Kontext aus.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>FILTER</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der auszuwertende Tabellenausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Filter</NAME>
              <DESCRIPTION>Ein boolescher Ausdruck oder ein Tabellenausdruck, der einen Filter definiert</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>true</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>DISTINCT</FUNCTION_NAME>
            <DESCRIPTION>Gibt eine Spaltentabelle zur&#252;ck, die die unterschiedlichen (eindeutigen) Werte in einer Spalte enth&#228;lt.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>FILTER</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, aus der die eindeutigen Werte zur&#252;ckgegeben werden sollen.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>EARLIER</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Wert in der Spalte vor der angegebenen Anzahl von Tabellenscans zur&#252;ck (der Standardwert ist 1).</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>FILTER</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, die den gew&#252;nschten Wert enth&#228;lt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Anzahl</NAME>
              <DESCRIPTION>Die Anzahl der Tabellenscans</DESCRIPTION>
              <OPTIONAL>true</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>EARLIEST</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Wert in der Spalte f&#252;r den ersten Punkt zur&#252;ck, an dem sich ein Zeilenkontext befand.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>FILTER</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, die den gew&#252;nschten Wert enth&#228;lt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>FILTER</FUNCTION_NAME>
            <DESCRIPTION>Gibt eine Tabelle zur&#252;ck, die gefiltert wurde.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>FILTER</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Tabelle</NAME>
              <DESCRIPTION>Die zu filternde Tabelle</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Filter</NAME>
              <DESCRIPTION>Ein boolescher Ausdruck, der f&#252;r jede Zeile der Tabelle ausgewertet werden soll</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>RELATED</FUNCTION_NAME>
            <DESCRIPTION>Gibt einen zugeh&#246;rigen Wert aus einer anderen Tabelle zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>FILTER</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, die den gew&#252;nschten Wert enth&#228;lt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>RELATEDTABLE</FUNCTION_NAME>
            <DESCRIPTION>Gibt die zugeh&#246;rigen Tabellen zur&#252;ck, die so gefiltert sind, dass sie nur die zugeh&#246;rigen Zeilen enthalten.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>FILTER</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Tabelle</NAME>
              <DESCRIPTION>Die Tabelle, die den gew&#252;nschten Wert enth&#228;lt</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>VALUES</FUNCTION_NAME>
            <DESCRIPTION>Gibt eine Spaltentabelle zur&#252;ck, die die unterschiedlichen (eindeutigen) Werte in einer Spalte enth&#228;lt.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>FILTER</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, aus der die eindeutigen Werte zur&#252;ckgegeben werden sollen.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>SUM</FUNCTION_NAME>
            <DESCRIPTION>F&#252;gt alle Zahlen in einer Spalte hinzu.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, die die zu summierenden Zahlen enth&#228;lt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>SUMX</FUNCTION_NAME>
            <DESCRIPTION>Gibt die Summe eines Ausdrucks zur&#252;ck, der f&#252;r jede Zeile in einer Tabelle ausgewertet wird.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>MATHTRIG</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Tabelle</NAME>
              <DESCRIPTION>Die Tabelle, die die Zeilen enth&#228;lt, f&#252;r die der Ausdruck ausgewertet wird.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der f&#252;r jede Zeile der Tabelle auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>AVERAGE</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Durchschnitt (arithmetisches Mittel) aller Zahlen in einer Spalte zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, die die Zahlen enth&#228;lt, deren Durchschnitt Sie bilden m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>AVERAGEA</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Durchschnitt (arithmetisches Mittel) aller Werte in einer Spalte zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Eine Spalte, die die Werte enth&#228;lt, f&#252;r die Sie den Durchschnitt bilden m&#246;chten</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>AVERAGEX</FUNCTION_NAME>
            <DESCRIPTION>Gibt den Durchschnitt (arithmetisches Mittel) aller Zahlen in einer Spalte zur&#252;ck.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Tabelle</NAME>
              <DESCRIPTION>Die Tabelle, die die Zeilen enth&#228;lt, f&#252;r die der Ausdruck ausgewertet wird.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der f&#252;r jede Zeile der Tabelle auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>COUNT</FUNCTION_NAME>
            <DESCRIPTION>Z&#228;hlt die Zahlen in einer Spalte.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, die die zu z&#228;hlenden Zahlen enth&#228;lt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>COUNTA</FUNCTION_NAME>
            <DESCRIPTION>Z&#228;hlt die Anzahl der Werte in einer Spalte.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, die die zu z&#228;hlenden Werte enth&#228;lt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>COUNTAX</FUNCTION_NAME>
            <DESCRIPTION>Z&#228;hlt die Anzahl der Werte, die aus der Auswertung eines Ausdrucks f&#252;r jede Zeile einer Tabelle resultieren.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Tabelle</NAME>
              <DESCRIPTION>Die Tabelle, die die Zeilen enth&#228;lt, f&#252;r die der Ausdruck ausgewertet wird.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der f&#252;r jede Zeile der Tabelle auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>COUNTBLANK</FUNCTION_NAME>
            <DESCRIPTION>Z&#228;hlt die Anzahl der Leerzeichen in einer Spalte.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, die die zu z&#228;hlenden Leerzeichen enth&#228;lt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>COUNTROWS</FUNCTION_NAME>
            <DESCRIPTION>Z&#228;hlt die Anzahl der Zeilen in einer Tabelle.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Tabelle</NAME>
              <DESCRIPTION>Die Spalte, die die zu z&#228;hlenden Zeilen enth&#228;lt.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>COUNTX</FUNCTION_NAME>
            <DESCRIPTION>Z&#228;hlt die Anzahl der Werte, die aus der Auswertung eines Ausdrucks f&#252;r jede Zeile einer Tabelle resultieren.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Tabelle</NAME>
              <DESCRIPTION>Die Tabelle, die die Zeilen enth&#228;lt, f&#252;r die der Ausdruck ausgewertet wird.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der f&#252;r jede Zeile der Tabelle auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>MAX</FUNCTION_NAME>
            <DESCRIPTION>Gibt den gr&#246;&#223;ten numerischen Wert in einer Spalte zur&#252;ck. Ignoriert logische Werte und logischen Text.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, in der Sie den gr&#246;&#223;ten numerischen Wert suchen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>MAXA</FUNCTION_NAME>
            <DESCRIPTION>Gibt den gr&#246;&#223;ten Wert in einer Spalte zur&#252;ck. Ignoriert keine logischen Werte und keinen Text.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, in der Sie den gr&#246;&#223;ten Wert suchen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>MAXX</FUNCTION_NAME>
            <DESCRIPTION>Gibt den gr&#246;&#223;ten numerischen Wert zur&#252;ck, der aus der Auswertung eines Ausdrucks f&#252;r jede Zeile einer Tabelle resultiert.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Tabelle</NAME>
              <DESCRIPTION>Die Tabelle, die die Zeilen enth&#228;lt, f&#252;r die der Ausdruck ausgewertet wird.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der f&#252;r jede Zeile der Tabelle auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>MIN</FUNCTION_NAME>
            <DESCRIPTION>Gibt den kleinsten numerischen Wert in einer Spalte zur&#252;ck. Ignoriert logische Werte und logischen Text.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, in der Sie den kleinsten numerischen Wert suchen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>MINA</FUNCTION_NAME>
            <DESCRIPTION>Gibt den kleinsten Wert in einer Spalte zur&#252;ck. Ignoriert keine logischen Werte und keinen logischen Text.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Spalte</NAME>
              <DESCRIPTION>Die Spalte, f&#252;r die Sie den kleinsten Wert suchen m&#246;chten.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
          <row>
            <FUNCTION_NAME>MINX</FUNCTION_NAME>
            <DESCRIPTION>Gibt den kleinsten numerischen Wert zur&#252;ck, der aus der Auswertung eines Ausdrucks f&#252;r jede Zeile einer Tabelle resultiert.</DESCRIPTION>
            <ORIGIN>3</ORIGIN>
            <INTERFACE_NAME>STATISTICAL</INTERFACE_NAME>
            <PARAMETERINFO>
              <NAME>Tabelle</NAME>
              <DESCRIPTION>Die Tabelle, die die Zeilen enth&#228;lt, f&#252;r die der Ausdruck ausgewertet wird.</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
            <PARAMETERINFO>
              <NAME>Ausdruck</NAME>
              <DESCRIPTION>Der f&#252;r jede Zeile der Tabelle auszuwertende Ausdruck</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_FUNCTIONS</RequestType>
      <Restrictions>
        <RestrictionList>
          <FUNCTION_NAME>TRIM</FUNCTION_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="FUNCTION_NAME" name="FUNCTION_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="PARAMETER_LIST" name="PARAMETER_LIST" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RETURN_TYPE" name="RETURN_TYPE" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="ORIGIN" name="ORIGIN" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="INTERFACE_NAME" name="INTERFACE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LIBRARY_NAME" name="LIBRARY_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DLL_NAME" name="DLL_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HELP_FILE" name="HELP_FILE" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HELP_CONTEXT" name="HELP_CONTEXT" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="OBJECT" name="OBJECT" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CAPTION" name="CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="PARAMETERINFO" name="PARAMETERINFO" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="NAME" name="NAME" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="OPTIONAL" name="OPTIONAL" type="xsd:boolean" minOccurs="0"/>
                      <xsd:element sql:field="REPEATABLE" name="REPEATABLE" type="xsd:boolean" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <FUNCTION_NAME>TRIM</FUNCTION_NAME>
            <DESCRIPTION>Entfernt alle Leerzeichen aus einer Textzeichenfolge mit Ausnahme einzelner Leerzeichen zwischen W&#246;rtern.</DESCRIPTION>
            <ORIGIN>4</ORIGIN>
            <INTERFACE_NAME>TEXT</INTERFACE_NAME>
            <LIBRARY_NAME>SCALAR</LIBRARY_NAME>
            <PARAMETERINFO>
              <NAME>Text</NAME>
              <DESCRIPTION>Der Text, aus dem Sie Leerzeichen entfernen m&#246;chten</DESCRIPTION>
              <OPTIONAL>false</OPTIONAL>
              <REPEATABLE>false</REPEATABLE>
            </PARAMETERINFO>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetMDSchemaHierarchies":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_HIERARCHIES</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>Adventure Works DW 2008R2</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_NAME" name="HIERARCHY_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_GUID" name="HIERARCHY_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_CAPTION" name="HIERARCHY_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_TYPE" name="DIMENSION_TYPE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_CARDINALITY" name="HIERARCHY_CARDINALITY" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="DEFAULT_MEMBER" name="DEFAULT_MEMBER" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="ALL_MEMBER" name="ALL_MEMBER" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="STRUCTURE" name="STRUCTURE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="IS_VIRTUAL" name="IS_VIRTUAL" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_READWRITE" name="IS_READWRITE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_UNIQUE_SETTINGS" name="DIMENSION_UNIQUE_SETTINGS" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_MASTER_UNIQUE_NAME" name="DIMENSION_MASTER_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_IS_VISIBLE" name="DIMENSION_IS_VISIBLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_ORDINAL" name="HIERARCHY_ORDINAL" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_IS_SHARED" name="DIMENSION_IS_SHARED" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_IS_VISIBLE" name="HIERARCHY_IS_VISIBLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_ORIGIN" name="HIERARCHY_ORIGIN" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_DISPLAY_FOLDER" name="HIERARCHY_DISPLAY_FOLDER" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="INSTANCE_SELECTION" name="INSTANCE_SELECTION" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="GROUPING_BEHAVIOR" name="GROUPING_BEHAVIOR" type="xsd:unsignedShort" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Account]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Account Number</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Account].[Account Number]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Account Number</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>6</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>101</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Account].[Account Number].[All Accounts]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Account].[Account Number].[All Accounts]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Account]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Account Type</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Account].[Account Type]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Account Type</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>6</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>10</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Account].[Account Type].[All Accounts]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Account].[Account Type].[All Accounts]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Account]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Accounts</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Account].[Accounts]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Accounts</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>6</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>127</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Account].[Accounts].&amp;[47]</DEFAULT_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>2</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>3</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>City</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[City]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>City</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>589</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[City].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[City].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>6</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Location</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>3</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Commute Distance</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Commute Distance]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Commute Distance</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Commute Distance].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Commute Distance].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>16</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Demographic</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Country</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Country]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Country</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>8</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Country].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Country].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Location</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Customer</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Customer</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>18486</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Customer].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Customer].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>2</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>4</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Customer Geography</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Customer Geography</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>19809</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Customer Geography].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Customer Geography].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>1</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Education</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Education]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Education</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Education].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Education].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>11</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Demographic</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Gender</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Gender]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Gender</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Gender].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Gender].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>14</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Demographic</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Home Owner</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Home Owner]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Home Owner</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Home Owner].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Home Owner].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>15</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Demographic</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Marital Status</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Marital Status]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Marital Status</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Marital Status].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Marital Status].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>13</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Demographic</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Number of Cars Owned</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Number of Cars Owned]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Number of Cars Owned</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Number of Cars Owned].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Number of Cars Owned].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>9</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Demographic</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Number of Children At Home</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Number of Children At Home]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Number of Children At Home</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>8</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Number of Children At Home].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Number of Children At Home].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>10</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Demographic</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Occupation</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Occupation]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Occupation</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Occupation].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Occupation].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>12</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Demographic</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Postal Code</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Postal Code]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Postal Code</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>657</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Postal Code].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Postal Code].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Location</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>3</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>State-Province</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[State-Province]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>State-Province</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>73</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[State-Province].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[State-Province].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>5</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Location</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Total Children</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Total Children]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Total Children</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>8</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Total Children].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Total Children].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>8</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Demographic</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Yearly Income</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Yearly Income]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Yearly Income</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>7</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Customer].[Yearly Income].[All Customers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Customer].[Yearly Income].[All Customers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>7</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Demographic</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Calendar]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Calendar</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>1260</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Calendar].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Calendar].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>2</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Quarter of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Calendar Quarter of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Calendar Quarter of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Calendar Quarter of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Calendar Quarter of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>21</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Semester of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Calendar Semester of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Calendar Semester of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Calendar Semester of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Calendar Semester of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>19</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Week of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Calendar Week of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Calendar Week of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>55</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Calendar Week of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Calendar Week of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>24</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Weeks</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Calendar Weeks]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Calendar Weeks</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>182</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Calendar Weeks].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Calendar Weeks].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Calendar Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Calendar Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Calendar Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Calendar Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>17</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Date</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Date]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Date</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>1190</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Date].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Date].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>6</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>3</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Day Name</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Day Name]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Day Name</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>9</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Day Name].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Day Name].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>12</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Day of Month</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Day of Month]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Day of Month</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>33</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Day of Month].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Day of Month].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>13</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Day of Week</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Day of Week]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Day of Week</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>9</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Day of Week].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Day of Week].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>11</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Day of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Day of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Day of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>367</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Day of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Day of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>14</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Fiscal]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Fiscal</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>1260</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Fiscal].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Fiscal].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Quarter of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Fiscal Quarter of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Fiscal Quarter of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Fiscal Quarter of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Fiscal Quarter of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>20</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Semester of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Fiscal Semester of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Fiscal Semester of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Fiscal Semester of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Fiscal Semester of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>18</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Week of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Fiscal Week of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Fiscal Week of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>55</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Fiscal Week of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Fiscal Week of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>25</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Weeks</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Fiscal Weeks]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Fiscal Weeks</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>182</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Fiscal Weeks].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Fiscal Weeks].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Fiscal Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Fiscal Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Fiscal Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Fiscal Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>5</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Month of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Date].[Month of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Date.Month of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>14</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Date].[Month of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Date].[Month of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>22</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Calendar]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Calendar</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>1260</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Calendar].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Calendar].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>2</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Quarter of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Calendar Quarter of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Calendar Quarter of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Calendar Quarter of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Calendar Quarter of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>21</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Semester of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Calendar Semester of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Calendar Semester of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Calendar Semester of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Calendar Semester of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>19</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Week of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Calendar Week of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Calendar Week of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>55</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Calendar Week of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Calendar Week of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>24</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Weeks</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Calendar Weeks]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Calendar Weeks</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>182</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Calendar Weeks].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Calendar Weeks].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Calendar Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Calendar Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Calendar Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Calendar Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>17</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Date</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Date]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Date</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>1190</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Date].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Date].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>6</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>3</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Day Name</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Day Name]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Day Name</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>9</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Day Name].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Day Name].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>12</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Day of Month</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Day of Month]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Day of Month</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>33</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Day of Month].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Day of Month].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>13</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Day of Week</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Day of Week]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Day of Week</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>9</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Day of Week].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Day of Week].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>11</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Day of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Day of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Day of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>367</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Day of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Day of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>14</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Fiscal]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Fiscal</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>1260</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Fiscal].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Fiscal].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Quarter of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Fiscal Quarter of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Fiscal Quarter of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Fiscal Quarter of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Fiscal Quarter of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>20</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Semester of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Fiscal Semester of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Fiscal Semester of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Fiscal Semester of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Fiscal Semester of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>18</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Week of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Fiscal Week of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Fiscal Week of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>55</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Fiscal Week of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Fiscal Week of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>25</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Weeks</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Fiscal Weeks]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Fiscal Weeks</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>182</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Fiscal Weeks].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Fiscal Weeks].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Fiscal Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Fiscal Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Fiscal Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Fiscal Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>5</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Delivery Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Month of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Delivery Date].[Month of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Delivery Date.Month of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>14</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Delivery Date].[Month of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Delivery Date].[Month of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>22</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Department]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Departments</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Department].[Departments]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Departments</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>9</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Department].[Departments].&amp;[1]</DEFAULT_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>2</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>3</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Destination Currency]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Destination Currency</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Destination Currency].[Destination Currency]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Destination Currency</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>11</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>15</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Destination Currency].[Destination Currency].&amp;[US Dollar]</DEFAULT_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Destination Currency]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Destination Currency Code</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Destination Currency].[Destination Currency Code]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Destination Currency Code</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>11</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>16</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Destination Currency].[Destination Currency Code].[All Destination Currencies]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Destination Currency].[Destination Currency Code].[All Destination Currencies]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>2</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Base Rate</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Base Rate]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Base Rate</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>9</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Base Rate].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Base Rate].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>9</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Demographic</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Department Name</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Department Name]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Department Name</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>18</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Department Name].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Department Name].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Organization</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Employee Department</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Employee Department]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Employee Department</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>383</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Employee Department].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Employee Department].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Employees</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Employees]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Employees</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>345</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Employees].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Employees].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>2</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>16</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>3</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>End Date</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[End Date]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>End Date</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>9</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[End Date].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[End Date].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>19</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>History</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Gender</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Gender]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Gender</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Gender].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Gender].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>13</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Demographic</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Hire Date</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Hire Date]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Hire Date</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>166</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Hire Date].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Hire Date].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>6</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>History</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Hire Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Hire Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Hire Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>10</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Hire Year].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Hire Year].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>20</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>History</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Marital Status</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Marital Status]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Marital Status</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Marital Status].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Marital Status].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>14</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Demographic</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Pay Frequency</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Pay Frequency]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Pay Frequency</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Pay Frequency].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Pay Frequency].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>10</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Organization</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Phone</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Phone]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Phone</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>290</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Phone].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Phone].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>11</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Contacts</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Salaried Flag</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Salaried Flag]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Salaried Flag</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Salaried Flag].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Salaried Flag].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>12</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Organization</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Person Flag</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Sales Person Flag]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Person Flag</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Sales Person Flag].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Sales Person Flag].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Organization</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sick Leave Hours</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Sick Leave Hours]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sick Leave Hours</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Sick Leave Hours].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Sick Leave Hours].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>7</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Organization</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Start Date</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Start Date]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Start Date</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>172</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Start Date].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Start Date].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>18</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>History</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Status</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Status]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Status</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Status].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Status].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>17</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Organization</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Title</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Title]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Title</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>69</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Title].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Title].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>5</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Organization</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Employee]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Vacation Hours</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Employee].[Vacation Hours]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Vacation Hours</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Employee].[Vacation Hours].[All Employees]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Employee].[Vacation Hours].[All Employees]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>8</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Organization</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Geography]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>City</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Geography].[City]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>City</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>17</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>589</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Geography].[City].[All Geographies]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Geography].[City].[All Geographies]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>2</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>3</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Geography]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Country</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Geography].[Country]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Country</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>17</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>8</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Geography].[Country].[All Geographies]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Geography].[Country].[All Geographies]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Geography]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Geography</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Geography].[Geography]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Geography</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>17</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>1324</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Geography].[Geography].[All Geographies]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Geography].[Geography].[All Geographies]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>1</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Geography]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Postal Code</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Geography].[Postal Code]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Postal Code</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>17</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>657</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Geography].[Postal Code].[All Geographies]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Geography].[Postal Code].[All Geographies]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>5</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>3</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Geography]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>State-Province</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Geography].[State-Province]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>State-Province</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>17</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>73</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Geography].[State-Province].[All Geographies]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Geography].[State-Province].[All Geographies]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Internet Sales Order Details]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Internet Sales Orders</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Internet Sales Order Details].[Internet Sales Orders]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Internet Sales Orders</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>3</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Internet Sales Order Details].[Internet Sales Orders].[All]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Internet Sales Order Details].[Internet Sales Orders].[All]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Internet Sales Order Details]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Order Line</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Internet Sales Order Details].[Sales Order Line]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Order Line</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>2</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Internet Sales Order Details].[Sales Order Line].[All Internet Sales Orders]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Internet Sales Order Details].[Sales Order Line].[All Internet Sales Orders]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Internet Sales Order Details]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Order Number</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Internet Sales Order Details].[Sales Order Number]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Order Number</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>2</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Internet Sales Order Details].[Sales Order Number].[All Internet Sales Orders]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Internet Sales Order Details].[Sales Order Number].[All Internet Sales Orders]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>4</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Measures]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Measures</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Measures]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Measures</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>2</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>38</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Measures].[Reseller Sales Amount]</DEFAULT_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>0</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Organization]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Currency Code</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Organization].[Currency Code]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Currency Code</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>15</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Organization].[Currency Code].[All Organizations]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Organization].[Currency Code].[All Organizations]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Organization]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Organizations</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Organization].[Organizations]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Organizations</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>15</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>20</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Organization].[Organizations].&amp;[1]</DEFAULT_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>2</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>3</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Category</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Category]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Category</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Category].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Category].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>6</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Class</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Class]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Class</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Class].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Class].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>16</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Stocking</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Color</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Color]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Color</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>12</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Color].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Color].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>7</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Stocking</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Days to Manufacture</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Days to Manufacture]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Days to Manufacture</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Days to Manufacture].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Days to Manufacture].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>14</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Stocking</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Dealer Price</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Dealer Price]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Dealer Price</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>123</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Dealer Price].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Dealer Price].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>15</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Financial</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>End Date</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[End Date]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>End Date</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>5</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[End Date].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[End Date].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>23</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>History</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Large Photo</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Large Photo]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Large Photo</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>608</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Large Photo].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Large Photo].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>24</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>List Price</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[List Price]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>List Price</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>123</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[List Price].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[List Price].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>10</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Financial</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Model Name</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Model Name]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Model Name</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>122</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Model Name].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Model Name].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>18</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Product</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Product]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Product</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>399</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Product].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Product].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Product Categories</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Product Categories]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Product Categories</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>442</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Product Categories].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Product Categories].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Product Line</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Product Line]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Product Line</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Product Line].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Product Line].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>19</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Product Model Lines</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Product Model Lines]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Product Model Lines</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>128</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Product Model Lines].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Product Model Lines].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>2</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Reorder Point</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Reorder Point]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Reorder Point</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>8</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Reorder Point].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Reorder Point].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>9</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Stocking</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Safety Stock Level</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Safety Stock Level]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Safety Stock Level</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>8</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Safety Stock Level].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Safety Stock Level].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>8</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Stocking</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Size</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Size]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Size</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>21</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Size].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Size].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>11</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Stocking</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Size Range</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Size Range]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Size Range</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>13</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Size Range].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Size Range].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>12</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Stocking</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Standard Cost</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Standard Cost]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Standard Cost</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>137</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Standard Cost].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Standard Cost].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>5</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Financial</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Start Date</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Start Date]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Start Date</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Start Date].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Start Date].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>22</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>History</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Status</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Status]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Status</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Status].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Status].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>21</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>History</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Stock Level</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Stock Level]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Stock Level</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>406</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Stock Level].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Stock Level].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Stocking</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Style</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Style]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Style</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Style].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Style].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>17</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Subcategory</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Subcategory]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Subcategory</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>39</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Subcategory].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Subcategory].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>20</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Weight</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Product].[Weight]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Weight</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>8</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>130</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Product].[Weight].[All Products]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Product].[Weight].[All Products]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>13</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Stocking</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Promotion]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Discount Percent</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Promotion].[Discount Percent]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Discount Percent</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>14</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>12</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Promotion].[Discount Percent].[All Promotions]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Promotion].[Discount Percent].[All Promotions]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Promotion]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>End Date</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Promotion].[End Date]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>End Date</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>14</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>12</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Promotion].[End Date].[All Promotions]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Promotion].[End Date].[All Promotions]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>8</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Promotion]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Max Quantity</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Promotion].[Max Quantity]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Max Quantity</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>14</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Promotion].[Max Quantity].[All Promotions]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Promotion].[Max Quantity].[All Promotions]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>0</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Promotion]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Min Quantity</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Promotion].[Min Quantity]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Min Quantity</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>14</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>8</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Promotion].[Min Quantity].[All Promotions]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Promotion].[Min Quantity].[All Promotions]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>6</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Promotion]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Promotion</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Promotion].[Promotion]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Promotion</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>14</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>18</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Promotion].[Promotion].[All Promotions]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Promotion].[Promotion].[All Promotions]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>2</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Promotion]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Promotion Category</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Promotion].[Promotion Category]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Promotion Category</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>14</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>5</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Promotion].[Promotion Category].[All Promotions]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Promotion].[Promotion Category].[All Promotions]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>7</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Promotion]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Promotion Type</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Promotion].[Promotion Type]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Promotion Type</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>14</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>8</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Promotion].[Promotion Type].[All Promotions]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Promotion].[Promotion Type].[All Promotions]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>5</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Promotion]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Promotions</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Promotion].[Promotions]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Promotions</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>14</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>29</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Promotion].[Promotions].[All Promotions]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Promotion].[Promotions].[All Promotions]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>1</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Promotion]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Start Date</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Promotion].[Start Date]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Start Date</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>14</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>10</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Promotion].[Start Date].[All Promotions]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Promotion].[Start Date].[All Promotions]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>9</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Annual Revenue</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller].[Annual Revenue]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Annual Revenue</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>13</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller].[Annual Revenue].[All Resellers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller].[Annual Revenue].[All Resellers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>10</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Sales Data</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Annual Sales</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller].[Annual Sales]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Annual Sales</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>13</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller].[Annual Sales].[All Resellers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller].[Annual Sales].[All Resellers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>9</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Sales Data</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Bank Name</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller].[Bank Name]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Bank Name</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>13</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>9</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller].[Bank Name].[All Resellers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller].[Bank Name].[All Resellers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>11</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Order Data</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Business Type</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller].[Business Type]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Business Type</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>13</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>5</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller].[Business Type].[All Resellers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller].[Business Type].[All Resellers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>7</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Number of Employees</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller].[Number of Employees]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Number of Employees</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>13</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller].[Number of Employees].[All Resellers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller].[Number of Employees].[All Resellers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>8</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Order Frequency</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller].[Order Frequency]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Order Frequency</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>13</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>5</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller].[Order Frequency].[All Resellers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller].[Order Frequency].[All Resellers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>12</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Order Data</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Order Month</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller].[Order Month]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Order Month</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>13</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>15</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller].[Order Month].[All Resellers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller].[Order Month].[All Resellers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>13</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Order Data</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Product Line</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller].[Product Line]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Product Line</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>13</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>5</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller].[Product Line].[All Resellers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller].[Product Line].[All Resellers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>6</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Reseller</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller].[Reseller]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Reseller</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>13</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>703</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller].[Reseller].[All Resellers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller].[Reseller].[All Resellers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>5</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Reseller Bank</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller].[Reseller Bank]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Reseller Bank</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>13</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>711</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller].[Reseller Bank].[All Resellers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller].[Reseller Bank].[All Resellers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>2</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Order Data</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Reseller Order Frequency</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller].[Reseller Order Frequency]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Reseller Order Frequency</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>13</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>707</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller].[Reseller Order Frequency].[All Resellers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller].[Reseller Order Frequency].[All Resellers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Order Data</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Reseller Order Month</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller].[Reseller Order Month]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Reseller Order Month</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>13</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>717</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller].[Reseller Order Month].[All Resellers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller].[Reseller Order Month].[All Resellers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Order Data</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Reseller Type</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller].[Reseller Type]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Reseller Type</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>13</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>707</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller].[Reseller Type].[All Resellers]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller].[Reseller Type].[All Resellers]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller Sales Order Details]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Carrier Tracking Number</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller Sales Order Details].[Carrier Tracking Number]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Carrier Tracking Number</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>2</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller Sales Order Details].[Carrier Tracking Number].[All Reseller Sales Orders]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller Sales Order Details].[Carrier Tracking Number].[All Reseller Sales Orders]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>4</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller Sales Order Details]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Customer PO Number</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller Sales Order Details].[Customer PO Number]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Customer PO Number</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>2</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller Sales Order Details].[Customer PO Number].[All Reseller Sales Orders]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller Sales Order Details].[Customer PO Number].[All Reseller Sales Orders]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>4</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller Sales Order Details]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Reseller Sales Orders</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller Sales Order Details].[Reseller Sales Orders]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Reseller Sales Orders</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>3</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller Sales Order Details].[Reseller Sales Orders].[All]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller Sales Order Details].[Reseller Sales Orders].[All]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller Sales Order Details]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Order Line</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller Sales Order Details].[Sales Order Line]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Order Line</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>2</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller Sales Order Details].[Sales Order Line].[All Reseller Sales Orders]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller Sales Order Details].[Sales Order Line].[All Reseller Sales Orders]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>6</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Reseller Sales Order Details]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Order Number</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Reseller Sales Order Details].[Sales Order Number]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Order Number</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>2</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Reseller Sales Order Details].[Sales Order Number].[All Reseller Sales Orders]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Reseller Sales Order Details].[Sales Order Number].[All Reseller Sales Orders]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>5</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>4</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Sales Channel]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Channel</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Sales Channel].[Sales Channel]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Channel</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Sales Channel].[Sales Channel].[All Sales Channels]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Sales Channel].[Sales Channel].[All Sales Channels]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Sales Reason]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Reason</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Sales Reason].[Sales Reason]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Reason</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>12</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Sales Reason].[Sales Reason].[All Sales Reasons]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Sales Reason].[Sales Reason].[All Sales Reasons]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>2</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Sales Reason]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Reason Type</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Sales Reason].[Sales Reason Type]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Reason Type</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>5</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Sales Reason].[Sales Reason Type].[All Sales Reasons]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Sales Reason].[Sales Reason Type].[All Sales Reasons]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Sales Reason]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Reasons</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Sales Reason].[Sales Reasons]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Reasons</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>16</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Sales Reason].[Sales Reasons].[All Sales Reasons]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Sales Reason].[Sales Reasons].[All Sales Reasons]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Sales Summary Order Details]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Carrier Tracking Number</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Sales Summary Order Details].[Carrier Tracking Number]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Carrier Tracking Number</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>2</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Sales Summary Order Details].[Carrier Tracking Number].[All Sales Order Details]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Sales Summary Order Details].[Carrier Tracking Number].[All Sales Order Details]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>4</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Sales Summary Order Details]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Customer PO Number</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Sales Summary Order Details].[Customer PO Number]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Customer PO Number</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>2</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Sales Summary Order Details].[Customer PO Number].[All Sales Order Details]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Sales Summary Order Details].[Customer PO Number].[All Sales Order Details]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>4</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Sales Summary Order Details]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Order Line</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Sales Summary Order Details].[Sales Order Line]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Order Line</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>2</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Sales Summary Order Details].[Sales Order Line].[All Sales Order Details]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Sales Summary Order Details].[Sales Order Line].[All Sales Order Details]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>6</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Sales Summary Order Details]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Order Number</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Sales Summary Order Details].[Sales Order Number]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Order Number</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>2</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Sales Summary Order Details].[Sales Order Number].[All Sales Order Details]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Sales Summary Order Details].[Sales Order Number].[All Sales Order Details]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>5</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>4</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Sales Summary Order Details]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Orders</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Sales Summary Order Details].[Sales Orders]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Orders</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>3</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Sales Summary Order Details].[Sales Orders].[All]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Sales Summary Order Details].[Sales Orders].[All]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Sales Territory]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Territory</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Sales Territory].[Sales Territory]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Territory</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>26</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Sales Territory].[Sales Territory].[All Sales Territories]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Sales Territory].[Sales Territory].[All Sales Territories]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>1</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Sales Territory]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Territory Country</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Sales Territory].[Sales Territory Country]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Territory Country</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>9</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Sales Territory].[Sales Territory Country].[All Sales Territories]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Sales Territory].[Sales Territory Country].[All Sales Territories]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Sales Territory]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Territory Group</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Sales Territory].[Sales Territory Group]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Territory Group</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Sales Territory].[Sales Territory Group].[All Sales Territories]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Sales Territory].[Sales Territory Group].[All Sales Territories]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Sales Territory]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Sales Territory Region</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Sales Territory].[Sales Territory Region]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Sales Territory Region</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>3</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>13</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Sales Territory].[Sales Territory Region].[All Sales Territories]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Sales Territory].[Sales Territory Region].[All Sales Territories]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>2</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Scenario]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Scenario</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Scenario].[Scenario]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Scenario</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>9</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Scenario].[Scenario].&amp;[1]</DEFAULT_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Calendar]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Calendar</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>1260</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Calendar].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Calendar].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>2</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Quarter of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Calendar Quarter of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Calendar Quarter of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Calendar Quarter of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Calendar Quarter of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>21</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Semester of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Calendar Semester of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Calendar Semester of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Calendar Semester of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Calendar Semester of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>19</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Week of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Calendar Week of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Calendar Week of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>55</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Calendar Week of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Calendar Week of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>24</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Weeks</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Calendar Weeks]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Calendar Weeks</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>182</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Calendar Weeks].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Calendar Weeks].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Calendar Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Calendar Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Calendar Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Calendar Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Calendar Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>17</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Calendar</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Date</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Date]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Date</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>1190</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Date].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Date].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>6</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>3</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Day Name</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Day Name]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Day Name</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>9</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Day Name].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Day Name].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>12</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Day of Month</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Day of Month]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Day of Month</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>33</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Day of Month].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Day of Month].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>13</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Day of Week</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Day of Week]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Day of Week</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>9</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Day of Week].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Day of Week].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>11</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Day of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Day of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Day of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>367</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Day of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Day of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>14</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>2</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Fiscal]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Fiscal</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>1260</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Fiscal].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Fiscal].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Quarter of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Fiscal Quarter of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Fiscal Quarter of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>6</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Fiscal Quarter of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Fiscal Quarter of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>20</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Semester of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Fiscal Semester of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Fiscal Semester of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>4</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Fiscal Semester of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Fiscal Semester of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>18</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Week of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Fiscal Week of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Fiscal Week of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>55</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Fiscal Week of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Fiscal Week of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>25</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Weeks</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Fiscal Weeks]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Fiscal Weeks</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>182</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Fiscal Weeks].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Fiscal Weeks].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>1</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Fiscal Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Fiscal Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Fiscal Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Fiscal Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Fiscal Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>5</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER>Fiscal</HIERARCHY_DISPLAY_FOLDER>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Ship Date]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Month of Year</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Ship Date].[Month of Year]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Ship Date.Month of Year</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>1</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>14</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Ship Date].[Month of Year].[All Periods]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Ship Date].[Month of Year].[All Periods]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>22</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>1</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Source Currency]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Source Currency</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Source Currency].[Source Currency]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Source Currency</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>11</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>107</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Source Currency].[Source Currency].[All Source Currencies]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Source Currency].[Source Currency].[All Source Currencies]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>2</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Source Currency]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Source Currency Code</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Source Currency].[Source Currency Code]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Source Currency Code</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>11</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>107</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Source Currency].[Source Currency Code].[All Source Currencies]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Source Currency].[Source Currency Code].[All Source Currencies]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>6</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_HIERARCHIES</RequestType>
      <Restrictions>
        <RestrictionList>
          <HIERARCHY_NAME>Account Number</HIERARCHY_NAME>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>Adventure Works DW 2008R2</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_NAME" name="HIERARCHY_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_GUID" name="HIERARCHY_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_CAPTION" name="HIERARCHY_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_TYPE" name="DIMENSION_TYPE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_CARDINALITY" name="HIERARCHY_CARDINALITY" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="DEFAULT_MEMBER" name="DEFAULT_MEMBER" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="ALL_MEMBER" name="ALL_MEMBER" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="STRUCTURE" name="STRUCTURE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="IS_VIRTUAL" name="IS_VIRTUAL" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_READWRITE" name="IS_READWRITE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_UNIQUE_SETTINGS" name="DIMENSION_UNIQUE_SETTINGS" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_MASTER_UNIQUE_NAME" name="DIMENSION_MASTER_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_IS_VISIBLE" name="DIMENSION_IS_VISIBLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_ORDINAL" name="HIERARCHY_ORDINAL" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_IS_SHARED" name="DIMENSION_IS_SHARED" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_IS_VISIBLE" name="HIERARCHY_IS_VISIBLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_ORIGIN" name="HIERARCHY_ORIGIN" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_DISPLAY_FOLDER" name="HIERARCHY_DISPLAY_FOLDER" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="INSTANCE_SELECTION" name="INSTANCE_SELECTION" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="GROUPING_BEHAVIOR" name="GROUPING_BEHAVIOR" type="xsd:unsignedShort" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Account]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_NAME>Account Number</HIERARCHY_NAME>
            <HIERARCHY_UNIQUE_NAME>[Account].[Account Number]</HIERARCHY_UNIQUE_NAME>
            <HIERARCHY_CAPTION>Account Number</HIERARCHY_CAPTION>
            <DIMENSION_TYPE>6</DIMENSION_TYPE>
            <HIERARCHY_CARDINALITY>101</HIERARCHY_CARDINALITY>
            <DEFAULT_MEMBER>[Account].[Account Number].[All Accounts]</DEFAULT_MEMBER>
            <ALL_MEMBER>[Account].[Account Number].[All Accounts]</ALL_MEMBER>
            <DESCRIPTION/>
            <STRUCTURE>0</STRUCTURE>
            <IS_VIRTUAL>false</IS_VIRTUAL>
            <IS_READWRITE>false</IS_READWRITE>
            <DIMENSION_UNIQUE_SETTINGS>1</DIMENSION_UNIQUE_SETTINGS>
            <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
            <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
            <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
            <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
            <HIERARCHY_ORIGIN>2</HIERARCHY_ORIGIN>
            <HIERARCHY_DISPLAY_FOLDER/>
            <INSTANCE_SELECTION>1</INSTANCE_SELECTION>
            <GROUPING_BEHAVIOR>2</GROUPING_BEHAVIOR>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetMDSchemaMeasures":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_MEASURES</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>Adventure Works DW 2008R2</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEASURE_NAME" name="MEASURE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEASURE_UNIQUE_NAME" name="MEASURE_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEASURE_CAPTION" name="MEASURE_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEASURE_GUID" name="MEASURE_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="MEASURE_AGGREGATOR" name="MEASURE_AGGREGATOR" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="DATA_TYPE" name="DATA_TYPE" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="NUMERIC_PRECISION" name="NUMERIC_PRECISION" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="NUMERIC_SCALE" name="NUMERIC_SCALE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="MEASURE_UNITS" name="MEASURE_UNITS" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="EXPRESSION" name="EXPRESSION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEASURE_IS_VISIBLE" name="MEASURE_IS_VISIBLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="LEVELS_LIST" name="LEVELS_LIST" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEASURE_NAME_SQL_COLUMN_NAME" name="MEASURE_NAME_SQL_COLUMN_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEASURE_UNQUALIFIED_CAPTION" name="MEASURE_UNQUALIFIED_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEASUREGROUP_NAME" name="MEASUREGROUP_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEASURE_DISPLAY_FOLDER" name="MEASURE_DISPLAY_FOLDER" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DEFAULT_FORMAT_STRING" name="DEFAULT_FORMAT_STRING" type="xsd:string" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Sales Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Sales Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Sales Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>6</DATA_TYPE>
            <NUMERIC_PRECISION>19</NUMERIC_PRECISION>
            <NUMERIC_SCALE>4</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Sales Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Sales Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Order Quantity</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Order Quantity]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Order Quantity</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>3</DATA_TYPE>
            <NUMERIC_PRECISION>10</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Order Quantity</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Order Quantity</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>#,#</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Extended Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Extended Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Extended Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>6</DATA_TYPE>
            <NUMERIC_PRECISION>19</NUMERIC_PRECISION>
            <NUMERIC_SCALE>4</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Extended Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Extended Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Tax Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Tax Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Tax Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>6</DATA_TYPE>
            <NUMERIC_PRECISION>19</NUMERIC_PRECISION>
            <NUMERIC_SCALE>4</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Tax Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Tax Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Freight Cost</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Freight Cost]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Freight Cost</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>6</DATA_TYPE>
            <NUMERIC_PRECISION>19</NUMERIC_PRECISION>
            <NUMERIC_SCALE>4</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Freight Cost</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Freight Cost</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Total Product Cost</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Total Product Cost]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Total Product Cost</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>6</DATA_TYPE>
            <NUMERIC_PRECISION>19</NUMERIC_PRECISION>
            <NUMERIC_SCALE>4</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Total Product Cost</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Total Product Cost</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Standard Product Cost</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Standard Product Cost]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Standard Product Cost</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>6</DATA_TYPE>
            <NUMERIC_PRECISION>19</NUMERIC_PRECISION>
            <NUMERIC_SCALE>4</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Standard Product Cost</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Standard Product Cost</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Order Count</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Order Count]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Order Count</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>8</MEASURE_AGGREGATOR>
            <DATA_TYPE>3</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Order Count</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Order Count</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Orders</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>#,#</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Customer Count</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Customer Count]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Customer Count</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>8</MEASURE_AGGREGATOR>
            <DATA_TYPE>3</DATA_TYPE>
            <NUMERIC_PRECISION>10</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Customer Count</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Customer Count</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Customers</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>#,#</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Sales Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Sales Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Sales Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>6</DATA_TYPE>
            <NUMERIC_PRECISION>19</NUMERIC_PRECISION>
            <NUMERIC_SCALE>4</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Sales Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Sales Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Order Quantity</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Order Quantity]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Order Quantity</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>3</DATA_TYPE>
            <NUMERIC_PRECISION>10</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Order Quantity</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Order Quantity</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>#,#</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Extended Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Extended Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Extended Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>6</DATA_TYPE>
            <NUMERIC_PRECISION>19</NUMERIC_PRECISION>
            <NUMERIC_SCALE>4</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Extended Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Extended Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Tax Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Tax Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Tax Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>6</DATA_TYPE>
            <NUMERIC_PRECISION>19</NUMERIC_PRECISION>
            <NUMERIC_SCALE>4</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Tax Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Tax Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Freight Cost</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Freight Cost]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Freight Cost</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>6</DATA_TYPE>
            <NUMERIC_PRECISION>19</NUMERIC_PRECISION>
            <NUMERIC_SCALE>4</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Freight Cost</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Freight Cost</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Discount Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Discount Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Discount Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>5</DATA_TYPE>
            <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Discount Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Discount Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Total Product Cost</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Total Product Cost]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Total Product Cost</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>6</DATA_TYPE>
            <NUMERIC_PRECISION>19</NUMERIC_PRECISION>
            <NUMERIC_SCALE>4</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Total Product Cost</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Total Product Cost</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Standard Product Cost</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Standard Product Cost]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Standard Product Cost</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>6</DATA_TYPE>
            <NUMERIC_PRECISION>19</NUMERIC_PRECISION>
            <NUMERIC_SCALE>4</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Standard Product Cost</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Standard Product Cost</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Order Count</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Order Count]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Order Count</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>8</MEASURE_AGGREGATOR>
            <DATA_TYPE>3</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Order Count</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Order Count</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Orders</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>#,#</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Order Quantity</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Order Quantity]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Order Quantity</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>3</DATA_TYPE>
            <NUMERIC_PRECISION>10</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Order Quantity</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Order Quantity</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>#,#</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Extended Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Extended Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Extended Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>5</DATA_TYPE>
            <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Extended Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Extended Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Standard Product Cost</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Standard Product Cost]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Standard Product Cost</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>5</DATA_TYPE>
            <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Standard Product Cost</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Standard Product Cost</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Total Product Cost</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Total Product Cost]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Total Product Cost</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>5</DATA_TYPE>
            <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Total Product Cost</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Total Product Cost</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Sales Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Sales Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Sales Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>5</DATA_TYPE>
            <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Sales Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Sales Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Tax Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Tax Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Tax Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>5</DATA_TYPE>
            <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Tax Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Tax Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Freight Cost</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Freight Cost]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Freight Cost</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>5</DATA_TYPE>
            <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Freight Cost</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Freight Cost</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Order Count</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Order Count]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Order Count</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>8</MEASURE_AGGREGATOR>
            <DATA_TYPE>3</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Order Count</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Order Count</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Orders</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>#,#</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Sales Amount Quota</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Sales Amount Quota]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Sales Amount Quota</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
            <DATA_TYPE>5</DATA_TYPE>
            <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Sales Amount Quota</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Sales Amount Quota</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Targets</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>15</MEASURE_AGGREGATOR>
            <DATA_TYPE>5</DATA_TYPE>
            <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Financial Reporting</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Average Rate</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Average Rate]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Average Rate</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>10</MEASURE_AGGREGATOR>
            <DATA_TYPE>5</DATA_TYPE>
            <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Average Rate</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Average Rate</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Exchange Rates</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>#,#.00</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>End of Day Rate</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[End of Day Rate]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>End of Day Rate</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>14</MEASURE_AGGREGATOR>
            <DATA_TYPE>5</DATA_TYPE>
            <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>End of Day Rate</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>End of Day Rate</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Exchange Rates</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>#,#.00</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Gross Profit</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Gross Profit]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Gross Profit</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>[Measures].[Internet Sales Amount] 
    - 
    [Measures].[Internet Total Product Cost]</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Gross Profit</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Gross Profit</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Gross Profit Margin</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Gross Profit Margin]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Gross Profit Margin</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>( 
      [Measures].[Internet Sales Amount] 
      - 
      [Measures].[Internet Total Product Cost] 
    ) 
    /
    [Measures].[Internet Sales Amount]</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Gross Profit Margin</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Gross Profit Margin</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Percent</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Average Unit Price</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Average Unit Price]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Average Unit Price</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>[Measures].[Internet Unit Price] 
    /
    [Measures].[Internet Transaction Count]</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Average Unit Price</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Average Unit Price</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Average Sales Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Average Sales Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Average Sales Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>[Measures].[Internet Sales Amount] 
    /
    [Measures].[Internet Order Count]</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Average Sales Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Average Sales Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Ratio to All Products</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Ratio to All Products]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Ratio to All Products</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>[Measures].[Internet Sales Amount]
    /
    ( 
      Root( [Product] ),
      [Measures].[Internet Sales Amount] 
    )</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Ratio to All Products</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Ratio to All Products</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Percent</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Internet Ratio to Parent Product</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Internet Ratio to Parent Product]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Internet Ratio to Parent Product</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>Case

        When [Product].[Product Categories].CurrentMember.Level.Ordinal 
             = 0
        Then 1

        Else [Measures].[Internet Sales Amount]
             /
             ( [Product].[Product Categories].CurrentMember.Parent,
               [Measures].[Internet Sales Amount] )

    End</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Internet Ratio to Parent Product</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Internet Ratio to Parent Product</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Percent</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Growth in Customer Base</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Growth in Customer Base]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Growth in Customer Base</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>Case

        When [Date].[Fiscal].CurrentMember.Level.Ordinal = 0
        Then "NA"

        When IsEmpty
             (  
               ( 
                 [Date].[Fiscal].CurrentMember.PrevMember, 
                 [Measures].[Customer Count] 
               ) 
             ) 
        Then Null

        Else ( 
               ( [Date].[Fiscal].CurrentMember, [Measures].[Customer Count] ) 
               -
               ( [Date].[Fiscal].PrevMember, [Measures].[Customer Count] ) 
             ) 
             /
             ( [Date].[Fiscal].PrevMember,[Measures].[Customer Count] )

    End</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Growth in Customer Base</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Growth in Customer Base</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Internet Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Percent</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Gross Profit</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Gross Profit]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Gross Profit</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>[Measures].[Reseller Sales Amount] 
    - 
    [Measures].[Reseller Total Product Cost]</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Gross Profit</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Gross Profit</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Gross Profit Margin</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Gross Profit Margin]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Gross Profit Margin</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>( 
      [Measures].[Reseller Sales Amount] 
      - 
      [Measures].[Reseller Total Product Cost] 
    ) 
    /
    [Measures].[Reseller Sales Amount]</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Gross Profit Margin</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Gross Profit Margin</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Percent</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Average Unit Price</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Average Unit Price]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Average Unit Price</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>[Measures].[Reseller Unit Price] 
    /
    [Measures].[Reseller Transaction Count]</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Average Unit Price</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Average Unit Price</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Average Sales Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Average Sales Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Average Sales Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>[Measures].[Reseller Sales Amount] 
    /
    [Measures].[Reseller Order Count]</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Average Sales Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Average Sales Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Ratio to All Products</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Ratio to All Products]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Ratio to All Products</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>[Measures].[Reseller Sales Amount]
    /
    ( 
      Root( [Product] ),
      [Measures].[Reseller Sales Amount] 
    )</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Ratio to All Products</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Ratio to All Products</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Percent</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Reseller Ratio to Parent Product</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Reseller Ratio to Parent Product]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Reseller Ratio to Parent Product</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>Case

        When [Product].[Product Categories].CurrentMember.Level.Ordinal 
             = 0
        Then 1

        Else [Measures].[Reseller Sales Amount]
             /
             ( [Product].[Product Categories].CurrentMember.Parent,
               [Measures].[Reseller Sales Amount] )

    End</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Reseller Ratio to Parent Product</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Reseller Ratio to Parent Product</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Percent</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Discount Percentage</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Discount Percentage]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Discount Percentage</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>[Measures].[Discount Amount] 
    / 
    [Measures].[Reseller Sales Amount]</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Discount Percentage</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Discount Percentage</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Reseller Sales</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Percent</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Average Unit Price</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Average Unit Price]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Average Unit Price</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>[Measures].[Unit Price] 
    /
    [Measures].[Transaction Count]</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Average Unit Price</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Average Unit Price</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Average Sales Amount</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Average Sales Amount]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Average Sales Amount</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>[Measures].[Sales Amount] 
    /
    [Measures].[Order Count]</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Average Sales Amount</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Average Sales Amount</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Gross Profit</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Gross Profit]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Gross Profit</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>[Measures].[Sales Amount] 
    - 
    [Measures].[Total Product Cost]</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Gross Profit</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Gross Profit</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Gross Profit Margin</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Gross Profit Margin]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Gross Profit Margin</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>( 
      [Measures].[Sales Amount] 
      - 
      [Measures].[Total Product Cost] 
    ) 
    /
    [Measures].[Sales Amount]</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Gross Profit Margin</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Gross Profit Margin</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Percent</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Expense to Revenue Ratio</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Expense to Revenue Ratio]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Expense to Revenue Ratio</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>IIf
    (
       IsEmpty
       (
          [Measures].[Sales Amount]
       ), 
       Null, 
       ( 
         [Measures].[Amount], [Account].[Accounts].[Account Level 03].&amp;[58] 
       )
       / 
       [Measures].[Sales Amount]
    )</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Expense to Revenue Ratio</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Expense to Revenue Ratio</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Percent</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Ratio to All Products</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Ratio to All Products]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Ratio to All Products</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>[Measures].[Sales Amount]
    /
    ( 
      Root( [Product] ),
      [Measures].[Sales Amount] 
    )</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Ratio to All Products</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Ratio to All Products</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Percent</DEFAULT_FORMAT_STRING>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <MEASURE_NAME>Ratio to Parent Product</MEASURE_NAME>
            <MEASURE_UNIQUE_NAME>[Measures].[Ratio to Parent Product]</MEASURE_UNIQUE_NAME>
            <MEASURE_CAPTION>Ratio to Parent Product</MEASURE_CAPTION>
            <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
            <DATA_TYPE>12</DATA_TYPE>
            <NUMERIC_PRECISION>65535</NUMERIC_PRECISION>
            <NUMERIC_SCALE>-1</NUMERIC_SCALE>
            <DESCRIPTION/>
            <EXPRESSION>Case

        When [Product].[Product Categories].CurrentMember.Level.Ordinal 
             = 0
        Then 1

        Else [Measures].[Sales Amount]
             /
             ( [Product].[Product Categories].CurrentMember.Parent,
               [Measures].[Sales Amount] )

    End</EXPRESSION>
            <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
            <MEASURE_NAME_SQL_COLUMN_NAME>Ratio to Parent Product</MEASURE_NAME_SQL_COLUMN_NAME>
            <MEASURE_UNQUALIFIED_CAPTION>Ratio to Parent Product</MEASURE_UNQUALIFIED_CAPTION>
            <MEASUREGROUP_NAME>Sales Summary</MEASUREGROUP_NAME>
            <MEASURE_DISPLAY_FOLDER/>
            <DEFAULT_FORMAT_STRING>Percent</DEFAULT_FORMAT_STRING>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetMDSchemaMembers":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_MEMBERS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
          <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>Adventure Works DW 2008R2</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_UNIQUE_NAME" name="LEVEL_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_NUMBER" name="LEVEL_NUMBER" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_ORDINAL" name="MEMBER_ORDINAL" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_NAME" name="MEMBER_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_UNIQUE_NAME" name="MEMBER_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_TYPE" name="MEMBER_TYPE" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_GUID" name="MEMBER_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_CAPTION" name="MEMBER_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CHILDREN_CARDINALITY" name="CHILDREN_CARDINALITY" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="PARENT_LEVEL" name="PARENT_LEVEL" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="PARENT_UNIQUE_NAME" name="PARENT_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="PARENT_COUNT" name="PARENT_COUNT" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="EXPRESSION" name="EXPRESSION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_KEY" name="MEMBER_KEY" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="IS_PLACEHOLDERMEMBER" name="IS_PLACEHOLDERMEMBER" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="IS_DATAMEMBER" name="IS_DATAMEMBER" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="SCOPE" name="SCOPE" type="xsd:int" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
            <LEVEL_NUMBER>1</LEVEL_NUMBER>
            <MEMBER_ORDINAL>1</MEMBER_ORDINAL>
            <MEMBER_NAME>Australia</MEMBER_NAME>
            <MEMBER_UNIQUE_NAME>[Customer].[Customer Geography].[Country].&amp;[Australia]</MEMBER_UNIQUE_NAME>
            <MEMBER_TYPE>1</MEMBER_TYPE>
            <MEMBER_CAPTION>Australia</MEMBER_CAPTION>
            <CHILDREN_CARDINALITY>5</CHILDREN_CARDINALITY>
            <PARENT_LEVEL>0</PARENT_LEVEL>
            <PARENT_UNIQUE_NAME>[Customer].[Customer Geography].[All Customers]</PARENT_UNIQUE_NAME>
            <PARENT_COUNT>1</PARENT_COUNT>
            <MEMBER_KEY>Australia</MEMBER_KEY>
            <IS_PLACEHOLDERMEMBER>false</IS_PLACEHOLDERMEMBER>
            <IS_DATAMEMBER>false</IS_DATAMEMBER>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
            <LEVEL_NUMBER>1</LEVEL_NUMBER>
            <MEMBER_ORDINAL>2</MEMBER_ORDINAL>
            <MEMBER_NAME>Canada</MEMBER_NAME>
            <MEMBER_UNIQUE_NAME>[Customer].[Customer Geography].[Country].&amp;[Canada]</MEMBER_UNIQUE_NAME>
            <MEMBER_TYPE>1</MEMBER_TYPE>
            <MEMBER_CAPTION>Canada</MEMBER_CAPTION>
            <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
            <PARENT_LEVEL>0</PARENT_LEVEL>
            <PARENT_UNIQUE_NAME>[Customer].[Customer Geography].[All Customers]</PARENT_UNIQUE_NAME>
            <PARENT_COUNT>1</PARENT_COUNT>
            <MEMBER_KEY>Canada</MEMBER_KEY>
            <IS_PLACEHOLDERMEMBER>false</IS_PLACEHOLDERMEMBER>
            <IS_DATAMEMBER>false</IS_DATAMEMBER>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
            <LEVEL_NUMBER>1</LEVEL_NUMBER>
            <MEMBER_ORDINAL>3</MEMBER_ORDINAL>
            <MEMBER_NAME>France</MEMBER_NAME>
            <MEMBER_UNIQUE_NAME>[Customer].[Customer Geography].[Country].&amp;[France]</MEMBER_UNIQUE_NAME>
            <MEMBER_TYPE>1</MEMBER_TYPE>
            <MEMBER_CAPTION>France</MEMBER_CAPTION>
            <CHILDREN_CARDINALITY>17</CHILDREN_CARDINALITY>
            <PARENT_LEVEL>0</PARENT_LEVEL>
            <PARENT_UNIQUE_NAME>[Customer].[Customer Geography].[All Customers]</PARENT_UNIQUE_NAME>
            <PARENT_COUNT>1</PARENT_COUNT>
            <MEMBER_KEY>France</MEMBER_KEY>
            <IS_PLACEHOLDERMEMBER>false</IS_PLACEHOLDERMEMBER>
            <IS_DATAMEMBER>false</IS_DATAMEMBER>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
            <LEVEL_NUMBER>1</LEVEL_NUMBER>
            <MEMBER_ORDINAL>4</MEMBER_ORDINAL>
            <MEMBER_NAME>Germany</MEMBER_NAME>
            <MEMBER_UNIQUE_NAME>[Customer].[Customer Geography].[Country].&amp;[Germany]</MEMBER_UNIQUE_NAME>
            <MEMBER_TYPE>1</MEMBER_TYPE>
            <MEMBER_CAPTION>Germany</MEMBER_CAPTION>
            <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
            <PARENT_LEVEL>0</PARENT_LEVEL>
            <PARENT_UNIQUE_NAME>[Customer].[Customer Geography].[All Customers]</PARENT_UNIQUE_NAME>
            <PARENT_COUNT>1</PARENT_COUNT>
            <MEMBER_KEY>Germany</MEMBER_KEY>
            <IS_PLACEHOLDERMEMBER>false</IS_PLACEHOLDERMEMBER>
            <IS_DATAMEMBER>false</IS_DATAMEMBER>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
            <LEVEL_NUMBER>1</LEVEL_NUMBER>
            <MEMBER_ORDINAL>5</MEMBER_ORDINAL>
            <MEMBER_NAME>United Kingdom</MEMBER_NAME>
            <MEMBER_UNIQUE_NAME>[Customer].[Customer Geography].[Country].&amp;[United Kingdom]</MEMBER_UNIQUE_NAME>
            <MEMBER_TYPE>1</MEMBER_TYPE>
            <MEMBER_CAPTION>United Kingdom</MEMBER_CAPTION>
            <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
            <PARENT_LEVEL>0</PARENT_LEVEL>
            <PARENT_UNIQUE_NAME>[Customer].[Customer Geography].[All Customers]</PARENT_UNIQUE_NAME>
            <PARENT_COUNT>1</PARENT_COUNT>
            <MEMBER_KEY>United Kingdom</MEMBER_KEY>
            <IS_PLACEHOLDERMEMBER>false</IS_PLACEHOLDERMEMBER>
            <IS_DATAMEMBER>false</IS_DATAMEMBER>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
            <LEVEL_NUMBER>1</LEVEL_NUMBER>
            <MEMBER_ORDINAL>6</MEMBER_ORDINAL>
            <MEMBER_NAME>United States</MEMBER_NAME>
            <MEMBER_UNIQUE_NAME>[Customer].[Customer Geography].[Country].&amp;[United States]</MEMBER_UNIQUE_NAME>
            <MEMBER_TYPE>1</MEMBER_TYPE>
            <MEMBER_CAPTION>United States</MEMBER_CAPTION>
            <CHILDREN_CARDINALITY>36</CHILDREN_CARDINALITY>
            <PARENT_LEVEL>0</PARENT_LEVEL>
            <PARENT_UNIQUE_NAME>[Customer].[Customer Geography].[All Customers]</PARENT_UNIQUE_NAME>
            <PARENT_COUNT>1</PARENT_COUNT>
            <MEMBER_KEY>United States</MEMBER_KEY>
            <IS_PLACEHOLDERMEMBER>false</IS_PLACEHOLDERMEMBER>
            <IS_DATAMEMBER>false</IS_DATAMEMBER>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetMDSchemaProperties":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_PROPERTIES</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
          <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>Adventure Works DW 2008R2</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_UNIQUE_NAME" name="LEVEL_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MEMBER_UNIQUE_NAME" name="MEMBER_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="PROPERTY_TYPE" name="PROPERTY_TYPE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="PROPERTY_NAME" name="PROPERTY_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="PROPERTY_CAPTION" name="PROPERTY_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DATA_TYPE" name="DATA_TYPE" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="CHARACTER_MAXIMUM_LENGTH" name="CHARACTER_MAXIMUM_LENGTH" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="CHARACTER_OCTET_LENGTH" name="CHARACTER_OCTET_LENGTH" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="NUMERIC_PRECISION" name="NUMERIC_PRECISION" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="NUMERIC_SCALE" name="NUMERIC_SCALE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="PROPERTY_CONTENT_TYPE" name="PROPERTY_CONTENT_TYPE" type="xsd:short" minOccurs="0"/>
                <xsd:element sql:field="SQL_COLUMN_NAME" name="SQL_COLUMN_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LANGUAGE" name="LANGUAGE" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="PROPERTY_ORIGIN" name="PROPERTY_ORIGIN" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="PROPERTY_ATTRIBUTE_HIERARCHY_NAME" name="PROPERTY_ATTRIBUTE_HIERARCHY_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="PROPERTY_CARDINALITY" name="PROPERTY_CARDINALITY" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="MIME_TYPE" name="MIME_TYPE" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="PROPERTY_IS_VISIBLE" name="PROPERTY_IS_VISIBLE" type="xsd:boolean" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
            <PROPERTY_TYPE>5</PROPERTY_TYPE>
            <PROPERTY_NAME>KEY0</PROPERTY_NAME>
            <PROPERTY_CAPTION>KEY0</PROPERTY_CAPTION>
            <DATA_TYPE>130</DATA_TYPE>
            <PROPERTY_ORIGIN>1</PROPERTY_ORIGIN>
            <PROPERTY_IS_VISIBLE>true</PROPERTY_IS_VISIBLE>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
            <PROPERTY_TYPE>5</PROPERTY_TYPE>
            <PROPERTY_NAME>NAME</PROPERTY_NAME>
            <PROPERTY_CAPTION>NAME</PROPERTY_CAPTION>
            <DATA_TYPE>130</DATA_TYPE>
            <PROPERTY_ORIGIN>1</PROPERTY_ORIGIN>
            <PROPERTY_IS_VISIBLE>true</PROPERTY_IS_VISIBLE>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
            <PROPERTY_TYPE>5</PROPERTY_TYPE>
            <PROPERTY_NAME>TRAN0</PROPERTY_NAME>
            <PROPERTY_CAPTION>TRAN0</PROPERTY_CAPTION>
            <DATA_TYPE>130</DATA_TYPE>
            <LANGUAGE>3082</LANGUAGE>
            <PROPERTY_ORIGIN>1</PROPERTY_ORIGIN>
            <PROPERTY_IS_VISIBLE>true</PROPERTY_IS_VISIBLE>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
            <PROPERTY_TYPE>5</PROPERTY_TYPE>
            <PROPERTY_NAME>TRAN1</PROPERTY_NAME>
            <PROPERTY_CAPTION>TRAN1</PROPERTY_CAPTION>
            <DATA_TYPE>130</DATA_TYPE>
            <LANGUAGE>1036</LANGUAGE>
            <PROPERTY_ORIGIN>1</PROPERTY_ORIGIN>
            <PROPERTY_IS_VISIBLE>true</PROPERTY_IS_VISIBLE>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
            <PROPERTY_TYPE>5</PROPERTY_TYPE>
            <PROPERTY_NAME>MEMBER_VALUE</PROPERTY_NAME>
            <PROPERTY_CAPTION>MEMBER_VALUE</PROPERTY_CAPTION>
            <DATA_TYPE>130</DATA_TYPE>
            <PROPERTY_ORIGIN>1</PROPERTY_ORIGIN>
            <PROPERTY_IS_VISIBLE>true</PROPERTY_IS_VISIBLE>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetMDSchemaSets":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_SETS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SET_NAME" name="SET_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SCOPE" name="SCOPE" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="EXPRESSION" name="EXPRESSION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSIONS" name="DIMENSIONS" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SET_CAPTION" name="SET_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SET_DISPLAY_FOLDER" name="SET_DISPLAY_FOLDER" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SET_EVALUATION_CONTEXT" name="SET_EVALUATION_CONTEXT" type="xsd:int" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <SET_NAME>Negative Margin Products</SET_NAME>
            <SCOPE>1</SCOPE>
            <DESCRIPTION/>
            <EXPRESSION>Filter
    (
       [Product].[Subcategory].[Subcategory], 
       [Measures].[Gross Profit Margin] &lt; 0
    )</EXPRESSION>
            <DIMENSIONS>[Product].[Subcategory]</DIMENSIONS>
            <SET_CAPTION>Negative Margin Products</SET_CAPTION>
            <SET_DISPLAY_FOLDER>Sets</SET_DISPLAY_FOLDER>
            <SET_EVALUATION_CONTEXT>2</SET_EVALUATION_CONTEXT>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <SET_NAME>Top 50 Customers</SET_NAME>
            <SCOPE>1</SCOPE>
            <DESCRIPTION/>
            <EXPRESSION>TopCount
    (
       [Customer].[Customer].[Customer].Members,
       50,
       [Measures].[Internet Sales Amount]
    )</EXPRESSION>
            <DIMENSIONS>[Customer].[Customer]</DIMENSIONS>
            <SET_CAPTION>Top 50 Customers</SET_CAPTION>
            <SET_DISPLAY_FOLDER>Sets</SET_DISPLAY_FOLDER>
            <SET_EVALUATION_CONTEXT>2</SET_EVALUATION_CONTEXT>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <SET_NAME>Top 25 Selling Products</SET_NAME>
            <SCOPE>1</SCOPE>
            <DESCRIPTION/>
            <EXPRESSION>TopCount
    (
       [Product].[Product].[Product].Members,
       25,
       [Measures].[Sales Amount]
    )</EXPRESSION>
            <DIMENSIONS>[Product].[Product]</DIMENSIONS>
            <SET_CAPTION>Top 25 Selling Products</SET_CAPTION>
            <SET_DISPLAY_FOLDER>Sets</SET_DISPLAY_FOLDER>
            <SET_EVALUATION_CONTEXT>2</SET_EVALUATION_CONTEXT>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <SET_NAME>New Product Models FY 2006</SET_NAME>
            <SCOPE>1</SCOPE>
            <DESCRIPTION/>
            <EXPRESSION>Exists
    (
       [Product].[Model Name].[Model Name].Members,
       [Product].[Start Date].&amp;[2005-07-01T00:00:00]
    )</EXPRESSION>
            <DIMENSIONS>[Product].[Model Name]</DIMENSIONS>
            <SET_CAPTION>New Product Models FY 2006</SET_CAPTION>
            <SET_DISPLAY_FOLDER>Sets</SET_DISPLAY_FOLDER>
            <SET_EVALUATION_CONTEXT>1</SET_EVALUATION_CONTEXT>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <SET_NAME>New Product Models FY 2007</SET_NAME>
            <SCOPE>1</SCOPE>
            <DESCRIPTION/>
            <EXPRESSION>Exists
    (
       [Product].[Model Name].[Model Name].Members,
       [Product].[Start Date].&amp;[2006-07-01T00:00:00]
    )</EXPRESSION>
            <DIMENSIONS>[Product].[Model Name]</DIMENSIONS>
            <SET_CAPTION>New Product Models FY 2007</SET_CAPTION>
            <SET_DISPLAY_FOLDER>Sets</SET_DISPLAY_FOLDER>
            <SET_EVALUATION_CONTEXT>1</SET_EVALUATION_CONTEXT>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <SET_NAME>New Product Models FY 2008</SET_NAME>
            <SCOPE>1</SCOPE>
            <DESCRIPTION/>
            <EXPRESSION>Exists
    (
       [Product].[Model Name].[Model Name].Members,
       [Product].[Start Date].&amp;[2007-07-01T00:00:00]
    )</EXPRESSION>
            <DIMENSIONS>[Product].[Model Name]</DIMENSIONS>
            <SET_CAPTION>New Product Models FY 2008</SET_CAPTION>
            <SET_DISPLAY_FOLDER>Sets</SET_DISPLAY_FOLDER>
            <SET_EVALUATION_CONTEXT>1</SET_EVALUATION_CONTEXT>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <SET_NAME>Long Lead Products</SET_NAME>
            <SCOPE>1</SCOPE>
            <DESCRIPTION/>
            <EXPRESSION>Exists
    (
       [Product].[Model Name].[Model Name].Members,
       [Product].[Days to Manufacture].&amp;[4]
    )</EXPRESSION>
            <DIMENSIONS>[Product].[Model Name]</DIMENSIONS>
            <SET_CAPTION>Long Lead Products</SET_CAPTION>
            <SET_DISPLAY_FOLDER>Sets</SET_DISPLAY_FOLDER>
            <SET_EVALUATION_CONTEXT>1</SET_EVALUATION_CONTEXT>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <SET_NAME>Core Product Group</SET_NAME>
            <SCOPE>1</SCOPE>
            <DESCRIPTION/>
            <EXPRESSION>DrillDownMember
    (
      [Product].[Product Categories].[Category].Members, 
      [Product].[Product Categories].[Category].[Bikes]
    )</EXPRESSION>
            <DIMENSIONS>[Product].[Product Categories]</DIMENSIONS>
            <SET_CAPTION>Core Product Group</SET_CAPTION>
            <SET_DISPLAY_FOLDER>Sets</SET_DISPLAY_FOLDER>
            <SET_EVALUATION_CONTEXT>1</SET_EVALUATION_CONTEXT>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <SET_NAME>Large Resellers</SET_NAME>
            <SCOPE>1</SCOPE>
            <DESCRIPTION/>
            <EXPRESSION>Exists
    (
       [Reseller].[Reseller].[Reseller].Members,
       [Reseller].[Number of Employees].[Number of Employees].[81 - 100]
    )</EXPRESSION>
            <DIMENSIONS>[Reseller].[Reseller]</DIMENSIONS>
            <SET_CAPTION>Large Resellers</SET_CAPTION>
            <SET_DISPLAY_FOLDER>Sets</SET_DISPLAY_FOLDER>
            <SET_EVALUATION_CONTEXT>1</SET_EVALUATION_CONTEXT>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <SET_NAME>High Discount Promotions</SET_NAME>
            <SCOPE>1</SCOPE>
            <DESCRIPTION/>
            <EXPRESSION>Exists
    (
       [Promotion].[Promotion].[Promotion].Members,
       Filter
       (
		  [Promotion].[Discount Percent].[Discount Percent].Members,
	      [Promotion].[Discount Percent].CurrentMember.MemberValue &gt;= .30
	   )
    )</EXPRESSION>
            <DIMENSIONS>[Promotion].[Promotion]</DIMENSIONS>
            <SET_CAPTION>High Discount Promotions</SET_CAPTION>
            <SET_DISPLAY_FOLDER>Sets</SET_DISPLAY_FOLDER>
            <SET_EVALUATION_CONTEXT>1</SET_EVALUATION_CONTEXT>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <SET_NAME>Summary P&amp;L</SET_NAME>
            <SCOPE>1</SCOPE>
            <DESCRIPTION/>
            <EXPRESSION>{
      [Account].[Accounts].[Account Level 01].&amp;[47], -- Net Income
      [Account].[Accounts].[Account Level 02].&amp;[48], -- Operating Profit
      [Account].[Accounts].[Account Level 03].&amp;[49], -- Gross Margin
      [Account].[Accounts].[Account Level 04].&amp;[50], -- Net Sales
      [Account].[Accounts].[Account Level 05].&amp;[54], -- Discounts
      [Account].[Accounts].[Account Level 05].&amp;[51], -- Gross Sales
      [Account].[Accounts].[Account Level 05].&amp;[53], -- Returns
      [Account].[Accounts].[Account Level 04].&amp;[55], -- Total Cost/Sales
      [Account].[Accounts].[Account Level 03].&amp;[58], -- Operating Expense
      [Account].[Accounts].[Account Level 02].&amp;[88], -- Other I/E
      [Account].[Accounts].[Account Level 03].&amp;[93], -- Currency G/L
      [Account].[Accounts].[Account Level 03].&amp;[91], -- Asset Sales G/L
      [Account].[Accounts].[Account Level 03].&amp;[90], -- Interest Expense
      [Account].[Accounts].[Account Level 03].&amp;[89], -- Interest Income
      [Account].[Accounts].[Account Level 03].&amp;[92], -- Other Income
      [Account].[Accounts].[Account Level 02].&amp;[94]  -- Taxes
    }</EXPRESSION>
            <DIMENSIONS>[Account].[Accounts]</DIMENSIONS>
            <SET_CAPTION>Summary P&amp;L</SET_CAPTION>
            <SET_DISPLAY_FOLDER>Sets</SET_DISPLAY_FOLDER>
            <SET_EVALUATION_CONTEXT>1</SET_EVALUATION_CONTEXT>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetProperties":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_PROPERTIES</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="PropertyName" name="PropertyName" type="xsd:string"/>
                <xsd:element sql:field="PropertyDescription" name="PropertyDescription" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="PropertyType" name="PropertyType" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="PropertyAccessType" name="PropertyAccessType" type="xsd:string"/>
                <xsd:element sql:field="IsRequired" name="IsRequired" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="Value" name="Value" type="xsd:string" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <PropertyName>Catalog</PropertyName>
            <PropertyDescription>Catalog</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>Adventure Works DW 2008R2</Value>
          </row>
          <row>
            <PropertyName>Timeout</PropertyName>
            <PropertyDescription>Timeout</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>Content</PropertyName>
            <PropertyDescription>Content</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>SchemaData</Value>
          </row>
          <row>
            <PropertyName>Format</PropertyName>
            <PropertyDescription>Format</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>Native</Value>
          </row>
          <row>
            <PropertyName>AxisFormat</PropertyName>
            <PropertyDescription>AxisFormat</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>TupleFormat</Value>
          </row>
          <row>
            <PropertyName>BeginRange</PropertyName>
            <PropertyDescription>BeginRange</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>-1</Value>
          </row>
          <row>
            <PropertyName>EndRange</PropertyName>
            <PropertyDescription>EndRange</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>-1</Value>
          </row>
          <row>
            <PropertyName>ShowHiddenCubes</PropertyName>
            <PropertyDescription>ShowHiddenCubes</PropertyDescription>
            <PropertyType>boolean</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>false</Value>
          </row>
          <row>
            <PropertyName>MaximumRows</PropertyName>
            <PropertyDescription>MaximumRows</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>VisualMode</PropertyName>
            <PropertyDescription>VisualMode</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropMsmdCachePolicy</PropertyName>
            <PropertyDescription>DbpropMsmdCachePolicy</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>DbpropMsmdCacheRatio</PropertyName>
            <PropertyDescription>DbpropMsmdCacheRatio</PropertyDescription>
            <PropertyType>double</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>DbpropMsmdCacheMode</PropertyName>
            <PropertyDescription>DbpropMsmdCacheMode</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>DbpropMsmdFlattened2</PropertyName>
            <PropertyDescription>DbpropMsmdFlattened2</PropertyDescription>
            <PropertyType>boolean</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>false</Value>
          </row>
          <row>
            <PropertyName>DbpropInitMode</PropertyName>
            <PropertyDescription>DbpropInitMode</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>SspropInitAppName</PropertyName>
            <PropertyDescription>SspropInitAppName</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>SecuredCellValue</PropertyName>
            <PropertyDescription>SecuredCellValue</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>NonEmptyThreshold</PropertyName>
            <PropertyDescription>NonEmptyThreshold</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>SafetyOptions</PropertyName>
            <PropertyDescription>SafetyOptions</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>DbpropMsmdCacheRatio2</PropertyName>
            <PropertyDescription>DbpropMsmdCacheRatio2</PropertyDescription>
            <PropertyType>double</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>DbpropMsmdUseFormulaCache</PropertyName>
            <PropertyDescription>DbpropMsmdUseFormulaCache</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>DbpropMsmdDynamicDebugLimit</PropertyName>
            <PropertyDescription>DbpropMsmdDynamicDebugLimit</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>DbpropMsmdDebugMode</PropertyName>
            <PropertyDescription>DbpropMsmdDebugMode</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>Dialect</PropertyName>
            <PropertyDescription>Dialect</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>ImpactAnalysis</PropertyName>
            <PropertyDescription>ImpactAnalysis</PropertyDescription>
            <PropertyType>boolean</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>SQLQueryMode</PropertyName>
            <PropertyDescription>SQLQueryMode</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>Calculated</Value>
          </row>
          <row>
            <PropertyName>ClientProcessID</PropertyName>
            <PropertyDescription>ClientProcessID</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>Cube</PropertyName>
            <PropertyDescription>Cube</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>ReturnCellProperties</PropertyName>
            <PropertyDescription>ReturnCellProperties</PropertyDescription>
            <PropertyType>boolean</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>false</Value>
          </row>
          <row>
            <PropertyName>CommitTimeout</PropertyName>
            <PropertyDescription>CommitTimeout</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>ForceCommitTimeout</PropertyName>
            <PropertyDescription>ForceCommitTimeout</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>ExecutionMode</PropertyName>
            <PropertyDescription>ExecutionMode</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>Execute</Value>
          </row>
          <row>
            <PropertyName>RealTimeOlap</PropertyName>
            <PropertyDescription>RealTimeOlap</PropertyDescription>
            <PropertyType>boolean</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>false</Value>
          </row>
          <row>
            <PropertyName>MdxMissingMemberMode</PropertyName>
            <PropertyDescription>MdxMissingMemberMode</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>Default</Value>
          </row>
          <row>
            <PropertyName>DisablePrefetchFacts</PropertyName>
            <PropertyDescription>DisablePrefetchFacts</PropertyDescription>
            <PropertyType>boolean</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>false</Value>
          </row>
          <row>
            <PropertyName>UpdateIsolationLevel</PropertyName>
            <PropertyDescription>UpdateIsolationLevel</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>2</Value>
          </row>
          <row>
            <PropertyName>DbpropMsmdOptimizeResponse</PropertyName>
            <PropertyDescription>DbpropMsmdOptimizeResponse</PropertyDescription>
            <PropertyType>long</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>ResponseEncoding</PropertyName>
            <PropertyDescription>ResponseEncoding</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>Default</Value>
          </row>
          <row>
            <PropertyName>DataSourceInfo</PropertyName>
            <PropertyDescription>DataSourceInfo</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>true</IsRequired>
          </row>
          <row>
            <PropertyName>Password</PropertyName>
            <PropertyDescription>Password</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>LocaleIdentifier</PropertyName>
            <PropertyDescription>LocaleIdentifier</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>1033</Value>
          </row>
          <row>
            <PropertyName>Roles</PropertyName>
            <PropertyDescription>Roles</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>EffectiveRoles</PropertyName>
            <PropertyDescription>EffectiveRoles</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>EffectiveUserName</PropertyName>
            <PropertyDescription>EffectiveUserName</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>DbpropMsmdMDXCompatibility</PropertyName>
            <PropertyDescription>DbpropMsmdMDXCompatibility</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropMsmdSQLCompatibility</PropertyName>
            <PropertyDescription>DbpropMsmdSQLCompatibility</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropMsmdMDXUniqueNameStyle</PropertyName>
            <PropertyDescription>DbpropMsmdMDXUniqueNameStyle</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropMsmdCompareCaseSensitiveStringFlags</PropertyName>
            <PropertyDescription>DbpropMsmdCompareCaseSensitiveStringFlags</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>DbpropMsmdCompareCaseNotSensitiveStringFlags</PropertyName>
            <PropertyDescription>DbpropMsmdCompareCaseNotSensitiveStringFlags</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>SspropInitWsid</PropertyName>
            <PropertyDescription>SspropInitWsid</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>SspropInitPacketsize</PropertyName>
            <PropertyDescription>SspropInitPacketsize</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>ReadOnlySession</PropertyName>
            <PropertyDescription>ReadOnlySession</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>CustomData</PropertyName>
            <PropertyDescription>CustomData</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value/>
          </row>
          <row>
            <PropertyName>DbpropMsmdErrorMessageMode</PropertyName>
            <PropertyDescription>DbpropMsmdErrorMessageMode</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Write</PropertyAccessType>
            <IsRequired>false</IsRequired>
          </row>
          <row>
            <PropertyName>DbpropMsmdSubqueries</PropertyName>
            <PropertyDescription>DbpropMsmdSubqueries</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropMsmdAutoExists</PropertyName>
            <PropertyDescription>DbpropMsmdAutoExists</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropMsmdCellErrorMode</PropertyName>
            <PropertyDescription>DbpropMsmdCellErrorMode</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>ReadWrite</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>Default</Value>
          </row>
          <row>
            <PropertyName>UserName</PropertyName>
            <PropertyDescription>UserName</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>someone</Value>
          </row>
          <row>
            <PropertyName>StateSupport</PropertyName>
            <PropertyDescription>StateSupport</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>Sessions</Value>
          </row>
          <row>
            <PropertyName>MDXSupport</PropertyName>
            <PropertyDescription>MDXSupport</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>Core</Value>
          </row>
          <row>
            <PropertyName>MemoryLockingMode</PropertyName>
            <PropertyDescription>MemoryLockingMode</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>1</Value>
          </row>
          <row>
            <PropertyName>ProviderName</PropertyName>
            <PropertyDescription>ProviderName</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>OLAP Server</Value>
          </row>
          <row>
            <PropertyName>ProviderVersion</PropertyName>
            <PropertyDescription>ProviderVersion</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>10.50.6560.0</Value>
          </row>
          <row>
            <PropertyName>DBMSVersion</PropertyName>
            <PropertyDescription>DBMSVersion</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>10.50.6560.0</Value>
          </row>
          <row>
            <PropertyName>ProviderType</PropertyName>
            <PropertyDescription>ProviderType</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>6</Value>
          </row>
          <row>
            <PropertyName>SQLSupport</PropertyName>
            <PropertyDescription>SQLSupport</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>512</Value>
          </row>
          <row>
            <PropertyName>TransactionDDL</PropertyName>
            <PropertyDescription>TransactionDDL</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>ServerName</PropertyName>
            <PropertyDescription>ServerName</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>DWH-BI</Value>
          </row>
          <row>
            <PropertyName>CatalogLocation</PropertyName>
            <PropertyDescription>CatalogLocation</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>1</Value>
          </row>
          <row>
            <PropertyName>DbpropCatalogTerm</PropertyName>
            <PropertyDescription>DbpropCatalogTerm</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>Database</Value>
          </row>
          <row>
            <PropertyName>DbpropCatalogUsage</PropertyName>
            <PropertyDescription>DbpropCatalogUsage</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropColumnDefinition</PropertyName>
            <PropertyDescription>DbpropColumnDefinition</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropConcatNullBehavior</PropertyName>
            <PropertyDescription>DbpropConcatNullBehavior</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>1</Value>
          </row>
          <row>
            <PropertyName>DbpropDataSourceReadOnly</PropertyName>
            <PropertyDescription>DbpropDataSourceReadOnly</PropertyDescription>
            <PropertyType>boolean</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>false</Value>
          </row>
          <row>
            <PropertyName>DbpropGroupBy</PropertyName>
            <PropertyDescription>DbpropGroupBy</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>2</Value>
          </row>
          <row>
            <PropertyName>DbpropHeterogeneousTables</PropertyName>
            <PropertyDescription>DbpropHeterogeneousTables</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropIdentifierCase</PropertyName>
            <PropertyDescription>DbpropIdentifierCase</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>8</Value>
          </row>
          <row>
            <PropertyName>DbpropMaxIndexSize</PropertyName>
            <PropertyDescription>DbpropMaxIndexSize</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropMaxOpenChapters</PropertyName>
            <PropertyDescription>DbpropMaxOpenChapters</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropMaxRowSize</PropertyName>
            <PropertyDescription>DbpropMaxRowSize</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropMaxRowSizeIncludeBlob</PropertyName>
            <PropertyDescription>DbpropMaxRowSizeIncludeBlob</PropertyDescription>
            <PropertyType>boolean</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>true</Value>
          </row>
          <row>
            <PropertyName>DbpropMaxTablesInSelect</PropertyName>
            <PropertyDescription>DbpropMaxTablesInSelect</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>1</Value>
          </row>
          <row>
            <PropertyName>DbpropMultiTableUpdate</PropertyName>
            <PropertyDescription>DbpropMultiTableUpdate</PropertyDescription>
            <PropertyType>boolean</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>false</Value>
          </row>
          <row>
            <PropertyName>DbpropNullCollation</PropertyName>
            <PropertyDescription>DbpropNullCollation</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>4</Value>
          </row>
          <row>
            <PropertyName>DbpropOrderByColumnsInSelect</PropertyName>
            <PropertyDescription>DbpropOrderByColumnsInSelect</PropertyDescription>
            <PropertyType>boolean</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>false</Value>
          </row>
          <row>
            <PropertyName>DbpropOutputParameterAvailable</PropertyName>
            <PropertyDescription>DbpropOutputParameterAvailable</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>1</Value>
          </row>
          <row>
            <PropertyName>DbpropPersistentIdType</PropertyName>
            <PropertyDescription>DbpropPersistentIdType</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>4</Value>
          </row>
          <row>
            <PropertyName>DbpropPrepareAbortBehavior</PropertyName>
            <PropertyDescription>DbpropPrepareAbortBehavior</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>1</Value>
          </row>
          <row>
            <PropertyName>DbpropPrepareCommitBehavior</PropertyName>
            <PropertyDescription>DbpropPrepareCommitBehavior</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>1</Value>
          </row>
          <row>
            <PropertyName>DbpropProcedureTerm</PropertyName>
            <PropertyDescription>DbpropProcedureTerm</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>Calculated member</Value>
          </row>
          <row>
            <PropertyName>DbpropQuotedIdentifierCase</PropertyName>
            <PropertyDescription>DbpropQuotedIdentifierCase</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>8</Value>
          </row>
          <row>
            <PropertyName>DbpropSchemaUsage</PropertyName>
            <PropertyDescription>DbpropSchemaUsage</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropSqlSupport</PropertyName>
            <PropertyDescription>DbpropSqlSupport</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>512</Value>
          </row>
          <row>
            <PropertyName>DbpropSubqueries</PropertyName>
            <PropertyDescription>DbpropSubqueries</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropSupportedTxnDdl</PropertyName>
            <PropertyDescription>DbpropSupportedTxnDdl</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>DbpropSupportedTxnIsoLevels</PropertyName>
            <PropertyDescription>DbpropSupportedTxnIsoLevels</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>4096</Value>
          </row>
          <row>
            <PropertyName>DbpropSupportedTxnIsoRetain</PropertyName>
            <PropertyDescription>DbpropSupportedTxnIsoRetain</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>292</Value>
          </row>
          <row>
            <PropertyName>DbpropTableTerm</PropertyName>
            <PropertyDescription>DbpropTableTerm</PropertyDescription>
            <PropertyType>string</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>Cube</Value>
          </row>
          <row>
            <PropertyName>MdpropAggregateCellUpdate</PropertyName>
            <PropertyDescription>MdpropAggregateCellUpdate</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>4</Value>
          </row>
          <row>
            <PropertyName>MdpropAxes</PropertyName>
            <PropertyDescription>MdpropAxes</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>2147483647</Value>
          </row>
          <row>
            <PropertyName>MdpropFlatteningSupport</PropertyName>
            <PropertyDescription>MdpropFlatteningSupport</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>1</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxCaseSupport</PropertyName>
            <PropertyDescription>MdpropMdxCaseSupport</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>3</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxDescFlags</PropertyName>
            <PropertyDescription>MdpropMdxDescFlags</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>7</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxDrillFunctions</PropertyName>
            <PropertyDescription>MdpropMdxDrillFunctions</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>7</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxFormulas</PropertyName>
            <PropertyDescription>MdpropMdxFormulas</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>63</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxJoinCubes</PropertyName>
            <PropertyDescription>MdpropMdxJoinCubes</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>1</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxMemberFunctions</PropertyName>
            <PropertyDescription>MdpropMdxMemberFunctions</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>15</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxNonMeasureExpressions</PropertyName>
            <PropertyDescription>MdpropMdxNonMeasureExpressions</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxNumericFunctions</PropertyName>
            <PropertyDescription>MdpropMdxNumericFunctions</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>2047</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxObjQualification</PropertyName>
            <PropertyDescription>MdpropMdxObjQualification</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>496</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxOuterReference</PropertyName>
            <PropertyDescription>MdpropMdxOuterReference</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>0</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxQueryByProperty</PropertyName>
            <PropertyDescription>MdpropMdxQueryByProperty</PropertyDescription>
            <PropertyType>boolean</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>true</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxRangeRowset</PropertyName>
            <PropertyDescription>MdpropMdxRangeRowset</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>4</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxSetFunctions</PropertyName>
            <PropertyDescription>MdpropMdxSetFunctions</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>524287</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxSlicer</PropertyName>
            <PropertyDescription>MdpropMdxSlicer</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>2</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxStringCompop</PropertyName>
            <PropertyDescription>MdpropMdxStringCompop</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>15</Value>
          </row>
          <row>
            <PropertyName>MdpropNamedLevels</PropertyName>
            <PropertyDescription>MdpropNamedLevels</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>3</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxSubqueries</PropertyName>
            <PropertyDescription>MdpropMdxSubqueries</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>31</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxNamedSets</PropertyName>
            <PropertyDescription>MdpropMdxNamedSets</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>15</Value>
          </row>
          <row>
            <PropertyName>MdpropMdxDdlExtensions</PropertyName>
            <PropertyDescription>MdpropMdxDdlExtensions</PropertyDescription>
            <PropertyType>int</PropertyType>
            <PropertyAccessType>Read</PropertyAccessType>
            <IsRequired>false</IsRequired>
            <Value>31</Value>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetSchemaLevels":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_LEVELS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Adventure Works</CUBE_NAME>
          <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>Adventure Works DW 2008R2</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_NAME" name="LEVEL_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_UNIQUE_NAME" name="LEVEL_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_GUID" name="LEVEL_GUID" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_CAPTION" name="LEVEL_CAPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_NUMBER" name="LEVEL_NUMBER" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_CARDINALITY" name="LEVEL_CARDINALITY" type="xsd:unsignedInt" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_TYPE" name="LEVEL_TYPE" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="CUSTOM_ROLLUP_SETTINGS" name="CUSTOM_ROLLUP_SETTINGS" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_UNIQUE_SETTINGS" name="LEVEL_UNIQUE_SETTINGS" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_IS_VISIBLE" name="LEVEL_IS_VISIBLE" type="xsd:boolean" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_ORDERING_PROPERTY" name="LEVEL_ORDERING_PROPERTY" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_DBTYPE" name="LEVEL_DBTYPE" type="xsd:int" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_MASTER_UNIQUE_NAME" name="LEVEL_MASTER_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_NAME_SQL_COLUMN_NAME" name="LEVEL_NAME_SQL_COLUMN_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_KEY_SQL_COLUMN_NAME" name="LEVEL_KEY_SQL_COLUMN_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME" name="LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_ATTRIBUTE_HIERARCHY_NAME" name="LEVEL_ATTRIBUTE_HIERARCHY_NAME" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_KEY_CARDINALITY" name="LEVEL_KEY_CARDINALITY" type="xsd:unsignedShort" minOccurs="0"/>
                <xsd:element sql:field="LEVEL_ORIGIN" name="LEVEL_ORIGIN" type="xsd:unsignedShort" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_NAME>(All)</LEVEL_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[(All)]</LEVEL_UNIQUE_NAME>
            <LEVEL_CAPTION>(All)</LEVEL_CAPTION>
            <LEVEL_NUMBER>0</LEVEL_NUMBER>
            <LEVEL_CARDINALITY>1</LEVEL_CARDINALITY>
            <LEVEL_TYPE>1</LEVEL_TYPE>
            <DESCRIPTION/>
            <CUSTOM_ROLLUP_SETTINGS>0</CUSTOM_ROLLUP_SETTINGS>
            <LEVEL_UNIQUE_SETTINGS>0</LEVEL_UNIQUE_SETTINGS>
            <LEVEL_IS_VISIBLE>true</LEVEL_IS_VISIBLE>
            <LEVEL_ORDERING_PROPERTY>(All)</LEVEL_ORDERING_PROPERTY>
            <LEVEL_DBTYPE>3</LEVEL_DBTYPE>
            <LEVEL_KEY_CARDINALITY>1</LEVEL_KEY_CARDINALITY>
            <LEVEL_ORIGIN>1</LEVEL_ORIGIN>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_NAME>Country</LEVEL_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Country]</LEVEL_UNIQUE_NAME>
            <LEVEL_CAPTION>Country</LEVEL_CAPTION>
            <LEVEL_NUMBER>1</LEVEL_NUMBER>
            <LEVEL_CARDINALITY>7</LEVEL_CARDINALITY>
            <LEVEL_TYPE>0</LEVEL_TYPE>
            <DESCRIPTION/>
            <CUSTOM_ROLLUP_SETTINGS>0</CUSTOM_ROLLUP_SETTINGS>
            <LEVEL_UNIQUE_SETTINGS>0</LEVEL_UNIQUE_SETTINGS>
            <LEVEL_IS_VISIBLE>true</LEVEL_IS_VISIBLE>
            <LEVEL_ORDERING_PROPERTY>Country</LEVEL_ORDERING_PROPERTY>
            <LEVEL_DBTYPE>130</LEVEL_DBTYPE>
            <LEVEL_NAME_SQL_COLUMN_NAME>NAME( [$Customer].[Country] )</LEVEL_NAME_SQL_COLUMN_NAME>
            <LEVEL_KEY_SQL_COLUMN_NAME>KEY( [$Customer].[Country] )</LEVEL_KEY_SQL_COLUMN_NAME>
            <LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME>UNIQUENAME( [$Customer].[Country] )</LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME>
            <LEVEL_ATTRIBUTE_HIERARCHY_NAME>Country</LEVEL_ATTRIBUTE_HIERARCHY_NAME>
            <LEVEL_KEY_CARDINALITY>1</LEVEL_KEY_CARDINALITY>
            <LEVEL_ORIGIN>1</LEVEL_ORIGIN>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_NAME>State-Province</LEVEL_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[State-Province]</LEVEL_UNIQUE_NAME>
            <LEVEL_CAPTION>State-Province</LEVEL_CAPTION>
            <LEVEL_NUMBER>2</LEVEL_NUMBER>
            <LEVEL_CARDINALITY>72</LEVEL_CARDINALITY>
            <LEVEL_TYPE>0</LEVEL_TYPE>
            <DESCRIPTION/>
            <CUSTOM_ROLLUP_SETTINGS>0</CUSTOM_ROLLUP_SETTINGS>
            <LEVEL_UNIQUE_SETTINGS>0</LEVEL_UNIQUE_SETTINGS>
            <LEVEL_IS_VISIBLE>true</LEVEL_IS_VISIBLE>
            <LEVEL_ORDERING_PROPERTY>State-Province</LEVEL_ORDERING_PROPERTY>
            <LEVEL_NAME_SQL_COLUMN_NAME>NAME( [$Customer].[State-Province] )</LEVEL_NAME_SQL_COLUMN_NAME>
            <LEVEL_KEY_SQL_COLUMN_NAME>KEY( [$Customer].[State-Province] )</LEVEL_KEY_SQL_COLUMN_NAME>
            <LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME>UNIQUENAME( [$Customer].[State-Province] )</LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME>
            <LEVEL_ATTRIBUTE_HIERARCHY_NAME>State-Province</LEVEL_ATTRIBUTE_HIERARCHY_NAME>
            <LEVEL_KEY_CARDINALITY>2</LEVEL_KEY_CARDINALITY>
            <LEVEL_ORIGIN>1</LEVEL_ORIGIN>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_NAME>City</LEVEL_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[City]</LEVEL_UNIQUE_NAME>
            <LEVEL_CAPTION>City</LEVEL_CAPTION>
            <LEVEL_NUMBER>3</LEVEL_NUMBER>
            <LEVEL_CARDINALITY>588</LEVEL_CARDINALITY>
            <LEVEL_TYPE>0</LEVEL_TYPE>
            <DESCRIPTION/>
            <CUSTOM_ROLLUP_SETTINGS>0</CUSTOM_ROLLUP_SETTINGS>
            <LEVEL_UNIQUE_SETTINGS>0</LEVEL_UNIQUE_SETTINGS>
            <LEVEL_IS_VISIBLE>true</LEVEL_IS_VISIBLE>
            <LEVEL_ORDERING_PROPERTY>City</LEVEL_ORDERING_PROPERTY>
            <LEVEL_NAME_SQL_COLUMN_NAME>NAME( [$Customer].[City] )</LEVEL_NAME_SQL_COLUMN_NAME>
            <LEVEL_KEY_SQL_COLUMN_NAME>KEY( [$Customer].[City] )</LEVEL_KEY_SQL_COLUMN_NAME>
            <LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME>UNIQUENAME( [$Customer].[City] )</LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME>
            <LEVEL_ATTRIBUTE_HIERARCHY_NAME>City</LEVEL_ATTRIBUTE_HIERARCHY_NAME>
            <LEVEL_KEY_CARDINALITY>2</LEVEL_KEY_CARDINALITY>
            <LEVEL_ORIGIN>1</LEVEL_ORIGIN>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_NAME>Postal Code</LEVEL_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Postal Code]</LEVEL_UNIQUE_NAME>
            <LEVEL_CAPTION>Postal Code</LEVEL_CAPTION>
            <LEVEL_NUMBER>4</LEVEL_NUMBER>
            <LEVEL_CARDINALITY>656</LEVEL_CARDINALITY>
            <LEVEL_TYPE>0</LEVEL_TYPE>
            <DESCRIPTION/>
            <CUSTOM_ROLLUP_SETTINGS>0</CUSTOM_ROLLUP_SETTINGS>
            <LEVEL_UNIQUE_SETTINGS>0</LEVEL_UNIQUE_SETTINGS>
            <LEVEL_IS_VISIBLE>true</LEVEL_IS_VISIBLE>
            <LEVEL_ORDERING_PROPERTY>Postal Code</LEVEL_ORDERING_PROPERTY>
            <LEVEL_NAME_SQL_COLUMN_NAME>NAME( [$Customer].[Postal Code] )</LEVEL_NAME_SQL_COLUMN_NAME>
            <LEVEL_KEY_SQL_COLUMN_NAME>KEY( [$Customer].[Postal Code] )</LEVEL_KEY_SQL_COLUMN_NAME>
            <LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME>UNIQUENAME( [$Customer].[Postal Code] )</LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME>
            <LEVEL_ATTRIBUTE_HIERARCHY_NAME>Postal Code</LEVEL_ATTRIBUTE_HIERARCHY_NAME>
            <LEVEL_KEY_CARDINALITY>3</LEVEL_KEY_CARDINALITY>
            <LEVEL_ORIGIN>1</LEVEL_ORIGIN>
          </row>
          <row>
            <CATALOG_NAME>Adventure Works DW 2008R2</CATALOG_NAME>
            <CUBE_NAME>Adventure Works</CUBE_NAME>
            <DIMENSION_UNIQUE_NAME>[Customer]</DIMENSION_UNIQUE_NAME>
            <HIERARCHY_UNIQUE_NAME>[Customer].[Customer Geography]</HIERARCHY_UNIQUE_NAME>
            <LEVEL_NAME>Customer</LEVEL_NAME>
            <LEVEL_UNIQUE_NAME>[Customer].[Customer Geography].[Customer]</LEVEL_UNIQUE_NAME>
            <LEVEL_CAPTION>Customer</LEVEL_CAPTION>
            <LEVEL_NUMBER>5</LEVEL_NUMBER>
            <LEVEL_CARDINALITY>18485</LEVEL_CARDINALITY>
            <LEVEL_TYPE>4129</LEVEL_TYPE>
            <DESCRIPTION/>
            <CUSTOM_ROLLUP_SETTINGS>0</CUSTOM_ROLLUP_SETTINGS>
            <LEVEL_UNIQUE_SETTINGS>0</LEVEL_UNIQUE_SETTINGS>
            <LEVEL_IS_VISIBLE>true</LEVEL_IS_VISIBLE>
            <LEVEL_ORDERING_PROPERTY>Customer</LEVEL_ORDERING_PROPERTY>
            <LEVEL_DBTYPE>3</LEVEL_DBTYPE>
            <LEVEL_NAME_SQL_COLUMN_NAME>NAME( [$Customer].[Customer] )</LEVEL_NAME_SQL_COLUMN_NAME>
            <LEVEL_KEY_SQL_COLUMN_NAME>KEY( [$Customer].[Customer] )</LEVEL_KEY_SQL_COLUMN_NAME>
            <LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME>UNIQUENAME( [$Customer].[Customer] )</LEVEL_UNIQUE_NAME_SQL_COLUMN_NAME>
            <LEVEL_ATTRIBUTE_HIERARCHY_NAME>Customer</LEVEL_ATTRIBUTE_HIERARCHY_NAME>
            <LEVEL_KEY_CARDINALITY>1</LEVEL_KEY_CARDINALITY>
            <LEVEL_ORIGIN>1</LEVEL_ORIGIN>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
    "testGetSchemaRowsets":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <DiscoverResponse xmlns="urn:schemas-microsoft-com:xml-analysis" xmlns:ddl2="http://schemas.microsoft.com/analysisservices/2003/engine/2" xmlns:ddl2_2="http://schemas.microsoft.com/analysisservices/2003/engine/2/2" xmlns:ddl100="http://schemas.microsoft.com/analysisservices/2008/engine/100" xmlns:ddl100_100="http://schemas.microsoft.com/analysisservices/2008/engine/100/100" xmlns:ddl200="http://schemas.microsoft.com/analysisservices/2010/engine/200" xmlns:ddl200_200="http://schemas.microsoft.com/analysisservices/2010/engine/200/200">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xsd:schema xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
            <xsd:element name="root">
              <xsd:complexType>
                <xsd:sequence minOccurs="0" maxOccurs="unbounded">
                  <xsd:element name="row" type="row"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:simpleType name="uuid">
              <xsd:restriction base="xsd:string">
                <xsd:pattern value="[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}"/>
              </xsd:restriction>
            </xsd:simpleType>
            <xsd:complexType name="xmlDocument">
              <xsd:sequence>
                <xsd:any/>
              </xsd:sequence>
            </xsd:complexType>
            <xsd:complexType name="row">
              <xsd:sequence>
                <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
                <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
                <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
                  <xsd:complexType>
                    <xsd:sequence>
                      <xsd:element sql:field="Name" name="Name" type="xsd:string" minOccurs="0"/>
                      <xsd:element sql:field="Type" name="Type" type="xsd:string" minOccurs="0"/>
                    </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
                <xsd:element sql:field="Description" name="Description" type="xsd:string" minOccurs="0"/>
                <xsd:element sql:field="RestrictionsMask" name="RestrictionsMask" type="xsd:unsignedLong" minOccurs="0"/>
              </xsd:sequence>
            </xsd:complexType>
          </xsd:schema>
          <row>
            <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
            <SchemaGuid>C8B52211-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_TABLES</SchemaName>
            <SchemaGuid>C8B52229-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
            <SchemaGuid>C8B52214-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>TABLE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TABLE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_OLAP_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
            <SchemaGuid>C8B5222C-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>DATA_TYPE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BEST_MATCH</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_CUBES</SchemaName>
            <SchemaGuid>C8B522D8-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>BASE_CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
            <SchemaGuid>C8B522D9-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
            <SchemaGuid>C8B522DA-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_LEVELS</SchemaName>
            <SchemaGuid>C8B522DB-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASURES</SchemaName>
            <SchemaGuid>C8B522DC-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
            <SchemaGuid>C8B522DD-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_CONTENT_TYPE</Name>
              <Type>xsd:short</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_ORIGIN</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>PROPERTY_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>8191</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
            <SchemaGuid>C8B522DE-5CF3-11CE-ADE5-00AA0044773D</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LEVEL_NUMBER</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEMBER_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OP</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>16383</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
            <SchemaGuid>A07CCD07-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LIBRARY_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>INTERFACE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ORIGIN</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
            <SchemaGuid>A07CCD08-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ACTION_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COORDINATE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>INVOCATION</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_SETS</SchemaName>
            <SchemaGuid>A07CCD0B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>HIERARCHY_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SET_EVALUATION_CONTEXT</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>255</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_INSTANCES</SchemaName>
            <SchemaGuid>20518699-2474-4C15-9885-0E947EC7A7E3</SchemaGuid>
            <Restrictions>
              <Name>INSTANCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_KPIS</SchemaName>
            <SchemaGuid>2AE44109-ED3D-4842-B16F-B694D1CB0E3F</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>KPI_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_SOURCE</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCOPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUPS</SchemaName>
            <SchemaGuid>E1625EBF-FA96-42FD-BEA6-DB90ADAFD96B</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_MEASUREGROUP_DIMENSIONS</SchemaName>
            <SchemaGuid>A07CCD33-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASUREGROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_VISIBILITY</Name>
              <Type>xsd:unsignedShort</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>MDSCHEMA_INPUT_DATASOURCES</SchemaName>
            <SchemaGuid>A07CCD32-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SCHEMA_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DATASOURCE_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICES</SchemaName>
            <SchemaGuid>3ADD8A95-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_SERVICE_PARAMETERS</SchemaName>
            <SchemaGuid>3ADD8A75-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARAMETER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_FUNCTIONS</SchemaName>
            <SchemaGuid>3ADD8A79-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>FUNCTION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT</SchemaName>
            <SchemaGuid>3ADD8A76-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ATTRIBUTE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_UNIQUE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_GUID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>NODE_CAPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TREE_OPERATION</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <RestrictionsMask>1023</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_XML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODEL_CONTENT_PMML</SchemaName>
            <SchemaGuid>4290B2D5-0E9C-4AA7-9369-98C95CFD9D13</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_MODELS</SchemaName>
            <SchemaGuid>3ADD8A77-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_TYPE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SERVICE_TYPE_ID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MINING_STRUCTURE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_COLUMNS</SchemaName>
            <SchemaGuid>3ADD8A78-D8B9-11D2-8D2A-00E029154FDE</SchemaGuid>
            <Restrictions>
              <Name>MODEL_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MODEL_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURES</SchemaName>
            <SchemaGuid>883269F3-0CAD-462F-B6F5-E88A72418C4B</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>7</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DMSCHEMA_MINING_STRUCTURE_COLUMNS</SchemaName>
            <SchemaGuid>9952E836-BFBF-4D1F-8535-9B67DBD9DDFE</SchemaGuid>
            <Restrictions>
              <Name>STRUCTURE_CATALOG</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_SCHEMA</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>STRUCTURE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>COLUMN_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DATASOURCES</SchemaName>
            <SchemaGuid>06C03D41-F66D-49F3-B1B8-987F7AF4CF18</SchemaGuid>
            <Restrictions>
              <Name>DataSourceName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>URL</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ProviderType</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AuthenticationMode</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PROPERTIES</SchemaName>
            <SchemaGuid>4B40ADFB-8B09-4758-97BB-636E8AE97BCF</SchemaGuid>
            <Restrictions>
              <Name>PropertyName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
            <SchemaGuid>EEA0302B-7922-4992-8991-0E605D0E5593</SchemaGuid>
            <Restrictions>
              <Name>SchemaName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
            <SchemaGuid>55A9E78B-ACCB-45B4-95A6-94C5065617A7</SchemaGuid>
            <Restrictions>
              <Name>EnumName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_KEYWORDS</SchemaName>
            <SchemaGuid>1426C443-4CDD-4A40-8F45-572FAB9BBAA1</SchemaGuid>
            <Restrictions>
              <Name>Keyword</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LITERALS</SchemaName>
            <SchemaGuid>C3EF5ECB-0A07-4665-A140-B075722DBDC2</SchemaGuid>
            <Restrictions>
              <Name>LiteralName</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_XML_METADATA</SchemaName>
            <SchemaGuid>3444B255-171E-4CB9-AD98-19E57888A75F</SchemaGuid>
            <Restrictions>
              <Name>DatabaseID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubeID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MeasureGroupID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PartitionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PerspectiveID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DimensionPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>RoleID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DatabasePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningModelPermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructureID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AggregationDesignID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MiningStructurePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CubePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>AssemblyID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MdxScriptID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourceViewID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DataSourcePermissionID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CalculatedColumns</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>ObjectExpansion</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>8388607</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACES</SchemaName>
            <SchemaGuid>A07CCD1A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TraceID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_DEFINITION_PROVIDERINFO</SchemaName>
            <SchemaGuid>A07CCD1B-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD18-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRACE_EVENT_CATEGORIES</SchemaName>
            <SchemaGuid>A07CCD19-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>Data</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYUSAGE</SchemaName>
            <SchemaGuid>A07CCD21-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>MemoryUsed</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>BaseObjectType</Name>
              <Type>xsd:unsignedInt</Type>
            </Restrictions>
            <Restrictions>
              <Name>Shrinkable</Name>
              <Type>xsd:boolean</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MEMORYGRANT</SchemaName>
            <SchemaGuid>A07CCD23-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCKS</SchemaName>
            <SchemaGuid>A07CCD24-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TRANSACTION_ID</Name>
              <Type>uuid</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_TYPE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCK_MIN_TOTAL_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>63</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD25-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IMPERSONATED_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_HOST_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_LAST_COMMAND_ELAPSED_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IDLE_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>127</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_SESSIONS</SchemaName>
            <SchemaGuid>A07CCD26-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_USER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CURRENT_DATABASE</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ELAPSED_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_CPU_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_IDLE_TIME_MS</Name>
              <Type>xsd:unsignedLong</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_STATUS</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>511</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_JOBS</SchemaName>
            <SchemaGuid>A07CCD27-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_DESCRIPTION</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_THREADPOOL_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>JOB_MIN_TOTAL_TIME_MS</Name>
              <Type>xsd:long</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_TRANSACTIONS</SchemaName>
            <SchemaGuid>A07CCD28-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>TRANSACTION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>TRANSACTION_SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DB_CONNECTIONS</SchemaName>
            <SchemaGuid>A07CCD2A-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>CONNECTION_ID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_IN_USE</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SERVER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_CATALOG_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CONNECTION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>31</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_MASTER_KEY</SchemaName>
            <SchemaGuid>A07CCD29-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>KEY</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PERFORMANCE_COUNTERS</SchemaName>
            <SchemaGuid>A07CCD2E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>PERF_COUNTER_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_LOCATIONS</SchemaName>
            <SchemaGuid>A07CCD92-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>LOCATION_BACKUP_FILE_PATHNAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>LOCATION_PASSWORD</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD8E-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_PARTITION_STAT</SchemaName>
            <SchemaGuid>A07CCD8F-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_DIMENSION_STAT</SchemaName>
            <SchemaGuid>A07CCD90-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>DIMENSION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMANDS</SchemaName>
            <SchemaGuid>A07CCD34-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <RestrictionsMask>1</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_COMMAND_OBJECTS</SchemaName>
            <SchemaGuid>A07CCD35-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>SESSION_SPID</Name>
              <Type>xsd:int</Type>
            </Restrictions>
            <Restrictions>
              <Name>SESSION_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_ACTIVITY</SchemaName>
            <SchemaGuid>A07CCD36-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_OBJECT_MEMORY_USAGE</SchemaName>
            <SchemaGuid>A07CCD37-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>OBJECT_PARENT_PATH</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>OBJECT_ID</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>3</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLES</SchemaName>
            <SchemaGuid>A07CCD43-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMNS</SchemaName>
            <SchemaGuid>A07CCD44-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
          <row>
            <SchemaName>DISCOVER_STORAGE_TABLE_COLUMN_SEGMENTS</SchemaName>
            <SchemaGuid>A07CCD45-8148-11D0-87BB-00C04FC33942</SchemaGuid>
            <Restrictions>
              <Name>DATABASE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>CUBE_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>MEASURE_GROUP_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <Restrictions>
              <Name>PARTITION_NAME</Name>
              <Type>xsd:string</Type>
            </Restrictions>
            <RestrictionsMask>15</RestrictionsMask>
          </row>
        </root>
      </return>
    </DiscoverResponse>
  </soap:Body>
</soap:Envelope>
"""),
    ],
}