# -*- coding: utf-8
conversation={
    "testFlow":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DBSCHEMA_CATALOGS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CATALOG_NAME>FoodMart</CATALOG_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string"/>
            <xsd:element sql:field="ROLES" name="ROLES" type="xsd:string"/>
            <xsd:element sql:field="DATE_MODIFIED" name="DATE_MODIFIED" type="xsd:dateTime" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <DESCRIPTION>No description available</DESCRIPTION>
        <ROLES/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_CUBES</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Sales</CUBE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>FoodMart</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="CUBE_TYPE" name="CUBE_TYPE" type="xsd:string"/>
            <xsd:element sql:field="CUBE_GUID" name="CUBE_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="CREATED_ON" name="CREATED_ON" type="xsd:dateTime" minOccurs="0"/>
            <xsd:element sql:field="LAST_SCHEMA_UPDATE" name="LAST_SCHEMA_UPDATE" type="xsd:dateTime" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_UPDATED_BY" name="SCHEMA_UPDATED_BY" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="LAST_DATA_UPDATE" name="LAST_DATA_UPDATE" type="xsd:dateTime" minOccurs="0"/>
            <xsd:element sql:field="DATA_UPDATED_BY" name="DATA_UPDATED_BY" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="IS_DRILLTHROUGH_ENABLED" name="IS_DRILLTHROUGH_ENABLED" type="xsd:boolean"/>
            <xsd:element sql:field="IS_WRITE_ENABLED" name="IS_WRITE_ENABLED" type="xsd:boolean"/>
            <xsd:element sql:field="IS_LINKABLE" name="IS_LINKABLE" type="xsd:boolean"/>
            <xsd:element sql:field="IS_SQL_ENABLED" name="IS_SQL_ENABLED" type="xsd:boolean"/>
            <xsd:element sql:field="CUBE_CAPTION" name="CUBE_CAPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DIMENSIONS" name="DIMENSIONS" minOccurs="0"/>
            <xsd:element sql:field="SETS" name="SETS" minOccurs="0"/>
            <xsd:element sql:field="MEASURES" name="MEASURES" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>Sales</CUBE_NAME>
        <CUBE_TYPE>CUBE</CUBE_TYPE>
        <LAST_SCHEMA_UPDATE>2019-04-10T20:16:40</LAST_SCHEMA_UPDATE>
        <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
        <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
        <IS_LINKABLE>false</IS_LINKABLE>
        <IS_SQL_ENABLED>false</IS_SQL_ENABLED>
        <CUBE_CAPTION>Verkaufen</CUBE_CAPTION>
        <DESCRIPTION>Cube Verkaufen</DESCRIPTION>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_HIERARCHIES</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Sales</CUBE_NAME>
          <HIERARCHY_UNIQUE_NAME>[Product]</HIERARCHY_UNIQUE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>FoodMart</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="HIERARCHY_NAME" name="HIERARCHY_NAME" type="xsd:string"/>
            <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="HIERARCHY_GUID" name="HIERARCHY_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="HIERARCHY_CAPTION" name="HIERARCHY_CAPTION" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_TYPE" name="DIMENSION_TYPE" type="xsd:short"/>
            <xsd:element sql:field="HIERARCHY_CARDINALITY" name="HIERARCHY_CARDINALITY" type="xsd:unsignedInt"/>
            <xsd:element sql:field="DEFAULT_MEMBER" name="DEFAULT_MEMBER" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="ALL_MEMBER" name="ALL_MEMBER" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="STRUCTURE" name="STRUCTURE" type="xsd:short"/>
            <xsd:element sql:field="IS_VIRTUAL" name="IS_VIRTUAL" type="xsd:boolean"/>
            <xsd:element sql:field="IS_READWRITE" name="IS_READWRITE" type="xsd:boolean"/>
            <xsd:element sql:field="DIMENSION_UNIQUE_SETTINGS" name="DIMENSION_UNIQUE_SETTINGS" type="xsd:int"/>
            <xsd:element sql:field="DIMENSION_IS_VISIBLE" name="DIMENSION_IS_VISIBLE" type="xsd:boolean"/>
            <xsd:element sql:field="HIERARCHY_IS_VISIBLE" name="HIERARCHY_IS_VISIBLE" type="xsd:boolean"/>
            <xsd:element sql:field="HIERARCHY_ORDINAL" name="HIERARCHY_ORDINAL" type="xsd:unsignedInt"/>
            <xsd:element sql:field="DIMENSION_IS_SHARED" name="DIMENSION_IS_SHARED" type="xsd:boolean"/>
            <xsd:element sql:field="PARENT_CHILD" name="PARENT_CHILD" type="xsd:boolean" minOccurs="0"/>
            <xsd:element sql:field="LEVELS" name="LEVELS" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>Sales</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_NAME>Product</HIERARCHY_NAME>
        <HIERARCHY_UNIQUE_NAME>[Product]</HIERARCHY_UNIQUE_NAME>
        <HIERARCHY_CAPTION>Product</HIERARCHY_CAPTION>
        <DIMENSION_TYPE>3</DIMENSION_TYPE>
        <HIERARCHY_CARDINALITY>2256</HIERARCHY_CARDINALITY>
        <DEFAULT_MEMBER>[Product].[All Products]</DEFAULT_MEMBER>
        <ALL_MEMBER>[Product].[All Products]</ALL_MEMBER>
        <DESCRIPTION>Sales Cube - Product Hierarchy</DESCRIPTION>
        <STRUCTURE>0</STRUCTURE>
        <IS_VIRTUAL>false</IS_VIRTUAL>
        <IS_READWRITE>false</IS_READWRITE>
        <DIMENSION_UNIQUE_SETTINGS>0</DIMENSION_UNIQUE_SETTINGS>
        <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
        <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
        <HIERARCHY_ORDINAL>6</HIERARCHY_ORDINAL>
        <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
        <PARENT_CHILD>false</PARENT_CHILD>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_LEVELS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Sales</CUBE_NAME>
          <HIERARCHY_UNIQUE_NAME>[Product]</HIERARCHY_UNIQUE_NAME>
          <LEVEL_UNIQUE_NAME>[Product].[Product Category]</LEVEL_UNIQUE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>FoodMart</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="LEVEL_NAME" name="LEVEL_NAME" type="xsd:string"/>
            <xsd:element sql:field="LEVEL_UNIQUE_NAME" name="LEVEL_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="LEVEL_GUID" name="LEVEL_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="LEVEL_CAPTION" name="LEVEL_CAPTION" type="xsd:string"/>
            <xsd:element sql:field="LEVEL_NUMBER" name="LEVEL_NUMBER" type="xsd:unsignedInt"/>
            <xsd:element sql:field="LEVEL_CARDINALITY" name="LEVEL_CARDINALITY" type="xsd:unsignedInt"/>
            <xsd:element sql:field="LEVEL_TYPE" name="LEVEL_TYPE" type="xsd:int"/>
            <xsd:element sql:field="CUSTOM_ROLLUP_SETTINGS" name="CUSTOM_ROLLUP_SETTINGS" type="xsd:int"/>
            <xsd:element sql:field="LEVEL_UNIQUE_SETTINGS" name="LEVEL_UNIQUE_SETTINGS" type="xsd:int"/>
            <xsd:element sql:field="LEVEL_IS_VISIBLE" name="LEVEL_IS_VISIBLE" type="xsd:boolean"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>Sales</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Product]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_NAME>Product Category</LEVEL_NAME>
        <LEVEL_UNIQUE_NAME>[Product].[Product Category]</LEVEL_UNIQUE_NAME>
        <LEVEL_CAPTION>Product Category</LEVEL_CAPTION>
        <LEVEL_NUMBER>3</LEVEL_NUMBER>
        <LEVEL_CARDINALITY>55</LEVEL_CARDINALITY>
        <LEVEL_TYPE>0</LEVEL_TYPE>
        <CUSTOM_ROLLUP_SETTINGS>0</CUSTOM_ROLLUP_SETTINGS>
        <LEVEL_UNIQUE_SETTINGS>0</LEVEL_UNIQUE_SETTINGS>
        <LEVEL_IS_VISIBLE>true</LEVEL_IS_VISIBLE>
        <DESCRIPTION>Sales Cube - Product Hierarchy - Product Category Level</DESCRIPTION>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_MEMBERS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>Sales</CUBE_NAME>
          <HIERARCHY_UNIQUE_NAME>[Product]</HIERARCHY_UNIQUE_NAME>
          <LEVEL_UNIQUE_NAME>[Product].[Product Category]</LEVEL_UNIQUE_NAME>
          <MEMBER_UNIQUE_NAME>[Product].[Drink].[Alcoholic Beverages].[Beer and Wine]</MEMBER_UNIQUE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>FoodMart</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="LEVEL_UNIQUE_NAME" name="LEVEL_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="LEVEL_NUMBER" name="LEVEL_NUMBER" type="xsd:unsignedInt"/>
            <xsd:element sql:field="MEMBER_ORDINAL" name="MEMBER_ORDINAL" type="xsd:unsignedInt"/>
            <xsd:element sql:field="MEMBER_NAME" name="MEMBER_NAME" type="xsd:string"/>
            <xsd:element sql:field="MEMBER_UNIQUE_NAME" name="MEMBER_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="MEMBER_TYPE" name="MEMBER_TYPE" type="xsd:int"/>
            <xsd:element sql:field="MEMBER_GUID" name="MEMBER_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="MEMBER_CAPTION" name="MEMBER_CAPTION" type="xsd:string"/>
            <xsd:element sql:field="CHILDREN_CARDINALITY" name="CHILDREN_CARDINALITY" type="xsd:unsignedInt"/>
            <xsd:element sql:field="PARENT_LEVEL" name="PARENT_LEVEL" type="xsd:unsignedInt"/>
            <xsd:element sql:field="PARENT_UNIQUE_NAME" name="PARENT_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="PARENT_COUNT" name="PARENT_COUNT" type="xsd:unsignedInt"/>
            <xsd:element sql:field="TREE_OP" name="TREE_OP" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DEPTH" name="DEPTH" type="xsd:int" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>Sales</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Product]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Product]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Product].[Product Category]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>3</LEVEL_NUMBER>
        <MEMBER_ORDINAL>3</MEMBER_ORDINAL>
        <MEMBER_NAME>Beer and Wine</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Product].[Drink].[Alcoholic Beverages].[Beer and Wine]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Beer and Wine</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>2</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>2</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Product].[Drink].[Alcoholic Beverages]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetDBSchemaCatalogs":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DBSCHEMA_CATALOGS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string"/>
            <xsd:element sql:field="ROLES" name="ROLES" type="xsd:string"/>
            <xsd:element sql:field="DATE_MODIFIED" name="DATE_MODIFIED" type="xsd:dateTime" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <DESCRIPTION>No description available</DESCRIPTION>
        <ROLES/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetDBSchemaColumns":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DBSCHEMA_COLUMNS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="TABLE_CATALOG" name="TABLE_CATALOG" type="xsd:string"/>
            <xsd:element sql:field="TABLE_SCHEMA" name="TABLE_SCHEMA" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="TABLE_NAME" name="TABLE_NAME" type="xsd:string"/>
            <xsd:element sql:field="COLUMN_NAME" name="COLUMN_NAME" type="xsd:string"/>
            <xsd:element sql:field="ORDINAL_POSITION" name="ORDINAL_POSITION" type="xsd:unsignedInt"/>
            <xsd:element sql:field="COLUMN_HAS_DEFAULT" name="COLUMN_HAS_DEFAULT" type="xsd:boolean" minOccurs="0"/>
            <xsd:element sql:field="COLUMN_FLAGS" name="COLUMN_FLAGS" type="xsd:unsignedInt"/>
            <xsd:element sql:field="IS_NULLABLE" name="IS_NULLABLE" type="xsd:boolean"/>
            <xsd:element sql:field="DATA_TYPE" name="DATA_TYPE" type="xsd:unsignedShort"/>
            <xsd:element sql:field="CHARACTER_MAXIMUM_LENGTH" name="CHARACTER_MAXIMUM_LENGTH" type="xsd:unsignedInt" minOccurs="0"/>
            <xsd:element sql:field="CHARACTER_OCTET_LENGTH" name="CHARACTER_OCTET_LENGTH" type="xsd:unsignedInt" minOccurs="0"/>
            <xsd:element sql:field="NUMERIC_PRECISION" name="NUMERIC_PRECISION" type="xsd:unsignedShort" minOccurs="0"/>
            <xsd:element sql:field="NUMERIC_SCALE" name="NUMERIC_SCALE" type="xsd:short" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>8</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>9</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>10</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>11</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>12</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>13</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>14</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>15</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>16</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>17</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>18</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>19</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>20</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>21</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>22</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>23</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>24</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>25</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>26</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>27</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>28</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>29</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>30</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>31</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>32</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>33</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>34</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>35</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>36</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>37</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>38</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>39</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>40</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>41</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>42</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>43</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>44</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>45</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>46</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>47</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>48</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>49</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>50</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>51</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>52</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>53</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>54</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>55</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>56</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>57</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>58</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>59</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>60</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>61</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>62</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>63</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>64</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>65</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>66</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>67</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Year!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>68</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>69</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>70</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>71</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>72</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>73</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>74</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>75</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>76</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>77</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>78</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>79</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>80</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>81</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>82</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>83</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>84</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>85</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>86</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>87</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>88</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>89</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>90</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>91</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>92</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>93</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>94</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>95</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>96</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>97</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>98</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>99</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>100</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>101</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>102</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>103</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>104</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>105</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>106</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>107</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>108</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>109</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>110</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>111</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>112</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>113</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>114</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>115</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>116</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>117</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>118</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>119</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>120</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>121</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>122</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>123</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>124</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>125</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>126</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>127</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>128</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>129</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>130</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>131</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>132</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>133</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>134</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>135</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>136</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Time:Month!$name</COLUMN_NAME>
        <ORDINAL_POSITION>137</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>138</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>139</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>140</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>141</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>142</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>143</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>144</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>145</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>146</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>147</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>148</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>149</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>150</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>151</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>152</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>153</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>154</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>155</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>156</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>157</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>158</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>159</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>160</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>161</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>162</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>163</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>164</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>165</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>166</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>167</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>168</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>169</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>170</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>171</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>172</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>173</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>174</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>175</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>176</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>177</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>178</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>179</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>180</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>181</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>182</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>183</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>184</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>185</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>186</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>187</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>188</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>189</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>190</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>191</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>192</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>193</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>194</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>195</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>196</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>197</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>198</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>199</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>200</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>201</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>202</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>203</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>204</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>205</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>206</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>207</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>208</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>209</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>210</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>211</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>212</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>213</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>214</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>215</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>216</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>217</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>218</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>219</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>220</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>221</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>222</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>223</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>224</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>225</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>226</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>227</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>228</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>229</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>230</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>231</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>232</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>233</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>234</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>235</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>236</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>237</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>238</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>239</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>240</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>241</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>242</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>243</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>244</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>245</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>246</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>247</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>248</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>249</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>250</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>251</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>252</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>253</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>254</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>255</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>256</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>257</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>258</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>259</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>260</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>261</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>262</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>263</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>264</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>265</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>266</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>267</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>268</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>269</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>270</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>271</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>272</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>273</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>274</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>275</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>276</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>277</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>278</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>279</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>280</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>281</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>282</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>283</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>284</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>285</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>286</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>287</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>288</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>289</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>290</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>291</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>292</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>293</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>294</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>295</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>296</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>297</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>298</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>299</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>300</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>301</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>302</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>303</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>304</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>305</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>306</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>307</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>308</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>309</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Type</COLUMN_NAME>
        <ORDINAL_POSITION>310</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Manager</COLUMN_NAME>
        <ORDINAL_POSITION>311</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>312</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Grocery Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>313</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Frozen Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>314</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Meat Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>315</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Has coffee bar</COLUMN_NAME>
        <ORDINAL_POSITION>316</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Street address</COLUMN_NAME>
        <ORDINAL_POSITION>317</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>318</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>319</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>320</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>321</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>322</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>323</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>324</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>325</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>326</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>327</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>328</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>329</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>330</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>331</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>332</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>333</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>334</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>335</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>336</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>337</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>338</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>339</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>340</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>341</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>342</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>343</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>344</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>345</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>346</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>347</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>348</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>349</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>350</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>351</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>352</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>353</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>354</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>355</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>356</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>357</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>358</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>359</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>360</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>361</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>362</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>363</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>364</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>365</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>366</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>367</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>368</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>369</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>370</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>371</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>372</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>373</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>374</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>375</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>376</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>377</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>378</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>379</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>380</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>381</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>382</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>383</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>384</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>385</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>386</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Pay Type:Pay Type!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>387</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>388</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>389</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>390</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>391</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>392</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>393</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>394</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>395</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>396</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>397</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>398</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>399</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>400</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>401</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>402</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>403</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>404</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>405</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>406</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>407</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>408</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>409</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>410</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>411</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>412</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>413</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>414</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>415</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>416</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>417</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>418</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>419</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>420</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>421</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>422</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>423</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>424</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>425</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>426</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>427</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>428</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>429</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>430</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>431</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>432</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>433</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>434</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>435</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>436</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>437</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>438</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>439</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>440</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>441</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>442</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>443</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>444</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>445</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>446</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>447</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>448</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>449</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>450</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>451</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>452</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>453</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>454</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>455</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>456</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>457</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>458</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>459</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>460</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>461</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>462</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>463</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>464</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>465</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>466</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>467</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>468</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>469</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>470</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>471</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>472</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>473</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>474</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>475</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>476</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>477</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>478</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>479</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>480</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>481</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>482</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>483</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>484</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>485</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>486</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>487</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>488</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>489</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>490</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>491</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>492</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>493</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>494</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>495</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>496</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>497</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>498</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>499</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>500</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>501</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>502</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>503</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>504</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>505</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>506</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>507</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>508</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>509</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>510</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>511</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>512</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>513</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>514</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>515</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>516</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>517</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>518</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>519</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>520</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>521</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>522</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>523</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>524</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>525</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>526</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Management Role!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>527</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>528</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>529</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>530</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>531</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>532</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>533</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>534</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>535</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>536</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>537</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>538</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>539</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>540</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>541</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>542</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>543</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>544</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>545</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>546</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>547</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>548</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>549</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>550</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>551</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>552</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>553</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>554</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>555</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>556</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>557</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>558</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>559</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>560</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Position:Position Title!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>561</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>562</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>563</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>564</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>565</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>566</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>567</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>568</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>569</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>570</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>571</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>572</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>573</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>574</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>575</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>576</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>577</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>578</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>579</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>580</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>581</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>582</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>583</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>584</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>585</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>586</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>587</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>588</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>589</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>590</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>591</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>592</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>593</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>594</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>595</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>596</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>597</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>598</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>599</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>600</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>601</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>602</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>603</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>604</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>605</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>606</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>607</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>608</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>609</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>610</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>611</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>612</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>613</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>614</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>615</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>616</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>617</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>618</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>619</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>620</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>621</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>622</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>623</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>624</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>625</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>626</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>627</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>628</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>629</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>630</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Department:Department Description!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>631</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>632</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>633</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>634</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>635</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>636</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>637</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>638</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>639</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>640</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>641</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>642</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>643</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>644</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>645</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>646</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>647</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>648</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>649</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>650</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>651</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>652</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>653</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>654</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>655</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>656</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>657</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>658</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>659</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>660</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>661</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>662</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>663</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>664</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>665</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>666</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>667</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>668</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>669</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>670</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>671</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>672</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>673</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>674</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>675</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>676</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>677</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>678</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>679</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>680</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>681</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>682</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>683</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>684</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>685</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>686</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>687</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>688</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>689</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>690</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>691</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>692</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>693</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>694</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>695</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>696</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>697</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>698</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>699</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>700</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>701</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!$name</COLUMN_NAME>
        <ORDINAL_POSITION>702</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!Marital Status</COLUMN_NAME>
        <ORDINAL_POSITION>703</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!Position Title</COLUMN_NAME>
        <ORDINAL_POSITION>704</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!Gender</COLUMN_NAME>
        <ORDINAL_POSITION>705</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!Salary</COLUMN_NAME>
        <ORDINAL_POSITION>706</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!Education Level</COLUMN_NAME>
        <ORDINAL_POSITION>707</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Employees:Employee Id!Management Role</COLUMN_NAME>
        <ORDINAL_POSITION>708</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:Count</COLUMN_NAME>
        <ORDINAL_POSITION>709</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:Number of Employees</COLUMN_NAME>
        <ORDINAL_POSITION>710</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:Employee Salary</COLUMN_NAME>
        <ORDINAL_POSITION>711</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <COLUMN_NAME>Measures:Avg Salary</COLUMN_NAME>
        <ORDINAL_POSITION>712</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>713</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>714</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>715</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>716</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>717</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>718</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>719</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>720</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>721</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>722</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>723</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>724</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>725</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>726</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>727</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>728</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>729</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>730</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>731</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>732</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>733</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>734</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>735</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>736</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>737</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>738</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>739</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>740</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>741</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>742</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>743</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>744</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>745</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>746</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>747</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>748</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>749</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>750</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>751</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>752</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>753</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>754</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>755</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>756</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>757</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>758</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>759</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>760</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>761</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>762</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>763</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>764</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>765</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>766</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>767</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>768</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>769</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>770</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>771</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>772</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>773</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>774</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>775</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>776</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>777</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>778</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>779</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>780</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>781</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>782</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>783</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>784</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>785</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>786</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>787</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>788</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>789</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>790</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>791</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>792</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>793</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>794</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>795</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>796</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>797</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>798</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>799</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>800</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>801</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>802</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>803</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>804</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>805</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>806</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>807</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>808</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>809</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>810</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>811</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>812</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>813</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>814</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>815</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>816</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>817</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>818</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>819</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>820</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>821</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>822</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>823</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>824</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>825</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>826</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>827</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>828</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>829</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>830</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>831</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>832</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>833</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>834</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>835</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>836</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>837</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>838</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>839</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>840</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>841</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>842</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>843</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>844</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>845</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>846</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>847</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>848</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>849</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>850</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>851</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>852</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>853</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>854</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>855</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>856</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>857</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>858</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>859</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>860</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>861</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>862</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>863</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>864</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>865</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>866</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>867</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>868</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>869</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>870</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>871</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>872</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>873</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>874</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>875</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>876</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>877</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>878</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>879</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>880</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>881</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>882</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>883</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>884</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>885</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>886</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>887</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>888</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>889</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>890</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>891</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>892</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>893</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>894</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>895</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>896</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>897</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>898</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>899</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>900</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>901</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>902</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>903</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>904</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>905</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>906</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>907</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>908</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>909</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>910</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>911</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>912</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>913</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>914</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>915</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>916</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>917</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>918</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Type</COLUMN_NAME>
        <ORDINAL_POSITION>919</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Manager</COLUMN_NAME>
        <ORDINAL_POSITION>920</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>921</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Grocery Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>922</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Frozen Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>923</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Meat Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>924</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Has coffee bar</COLUMN_NAME>
        <ORDINAL_POSITION>925</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Street address</COLUMN_NAME>
        <ORDINAL_POSITION>926</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>927</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>928</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>929</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>930</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>931</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>932</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>933</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>934</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>935</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>936</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>937</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>938</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>939</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>940</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>941</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>942</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>943</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>944</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>945</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>946</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>947</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>948</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>949</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>950</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>951</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>952</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>953</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>954</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>955</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>956</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>957</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>958</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>959</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>960</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>961</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>962</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>963</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>964</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>965</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>966</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>967</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>968</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>969</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>970</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>971</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>972</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>973</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>974</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>975</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>976</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>977</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>978</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>979</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>980</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>981</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>982</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>983</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>984</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>985</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>986</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>987</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>988</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>989</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>990</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>991</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>992</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>993</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>994</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>995</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>996</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>997</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>998</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>999</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1000</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1001</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1002</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1003</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1004</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1005</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1006</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1007</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1008</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1009</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1010</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1011</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1012</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1013</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1014</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1015</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1016</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1017</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1018</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1019</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1020</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1021</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1022</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1023</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1024</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1025</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1026</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1027</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1028</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1029</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1030</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1031</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1032</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1033</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1034</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1035</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1036</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1037</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1038</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1039</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1040</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1041</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1042</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1043</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1044</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1045</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1046</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1047</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1048</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1049</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1050</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1051</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1052</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1053</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1054</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1055</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1056</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1057</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1058</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1059</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1060</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1061</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1062</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1063</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1064</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1065</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1066</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1067</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1068</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1069</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1070</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1071</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1072</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1073</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1074</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1075</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1076</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1077</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1078</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1079</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1080</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1081</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1082</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1083</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1084</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1085</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1086</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1087</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1088</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1089</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1090</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1091</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1092</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1093</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1094</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1095</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1096</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1097</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1098</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1099</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1100</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1101</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1102</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1103</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1104</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1105</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1106</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1107</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1108</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1109</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1110</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1111</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1112</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1113</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1114</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1115</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1116</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1117</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1118</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1119</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1120</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1121</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1122</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1123</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1124</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1125</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1126</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1127</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1128</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1129</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1130</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1131</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1132</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1133</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1134</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1135</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1136</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1137</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1138</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1139</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1140</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1141</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1142</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1143</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1144</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1145</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1146</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1147</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1148</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1149</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1150</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1151</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1152</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1153</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1154</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1155</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1156</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1157</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1158</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1159</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1160</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1161</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1162</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1163</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1164</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1165</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1166</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1167</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1168</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1169</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1170</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1171</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1172</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1173</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1174</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1175</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1176</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1177</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1178</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1179</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1180</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1181</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1182</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1183</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1184</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1185</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1186</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1187</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1188</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1189</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1190</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1191</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1192</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1193</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1194</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1195</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1196</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1197</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1198</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1199</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1200</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1201</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1202</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1203</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1204</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1205</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1206</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1207</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1208</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1209</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1210</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1211</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1212</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1213</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1214</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1215</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1216</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1217</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1218</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1219</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1220</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1221</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1222</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1223</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1224</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1225</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1226</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1227</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1228</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1229</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1230</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1231</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1232</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1233</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1234</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1235</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1236</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1237</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1238</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1239</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1240</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1241</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1242</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1243</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1244</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1245</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1246</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1247</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1248</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1249</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1250</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1251</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1252</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1253</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1254</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1255</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1256</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1257</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1258</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1259</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1260</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1261</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1262</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1263</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1264</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1265</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1266</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1267</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1268</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1269</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1270</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1271</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1272</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1273</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1274</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1275</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1276</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1277</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1278</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1279</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1280</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1281</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1282</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1283</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1284</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1285</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1286</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1287</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1288</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1289</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1290</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1291</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1292</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1293</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1294</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1295</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1296</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1297</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1298</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1299</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1300</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1301</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1302</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1303</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1304</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1305</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1306</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1307</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1308</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1309</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1310</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1311</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1312</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1313</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1314</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1315</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1316</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1317</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1318</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1319</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1320</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1321</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1322</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1323</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1324</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1325</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1326</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1327</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1328</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1329</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1330</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1331</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1332</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1333</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1334</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1335</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1336</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1337</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1338</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1339</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1340</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1341</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1342</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1343</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1344</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1345</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1346</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1347</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1348</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1349</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1350</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1351</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1352</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1353</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1354</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1355</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1356</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1357</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1358</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1359</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1360</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1361</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1362</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1363</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1364</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1365</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1366</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1367</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1368</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1369</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1370</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1371</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1372</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1373</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1374</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1375</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1376</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1377</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1378</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1379</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1380</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1381</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1382</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1383</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1384</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1385</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1386</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1387</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1388</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1389</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1390</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1391</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1392</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1393</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1394</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1395</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1396</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1397</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1398</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1399</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1400</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1401</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1402</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1403</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1404</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1405</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1406</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1407</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1408</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1409</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1410</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1411</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1412</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1413</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1414</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1415</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1416</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1417</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1418</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1419</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1420</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1421</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1422</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1423</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1424</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1425</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1426</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1427</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1428</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1429</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1430</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1431</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1432</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1433</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1434</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1435</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1436</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1437</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1438</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1439</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1440</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1441</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1442</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1443</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1444</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1445</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1446</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1447</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1448</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1449</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1450</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1451</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1452</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1453</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1454</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1455</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1456</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1457</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1458</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1459</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1460</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1461</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1462</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1463</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1464</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1465</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1466</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1467</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1468</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1469</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1470</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1471</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1472</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1473</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1474</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1475</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1476</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1477</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1478</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1479</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1480</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1481</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1482</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1483</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1484</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1485</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1486</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1487</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1488</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1489</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1490</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1491</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1492</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1493</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1494</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1495</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1496</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1497</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1498</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1499</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1500</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1501</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1502</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1503</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1504</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1505</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1506</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1507</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1508</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1509</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1510</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1511</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1512</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1513</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1514</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1515</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1516</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1517</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1518</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1519</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1520</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1521</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1522</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1523</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1524</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1525</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1526</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1527</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1528</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1529</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1530</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1531</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1532</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1533</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1534</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1535</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1536</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1537</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1538</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1539</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1540</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1541</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1542</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1543</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1544</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1545</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1546</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1547</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1548</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1549</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1550</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1551</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1552</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1553</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1554</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1555</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1556</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1557</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1558</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1559</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1560</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1561</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1562</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1563</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1564</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1565</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1566</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1567</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1568</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1569</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1570</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1571</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1572</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1573</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1574</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1575</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1576</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1577</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1578</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1579</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1580</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1581</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1582</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1583</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1584</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1585</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1586</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1587</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1588</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1589</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1590</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1591</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1592</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1593</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1594</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1595</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1596</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1597</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1598</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1599</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1600</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1601</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1602</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1603</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1604</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1605</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1606</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1607</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1608</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1609</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1610</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1611</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1612</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1613</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1614</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1615</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1616</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1617</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1618</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1619</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1620</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1621</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1622</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1623</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1624</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1625</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1626</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1627</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1628</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1629</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1630</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1631</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1632</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1633</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1634</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1635</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1636</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1637</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1638</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1639</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1640</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1641</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1642</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1643</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1644</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1645</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1646</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1647</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1648</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1649</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1650</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1651</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1652</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1653</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1654</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1655</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1656</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1657</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1658</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1659</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1660</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1661</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1662</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1663</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1664</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1665</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1666</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1667</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1668</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1669</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1670</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1671</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1672</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1673</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1674</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1675</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1676</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1677</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1678</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1679</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1680</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1681</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1682</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1683</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1684</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1685</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1686</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1687</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1688</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1689</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1690</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1691</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1692</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1693</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1694</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1695</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1696</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1697</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1698</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1699</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1700</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1701</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1702</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1703</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1704</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1705</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1706</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1707</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1708</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1709</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1710</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1711</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1712</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1713</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1714</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1715</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1716</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1717</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1718</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1719</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1720</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1721</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1722</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1723</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1724</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1725</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1726</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1727</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1728</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1729</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1730</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1731</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1732</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1733</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1734</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1735</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1736</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1737</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1738</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1739</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1740</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1741</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1742</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1743</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1744</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1745</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1746</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1747</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1748</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1749</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1750</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1751</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1752</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1753</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1754</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1755</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1756</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1757</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1758</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1759</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1760</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1761</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1762</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1763</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1764</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1765</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1766</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1767</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1768</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1769</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1770</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1771</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1772</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1773</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1774</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1775</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1776</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1777</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1778</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1779</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1780</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1781</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1782</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1783</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1784</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1785</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1786</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1787</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1788</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1789</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1790</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1791</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1792</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1793</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1794</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1795</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1796</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1797</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1798</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1799</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1800</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1801</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1802</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1803</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1804</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1805</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1806</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1807</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1808</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1809</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1810</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1811</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1812</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1813</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1814</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1815</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1816</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1817</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1818</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1819</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1820</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1821</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1822</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1823</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1824</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1825</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1826</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1827</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1828</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1829</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1830</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1831</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1832</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1833</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1834</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1835</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1836</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1837</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1838</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1839</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1840</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1841</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1842</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1843</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1844</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1845</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1846</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1847</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1848</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1849</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1850</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1851</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1852</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1853</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1854</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1855</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1856</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1857</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1858</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!$name</COLUMN_NAME>
        <ORDINAL_POSITION>1859</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!Gender</COLUMN_NAME>
        <ORDINAL_POSITION>1860</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!Marital Status</COLUMN_NAME>
        <ORDINAL_POSITION>1861</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!Education</COLUMN_NAME>
        <ORDINAL_POSITION>1862</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!Yearly Income</COLUMN_NAME>
        <ORDINAL_POSITION>1863</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1864</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1865</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1866</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1867</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1868</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1869</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1870</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1871</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1872</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1873</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1874</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1875</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1876</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1877</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1878</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1879</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1880</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1881</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1882</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1883</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1884</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1885</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1886</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1887</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1888</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1889</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1890</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1891</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1892</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1893</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1894</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1895</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1896</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1897</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1898</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1899</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1900</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1901</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1902</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1903</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1904</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1905</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1906</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1907</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1908</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1909</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1910</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1911</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1912</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1913</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1914</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1915</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1916</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1917</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1918</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1919</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1920</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1921</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1922</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1923</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1924</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1925</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1926</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1927</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1928</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1929</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1930</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1931</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1932</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1933</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1934</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1935</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1936</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1937</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1938</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1939</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1940</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1941</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1942</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1943</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1944</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1945</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1946</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1947</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1948</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1949</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1950</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1951</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1952</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1953</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1954</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1955</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1956</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1957</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1958</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1959</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1960</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1961</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1962</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1963</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1964</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1965</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>1966</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>1967</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>1968</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1969</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1970</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1971</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1972</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1973</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1974</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1975</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1976</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1977</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1978</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>1979</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1980</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1981</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>1982</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>1983</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1984</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>1985</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>1986</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>1987</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>1988</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>1989</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>1990</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>1991</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1992</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>1993</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>1994</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>1995</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>1996</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>1997</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>1998</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>1999</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2000</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2001</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2002</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2003</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2004</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2005</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2006</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2007</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2008</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2009</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2010</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2011</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2012</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2013</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2014</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2015</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2016</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2017</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2018</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2019</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2020</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2021</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2022</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2023</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2024</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2025</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2026</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2027</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2028</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2029</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2030</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2031</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2032</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2033</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2034</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2035</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2036</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2037</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2038</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2039</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2040</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2041</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2042</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2043</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2044</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2045</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2046</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2047</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2048</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2049</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2050</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2051</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2052</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2053</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2054</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2055</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2056</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2057</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2058</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2059</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2060</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2061</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2062</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2063</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2064</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2065</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2066</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2067</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2068</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2069</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2070</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2071</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2072</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2073</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2074</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2075</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2076</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2077</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2078</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2079</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2080</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2081</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2082</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2083</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2084</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2085</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2086</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2087</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2088</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2089</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2090</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2091</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2092</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2093</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2094</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2095</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2096</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2097</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2098</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2099</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2100</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2101</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2102</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2103</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2104</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2105</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2106</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2107</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2108</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2109</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2110</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2111</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2112</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2113</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2114</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2115</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2116</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2117</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2118</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2119</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2120</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2121</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2122</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2123</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2124</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2125</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2126</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2127</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2128</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2129</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2130</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2131</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2132</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2133</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2134</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2135</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2136</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2137</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2138</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2139</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2140</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2141</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2142</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2143</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Store Cost</COLUMN_NAME>
        <ORDINAL_POSITION>2144</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Store Sales</COLUMN_NAME>
        <ORDINAL_POSITION>2145</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Sales Count</COLUMN_NAME>
        <ORDINAL_POSITION>2146</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Customer Count</COLUMN_NAME>
        <ORDINAL_POSITION>2147</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Promotion Sales</COLUMN_NAME>
        <ORDINAL_POSITION>2148</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Profit</COLUMN_NAME>
        <ORDINAL_POSITION>2149</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Profit Growth</COLUMN_NAME>
        <ORDINAL_POSITION>2150</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2151</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2152</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2153</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2154</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2155</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2156</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2157</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2158</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2159</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2160</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2161</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2162</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2163</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2164</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2165</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2166</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2167</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2168</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2169</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2170</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2171</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2172</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2173</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2174</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2175</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2176</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2177</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2178</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2179</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2180</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2181</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2182</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2183</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2184</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2185</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2186</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2187</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2188</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2189</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2190</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2191</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2192</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2193</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2194</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2195</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2196</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2197</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2198</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2199</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2200</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2201</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2202</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2203</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2204</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2205</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2206</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2207</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2208</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2209</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2210</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2211</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2212</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2213</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2214</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2215</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2216</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2217</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Year!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2218</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2219</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2220</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2221</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2222</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2223</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2224</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2225</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2226</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2227</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2228</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2229</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2230</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2231</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2232</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2233</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2234</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2235</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2236</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2237</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2238</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2239</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2240</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2241</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2242</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2243</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2244</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2245</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2246</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2247</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2248</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2249</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2250</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2251</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2252</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2253</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2254</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2255</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2256</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2257</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2258</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2259</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2260</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2261</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2262</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2263</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2264</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2265</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2266</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2267</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2268</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2269</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2270</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2271</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2272</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2273</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2274</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2275</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2276</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2277</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2278</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2279</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2280</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2281</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2282</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2283</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2284</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2285</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time:Month!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2286</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2287</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2288</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2289</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2290</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2291</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2292</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2293</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2294</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2295</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2296</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2297</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2298</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2299</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2300</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2301</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2302</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2303</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2304</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2305</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2306</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2307</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2308</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2309</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2310</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2311</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2312</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2313</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2314</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2315</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2316</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2317</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2318</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2319</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2320</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2321</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2322</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2323</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2324</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2325</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2326</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2327</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2328</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2329</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2330</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2331</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2332</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2333</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2334</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2335</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2336</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2337</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2338</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2339</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2340</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2341</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2342</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2343</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2344</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2345</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2346</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2347</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2348</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2349</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2350</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2351</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2352</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2353</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2354</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2355</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2356</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2357</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2358</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2359</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2360</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2361</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2362</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2363</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2364</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2365</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2366</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2367</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2368</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2369</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2370</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2371</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2372</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2373</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2374</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2375</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2376</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2377</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2378</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2379</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2380</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2381</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2382</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2383</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2384</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2385</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2386</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2387</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2388</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2389</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2390</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2391</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2392</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2393</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2394</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2395</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2396</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2397</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2398</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2399</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2400</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2401</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2402</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2403</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2404</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2405</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2406</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2407</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2408</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2409</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2410</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2411</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2412</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2413</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2414</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2415</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2416</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2417</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2418</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2419</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2420</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2421</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2422</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2423</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2424</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2425</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2426</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2427</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2428</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2429</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2430</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2431</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2432</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2433</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2434</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2435</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2436</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2437</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2438</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2439</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2440</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2441</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2442</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2443</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2444</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2445</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2446</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2447</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2448</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2449</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2450</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2451</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2452</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2453</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2454</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2455</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2456</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2457</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2458</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2459</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2460</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2461</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2462</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2463</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2464</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2465</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2466</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2467</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2468</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2469</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2470</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2471</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2472</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2473</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2474</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2475</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2476</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2477</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2478</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2479</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2480</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2481</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2482</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2483</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2484</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2485</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2486</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2487</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2488</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2489</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2490</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2491</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2492</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2493</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2494</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2495</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2496</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2497</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2498</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2499</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2500</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2501</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2502</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2503</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2504</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2505</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2506</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2507</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2508</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2509</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2510</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2511</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2512</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2513</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2514</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2515</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2516</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2517</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2518</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2519</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2520</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2521</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2522</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2523</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2524</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2525</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2526</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2527</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2528</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2529</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2530</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2531</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2532</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2533</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2534</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2535</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2536</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2537</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2538</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2539</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2540</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2541</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2542</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2543</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2544</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2545</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2546</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2547</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2548</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2549</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2550</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2551</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2552</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2553</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2554</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2555</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2556</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2557</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2558</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2559</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2560</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2561</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2562</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2563</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2564</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2565</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2566</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2567</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2568</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2569</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2570</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2571</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2572</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2573</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2574</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2575</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2576</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2577</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2578</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2579</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2580</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2581</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2582</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2583</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2584</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2585</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2586</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2587</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2588</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2589</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2590</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2591</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2592</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2593</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2594</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2595</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2596</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2597</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2598</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2599</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2600</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2601</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2602</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2603</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2604</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2605</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2606</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2607</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2608</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2609</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2610</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2611</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2612</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2613</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2614</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2615</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2616</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2617</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2618</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2619</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2620</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2621</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2622</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2623</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2624</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2625</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2626</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2627</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2628</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2629</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2630</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2631</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2632</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2633</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2634</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2635</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2636</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2637</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2638</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2639</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2640</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2641</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2642</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2643</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2644</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2645</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2646</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2647</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2648</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2649</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2650</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2651</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2652</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2653</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2654</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2655</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2656</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2657</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2658</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2659</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2660</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2661</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2662</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2663</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2664</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2665</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2666</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2667</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2668</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2669</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2670</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2671</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2672</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2673</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2674</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2675</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2676</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2677</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2678</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2679</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2680</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2681</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2682</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2683</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2684</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2685</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2686</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2687</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2688</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2689</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2690</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2691</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2692</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2693</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2694</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2695</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2696</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2697</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2698</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2699</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2700</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2701</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2702</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2703</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2704</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2705</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2706</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2707</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2708</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2709</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2710</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2711</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2712</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2713</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2714</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2715</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2716</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2717</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2718</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2719</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2720</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2721</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2722</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2723</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2724</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2725</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2726</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2727</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2728</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2729</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2730</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2731</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2732</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2733</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2734</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:Unit Sales</COLUMN_NAME>
        <ORDINAL_POSITION>2735</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:Store Sales</COLUMN_NAME>
        <ORDINAL_POSITION>2736</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:Store Cost</COLUMN_NAME>
        <ORDINAL_POSITION>2737</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:Customer Count</COLUMN_NAME>
        <ORDINAL_POSITION>2738</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <COLUMN_NAME>Measures:Profit</COLUMN_NAME>
        <ORDINAL_POSITION>2739</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2740</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2741</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2742</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2743</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2744</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2745</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2746</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2747</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2748</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2749</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2750</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2751</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2752</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2753</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2754</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2755</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2756</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2757</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2758</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2759</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2760</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2761</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2762</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2763</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2764</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2765</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2766</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2767</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2768</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2769</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2770</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2771</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2772</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2773</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2774</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2775</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2776</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2777</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2778</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2779</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2780</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2781</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2782</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2783</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2784</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2785</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2786</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2787</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2788</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2789</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2790</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2791</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2792</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2793</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2794</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2795</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2796</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2797</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2798</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2799</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2800</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2801</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2802</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2803</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2804</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2805</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2806</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2807</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2808</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2809</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2810</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2811</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2812</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2813</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2814</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2815</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2816</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2817</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2818</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2819</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2820</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2821</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2822</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2823</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2824</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2825</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2826</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2827</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2828</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2829</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2830</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2831</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2832</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2833</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2834</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2835</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2836</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2837</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2838</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2839</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2840</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2841</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2842</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2843</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2844</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2845</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2846</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2847</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2848</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2849</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2850</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2851</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2852</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2853</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2854</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2855</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2856</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2857</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2858</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2859</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2860</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2861</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2862</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2863</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2864</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2865</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2866</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2867</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2868</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2869</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2870</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2871</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2872</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2873</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2874</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2875</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2876</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2877</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2878</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2879</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2880</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2881</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2882</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2883</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2884</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2885</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2886</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2887</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2888</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2889</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2890</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2891</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2892</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2893</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2894</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2895</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2896</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2897</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2898</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2899</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2900</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2901</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2902</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2903</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2904</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2905</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2906</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2907</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2908</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2909</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2910</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2911</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2912</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2913</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2914</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2915</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2916</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2917</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2918</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2919</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2920</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2921</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2922</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2923</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2924</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2925</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2926</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2927</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2928</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2929</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2930</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2931</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2932</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2933</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2934</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2935</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2936</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2937</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2938</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2939</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2940</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2941</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2942</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2943</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2944</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2945</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Type</COLUMN_NAME>
        <ORDINAL_POSITION>2946</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Manager</COLUMN_NAME>
        <ORDINAL_POSITION>2947</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>2948</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Grocery Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>2949</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Frozen Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>2950</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Meat Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>2951</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Has coffee bar</COLUMN_NAME>
        <ORDINAL_POSITION>2952</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Street address</COLUMN_NAME>
        <ORDINAL_POSITION>2953</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2954</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2955</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2956</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2957</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2958</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2959</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2960</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2961</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2962</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2963</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2964</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2965</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2966</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2967</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>2968</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>2969</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2970</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>2971</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>2972</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2973</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>2974</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>2975</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>2976</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2977</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2978</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2979</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>2980</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>2981</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>2982</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>2983</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>2984</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>2985</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>2986</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>2987</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>2988</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>2989</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2990</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2991</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2992</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2993</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2994</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2995</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2996</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>2997</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>2998</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>2999</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3000</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3001</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3002</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3003</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3004</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3005</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3006</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3007</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3008</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3009</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3010</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3011</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3012</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3013</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3014</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3015</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3016</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3017</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3018</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3019</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3020</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3021</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3022</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:Country!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3023</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3024</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3025</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3026</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3027</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3028</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3029</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3030</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3031</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3032</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3033</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3034</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3035</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3036</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3037</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3038</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3039</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3040</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3041</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3042</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3043</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3044</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3045</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3046</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3047</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3048</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3049</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3050</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3051</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3052</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3053</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3054</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3055</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3056</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:State!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3057</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3058</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3059</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3060</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3061</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3062</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3063</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3064</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3065</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3066</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3067</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3068</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3069</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3070</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3071</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3072</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3073</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3074</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3075</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3076</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3077</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3078</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3079</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3080</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3081</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3082</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3083</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3084</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3085</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3086</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3087</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3088</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3089</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3090</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Geography:City!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3091</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3092</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3093</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3094</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3095</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3096</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3097</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3098</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3099</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3100</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3101</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3102</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3103</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3104</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3105</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3106</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3107</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3108</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3109</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3110</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3111</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3112</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3113</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3114</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3115</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3116</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3117</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3118</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3119</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3120</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3121</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3122</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3123</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3124</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3125</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3126</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3127</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3128</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3129</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3130</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3131</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3132</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3133</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3134</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3135</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3136</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3137</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3138</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3139</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3140</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3141</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3142</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3143</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3144</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3145</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3146</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3147</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3148</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3149</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3150</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3151</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3152</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3153</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3154</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3155</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3156</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3157</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3158</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3159</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3160</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3161</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3162</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3163</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3164</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3165</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3166</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3167</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3168</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3169</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3170</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3171</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3172</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3173</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3174</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3175</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3176</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3177</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3178</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3179</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3180</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3181</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3182</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3183</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3184</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3185</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3186</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3187</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3188</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3189</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3190</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3191</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3192</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3193</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3194</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3195</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3196</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3197</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3198</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3199</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3200</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3201</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3202</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3203</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3204</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3205</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3206</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3207</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3208</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3209</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3210</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3211</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3212</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3213</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3214</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3215</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3216</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3217</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3218</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3219</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3220</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3221</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3222</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3223</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3224</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3225</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3226</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3227</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3228</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3229</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3230</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3231</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3232</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3233</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3234</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3235</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3236</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3237</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3238</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3239</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3240</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3241</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3242</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3243</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3244</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3245</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3246</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3247</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3248</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3249</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3250</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3251</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3252</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3253</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3254</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3255</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3256</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3257</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3258</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3259</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3260</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3261</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3262</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3263</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3264</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Year!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3265</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3266</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3267</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3268</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3269</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3270</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3271</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3272</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3273</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3274</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3275</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3276</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3277</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3278</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3279</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3280</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3281</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3282</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3283</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3284</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3285</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3286</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3287</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3288</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3289</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3290</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3291</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3292</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3293</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3294</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3295</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3296</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3297</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3298</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3299</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3300</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3301</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3302</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3303</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3304</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3305</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3306</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3307</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3308</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3309</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3310</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3311</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3312</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3313</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3314</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3315</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3316</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3317</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3318</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3319</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3320</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3321</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3322</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3323</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3324</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3325</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3326</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3327</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3328</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3329</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3330</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3331</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3332</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time:Month!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3333</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3334</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3335</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3336</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3337</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3338</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3339</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3340</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3341</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3342</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3343</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3344</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3345</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3346</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3347</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3348</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3349</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3350</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3351</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3352</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3353</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3354</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3355</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3356</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3357</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3358</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3359</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3360</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3361</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3362</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3363</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3364</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3365</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3366</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3367</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3368</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3369</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3370</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3371</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3372</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3373</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3374</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3375</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3376</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3377</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3378</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3379</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3380</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3381</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3382</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3383</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3384</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3385</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3386</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3387</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3388</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3389</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3390</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3391</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3392</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3393</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3394</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3395</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3396</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3397</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3398</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3399</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3400</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3401</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3402</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3403</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3404</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3405</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3406</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3407</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3408</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3409</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3410</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3411</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3412</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3413</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3414</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3415</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3416</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3417</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3418</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3419</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3420</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3421</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3422</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3423</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3424</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3425</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3426</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3427</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3428</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3429</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3430</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3431</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3432</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3433</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3434</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3435</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3436</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3437</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3438</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3439</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3440</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3441</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3442</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3443</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3444</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3445</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3446</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3447</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3448</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3449</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3450</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3451</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3452</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3453</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3454</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3455</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3456</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3457</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3458</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3459</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3460</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3461</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3462</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3463</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3464</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3465</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3466</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3467</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3468</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3469</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3470</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3471</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3472</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3473</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3474</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3475</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3476</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3477</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3478</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3479</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3480</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3481</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3482</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3483</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3484</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3485</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3486</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3487</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3488</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3489</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3490</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3491</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3492</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3493</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3494</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3495</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3496</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3497</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3498</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3499</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3500</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3501</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3502</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3503</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3504</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3505</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3506</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3507</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3508</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3509</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3510</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3511</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3512</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3513</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3514</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3515</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3516</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3517</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3518</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3519</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3520</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3521</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3522</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3523</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3524</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3525</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3526</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3527</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3528</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3529</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3530</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3531</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3532</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3533</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3534</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3535</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3536</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3537</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3538</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3539</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3540</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3541</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3542</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3543</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3544</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3545</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3546</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3547</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3548</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3549</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3550</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3551</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3552</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3553</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3554</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3555</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3556</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3557</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3558</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3559</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3560</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3561</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3562</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3563</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3564</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3565</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3566</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3567</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3568</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3569</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3570</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3571</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3572</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3573</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3574</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3575</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3576</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3577</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3578</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3579</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3580</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3581</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3582</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3583</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3584</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3585</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3586</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3587</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3588</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3589</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3590</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3591</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3592</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3593</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3594</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3595</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3596</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3597</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3598</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3599</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3600</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3601</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3602</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3603</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3604</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3605</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3606</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3607</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3608</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3609</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3610</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3611</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3612</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3613</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3614</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3615</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3616</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3617</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3618</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3619</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3620</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3621</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3622</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3623</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3624</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3625</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3626</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3627</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3628</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3629</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3630</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3631</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3632</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3633</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3634</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3635</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3636</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3637</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3638</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3639</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3640</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3641</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3642</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3643</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3644</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3645</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3646</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3647</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3648</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3649</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3650</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3651</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3652</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3653</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3654</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3655</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3656</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3657</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3658</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3659</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3660</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3661</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3662</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3663</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3664</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3665</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3666</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3667</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3668</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3669</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3670</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3671</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3672</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3673</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3674</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3675</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3676</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3677</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3678</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3679</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3680</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3681</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3682</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3683</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3684</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3685</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3686</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3687</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3688</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3689</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3690</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3691</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3692</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3693</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3694</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3695</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3696</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3697</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3698</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3699</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3700</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3701</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3702</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3703</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3704</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3705</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3706</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3707</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3708</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3709</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3710</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3711</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3712</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3713</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3714</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3715</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3716</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3717</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3718</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3719</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3720</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3721</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3722</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3723</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3724</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3725</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3726</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3727</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3728</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3729</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3730</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3731</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3732</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3733</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3734</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3735</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3736</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3737</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3738</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3739</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3740</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3741</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3742</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3743</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3744</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3745</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3746</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3747</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3748</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3749</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3750</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3751</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3752</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3753</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3754</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3755</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3756</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3757</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3758</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3759</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3760</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3761</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3762</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3763</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3764</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3765</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3766</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3767</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3768</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3769</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3770</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3771</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3772</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3773</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3774</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3775</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3776</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3777</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3778</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3779</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3780</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3781</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3782</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3783</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3784</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3785</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3786</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3787</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3788</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3789</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3790</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3791</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3792</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3793</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3794</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3795</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3796</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3797</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3798</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3799</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3800</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3801</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3802</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3803</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3804</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3805</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3806</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3807</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3808</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3809</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3810</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3811</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3812</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3813</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3814</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3815</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3816</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3817</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3818</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3819</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3820</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3821</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3822</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3823</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3824</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3825</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3826</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3827</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3828</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3829</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3830</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3831</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3832</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3833</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3834</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3835</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3836</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3837</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3838</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3839</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3840</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3841</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3842</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3843</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3844</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3845</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3846</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3847</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3848</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3849</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3850</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3851</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3852</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3853</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3854</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3855</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3856</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3857</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3858</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3859</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3860</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3861</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3862</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3863</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3864</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3865</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3866</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3867</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3868</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3869</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3870</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3871</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3872</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3873</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3874</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3875</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3876</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3877</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3878</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3879</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3880</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3881</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3882</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3883</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3884</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3885</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3886</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3887</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3888</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3889</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3890</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3891</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3892</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3893</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3894</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3895</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3896</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3897</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3898</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3899</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3900</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3901</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3902</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3903</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3904</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3905</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3906</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3907</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3908</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3909</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3910</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3911</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3912</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3913</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3914</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3915</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3916</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3917</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3918</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3919</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3920</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3921</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3922</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3923</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3924</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3925</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3926</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3927</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3928</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3929</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3930</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3931</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3932</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3933</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3934</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3935</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3936</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3937</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3938</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3939</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3940</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3941</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3942</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3943</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3944</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3945</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3946</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3947</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3948</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3949</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3950</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3951</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3952</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3953</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3954</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3955</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3956</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3957</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3958</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3959</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3960</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3961</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3962</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3963</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3964</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3965</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3966</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3967</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>3968</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>3969</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3970</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>3971</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>3972</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3973</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>3974</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>3975</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>3976</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3977</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3978</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3979</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>3980</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>3981</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>3982</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>3983</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>3984</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>3985</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>3986</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>3987</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>3988</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:City!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>3989</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3990</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3991</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3992</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3993</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3994</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3995</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3996</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>3997</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>3998</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>3999</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4000</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4001</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4002</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4003</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4004</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4005</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4006</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4007</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4008</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4009</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4010</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4011</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4012</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4013</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4014</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4015</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4016</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4017</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4018</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4019</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4020</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4021</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4022</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4023</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!Gender</COLUMN_NAME>
        <ORDINAL_POSITION>4024</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!Marital Status</COLUMN_NAME>
        <ORDINAL_POSITION>4025</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!Education</COLUMN_NAME>
        <ORDINAL_POSITION>4026</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!Yearly Income</COLUMN_NAME>
        <ORDINAL_POSITION>4027</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4028</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4029</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4030</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4031</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4032</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4033</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4034</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4035</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4036</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4037</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4038</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4039</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4040</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4041</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4042</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4043</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4044</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4045</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4046</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4047</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4048</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4049</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4050</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4051</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4052</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4053</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4054</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4055</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4056</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4057</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4058</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4059</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4060</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4061</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4062</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4063</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4064</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4065</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4066</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4067</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4068</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4069</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4070</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4071</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4072</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4073</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4074</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4075</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4076</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4077</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4078</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4079</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4080</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4081</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4082</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4083</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4084</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4085</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4086</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4087</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4088</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4089</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4090</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4091</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4092</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4093</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4094</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4095</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4096</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4097</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4098</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4099</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4100</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4101</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4102</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4103</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4104</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4105</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4106</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4107</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4108</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4109</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4110</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4111</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4112</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4113</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4114</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4115</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4116</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4117</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4118</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4119</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4120</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4121</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4122</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4123</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4124</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4125</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4126</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4127</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4128</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4129</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4130</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4131</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4132</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4133</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4134</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4135</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4136</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4137</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4138</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4139</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4140</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4141</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4142</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4143</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4144</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4145</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4146</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4147</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4148</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4149</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4150</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4151</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4152</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4153</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4154</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4155</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4156</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4157</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4158</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4159</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4160</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4161</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4162</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4163</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4164</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4165</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4166</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4167</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4168</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4169</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4170</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4171</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4172</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4173</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4174</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4175</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4176</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4177</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4178</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4179</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4180</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4181</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4182</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4183</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4184</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4185</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4186</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4187</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4188</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4189</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4190</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4191</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4192</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4193</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4194</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4195</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4196</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4197</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4198</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4199</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4200</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4201</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4202</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4203</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4204</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4205</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4206</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4207</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4208</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4209</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4210</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4211</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4212</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4213</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4214</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4215</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4216</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4217</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4218</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4219</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4220</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4221</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4222</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4223</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4224</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4225</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4226</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4227</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4228</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4229</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4230</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4231</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4232</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4233</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4234</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4235</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4236</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4237</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4238</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4239</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4240</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4241</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4242</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4243</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4244</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4245</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4246</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4247</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4248</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4249</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4250</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4251</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4252</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4253</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4254</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4255</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4256</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4257</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4258</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4259</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4260</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4261</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4262</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4263</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4264</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4265</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4266</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4267</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4268</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4269</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4270</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4271</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4272</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4273</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4274</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4275</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4276</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4277</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4278</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4279</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4280</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4281</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4282</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4283</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4284</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4285</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4286</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4287</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4288</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4289</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4290</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4291</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4292</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4293</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4294</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4295</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4296</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4297</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4298</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4299</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4300</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4301</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4302</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4303</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4304</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4305</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4306</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4307</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:Store Cost</COLUMN_NAME>
        <ORDINAL_POSITION>4308</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:Store Sales</COLUMN_NAME>
        <ORDINAL_POSITION>4309</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:Sales Count</COLUMN_NAME>
        <ORDINAL_POSITION>4310</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <COLUMN_NAME>Measures:Customer Count</COLUMN_NAME>
        <ORDINAL_POSITION>4311</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4312</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4313</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4314</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4315</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4316</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4317</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4318</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4319</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4320</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4321</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4322</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4323</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4324</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4325</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4326</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4327</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4328</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4329</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4330</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4331</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4332</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4333</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4334</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4335</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4336</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4337</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4338</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4339</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4340</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4341</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4342</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4343</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4344</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4345</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4346</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4347</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4348</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4349</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4350</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4351</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4352</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4353</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4354</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4355</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4356</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4357</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4358</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4359</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4360</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4361</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4362</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4363</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4364</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4365</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4366</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4367</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4368</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4369</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4370</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4371</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4372</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4373</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4374</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4375</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4376</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4377</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4378</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4379</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4380</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4381</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4382</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4383</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4384</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4385</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4386</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4387</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4388</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4389</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4390</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4391</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4392</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4393</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4394</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4395</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4396</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4397</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4398</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4399</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4400</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4401</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4402</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4403</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4404</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4405</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4406</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4407</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4408</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4409</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4410</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4411</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4412</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4413</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4414</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4415</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4416</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4417</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4418</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4419</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4420</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4421</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4422</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4423</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4424</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4425</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4426</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4427</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4428</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4429</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4430</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4431</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4432</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4433</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4434</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4435</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4436</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4437</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4438</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4439</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4440</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4441</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4442</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4443</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4444</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4445</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4446</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4447</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4448</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4449</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4450</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4451</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4452</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4453</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4454</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4455</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4456</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4457</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4458</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4459</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4460</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4461</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4462</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4463</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4464</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4465</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4466</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4467</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4468</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4469</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4470</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4471</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4472</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4473</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4474</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4475</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4476</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4477</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4478</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4479</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4480</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4481</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4482</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4483</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4484</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4485</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4486</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4487</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4488</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4489</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4490</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4491</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4492</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4493</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4494</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4495</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4496</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4497</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4498</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4499</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4500</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4501</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4502</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4503</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4504</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4505</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4506</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4507</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4508</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4509</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4510</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4511</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4512</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4513</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4514</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4515</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4516</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4517</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4518</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4519</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4520</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4521</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4522</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4523</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4524</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4525</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4526</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4527</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4528</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4529</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4530</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4531</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4532</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4533</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4534</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4535</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4536</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4537</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4538</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4539</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4540</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4541</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4542</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4543</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4544</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4545</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4546</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4547</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4548</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4549</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4550</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4551</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4552</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4553</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4554</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4555</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4556</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4557</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4558</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4559</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4560</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4561</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4562</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4563</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4564</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4565</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4566</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4567</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4568</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4569</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4570</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4571</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4572</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4573</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4574</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4575</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4576</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4577</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4578</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4579</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4580</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4581</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4582</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4583</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4584</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4585</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4586</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4587</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Type</COLUMN_NAME>
        <ORDINAL_POSITION>4588</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Manager</COLUMN_NAME>
        <ORDINAL_POSITION>4589</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>4590</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Grocery Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>4591</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Frozen Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>4592</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Meat Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>4593</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Has coffee bar</COLUMN_NAME>
        <ORDINAL_POSITION>4594</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Street address</COLUMN_NAME>
        <ORDINAL_POSITION>4595</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4596</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4597</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4598</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4599</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4600</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4601</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4602</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4603</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4604</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4605</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4606</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4607</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4608</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4609</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4610</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4611</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4612</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4613</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4614</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4615</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4616</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4617</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4618</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4619</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4620</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4621</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4622</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4623</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4624</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4625</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4626</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4627</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4628</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4629</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4630</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4631</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4632</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4633</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4634</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4635</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4636</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4637</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4638</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4639</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4640</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4641</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4642</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4643</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4644</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4645</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4646</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4647</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4648</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4649</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4650</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4651</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4652</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4653</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4654</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4655</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4656</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4657</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4658</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4659</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4660</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4661</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4662</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4663</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4664</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Has coffee bar:Has coffee bar!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4665</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <COLUMN_NAME>Measures:Grocery Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>4666</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4667</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4668</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4669</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4670</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4671</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4672</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4673</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4674</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4675</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4676</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4677</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4678</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4679</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4680</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4681</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4682</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4683</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4684</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4685</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4686</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4687</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4688</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4689</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4690</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4691</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4692</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4693</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4694</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4695</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4696</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4697</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4698</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4699</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4700</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4701</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4702</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4703</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4704</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4705</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4706</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4707</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4708</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4709</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4710</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4711</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4712</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4713</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4714</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4715</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4716</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4717</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4718</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4719</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4720</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4721</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4722</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4723</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4724</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4725</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4726</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4727</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4728</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4729</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4730</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4731</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4732</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4733</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4734</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4735</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4736</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4737</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4738</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4739</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4740</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4741</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4742</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4743</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4744</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4745</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4746</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4747</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4748</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4749</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4750</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4751</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4752</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4753</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4754</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4755</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4756</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4757</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4758</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4759</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4760</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4761</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4762</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4763</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4764</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4765</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4766</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4767</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4768</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4769</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4770</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4771</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4772</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4773</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4774</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4775</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4776</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4777</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4778</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4779</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4780</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4781</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4782</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4783</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4784</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4785</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4786</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4787</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4788</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4789</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4790</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4791</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4792</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4793</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4794</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4795</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4796</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4797</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4798</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4799</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4800</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4801</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4802</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4803</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4804</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4805</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4806</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4807</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4808</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4809</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4810</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4811</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4812</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4813</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4814</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4815</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4816</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4817</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4818</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4819</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4820</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4821</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4822</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4823</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4824</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4825</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4826</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4827</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4828</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4829</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4830</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4831</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4832</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4833</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4834</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4835</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4836</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4837</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4838</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4839</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4840</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4841</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4842</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4843</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4844</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4845</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4846</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4847</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4848</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4849</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4850</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4851</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4852</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4853</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4854</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4855</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4856</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4857</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4858</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4859</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4860</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4861</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4862</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4863</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4864</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4865</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4866</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4867</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4868</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4869</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4870</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4871</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4872</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Type</COLUMN_NAME>
        <ORDINAL_POSITION>4873</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Manager</COLUMN_NAME>
        <ORDINAL_POSITION>4874</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>4875</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Grocery Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>4876</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Frozen Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>4877</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Meat Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>4878</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Has coffee bar</COLUMN_NAME>
        <ORDINAL_POSITION>4879</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Street address</COLUMN_NAME>
        <ORDINAL_POSITION>4880</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4881</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4882</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4883</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4884</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4885</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4886</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4887</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4888</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4889</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4890</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4891</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4892</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4893</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4894</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4895</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4896</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4897</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4898</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4899</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4900</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4901</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4902</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4903</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4904</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4905</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4906</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4907</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4908</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4909</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4910</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4911</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4912</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4913</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4914</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4915</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4916</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4917</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4918</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4919</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4920</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4921</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4922</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4923</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4924</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4925</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4926</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4927</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4928</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4929</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4930</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4931</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4932</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4933</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4934</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4935</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4936</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4937</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4938</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4939</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4940</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4941</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4942</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4943</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4944</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4945</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4946</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4947</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4948</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4949</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Size in SQFT:Store Sqft!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4950</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4951</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4952</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4953</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4954</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4955</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4956</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4957</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4958</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4959</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4960</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4961</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4962</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4963</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4964</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4965</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>4966</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4967</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>4968</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>4969</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4970</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>4971</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>4972</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>4973</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4974</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4975</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4976</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>4977</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>4978</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>4979</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>4980</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>4981</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>4982</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>4983</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>4984</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>4985</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>4986</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4987</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4988</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4989</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4990</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4991</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4992</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4993</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4994</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>4995</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>4996</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4997</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>4998</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>4999</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5000</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5001</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5002</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5003</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5004</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5005</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5006</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5007</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5008</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5009</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5010</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5011</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5012</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5013</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5014</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5015</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5016</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5017</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5018</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5019</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Store Type:Store Type!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5020</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5021</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5022</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5023</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5024</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5025</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5026</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5027</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5028</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5029</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5030</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5031</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5032</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5033</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5034</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5035</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5036</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5037</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5038</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5039</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5040</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5041</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5042</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5043</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5044</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5045</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5046</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5047</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5048</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5049</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5050</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5051</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5052</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5053</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Year!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5054</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5055</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5056</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5057</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5058</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5059</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5060</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5061</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5062</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5063</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5064</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5065</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5066</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5067</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5068</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5069</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5070</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5071</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5072</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5073</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5074</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5075</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5076</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5077</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5078</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5079</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5080</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5081</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5082</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5083</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5084</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5085</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5086</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5087</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5088</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5089</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5090</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5091</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5092</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5093</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5094</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5095</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5096</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5097</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5098</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5099</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5100</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5101</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5102</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5103</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5104</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5105</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5106</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5107</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5108</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5109</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5110</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5111</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5112</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5113</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5114</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5115</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5116</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5117</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5118</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5119</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5120</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5121</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time:Month!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5122</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5123</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5124</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5125</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5126</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5127</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5128</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5129</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5130</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5131</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5132</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5133</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5134</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5135</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5136</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5137</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5138</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5139</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5140</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5141</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5142</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5143</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5144</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5145</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5146</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5147</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5148</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5149</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5150</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5151</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5152</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5153</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5154</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5155</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5156</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5157</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5158</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5159</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5160</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5161</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5162</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5163</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5164</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5165</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5166</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5167</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5168</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5169</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5170</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5171</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5172</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5173</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5174</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5175</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5176</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5177</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5178</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5179</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5180</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5181</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5182</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5183</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5184</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5185</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5186</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5187</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5188</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5189</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5190</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5191</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5192</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5193</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5194</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5195</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5196</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5197</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5198</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5199</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5200</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5201</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5202</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5203</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5204</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5205</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5206</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5207</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5208</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5209</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5210</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5211</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5212</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5213</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5214</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5215</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5216</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5217</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5218</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5219</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5220</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5221</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5222</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5223</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5224</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5225</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5226</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5227</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5228</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5229</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5230</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5231</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5232</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5233</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5234</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5235</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5236</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5237</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5238</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5239</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5240</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5241</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5242</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5243</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5244</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5245</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5246</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5247</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5248</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5249</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5250</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5251</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5252</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5253</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5254</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5255</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5256</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5257</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5258</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5259</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5260</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5261</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5262</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5263</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5264</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5265</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5266</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5267</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5268</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5269</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5270</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5271</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5272</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5273</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5274</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5275</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5276</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5277</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5278</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5279</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5280</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5281</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5282</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5283</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5284</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5285</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5286</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5287</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5288</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5289</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5290</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5291</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5292</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5293</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5294</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5295</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5296</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5297</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5298</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5299</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5300</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5301</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5302</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5303</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5304</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5305</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5306</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5307</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5308</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5309</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5310</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5311</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5312</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5313</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5314</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5315</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5316</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5317</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5318</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5319</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5320</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5321</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5322</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5323</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5324</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5325</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5326</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5327</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5328</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5329</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5330</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5331</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5332</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5333</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5334</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5335</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5336</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5337</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5338</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5339</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5340</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5341</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5342</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5343</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5344</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5345</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5346</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5347</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5348</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5349</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5350</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5351</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5352</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5353</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5354</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5355</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5356</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5357</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5358</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5359</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5360</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5361</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5362</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5363</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5364</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5365</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5366</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5367</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5368</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5369</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5370</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5371</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5372</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5373</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5374</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5375</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5376</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5377</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5378</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5379</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5380</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5381</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5382</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5383</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5384</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5385</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5386</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5387</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5388</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5389</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5390</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5391</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5392</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5393</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5394</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5395</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5396</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5397</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5398</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5399</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5400</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5401</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5402</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5403</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5404</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5405</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5406</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5407</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5408</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5409</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5410</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5411</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5412</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5413</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5414</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5415</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5416</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5417</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5418</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5419</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5420</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5421</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5422</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5423</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5424</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5425</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5426</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5427</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5428</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5429</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5430</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5431</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5432</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5433</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5434</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5435</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5436</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5437</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5438</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5439</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5440</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5441</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5442</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5443</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5444</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5445</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5446</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5447</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5448</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5449</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5450</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5451</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5452</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5453</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5454</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5455</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5456</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5457</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5458</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5459</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5460</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5461</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5462</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5463</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5464</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5465</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5466</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5467</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5468</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5469</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5470</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5471</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5472</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5473</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5474</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5475</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5476</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5477</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5478</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5479</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5480</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5481</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5482</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5483</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5484</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5485</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5486</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5487</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5488</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5489</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5490</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5491</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5492</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5493</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5494</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5495</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5496</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5497</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5498</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5499</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5500</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5501</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5502</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5503</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5504</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5505</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5506</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5507</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5508</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5509</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5510</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5511</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5512</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5513</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5514</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5515</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5516</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5517</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5518</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5519</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5520</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5521</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5522</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5523</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5524</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5525</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5526</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5527</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5528</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5529</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5530</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5531</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5532</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5533</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5534</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5535</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5536</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5537</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5538</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5539</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5540</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5541</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5542</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5543</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5544</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5545</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5546</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5547</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5548</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5549</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5550</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5551</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5552</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5553</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5554</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5555</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5556</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5557</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5558</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5559</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5560</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5561</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5562</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5563</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5564</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5565</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5566</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5567</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5568</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5569</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5570</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5571</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5572</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5573</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5574</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5575</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5576</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5577</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5578</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5579</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5580</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5581</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5582</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5583</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5584</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5585</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5586</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5587</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5588</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5589</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5590</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5591</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5592</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5593</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5594</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5595</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5596</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5597</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5598</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5599</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5600</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5601</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5602</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5603</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5604</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5605</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5606</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5607</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5608</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5609</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5610</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5611</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5612</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5613</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5614</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5615</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5616</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5617</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5618</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5619</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5620</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5621</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5622</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5623</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5624</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5625</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5626</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5627</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5628</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5629</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5630</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5631</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5632</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5633</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5634</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5635</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5636</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5637</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5638</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5639</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5640</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5641</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5642</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5643</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5644</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5645</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5646</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5647</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5648</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5649</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5650</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5651</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5652</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5653</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5654</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5655</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5656</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5657</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5658</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5659</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5660</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5661</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5662</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5663</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5664</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5665</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5666</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5667</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5668</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5669</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5670</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5671</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5672</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:Supply Time</COLUMN_NAME>
        <ORDINAL_POSITION>5673</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:Warehouse Cost</COLUMN_NAME>
        <ORDINAL_POSITION>5674</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:Warehouse Sales</COLUMN_NAME>
        <ORDINAL_POSITION>5675</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:Units Shipped</COLUMN_NAME>
        <ORDINAL_POSITION>5676</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:Units Ordered</COLUMN_NAME>
        <ORDINAL_POSITION>5677</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:Warehouse Profit</COLUMN_NAME>
        <ORDINAL_POSITION>5678</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <COLUMN_NAME>Measures:Average Warehouse Sale</COLUMN_NAME>
        <ORDINAL_POSITION>5679</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5680</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5681</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5682</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5683</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5684</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5685</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5686</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5687</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5688</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5689</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5690</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5691</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5692</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5693</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5694</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5695</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5696</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5697</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5698</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5699</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5700</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5701</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5702</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5703</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5704</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5705</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5706</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5707</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5708</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5709</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5710</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5711</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5712</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:MeasuresLevel!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5713</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5714</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5715</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5716</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5717</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5718</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5719</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5720</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5721</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5722</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5723</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5724</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5725</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5726</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5727</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5728</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5729</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5730</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5731</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5732</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5733</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5734</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5735</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5736</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5737</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5738</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5739</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5740</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5741</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5742</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5743</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5744</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5745</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5746</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5747</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5748</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5749</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5750</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5751</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5752</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5753</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5754</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5755</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5756</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5757</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5758</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5759</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5760</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5761</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5762</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5763</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5764</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5765</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5766</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5767</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5768</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5769</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5770</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5771</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5772</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5773</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5774</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5775</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5776</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5777</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5778</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5779</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5780</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5781</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5782</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Country!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5783</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5784</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5785</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5786</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5787</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5788</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5789</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5790</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5791</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5792</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5793</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5794</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5795</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5796</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5797</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5798</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5799</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5800</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5801</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5802</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5803</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5804</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5805</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5806</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5807</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5808</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5809</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5810</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5811</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5812</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5813</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5814</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5815</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5816</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:State Province!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5817</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5818</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5819</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5820</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5821</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5822</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5823</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5824</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5825</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5826</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5827</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5828</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5829</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5830</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5831</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5832</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5833</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5834</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5835</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5836</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5837</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5838</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5839</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5840</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5841</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5842</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5843</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5844</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5845</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5846</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5847</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5848</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5849</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5850</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:City!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5851</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5852</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5853</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5854</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5855</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5856</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5857</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5858</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5859</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5860</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5861</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5862</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5863</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5864</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5865</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5866</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5867</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5868</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5869</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5870</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5871</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5872</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5873</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5874</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5875</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5876</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5877</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5878</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5879</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5880</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5881</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5882</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5883</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5884</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5885</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!$name</COLUMN_NAME>
        <ORDINAL_POSITION>5886</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!Gender</COLUMN_NAME>
        <ORDINAL_POSITION>5887</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!Marital Status</COLUMN_NAME>
        <ORDINAL_POSITION>5888</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!Education</COLUMN_NAME>
        <ORDINAL_POSITION>5889</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Customers:Name!Yearly Income</COLUMN_NAME>
        <ORDINAL_POSITION>5890</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5891</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5892</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5893</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5894</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5895</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5896</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5897</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5898</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5899</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5900</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5901</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5902</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5903</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5904</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5905</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5906</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5907</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5908</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5909</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5910</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5911</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5912</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5913</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5914</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5915</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5916</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5917</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5918</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5919</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5920</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5921</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5922</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5923</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5924</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5925</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5926</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5927</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5928</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5929</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5930</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5931</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5932</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5933</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5934</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5935</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5936</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5937</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5938</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5939</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5940</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5941</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5942</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5943</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5944</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5945</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5946</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5947</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5948</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5949</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5950</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5951</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5952</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5953</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5954</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5955</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5956</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5957</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5958</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5959</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Education Level:Education Level!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5960</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5961</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5962</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5963</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5964</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5965</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5966</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5967</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5968</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5969</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5970</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5971</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>5972</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5973</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5974</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>5975</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>5976</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5977</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>5978</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>5979</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5980</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>5981</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>5982</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>5983</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5984</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5985</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>5986</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>5987</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>5988</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>5989</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>5990</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>5991</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>5992</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>5993</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>5994</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>5995</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>5996</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5997</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5998</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>5999</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6000</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6001</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6002</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6003</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6004</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6005</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6006</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6007</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6008</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6009</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6010</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6011</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6012</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6013</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6014</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6015</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6016</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6017</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6018</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6019</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6020</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6021</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6022</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6023</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6024</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6025</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6026</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6027</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6028</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6029</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Gender:Gender!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6030</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6031</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6032</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6033</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6034</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6035</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6036</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6037</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6038</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6039</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6040</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6041</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6042</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6043</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6044</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6045</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6046</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6047</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6048</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6049</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6050</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6051</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6052</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6053</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6054</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6055</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6056</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6057</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6058</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6059</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6060</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6061</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6062</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6063</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6064</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6065</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6066</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6067</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6068</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6069</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6070</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6071</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6072</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6073</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6074</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6075</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6076</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6077</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6078</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6079</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6080</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6081</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6082</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6083</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6084</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6085</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6086</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6087</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6088</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6089</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6090</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6091</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6092</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6093</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6094</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6095</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6096</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6097</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6098</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6099</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Marital Status:Marital Status!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6100</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6101</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6102</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6103</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6104</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6105</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6106</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6107</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6108</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6109</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6110</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6111</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6112</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6113</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6114</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6115</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6116</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6117</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6118</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6119</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6120</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6121</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6122</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6123</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6124</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6125</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6126</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6127</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6128</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6129</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6130</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6131</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6132</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6133</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6134</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6135</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6136</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6137</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6138</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6139</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6140</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6141</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6142</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6143</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6144</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6145</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6146</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6147</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6148</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6149</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6150</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6151</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6152</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6153</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6154</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6155</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6156</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6157</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6158</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6159</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6160</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6161</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6162</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6163</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6164</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6165</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6166</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6167</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6168</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6169</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Family!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6170</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6171</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6172</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6173</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6174</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6175</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6176</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6177</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6178</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6179</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6180</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6181</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6182</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6183</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6184</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6185</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6186</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6187</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6188</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6189</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6190</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6191</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6192</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6193</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6194</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6195</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6196</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6197</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6198</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6199</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6200</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6201</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6202</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6203</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Department!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6204</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6205</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6206</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6207</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6208</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6209</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6210</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6211</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6212</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6213</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6214</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6215</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6216</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6217</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6218</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6219</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6220</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6221</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6222</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6223</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6224</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6225</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6226</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6227</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6228</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6229</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6230</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6231</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6232</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6233</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6234</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6235</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6236</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6237</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Category!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6238</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6239</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6240</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6241</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6242</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6243</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6244</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6245</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6246</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6247</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6248</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6249</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6250</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6251</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6252</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6253</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6254</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6255</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6256</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6257</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6258</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6259</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6260</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6261</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6262</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6263</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6264</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6265</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6266</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6267</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6268</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6269</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6270</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6271</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Subcategory!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6272</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6273</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6274</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6275</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6276</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6277</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6278</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6279</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6280</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6281</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6282</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6283</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6284</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6285</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6286</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6287</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6288</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6289</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6290</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6291</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6292</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6293</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6294</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6295</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6296</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6297</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6298</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6299</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6300</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6301</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6302</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6303</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6304</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6305</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Brand Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6306</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6307</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6308</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6309</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6310</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6311</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6312</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6313</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6314</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6315</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6316</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6317</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6318</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6319</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6320</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6321</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6322</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6323</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6324</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6325</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6326</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6327</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6328</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6329</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6330</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6331</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6332</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6333</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6334</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6335</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6336</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6337</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6338</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6339</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Product:Product Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6340</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6341</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6342</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6343</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6344</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6345</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6346</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6347</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6348</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6349</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6350</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6351</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6352</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6353</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6354</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6355</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6356</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6357</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6358</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6359</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6360</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6361</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6362</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6363</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6364</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6365</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6366</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6367</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6368</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6369</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6370</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6371</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6372</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6373</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6374</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6375</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6376</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6377</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6378</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6379</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6380</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6381</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6382</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6383</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6384</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6385</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6386</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6387</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6388</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6389</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6390</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6391</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6392</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6393</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6394</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6395</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6396</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6397</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6398</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6399</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6400</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6401</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6402</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6403</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6404</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6405</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6406</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6407</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6408</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6409</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotion Media:Media Type!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6410</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6411</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6412</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6413</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6414</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6415</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6416</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6417</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6418</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6419</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6420</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6421</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6422</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6423</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6424</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6425</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6426</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6427</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6428</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6429</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6430</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6431</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6432</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6433</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6434</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6435</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6436</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6437</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6438</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6439</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6440</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6441</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6442</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6443</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6444</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6445</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6446</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6447</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6448</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6449</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6450</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6451</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6452</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6453</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6454</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6455</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6456</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6457</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6458</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6459</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6460</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6461</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6462</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6463</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6464</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6465</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6466</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6467</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6468</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6469</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6470</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6471</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6472</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6473</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6474</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6475</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6476</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6477</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6478</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6479</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Promotions:Promotion Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6480</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6481</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6482</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6483</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6484</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6485</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6486</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6487</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6488</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6489</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6490</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6491</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6492</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6493</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6494</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6495</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6496</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6497</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6498</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6499</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6500</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6501</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6502</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6503</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6504</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6505</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6506</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6507</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6508</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6509</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6510</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6511</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6512</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6513</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6514</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6515</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6516</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6517</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6518</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6519</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6520</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6521</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6522</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6523</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6524</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6525</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6526</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6527</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6528</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6529</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6530</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6531</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6532</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6533</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6534</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6535</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6536</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6537</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6538</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6539</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6540</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6541</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6542</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6543</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6544</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6545</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6546</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6547</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6548</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6549</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Country!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6550</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6551</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6552</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6553</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6554</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6555</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6556</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6557</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6558</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6559</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6560</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6561</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6562</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6563</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6564</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6565</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6566</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6567</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6568</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6569</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6570</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6571</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6572</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6573</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6574</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6575</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6576</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6577</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6578</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6579</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6580</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6581</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6582</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6583</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store State!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6584</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6585</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6586</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6587</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6588</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6589</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6590</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6591</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6592</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6593</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6594</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6595</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6596</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6597</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6598</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6599</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6600</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6601</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6602</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6603</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6604</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6605</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6606</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6607</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6608</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6609</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6610</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6611</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6612</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6613</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6614</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6615</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6616</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6617</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store City!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6618</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6619</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6620</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6621</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6622</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6623</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6624</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6625</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6626</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6627</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6628</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6629</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6630</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6631</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6632</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6633</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6634</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6635</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6636</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6637</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6638</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6639</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6640</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6641</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6642</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6643</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6644</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6645</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6646</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6647</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6648</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6649</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6650</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6651</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6652</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Type</COLUMN_NAME>
        <ORDINAL_POSITION>6653</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Manager</COLUMN_NAME>
        <ORDINAL_POSITION>6654</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Store Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>6655</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Grocery Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>6656</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Frozen Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>6657</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Meat Sqft</COLUMN_NAME>
        <ORDINAL_POSITION>6658</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Has coffee bar</COLUMN_NAME>
        <ORDINAL_POSITION>6659</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Store:Store Name!Street address</COLUMN_NAME>
        <ORDINAL_POSITION>6660</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6661</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6662</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6663</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6664</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6665</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6666</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6667</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6668</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6669</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6670</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6671</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6672</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6673</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6674</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6675</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6676</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6677</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6678</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6679</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6680</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6681</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6682</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6683</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6684</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6685</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6686</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6687</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6688</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6689</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6690</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6691</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6692</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6693</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Year!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6694</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6695</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6696</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6697</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6698</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6699</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6700</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6701</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6702</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6703</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6704</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6705</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6706</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6707</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6708</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6709</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6710</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6711</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6712</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6713</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6714</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6715</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6716</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6717</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6718</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6719</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6720</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6721</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6722</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6723</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6724</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6725</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6726</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6727</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Quarter!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6728</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6729</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6730</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6731</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6732</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6733</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6734</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6735</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6736</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6737</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6738</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6739</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6740</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6741</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6742</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6743</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6744</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6745</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6746</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6747</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6748</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6749</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6750</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6751</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6752</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6753</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6754</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6755</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6756</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6757</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6758</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6759</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6760</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6761</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time:Month!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6762</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6763</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6764</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6765</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6766</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6767</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6768</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6769</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6770</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6771</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6772</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6773</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6774</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6775</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6776</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6777</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6778</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6779</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6780</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6781</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6782</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6783</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6784</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6785</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6786</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6787</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6788</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6789</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6790</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6791</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6792</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6793</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6794</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6795</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6796</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6797</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6798</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6799</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6800</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6801</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6802</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6803</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6804</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6805</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6806</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6807</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6808</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6809</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6810</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6811</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6812</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6813</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6814</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6815</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6816</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6817</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6818</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6819</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6820</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6821</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6822</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6823</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6824</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6825</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6826</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6827</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6828</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6829</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6830</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6831</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Year!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6832</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6833</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6834</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6835</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6836</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6837</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6838</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6839</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6840</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6841</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6842</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6843</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6844</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6845</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6846</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6847</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6848</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6849</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6850</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6851</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6852</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6853</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6854</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6855</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6856</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6857</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6858</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6859</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6860</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6861</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6862</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6863</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6864</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6865</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Week!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6866</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6867</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6868</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6869</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6870</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6871</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6872</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6873</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6874</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6875</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6876</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6877</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6878</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6879</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6880</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6881</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6882</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6883</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6884</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6885</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6886</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6887</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6888</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6889</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6890</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6891</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6892</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6893</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6894</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6895</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6896</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6897</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6898</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6899</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Time.Weekly:Day!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6900</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6901</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6902</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6903</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6904</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6905</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6906</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6907</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6908</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6909</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6910</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6911</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6912</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6913</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6914</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6915</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6916</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6917</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6918</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6919</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6920</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6921</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6922</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6923</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6924</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6925</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6926</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6927</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6928</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6929</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6930</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6931</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6932</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6933</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6934</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6935</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6936</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6937</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6938</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6939</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6940</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6941</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6942</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6943</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6944</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6945</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6946</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6947</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6948</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6949</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6950</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6951</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6952</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6953</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6954</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6955</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6956</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6957</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6958</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6959</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6960</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6961</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6962</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6963</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>6964</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>6965</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>6966</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>6967</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>6968</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>6969</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Yearly Income:Yearly Income!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6970</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6971</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6972</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6973</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6974</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6975</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6976</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6977</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6978</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6979</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6980</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6981</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>6982</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6983</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6984</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>6985</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>6986</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6987</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>6988</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>6989</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>6990</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>6991</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>6992</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>6993</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>6994</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6995</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>6996</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>6997</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>6998</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>6999</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>7000</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>7001</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>7002</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>7003</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>7004</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>7005</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:(All)!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>7006</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7007</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7008</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7009</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7010</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7011</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7012</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7013</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7014</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>7015</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>7016</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7017</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7018</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>7019</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>7020</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>7021</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>7022</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>7023</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7024</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>7025</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>7026</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>7027</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>7028</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>7029</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>7030</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>7031</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>7032</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>7033</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>7034</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>7035</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>7036</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>7037</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>7038</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>7039</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Country!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>7040</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7041</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7042</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7043</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7044</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7045</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7046</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7047</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7048</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>7049</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>7050</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7051</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7052</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>7053</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>7054</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>7055</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>7056</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>7057</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7058</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>7059</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>7060</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>7061</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>7062</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>7063</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>7064</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>7065</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>7066</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>7067</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>7068</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>7069</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>7070</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>7071</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>7072</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>7073</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:State Province!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>7074</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7075</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7076</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7077</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7078</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7079</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7080</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7081</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7082</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>7083</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>7084</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7085</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7086</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>7087</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>7088</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>7089</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>7090</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>7091</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7092</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>7093</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>7094</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>7095</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>7096</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>7097</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>7098</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>7099</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>7100</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>7101</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>7102</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>7103</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>7104</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>7105</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>7106</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>7107</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:City!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>7108</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7109</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7110</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!CATALOG_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7111</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!SCHEMA_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7112</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!CUBE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7113</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!DIMENSION_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7114</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!HIERARCHY_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7115</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!LEVEL_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7116</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!LEVEL_NUMBER</COLUMN_NAME>
        <ORDINAL_POSITION>7117</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_ORDINAL</COLUMN_NAME>
        <ORDINAL_POSITION>7118</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7119</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7120</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_TYPE</COLUMN_NAME>
        <ORDINAL_POSITION>7121</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_GUID</COLUMN_NAME>
        <ORDINAL_POSITION>7122</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_CAPTION</COLUMN_NAME>
        <ORDINAL_POSITION>7123</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!CHILDREN_CARDINALITY</COLUMN_NAME>
        <ORDINAL_POSITION>7124</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!PARENT_LEVEL</COLUMN_NAME>
        <ORDINAL_POSITION>7125</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!PARENT_UNIQUE_NAME</COLUMN_NAME>
        <ORDINAL_POSITION>7126</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!PARENT_COUNT</COLUMN_NAME>
        <ORDINAL_POSITION>7127</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!DESCRIPTION</COLUMN_NAME>
        <ORDINAL_POSITION>7128</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!$visible</COLUMN_NAME>
        <ORDINAL_POSITION>7129</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!MEMBER_KEY</COLUMN_NAME>
        <ORDINAL_POSITION>7130</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!IS_PLACEHOLDERMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>7131</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!IS_DATAMEMBER</COLUMN_NAME>
        <ORDINAL_POSITION>7132</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>11</DATA_TYPE>
        <NUMERIC_PRECISION>255</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!DEPTH</COLUMN_NAME>
        <ORDINAL_POSITION>7133</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!DISPLAY_INFO</COLUMN_NAME>
        <ORDINAL_POSITION>7134</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!VALUE</COLUMN_NAME>
        <ORDINAL_POSITION>7135</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!$scenario</COLUMN_NAME>
        <ORDINAL_POSITION>7136</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!CELL_FORMATTER</COLUMN_NAME>
        <ORDINAL_POSITION>7137</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!CELL_FORMATTER_SCRIPT</COLUMN_NAME>
        <ORDINAL_POSITION>7138</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!CELL_FORMATTER_SCRIPT_LANGUAGE</COLUMN_NAME>
        <ORDINAL_POSITION>7139</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!DISPLAY_FOLDER</COLUMN_NAME>
        <ORDINAL_POSITION>7140</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!FORMAT_EXP</COLUMN_NAME>
        <ORDINAL_POSITION>7141</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Warehouse:Warehouse Name!KEY</COLUMN_NAME>
        <ORDINAL_POSITION>7142</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>130</DATA_TYPE>
        <CHARACTER_MAXIMUM_LENGTH>0</CHARACTER_MAXIMUM_LENGTH>
        <CHARACTER_OCTET_LENGTH>0</CHARACTER_OCTET_LENGTH>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Store Cost</COLUMN_NAME>
        <ORDINAL_POSITION>7143</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Store Sales</COLUMN_NAME>
        <ORDINAL_POSITION>7144</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Unit Sales</COLUMN_NAME>
        <ORDINAL_POSITION>7145</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Store Invoice</COLUMN_NAME>
        <ORDINAL_POSITION>7146</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Supply Time</COLUMN_NAME>
        <ORDINAL_POSITION>7147</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Units Ordered</COLUMN_NAME>
        <ORDINAL_POSITION>7148</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Units Shipped</COLUMN_NAME>
        <ORDINAL_POSITION>7149</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Warehouse Cost</COLUMN_NAME>
        <ORDINAL_POSITION>7150</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Warehouse Profit</COLUMN_NAME>
        <ORDINAL_POSITION>7151</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Warehouse Sales</COLUMN_NAME>
        <ORDINAL_POSITION>7152</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Profit</COLUMN_NAME>
        <ORDINAL_POSITION>7153</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Profit Growth</COLUMN_NAME>
        <ORDINAL_POSITION>7154</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Average Warehouse Sale</COLUMN_NAME>
        <ORDINAL_POSITION>7155</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <COLUMN_NAME>Measures:Profit Per Unit Shipped</COLUMN_NAME>
        <ORDINAL_POSITION>7156</ORDINAL_POSITION>
        <COLUMN_HAS_DEFAULT>false</COLUMN_HAS_DEFAULT>
        <COLUMN_FLAGS>0</COLUMN_FLAGS>
        <IS_NULLABLE>false</IS_NULLABLE>
        <DATA_TYPE>5</DATA_TYPE>
        <NUMERIC_PRECISION>16</NUMERIC_PRECISION>
        <NUMERIC_SCALE>255</NUMERIC_SCALE>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetDBSchemaProviderTypes":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DBSCHEMA_PROVIDER_TYPES</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="TYPE_NAME" name="TYPE_NAME" type="xsd:string"/>
            <xsd:element sql:field="DATA_TYPE" name="DATA_TYPE" type="xsd:unsignedShort"/>
            <xsd:element sql:field="COLUMN_SIZE" name="COLUMN_SIZE" type="xsd:unsignedInt"/>
            <xsd:element sql:field="LITERAL_PREFIX" name="LITERAL_PREFIX" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="LITERAL_SUFFIX" name="LITERAL_SUFFIX" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="IS_NULLABLE" name="IS_NULLABLE" type="xsd:boolean" minOccurs="0"/>
            <xsd:element sql:field="CASE_SENSITIVE" name="CASE_SENSITIVE" type="xsd:boolean" minOccurs="0"/>
            <xsd:element sql:field="SEARCHABLE" name="SEARCHABLE" type="xsd:unsignedInt" minOccurs="0"/>
            <xsd:element sql:field="UNSIGNED_ATTRIBUTE" name="UNSIGNED_ATTRIBUTE" type="xsd:boolean" minOccurs="0"/>
            <xsd:element sql:field="FIXED_PREC_SCALE" name="FIXED_PREC_SCALE" type="xsd:boolean" minOccurs="0"/>
            <xsd:element sql:field="AUTO_UNIQUE_VALUE" name="AUTO_UNIQUE_VALUE" type="xsd:boolean" minOccurs="0"/>
            <xsd:element sql:field="IS_LONG" name="IS_LONG" type="xsd:boolean" minOccurs="0"/>
            <xsd:element sql:field="BEST_MATCH" name="BEST_MATCH" type="xsd:boolean" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <TYPE_NAME>INTEGER</TYPE_NAME>
        <DATA_TYPE>3</DATA_TYPE>
        <COLUMN_SIZE>8</COLUMN_SIZE>
        <IS_NULLABLE>true</IS_NULLABLE>
        <UNSIGNED_ATTRIBUTE>false</UNSIGNED_ATTRIBUTE>
        <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
        <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
        <IS_LONG>false</IS_LONG>
        <BEST_MATCH>true</BEST_MATCH>
      </row>
      <row>
        <TYPE_NAME>DOUBLE</TYPE_NAME>
        <DATA_TYPE>5</DATA_TYPE>
        <COLUMN_SIZE>16</COLUMN_SIZE>
        <IS_NULLABLE>true</IS_NULLABLE>
        <UNSIGNED_ATTRIBUTE>false</UNSIGNED_ATTRIBUTE>
        <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
        <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
        <IS_LONG>false</IS_LONG>
        <BEST_MATCH>true</BEST_MATCH>
      </row>
      <row>
        <TYPE_NAME>CURRENCY</TYPE_NAME>
        <DATA_TYPE>6</DATA_TYPE>
        <COLUMN_SIZE>8</COLUMN_SIZE>
        <IS_NULLABLE>true</IS_NULLABLE>
        <UNSIGNED_ATTRIBUTE>false</UNSIGNED_ATTRIBUTE>
        <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
        <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
        <IS_LONG>false</IS_LONG>
        <BEST_MATCH>true</BEST_MATCH>
      </row>
      <row>
        <TYPE_NAME>BOOLEAN</TYPE_NAME>
        <DATA_TYPE>11</DATA_TYPE>
        <COLUMN_SIZE>1</COLUMN_SIZE>
        <IS_NULLABLE>true</IS_NULLABLE>
        <UNSIGNED_ATTRIBUTE>false</UNSIGNED_ATTRIBUTE>
        <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
        <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
        <IS_LONG>false</IS_LONG>
        <BEST_MATCH>true</BEST_MATCH>
      </row>
      <row>
        <TYPE_NAME>LARGE_INTEGER</TYPE_NAME>
        <DATA_TYPE>20</DATA_TYPE>
        <COLUMN_SIZE>16</COLUMN_SIZE>
        <IS_NULLABLE>true</IS_NULLABLE>
        <UNSIGNED_ATTRIBUTE>false</UNSIGNED_ATTRIBUTE>
        <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
        <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
        <IS_LONG>false</IS_LONG>
        <BEST_MATCH>true</BEST_MATCH>
      </row>
      <row>
        <TYPE_NAME>STRING</TYPE_NAME>
        <DATA_TYPE>130</DATA_TYPE>
        <COLUMN_SIZE>255</COLUMN_SIZE>
        <LITERAL_PREFIX>"</LITERAL_PREFIX>
        <LITERAL_SUFFIX>"</LITERAL_SUFFIX>
        <IS_NULLABLE>true</IS_NULLABLE>
        <CASE_SENSITIVE>false</CASE_SENSITIVE>
        <FIXED_PREC_SCALE>false</FIXED_PREC_SCALE>
        <AUTO_UNIQUE_VALUE>false</AUTO_UNIQUE_VALUE>
        <IS_LONG>false</IS_LONG>
        <BEST_MATCH>true</BEST_MATCH>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetDBSchemaSchemata":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DBSCHEMA_SCHEMATA</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string"/>
            <xsd:element sql:field="SCHEMA_OWNER" name="SCHEMA_OWNER" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <SCHEMA_OWNER/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetDBSchemaTables":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DBSCHEMA_TABLES</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="TABLE_CATALOG" name="TABLE_CATALOG" type="xsd:string"/>
            <xsd:element sql:field="TABLE_SCHEMA" name="TABLE_SCHEMA" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="TABLE_NAME" name="TABLE_NAME" type="xsd:string"/>
            <xsd:element sql:field="TABLE_TYPE" name="TABLE_TYPE" type="xsd:string"/>
            <xsd:element sql:field="TABLE_GUID" name="TABLE_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="TABLE_PROPID" name="TABLE_PROPID" type="xsd:unsignedInt" minOccurs="0"/>
            <xsd:element sql:field="DATE_CREATED" name="DATE_CREATED" type="xsd:dateTime" minOccurs="0"/>
            <xsd:element sql:field="DATE_MODIFIED" name="DATE_MODIFIED" type="xsd:dateTime" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Department:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Department Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Department:Department Description</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Department Hierarchy - Department Description Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Employees:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Employees Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Employees:Employee Id</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Employees Hierarchy - Employee Id Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Pay Type:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Pay Type Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Pay Type:Pay Type</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Pay Type Hierarchy - Pay Type Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Position:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Position Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Position:Management Role</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Position Hierarchy - Management Role Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Position:Position Title</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Position Hierarchy - Position Title Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Store Type:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Store Type Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Store Type:Store Type</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Store Type Hierarchy - Store Type Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Store:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Store Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Store:Store City</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Store Hierarchy - Store City Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Store:Store Country</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Store Hierarchy - Store Country Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Store:Store Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Store Hierarchy - Store Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Store:Store State</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Store Hierarchy - Store State Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Time:Month</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Time Hierarchy - Month Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Time:Quarter</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Time Hierarchy - Quarter Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR:Time:Year</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube - Time Hierarchy - Year Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Gender:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Gender Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Gender:Gender</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Gender Hierarchy - Gender Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Product:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Product Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Product:Brand Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Product Hierarchy - Brand Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Product:Product Category</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Product Hierarchy - Product Category Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Product:Product Department</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Product Hierarchy - Product Department Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Product:Product Family</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Product Hierarchy - Product Family Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Product:Product Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Product Hierarchy - Product Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Product:Product Subcategory</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Product Hierarchy - Product Subcategory Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Time.Weekly:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Time.Weekly Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Time.Weekly:Day</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Time.Weekly Hierarchy - Day Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Time.Weekly:Week</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Time.Weekly Hierarchy - Week Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Time.Weekly:Year</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Time.Weekly Hierarchy - Year Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Time:Month</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Time Hierarchy - Month Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Time:Quarter</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Time Hierarchy - Quarter Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2:Time:Year</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube - Time Hierarchy - Year Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Customers:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Customers Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Customers:City</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Customers Hierarchy - City Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Customers:Country</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Customers Hierarchy - Country Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Customers:Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Customers Hierarchy - Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Customers:State Province</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Customers Hierarchy - State Province Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Education Level:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Education Level Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Education Level:Education Level</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Education Level Hierarchy - Education Level Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Gender:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Gender Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Gender:Gender</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Gender Hierarchy - Gender Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Geography:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Geography Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Geography:City</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Geography Hierarchy - City Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Geography:Country</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Geography Hierarchy - Country Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Geography:State</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Geography Hierarchy - State Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Marital Status:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Marital Status Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Marital Status:Marital Status</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Marital Status Hierarchy - Marital Status Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Product:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Product Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Product:Brand Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Product Hierarchy - Brand Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Product:Product Category</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Product Hierarchy - Product Category Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Product:Product Department</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Product Hierarchy - Product Department Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Product:Product Family</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Product Hierarchy - Product Family Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Product:Product Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Product Hierarchy - Product Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Product:Product Subcategory</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Product Hierarchy - Product Subcategory Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Promotion Media:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Promotion Media Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Promotion Media:Media Type</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Promotion Media Hierarchy - Media Type Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Promotions:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Promotions Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Promotions:Promotion Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Promotions Hierarchy - Promotion Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Store Size in SQFT:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Store Size in SQFT Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Store Size in SQFT:Store Sqft</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Store Size in SQFT Hierarchy - Store Sqft Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Store Type:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Store Type Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Store Type:Store Type</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Store Type Hierarchy - Store Type Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Store:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Store Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Store:Store City</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Store Hierarchy - Store City Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Store:Store Country</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Store Hierarchy - Store Country Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Store:Store Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Store Hierarchy - Store Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Store:Store State</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Store Hierarchy - Store State Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Time.Weekly:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Time.Weekly Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Time.Weekly:Day</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Time.Weekly Hierarchy - Day Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Time.Weekly:Week</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Time.Weekly Hierarchy - Week Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Time.Weekly:Year</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Time.Weekly Hierarchy - Year Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Time:Month</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Time Hierarchy - Month Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Time:Quarter</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Time Hierarchy - Quarter Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Time:Year</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Time Hierarchy - Year Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Yearly Income:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Yearly Income Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged:Yearly Income:Yearly Income</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube - Yearly Income Hierarchy - Yearly Income Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Customers:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Customers Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Customers:City</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Customers Hierarchy - City Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Customers:Country</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Customers Hierarchy - Country Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Customers:Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Customers Hierarchy - Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Customers:State Province</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Customers Hierarchy - State Province Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Education Level:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Education Level Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Education Level:Education Level</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Education Level Hierarchy - Education Level Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Gender:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Gender Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Gender:Gender</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Gender Hierarchy - Gender Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Marital Status:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Marital Status Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Marital Status:Marital Status</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Marital Status Hierarchy - Marital Status Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Product:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Product Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Product:Brand Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Product Hierarchy - Brand Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Product:Product Category</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Product Hierarchy - Product Category Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Product:Product Department</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Product Hierarchy - Product Department Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Product:Product Family</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Product Hierarchy - Product Family Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Product:Product Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Product Hierarchy - Product Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Product:Product Subcategory</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Product Hierarchy - Product Subcategory Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Promotion Media:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Promotion Media Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Promotion Media:Media Type</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Promotion Media Hierarchy - Media Type Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Promotions:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Promotions Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Promotions:Promotion Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Promotions Hierarchy - Promotion Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Store Size in SQFT:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Store Size in SQFT Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Store Size in SQFT:Store Sqft</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Store Size in SQFT Hierarchy - Store Sqft Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Store Type:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Store Type Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Store Type:Store Type</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Store Type Hierarchy - Store Type Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Store:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Store Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Store:Store City</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Store Hierarchy - Store City Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Store:Store Country</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Store Hierarchy - Store Country Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Store:Store Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Store Hierarchy - Store Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Store:Store State</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Store Hierarchy - Store State Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Time.Weekly:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Time.Weekly Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Time.Weekly:Day</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Time.Weekly Hierarchy - Day Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Time.Weekly:Week</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Time.Weekly Hierarchy - Week Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Time.Weekly:Year</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Time.Weekly Hierarchy - Year Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Time:Month</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Time Hierarchy - Month Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Time:Quarter</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Time Hierarchy - Quarter Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Time:Year</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Time Hierarchy - Year Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Yearly Income:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Yearly Income Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales:Yearly Income:Yearly Income</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Cube - Yearly Income Hierarchy - Yearly Income Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store:Has coffee bar:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Store Cube - Has coffee bar Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store:Has coffee bar:Has coffee bar</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Store Cube - Has coffee bar Hierarchy - Has coffee bar Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store:Store Type:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Store Cube - Store Type Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store:Store Type:Store Type</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Store Cube - Store Type Hierarchy - Store Type Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store:Store:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Store Cube - Store Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store:Store:Store City</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Store Cube - Store Hierarchy - Store City Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store:Store:Store Country</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Store Cube - Store Hierarchy - Store Country Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store:Store:Store Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Store Cube - Store Hierarchy - Store Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store:Store:Store State</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Store Cube - Store Hierarchy - Store State Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Customers:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Customers Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Customers:City</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Customers Hierarchy - City Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Customers:Country</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Customers Hierarchy - Country Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Customers:Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Customers Hierarchy - Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Customers:State Province</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Customers Hierarchy - State Province Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Education Level:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Education Level Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Education Level:Education Level</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Education Level Hierarchy - Education Level Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Gender:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Gender Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Gender:Gender</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Gender Hierarchy - Gender Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Marital Status:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Marital Status Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Marital Status:Marital Status</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Marital Status Hierarchy - Marital Status Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Product:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Product Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Product:Brand Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Product Hierarchy - Brand Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Product:Product Category</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Product Hierarchy - Product Category Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Product:Product Department</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Product Hierarchy - Product Department Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Product:Product Family</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Product Hierarchy - Product Family Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Product:Product Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Product Hierarchy - Product Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Product:Product Subcategory</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Product Hierarchy - Product Subcategory Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Promotion Media:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Promotion Media Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Promotion Media:Media Type</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Promotion Media Hierarchy - Media Type Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Promotions:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Promotions Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Promotions:Promotion Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Promotions Hierarchy - Promotion Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Store:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Store Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Store:Store City</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Store Hierarchy - Store City Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Store:Store Country</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Store Hierarchy - Store Country Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Store:Store Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Store Hierarchy - Store Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Store:Store State</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Store Hierarchy - Store State Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Time.Weekly:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Time.Weekly Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Time.Weekly:Day</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Time.Weekly Hierarchy - Day Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Time.Weekly:Week</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Time.Weekly Hierarchy - Week Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Time.Weekly:Year</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Time.Weekly Hierarchy - Year Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Time:Month</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Time Hierarchy - Month Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Time:Quarter</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Time Hierarchy - Quarter Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Time:Year</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Time Hierarchy - Year Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Warehouse:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Warehouse Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Warehouse:City</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Warehouse Hierarchy - City Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Warehouse:Country</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Warehouse Hierarchy - Country Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Warehouse:State Province</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Warehouse Hierarchy - State Province Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Warehouse:Warehouse Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Warehouse Hierarchy - Warehouse Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Yearly Income:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Yearly Income Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales:Yearly Income:Yearly Income</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube - Yearly Income Hierarchy - Yearly Income Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Product:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Product Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Product:Brand Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Product Hierarchy - Brand Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Product:Product Category</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Product Hierarchy - Product Category Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Product:Product Department</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Product Hierarchy - Product Department Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Product:Product Family</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Product Hierarchy - Product Family Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Product:Product Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Product Hierarchy - Product Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Product:Product Subcategory</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Product Hierarchy - Product Subcategory Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Store Size in SQFT:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Store Size in SQFT Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Store Size in SQFT:Store Sqft</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Store Size in SQFT Hierarchy - Store Sqft Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Store Type:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Store Type Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Store Type:Store Type</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Store Type Hierarchy - Store Type Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Store:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Store Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Store:Store City</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Store Hierarchy - Store City Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Store:Store Country</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Store Hierarchy - Store Country Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Store:Store Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Store Hierarchy - Store Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Store:Store State</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Store Hierarchy - Store State Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Time.Weekly:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Time.Weekly Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Time.Weekly:Day</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Time.Weekly Hierarchy - Day Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Time.Weekly:Week</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Time.Weekly Hierarchy - Week Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Time.Weekly:Year</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Time.Weekly Hierarchy - Year Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Time:Month</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Time Hierarchy - Month Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Time:Quarter</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Time Hierarchy - Quarter Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Time:Year</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Time Hierarchy - Year Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Warehouse:(All)</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Warehouse Hierarchy - (All) Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Warehouse:City</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Warehouse Hierarchy - City Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Warehouse:Country</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Warehouse Hierarchy - Country Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Warehouse:State Province</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Warehouse Hierarchy - State Province Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse:Warehouse:Warehouse Name</TABLE_NAME>
        <TABLE_TYPE>SYSTEM TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube - Warehouse Hierarchy - Warehouse Name Level</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - HR Cube</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <DESCRIPTION>Cube Verkaufen</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales 2 Cube</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Sales Ragged Cube</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Store Cube</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse Cube</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube</DESCRIPTION>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetDBSchemaTablesInfo":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DBSCHEMA_TABLES_INFO</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="TABLE_CATALOG" name="TABLE_CATALOG" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="TABLE_SCHEMA" name="TABLE_SCHEMA" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="TABLE_NAME" name="TABLE_NAME" type="xsd:string"/>
            <xsd:element sql:field="TABLE_TYPE" name="TABLE_TYPE" type="xsd:string"/>
            <xsd:element sql:field="TABLE_GUID" name="TABLE_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="BOOKMARKS" name="BOOKMARKS" type="xsd:boolean"/>
            <xsd:element sql:field="BOOKMARK_TYPE" name="BOOKMARK_TYPE" type="xsd:int" minOccurs="0"/>
            <xsd:element sql:field="BOOKMARK_DATATYPE" name="BOOKMARK_DATATYPE" type="xsd:unsignedShort" minOccurs="0"/>
            <xsd:element sql:field="BOOKMARK_MAXIMUM_LENGTH" name="BOOKMARK_MAXIMUM_LENGTH" type="xsd:unsignedInt" minOccurs="0"/>
            <xsd:element sql:field="BOOKMARK_INFORMATION" name="BOOKMARK_INFORMATION" type="xsd:unsignedInt" minOccurs="0"/>
            <xsd:element sql:field="TABLE_VERSION" name="TABLE_VERSION" type="xsd:long" minOccurs="0"/>
            <xsd:element sql:field="CARDINALITY" name="CARDINALITY" type="xsd:unsignedLong"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="TABLE_PROPID" name="TABLE_PROPID" type="xsd:unsignedInt" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>HR</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <BOOKMARKS>false</BOOKMARKS>
        <TABLE_VERSION>null</TABLE_VERSION>
        <CARDINALITY>1000000</CARDINALITY>
        <DESCRIPTION>FoodMart - HR Cube</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <BOOKMARKS>false</BOOKMARKS>
        <TABLE_VERSION>null</TABLE_VERSION>
        <CARDINALITY>1000000</CARDINALITY>
        <DESCRIPTION>Cube Verkaufen</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales 2</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <BOOKMARKS>false</BOOKMARKS>
        <TABLE_VERSION>null</TABLE_VERSION>
        <CARDINALITY>1000000</CARDINALITY>
        <DESCRIPTION>FoodMart - Sales 2 Cube</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Sales Ragged</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <BOOKMARKS>false</BOOKMARKS>
        <TABLE_VERSION>null</TABLE_VERSION>
        <CARDINALITY>1000000</CARDINALITY>
        <DESCRIPTION>FoodMart - Sales Ragged Cube</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Store</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <BOOKMARKS>false</BOOKMARKS>
        <TABLE_VERSION>null</TABLE_VERSION>
        <CARDINALITY>1000000</CARDINALITY>
        <DESCRIPTION>FoodMart - Store Cube</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <BOOKMARKS>false</BOOKMARKS>
        <TABLE_VERSION>null</TABLE_VERSION>
        <CARDINALITY>1000000</CARDINALITY>
        <DESCRIPTION>FoodMart - Warehouse Cube</DESCRIPTION>
      </row>
      <row>
        <TABLE_CATALOG>FoodMart</TABLE_CATALOG>
        <TABLE_NAME>Warehouse and Sales</TABLE_NAME>
        <TABLE_TYPE>TABLE</TABLE_TYPE>
        <BOOKMARKS>false</BOOKMARKS>
        <TABLE_VERSION>null</TABLE_VERSION>
        <CARDINALITY>1000000</CARDINALITY>
        <DESCRIPTION>FoodMart - Warehouse and Sales Cube</DESCRIPTION>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetDatasources":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_DATASOURCES</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="DataSourceName" name="DataSourceName" type="xsd:string"/>
            <xsd:element sql:field="DataSourceDescription" name="DataSourceDescription" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="URL" name="URL" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DataSourceInfo" name="DataSourceInfo" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="ProviderName" name="ProviderName" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="ProviderType" name="ProviderType" type="xsd:string" maxOccurs="unbounded"/>
            <xsd:element sql:field="AuthenticationMode" name="AuthenticationMode" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <DataSourceName>Foodmart</DataSourceName>
        <DataSourceDescription>Foodmart Sample Data</DataSourceDescription>
        <URL>http://localhost:8080/xmondrian/xmla</URL>
        <DataSourceInfo>Provider=mondrian; JdbcDrivers=org.hsqldb.jdbc.JDBCDriver</DataSourceInfo>
        <ProviderName>Mondrian</ProviderName>
        <ProviderType>MDP</ProviderType>
        <AuthenticationMode>Unauthenticated</AuthenticationMode>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetEnumerators":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_ENUMERATORS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="EnumName" name="EnumName" type="xsd:string"/>
            <xsd:element sql:field="EnumDescription" name="EnumDescription" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="EnumType" name="EnumType" type="xsd:string"/>
            <xsd:element sql:field="ElementName" name="ElementName" type="xsd:string"/>
            <xsd:element sql:field="ElementDescription" name="ElementDescription" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="ElementValue" name="ElementValue" type="xsd:string" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <EnumName>Access</EnumName>
        <EnumDescription>The read/write behavior of a property</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>Read</ElementName>
        <ElementValue>1</ElementValue>
      </row>
      <row>
        <EnumName>Access</EnumName>
        <EnumDescription>The read/write behavior of a property</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>Write</ElementName>
        <ElementValue>2</ElementValue>
      </row>
      <row>
        <EnumName>Access</EnumName>
        <EnumDescription>The read/write behavior of a property</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>ReadWrite</ElementName>
        <ElementValue>3</ElementValue>
      </row>
      <row>
        <EnumName>AuthenticationMode</EnumName>
        <EnumDescription>Specification of what type of security mode the data source uses.</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>Unauthenticated</ElementName>
        <ElementDescription>no user ID or password needs to be sent.</ElementDescription>
        <ElementValue>0</ElementValue>
      </row>
      <row>
        <EnumName>AuthenticationMode</EnumName>
        <EnumDescription>Specification of what type of security mode the data source uses.</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>Authenticated</ElementName>
        <ElementDescription>User ID and Password must be included in the information required for the connection.</ElementDescription>
        <ElementValue>1</ElementValue>
      </row>
      <row>
        <EnumName>AuthenticationMode</EnumName>
        <EnumDescription>Specification of what type of security mode the data source uses.</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>Integrated</ElementName>
        <ElementDescription>the data source uses the underlying security to determine authorization, such as Integrated Security provided by Microsoft Internet Information Services (IIS).</ElementDescription>
        <ElementValue>2</ElementValue>
      </row>
      <row>
        <EnumName>ProviderType</EnumName>
        <EnumDescription>The types of data supported by the provider.</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>TDP</ElementName>
        <ElementDescription>tabular data provider.</ElementDescription>
        <ElementValue>0</ElementValue>
      </row>
      <row>
        <EnumName>ProviderType</EnumName>
        <EnumDescription>The types of data supported by the provider.</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>MDP</ElementName>
        <ElementDescription>multidimensional data provider.</ElementDescription>
        <ElementValue>1</ElementValue>
      </row>
      <row>
        <EnumName>ProviderType</EnumName>
        <EnumDescription>The types of data supported by the provider.</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>DMP</ElementName>
        <ElementDescription>data mining provider. A DMP provider implements the OLE DB for Data Mining specification.</ElementDescription>
        <ElementValue>2</ElementValue>
      </row>
      <row>
        <EnumName>TREE_OP</EnumName>
        <EnumDescription>Bitmap which controls which relatives of a member are returned</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>MDTREEOP_CHILDREN</ElementName>
        <ElementDescription>Tree operation which returns only the immediate children.</ElementDescription>
        <ElementValue>1</ElementValue>
      </row>
      <row>
        <EnumName>TREE_OP</EnumName>
        <EnumDescription>Bitmap which controls which relatives of a member are returned</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>MDTREEOP_SIBLINGS</ElementName>
        <ElementDescription>Tree operation which returns members on the same level.</ElementDescription>
        <ElementValue>2</ElementValue>
      </row>
      <row>
        <EnumName>TREE_OP</EnumName>
        <EnumDescription>Bitmap which controls which relatives of a member are returned</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>MDTREEOP_PARENT</ElementName>
        <ElementDescription>Tree operation which returns only the immediate parent.</ElementDescription>
        <ElementValue>4</ElementValue>
      </row>
      <row>
        <EnumName>TREE_OP</EnumName>
        <EnumDescription>Bitmap which controls which relatives of a member are returned</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>MDTREEOP_SELF</ElementName>
        <ElementDescription>Tree operation which returns itself in the list of returned rows.</ElementDescription>
        <ElementValue>8</ElementValue>
      </row>
      <row>
        <EnumName>TREE_OP</EnumName>
        <EnumDescription>Bitmap which controls which relatives of a member are returned</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>MDTREEOP_DESCENDANTS</ElementName>
        <ElementDescription>Tree operation which returns all of the descendants.</ElementDescription>
        <ElementValue>16</ElementValue>
      </row>
      <row>
        <EnumName>TREE_OP</EnumName>
        <EnumDescription>Bitmap which controls which relatives of a member are returned</EnumDescription>
        <EnumType>string</EnumType>
        <ElementName>MDTREEOP_ANCESTORS</ElementName>
        <ElementDescription>Tree operation which returns all of the ancestors.</ElementDescription>
        <ElementValue>32</ElementValue>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetKeywords":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_KEYWORDS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="Keyword" name="Keyword" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <Keyword>$AdjustedProbability</Keyword>
      </row>
      <row>
        <Keyword>$Distance</Keyword>
      </row>
      <row>
        <Keyword>$Probability</Keyword>
      </row>
      <row>
        <Keyword>$ProbabilityStDev</Keyword>
      </row>
      <row>
        <Keyword>$ProbabilityStdDeV</Keyword>
      </row>
      <row>
        <Keyword>$ProbabilityVariance</Keyword>
      </row>
      <row>
        <Keyword>$StDev</Keyword>
      </row>
      <row>
        <Keyword>$StdDeV</Keyword>
      </row>
      <row>
        <Keyword>$Support</Keyword>
      </row>
      <row>
        <Keyword>$Variance</Keyword>
      </row>
      <row>
        <Keyword>AddCalculatedMembers</Keyword>
      </row>
      <row>
        <Keyword>Action</Keyword>
      </row>
      <row>
        <Keyword>After</Keyword>
      </row>
      <row>
        <Keyword>Aggregate</Keyword>
      </row>
      <row>
        <Keyword>All</Keyword>
      </row>
      <row>
        <Keyword>Alter</Keyword>
      </row>
      <row>
        <Keyword>Ancestor</Keyword>
      </row>
      <row>
        <Keyword>And</Keyword>
      </row>
      <row>
        <Keyword>Append</Keyword>
      </row>
      <row>
        <Keyword>As</Keyword>
      </row>
      <row>
        <Keyword>ASC</Keyword>
      </row>
      <row>
        <Keyword>Axis</Keyword>
      </row>
      <row>
        <Keyword>Automatic</Keyword>
      </row>
      <row>
        <Keyword>Back_Color</Keyword>
      </row>
      <row>
        <Keyword>BASC</Keyword>
      </row>
      <row>
        <Keyword>BDESC</Keyword>
      </row>
      <row>
        <Keyword>Before</Keyword>
      </row>
      <row>
        <Keyword>Before_And_After</Keyword>
      </row>
      <row>
        <Keyword>Before_And_Self</Keyword>
      </row>
      <row>
        <Keyword>Before_Self_After</Keyword>
      </row>
      <row>
        <Keyword>BottomCount</Keyword>
      </row>
      <row>
        <Keyword>BottomPercent</Keyword>
      </row>
      <row>
        <Keyword>BottomSum</Keyword>
      </row>
      <row>
        <Keyword>Break</Keyword>
      </row>
      <row>
        <Keyword>Boolean</Keyword>
      </row>
      <row>
        <Keyword>Cache</Keyword>
      </row>
      <row>
        <Keyword>Calculated</Keyword>
      </row>
      <row>
        <Keyword>Call</Keyword>
      </row>
      <row>
        <Keyword>Case</Keyword>
      </row>
      <row>
        <Keyword>Catalog_Name</Keyword>
      </row>
      <row>
        <Keyword>Cell</Keyword>
      </row>
      <row>
        <Keyword>Cell_Ordinal</Keyword>
      </row>
      <row>
        <Keyword>Cells</Keyword>
      </row>
      <row>
        <Keyword>Chapters</Keyword>
      </row>
      <row>
        <Keyword>Children</Keyword>
      </row>
      <row>
        <Keyword>Children_Cardinality</Keyword>
      </row>
      <row>
        <Keyword>ClosingPeriod</Keyword>
      </row>
      <row>
        <Keyword>Cluster</Keyword>
      </row>
      <row>
        <Keyword>ClusterDistance</Keyword>
      </row>
      <row>
        <Keyword>ClusterProbability</Keyword>
      </row>
      <row>
        <Keyword>Clusters</Keyword>
      </row>
      <row>
        <Keyword>CoalesceEmpty</Keyword>
      </row>
      <row>
        <Keyword>Column_Values</Keyword>
      </row>
      <row>
        <Keyword>Columns</Keyword>
      </row>
      <row>
        <Keyword>Content</Keyword>
      </row>
      <row>
        <Keyword>Contingent</Keyword>
      </row>
      <row>
        <Keyword>Continuous</Keyword>
      </row>
      <row>
        <Keyword>Correlation</Keyword>
      </row>
      <row>
        <Keyword>Cousin</Keyword>
      </row>
      <row>
        <Keyword>Covariance</Keyword>
      </row>
      <row>
        <Keyword>CovarianceN</Keyword>
      </row>
      <row>
        <Keyword>Create</Keyword>
      </row>
      <row>
        <Keyword>CreatePropertySet</Keyword>
      </row>
      <row>
        <Keyword>CrossJoin</Keyword>
      </row>
      <row>
        <Keyword>Cube</Keyword>
      </row>
      <row>
        <Keyword>Cube_Name</Keyword>
      </row>
      <row>
        <Keyword>CurrentMember</Keyword>
      </row>
      <row>
        <Keyword>CurrentCube</Keyword>
      </row>
      <row>
        <Keyword>Custom</Keyword>
      </row>
      <row>
        <Keyword>Cyclical</Keyword>
      </row>
      <row>
        <Keyword>DefaultMember</Keyword>
      </row>
      <row>
        <Keyword>Default_Member</Keyword>
      </row>
      <row>
        <Keyword>DESC</Keyword>
      </row>
      <row>
        <Keyword>Descendents</Keyword>
      </row>
      <row>
        <Keyword>Description</Keyword>
      </row>
      <row>
        <Keyword>Dimension</Keyword>
      </row>
      <row>
        <Keyword>Dimension_Unique_Name</Keyword>
      </row>
      <row>
        <Keyword>Dimensions</Keyword>
      </row>
      <row>
        <Keyword>Discrete</Keyword>
      </row>
      <row>
        <Keyword>Discretized</Keyword>
      </row>
      <row>
        <Keyword>DrillDownLevel</Keyword>
      </row>
      <row>
        <Keyword>DrillDownLevelBottom</Keyword>
      </row>
      <row>
        <Keyword>DrillDownLevelTop</Keyword>
      </row>
      <row>
        <Keyword>DrillDownMember</Keyword>
      </row>
      <row>
        <Keyword>DrillDownMemberBottom</Keyword>
      </row>
      <row>
        <Keyword>DrillDownMemberTop</Keyword>
      </row>
      <row>
        <Keyword>DrillTrough</Keyword>
      </row>
      <row>
        <Keyword>DrillUpLevel</Keyword>
      </row>
      <row>
        <Keyword>DrillUpMember</Keyword>
      </row>
      <row>
        <Keyword>Drop</Keyword>
      </row>
      <row>
        <Keyword>Else</Keyword>
      </row>
      <row>
        <Keyword>Empty</Keyword>
      </row>
      <row>
        <Keyword>End</Keyword>
      </row>
      <row>
        <Keyword>Equal_Areas</Keyword>
      </row>
      <row>
        <Keyword>Exclude_Null</Keyword>
      </row>
      <row>
        <Keyword>ExcludeEmpty</Keyword>
      </row>
      <row>
        <Keyword>Exclusive</Keyword>
      </row>
      <row>
        <Keyword>Expression</Keyword>
      </row>
      <row>
        <Keyword>Filter</Keyword>
      </row>
      <row>
        <Keyword>FirstChild</Keyword>
      </row>
      <row>
        <Keyword>FirstRowset</Keyword>
      </row>
      <row>
        <Keyword>FirstSibling</Keyword>
      </row>
      <row>
        <Keyword>Flattened</Keyword>
      </row>
      <row>
        <Keyword>Font_Flags</Keyword>
      </row>
      <row>
        <Keyword>Font_Name</Keyword>
      </row>
      <row>
        <Keyword>Font_size</Keyword>
      </row>
      <row>
        <Keyword>Fore_Color</Keyword>
      </row>
      <row>
        <Keyword>Format_String</Keyword>
      </row>
      <row>
        <Keyword>Formatted_Value</Keyword>
      </row>
      <row>
        <Keyword>Formula</Keyword>
      </row>
      <row>
        <Keyword>From</Keyword>
      </row>
      <row>
        <Keyword>Generate</Keyword>
      </row>
      <row>
        <Keyword>Global</Keyword>
      </row>
      <row>
        <Keyword>Head</Keyword>
      </row>
      <row>
        <Keyword>Hierarchize</Keyword>
      </row>
      <row>
        <Keyword>Hierarchy</Keyword>
      </row>
      <row>
        <Keyword>Hierary_Unique_name</Keyword>
      </row>
      <row>
        <Keyword>IIF</Keyword>
      </row>
      <row>
        <Keyword>IsEmpty</Keyword>
      </row>
      <row>
        <Keyword>Include_Null</Keyword>
      </row>
      <row>
        <Keyword>Include_Statistics</Keyword>
      </row>
      <row>
        <Keyword>Inclusive</Keyword>
      </row>
      <row>
        <Keyword>Input_Only</Keyword>
      </row>
      <row>
        <Keyword>IsDescendant</Keyword>
      </row>
      <row>
        <Keyword>Item</Keyword>
      </row>
      <row>
        <Keyword>Lag</Keyword>
      </row>
      <row>
        <Keyword>LastChild</Keyword>
      </row>
      <row>
        <Keyword>LastPeriods</Keyword>
      </row>
      <row>
        <Keyword>LastSibling</Keyword>
      </row>
      <row>
        <Keyword>Lead</Keyword>
      </row>
      <row>
        <Keyword>Level</Keyword>
      </row>
      <row>
        <Keyword>Level_Unique_Name</Keyword>
      </row>
      <row>
        <Keyword>Levels</Keyword>
      </row>
      <row>
        <Keyword>LinRegIntercept</Keyword>
      </row>
      <row>
        <Keyword>LinRegR2</Keyword>
      </row>
      <row>
        <Keyword>LinRegPoint</Keyword>
      </row>
      <row>
        <Keyword>LinRegSlope</Keyword>
      </row>
      <row>
        <Keyword>LinRegVariance</Keyword>
      </row>
      <row>
        <Keyword>Long</Keyword>
      </row>
      <row>
        <Keyword>MaxRows</Keyword>
      </row>
      <row>
        <Keyword>Median</Keyword>
      </row>
      <row>
        <Keyword>Member</Keyword>
      </row>
      <row>
        <Keyword>Member_Caption</Keyword>
      </row>
      <row>
        <Keyword>Member_Guid</Keyword>
      </row>
      <row>
        <Keyword>Member_Name</Keyword>
      </row>
      <row>
        <Keyword>Member_Ordinal</Keyword>
      </row>
      <row>
        <Keyword>Member_Type</Keyword>
      </row>
      <row>
        <Keyword>Member_Unique_Name</Keyword>
      </row>
      <row>
        <Keyword>Members</Keyword>
      </row>
      <row>
        <Keyword>Microsoft_Clustering</Keyword>
      </row>
      <row>
        <Keyword>Microsoft_Decision_Trees</Keyword>
      </row>
      <row>
        <Keyword>Mining</Keyword>
      </row>
      <row>
        <Keyword>Model</Keyword>
      </row>
      <row>
        <Keyword>Model_Existence_Only</Keyword>
      </row>
      <row>
        <Keyword>Models</Keyword>
      </row>
      <row>
        <Keyword>Move</Keyword>
      </row>
      <row>
        <Keyword>MTD</Keyword>
      </row>
      <row>
        <Keyword>Name</Keyword>
      </row>
      <row>
        <Keyword>Nest</Keyword>
      </row>
      <row>
        <Keyword>NextMember</Keyword>
      </row>
      <row>
        <Keyword>Non</Keyword>
      </row>
      <row>
        <Keyword>Normal</Keyword>
      </row>
      <row>
        <Keyword>Not</Keyword>
      </row>
      <row>
        <Keyword>Ntext</Keyword>
      </row>
      <row>
        <Keyword>Nvarchar</Keyword>
      </row>
      <row>
        <Keyword>OLAP</Keyword>
      </row>
      <row>
        <Keyword>On</Keyword>
      </row>
      <row>
        <Keyword>OpeningPeriod</Keyword>
      </row>
      <row>
        <Keyword>OpenQuery</Keyword>
      </row>
      <row>
        <Keyword>Or</Keyword>
      </row>
      <row>
        <Keyword>Ordered</Keyword>
      </row>
      <row>
        <Keyword>Ordinal</Keyword>
      </row>
      <row>
        <Keyword>Pages</Keyword>
      </row>
      <row>
        <Keyword>Pages</Keyword>
      </row>
      <row>
        <Keyword>ParallelPeriod</Keyword>
      </row>
      <row>
        <Keyword>Parent</Keyword>
      </row>
      <row>
        <Keyword>Parent_Level</Keyword>
      </row>
      <row>
        <Keyword>Parent_Unique_Name</Keyword>
      </row>
      <row>
        <Keyword>PeriodsToDate</Keyword>
      </row>
      <row>
        <Keyword>PMML</Keyword>
      </row>
      <row>
        <Keyword>Predict</Keyword>
      </row>
      <row>
        <Keyword>Predict_Only</Keyword>
      </row>
      <row>
        <Keyword>PredictAdjustedProbability</Keyword>
      </row>
      <row>
        <Keyword>PredictHistogram</Keyword>
      </row>
      <row>
        <Keyword>Prediction</Keyword>
      </row>
      <row>
        <Keyword>PredictionScore</Keyword>
      </row>
      <row>
        <Keyword>PredictProbability</Keyword>
      </row>
      <row>
        <Keyword>PredictProbabilityStDev</Keyword>
      </row>
      <row>
        <Keyword>PredictProbabilityVariance</Keyword>
      </row>
      <row>
        <Keyword>PredictStDev</Keyword>
      </row>
      <row>
        <Keyword>PredictSupport</Keyword>
      </row>
      <row>
        <Keyword>PredictVariance</Keyword>
      </row>
      <row>
        <Keyword>PrevMember</Keyword>
      </row>
      <row>
        <Keyword>Probability</Keyword>
      </row>
      <row>
        <Keyword>Probability_StDev</Keyword>
      </row>
      <row>
        <Keyword>Probability_StdDev</Keyword>
      </row>
      <row>
        <Keyword>Probability_Variance</Keyword>
      </row>
      <row>
        <Keyword>Properties</Keyword>
      </row>
      <row>
        <Keyword>Property</Keyword>
      </row>
      <row>
        <Keyword>QTD</Keyword>
      </row>
      <row>
        <Keyword>RangeMax</Keyword>
      </row>
      <row>
        <Keyword>RangeMid</Keyword>
      </row>
      <row>
        <Keyword>RangeMin</Keyword>
      </row>
      <row>
        <Keyword>Rank</Keyword>
      </row>
      <row>
        <Keyword>Recursive</Keyword>
      </row>
      <row>
        <Keyword>Refresh</Keyword>
      </row>
      <row>
        <Keyword>Related</Keyword>
      </row>
      <row>
        <Keyword>Rename</Keyword>
      </row>
      <row>
        <Keyword>Rollup</Keyword>
      </row>
      <row>
        <Keyword>Rows</Keyword>
      </row>
      <row>
        <Keyword>Schema_Name</Keyword>
      </row>
      <row>
        <Keyword>Sections</Keyword>
      </row>
      <row>
        <Keyword>Select</Keyword>
      </row>
      <row>
        <Keyword>Self</Keyword>
      </row>
      <row>
        <Keyword>Self_And_After</Keyword>
      </row>
      <row>
        <Keyword>Sequence_Time</Keyword>
      </row>
      <row>
        <Keyword>Server</Keyword>
      </row>
      <row>
        <Keyword>Session</Keyword>
      </row>
      <row>
        <Keyword>Set</Keyword>
      </row>
      <row>
        <Keyword>SetToArray</Keyword>
      </row>
      <row>
        <Keyword>SetToStr</Keyword>
      </row>
      <row>
        <Keyword>Shape</Keyword>
      </row>
      <row>
        <Keyword>Skip</Keyword>
      </row>
      <row>
        <Keyword>Solve_Order</Keyword>
      </row>
      <row>
        <Keyword>Sort</Keyword>
      </row>
      <row>
        <Keyword>StdDev</Keyword>
      </row>
      <row>
        <Keyword>Stdev</Keyword>
      </row>
      <row>
        <Keyword>StripCalculatedMembers</Keyword>
      </row>
      <row>
        <Keyword>StrToSet</Keyword>
      </row>
      <row>
        <Keyword>StrToTuple</Keyword>
      </row>
      <row>
        <Keyword>SubSet</Keyword>
      </row>
      <row>
        <Keyword>Support</Keyword>
      </row>
      <row>
        <Keyword>Tail</Keyword>
      </row>
      <row>
        <Keyword>Text</Keyword>
      </row>
      <row>
        <Keyword>Thresholds</Keyword>
      </row>
      <row>
        <Keyword>ToggleDrillState</Keyword>
      </row>
      <row>
        <Keyword>TopCount</Keyword>
      </row>
      <row>
        <Keyword>TopPercent</Keyword>
      </row>
      <row>
        <Keyword>TopSum</Keyword>
      </row>
      <row>
        <Keyword>TupleToStr</Keyword>
      </row>
      <row>
        <Keyword>Under</Keyword>
      </row>
      <row>
        <Keyword>Uniform</Keyword>
      </row>
      <row>
        <Keyword>UniqueName</Keyword>
      </row>
      <row>
        <Keyword>Use</Keyword>
      </row>
      <row>
        <Keyword>Value</Keyword>
      </row>
      <row>
        <Keyword>Value</Keyword>
      </row>
      <row>
        <Keyword>Var</Keyword>
      </row>
      <row>
        <Keyword>Variance</Keyword>
      </row>
      <row>
        <Keyword>VarP</Keyword>
      </row>
      <row>
        <Keyword>VarianceP</Keyword>
      </row>
      <row>
        <Keyword>VisualTotals</Keyword>
      </row>
      <row>
        <Keyword>When</Keyword>
      </row>
      <row>
        <Keyword>Where</Keyword>
      </row>
      <row>
        <Keyword>With</Keyword>
      </row>
      <row>
        <Keyword>WTD</Keyword>
      </row>
      <row>
        <Keyword>Xor</Keyword>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetLiterals":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_LITERALS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="LiteralName" name="LiteralName" type="xsd:string"/>
            <xsd:element sql:field="LiteralValue" name="LiteralValue" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="LiteralInvalidChars" name="LiteralInvalidChars" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="LiteralInvalidStartingChars" name="LiteralInvalidStartingChars" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="LiteralMaxLength" name="LiteralMaxLength" type="xsd:int" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <LiteralName>DBLITERAL_CATALOG_NAME</LiteralName>
        <LiteralInvalidChars>.</LiteralInvalidChars>
        <LiteralInvalidStartingChars>0123456789</LiteralInvalidStartingChars>
        <LiteralMaxLength>24</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_CATALOG_SEPARATOR</LiteralName>
        <LiteralValue>.</LiteralValue>
        <LiteralMaxLength>0</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_COLUMN_ALIAS</LiteralName>
        <LiteralInvalidChars>'"[]</LiteralInvalidChars>
        <LiteralInvalidStartingChars>0123456789</LiteralInvalidStartingChars>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_COLUMN_NAME</LiteralName>
        <LiteralInvalidChars>.</LiteralInvalidChars>
        <LiteralInvalidStartingChars>0123456789</LiteralInvalidStartingChars>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_CORRELATION_NAME</LiteralName>
        <LiteralInvalidChars>'"[]</LiteralInvalidChars>
        <LiteralInvalidStartingChars>0123456789</LiteralInvalidStartingChars>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_CUBE_NAME</LiteralName>
        <LiteralInvalidChars>.</LiteralInvalidChars>
        <LiteralInvalidStartingChars>0123456789</LiteralInvalidStartingChars>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_DIMENSION_NAME</LiteralName>
        <LiteralInvalidChars>.</LiteralInvalidChars>
        <LiteralInvalidStartingChars>0123456789</LiteralInvalidStartingChars>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_HIERARCHY_NAME</LiteralName>
        <LiteralInvalidChars>.</LiteralInvalidChars>
        <LiteralInvalidStartingChars>0123456789</LiteralInvalidStartingChars>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_LEVEL_NAME</LiteralName>
        <LiteralInvalidChars>.</LiteralInvalidChars>
        <LiteralInvalidStartingChars>0123456789</LiteralInvalidStartingChars>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_MEMBER_NAME</LiteralName>
        <LiteralInvalidChars>.</LiteralInvalidChars>
        <LiteralInvalidStartingChars>0123456789</LiteralInvalidStartingChars>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_PROCEDURE_NAME</LiteralName>
        <LiteralInvalidChars>.</LiteralInvalidChars>
        <LiteralInvalidStartingChars>0123456789</LiteralInvalidStartingChars>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_PROPERTY_NAME</LiteralName>
        <LiteralInvalidChars>.</LiteralInvalidChars>
        <LiteralInvalidStartingChars>0123456789</LiteralInvalidStartingChars>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_QUOTE</LiteralName>
        <LiteralValue>[</LiteralValue>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_QUOTE_SUFFIX</LiteralName>
        <LiteralValue>]</LiteralValue>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_TABLE_NAME</LiteralName>
        <LiteralInvalidChars>.</LiteralInvalidChars>
        <LiteralInvalidStartingChars>0123456789</LiteralInvalidStartingChars>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_TEXT_COMMAND</LiteralName>
        <LiteralMaxLength>-1</LiteralMaxLength>
      </row>
      <row>
        <LiteralName>DBLITERAL_USER_NAME</LiteralName>
        <LiteralMaxLength>0</LiteralMaxLength>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetMDSchemaActions":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_ACTIONS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>HR</CUBE_NAME>
          <COORDINATE>HR</COORDINATE>
          <COORDINATE_TYPE>1</COORDINATE_TYPE>
        </RestrictionList>
      </Restrictions>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="ACTION_NAME" name="ACTION_NAME" type="xsd:string"/>
            <xsd:element sql:field="COORDINATE" name="COORDINATE" type="xsd:string"/>
            <xsd:element sql:field="COORDINATE_TYPE" name="COORDINATE_TYPE" type="xsd:int"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetMDSchemaCubes":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_CUBES</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties>
        <PropertyList>
          <Catalog>FoodMart</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="CUBE_TYPE" name="CUBE_TYPE" type="xsd:string"/>
            <xsd:element sql:field="CUBE_GUID" name="CUBE_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="CREATED_ON" name="CREATED_ON" type="xsd:dateTime" minOccurs="0"/>
            <xsd:element sql:field="LAST_SCHEMA_UPDATE" name="LAST_SCHEMA_UPDATE" type="xsd:dateTime" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_UPDATED_BY" name="SCHEMA_UPDATED_BY" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="LAST_DATA_UPDATE" name="LAST_DATA_UPDATE" type="xsd:dateTime" minOccurs="0"/>
            <xsd:element sql:field="DATA_UPDATED_BY" name="DATA_UPDATED_BY" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="IS_DRILLTHROUGH_ENABLED" name="IS_DRILLTHROUGH_ENABLED" type="xsd:boolean"/>
            <xsd:element sql:field="IS_WRITE_ENABLED" name="IS_WRITE_ENABLED" type="xsd:boolean"/>
            <xsd:element sql:field="IS_LINKABLE" name="IS_LINKABLE" type="xsd:boolean"/>
            <xsd:element sql:field="IS_SQL_ENABLED" name="IS_SQL_ENABLED" type="xsd:boolean"/>
            <xsd:element sql:field="CUBE_CAPTION" name="CUBE_CAPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DIMENSIONS" name="DIMENSIONS" minOccurs="0"/>
            <xsd:element sql:field="SETS" name="SETS" minOccurs="0"/>
            <xsd:element sql:field="MEASURES" name="MEASURES" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <CUBE_TYPE>CUBE</CUBE_TYPE>
        <LAST_SCHEMA_UPDATE>2019-04-10T20:16:40</LAST_SCHEMA_UPDATE>
        <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
        <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
        <IS_LINKABLE>false</IS_LINKABLE>
        <IS_SQL_ENABLED>false</IS_SQL_ENABLED>
        <CUBE_CAPTION>HR</CUBE_CAPTION>
        <DESCRIPTION>FoodMart Schema - HR Cube</DESCRIPTION>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>Sales</CUBE_NAME>
        <CUBE_TYPE>CUBE</CUBE_TYPE>
        <LAST_SCHEMA_UPDATE>2019-04-10T20:16:40</LAST_SCHEMA_UPDATE>
        <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
        <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
        <IS_LINKABLE>false</IS_LINKABLE>
        <IS_SQL_ENABLED>false</IS_SQL_ENABLED>
        <CUBE_CAPTION>Verkaufen</CUBE_CAPTION>
        <DESCRIPTION>Cube Verkaufen</DESCRIPTION>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>Sales 2</CUBE_NAME>
        <CUBE_TYPE>CUBE</CUBE_TYPE>
        <LAST_SCHEMA_UPDATE>2019-04-10T20:16:40</LAST_SCHEMA_UPDATE>
        <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
        <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
        <IS_LINKABLE>false</IS_LINKABLE>
        <IS_SQL_ENABLED>false</IS_SQL_ENABLED>
        <CUBE_CAPTION>Sales 2</CUBE_CAPTION>
        <DESCRIPTION>FoodMart Schema - Sales 2 Cube</DESCRIPTION>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>Sales Ragged</CUBE_NAME>
        <CUBE_TYPE>CUBE</CUBE_TYPE>
        <LAST_SCHEMA_UPDATE>2019-04-10T20:16:40</LAST_SCHEMA_UPDATE>
        <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
        <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
        <IS_LINKABLE>false</IS_LINKABLE>
        <IS_SQL_ENABLED>false</IS_SQL_ENABLED>
        <CUBE_CAPTION>Sales Ragged</CUBE_CAPTION>
        <DESCRIPTION>FoodMart Schema - Sales Ragged Cube</DESCRIPTION>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>Store</CUBE_NAME>
        <CUBE_TYPE>CUBE</CUBE_TYPE>
        <LAST_SCHEMA_UPDATE>2019-04-10T20:16:40</LAST_SCHEMA_UPDATE>
        <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
        <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
        <IS_LINKABLE>false</IS_LINKABLE>
        <IS_SQL_ENABLED>false</IS_SQL_ENABLED>
        <CUBE_CAPTION>Store</CUBE_CAPTION>
        <DESCRIPTION>FoodMart Schema - Store Cube</DESCRIPTION>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>Warehouse</CUBE_NAME>
        <CUBE_TYPE>CUBE</CUBE_TYPE>
        <LAST_SCHEMA_UPDATE>2019-04-10T20:16:40</LAST_SCHEMA_UPDATE>
        <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
        <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
        <IS_LINKABLE>false</IS_LINKABLE>
        <IS_SQL_ENABLED>false</IS_SQL_ENABLED>
        <CUBE_CAPTION>Warehouse</CUBE_CAPTION>
        <DESCRIPTION>FoodMart Schema - Warehouse Cube</DESCRIPTION>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>Warehouse and Sales</CUBE_NAME>
        <CUBE_TYPE>VIRTUAL CUBE</CUBE_TYPE>
        <LAST_SCHEMA_UPDATE>2019-04-10T20:16:40</LAST_SCHEMA_UPDATE>
        <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
        <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
        <IS_LINKABLE>false</IS_LINKABLE>
        <IS_SQL_ENABLED>false</IS_SQL_ENABLED>
        <CUBE_CAPTION>Warehouse and Sales</CUBE_CAPTION>
        <DESCRIPTION>FoodMart Schema - Warehouse and Sales Cube</DESCRIPTION>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_CUBES</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>HR</CUBE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>FoodMart</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="CUBE_TYPE" name="CUBE_TYPE" type="xsd:string"/>
            <xsd:element sql:field="CUBE_GUID" name="CUBE_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="CREATED_ON" name="CREATED_ON" type="xsd:dateTime" minOccurs="0"/>
            <xsd:element sql:field="LAST_SCHEMA_UPDATE" name="LAST_SCHEMA_UPDATE" type="xsd:dateTime" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_UPDATED_BY" name="SCHEMA_UPDATED_BY" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="LAST_DATA_UPDATE" name="LAST_DATA_UPDATE" type="xsd:dateTime" minOccurs="0"/>
            <xsd:element sql:field="DATA_UPDATED_BY" name="DATA_UPDATED_BY" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="IS_DRILLTHROUGH_ENABLED" name="IS_DRILLTHROUGH_ENABLED" type="xsd:boolean"/>
            <xsd:element sql:field="IS_WRITE_ENABLED" name="IS_WRITE_ENABLED" type="xsd:boolean"/>
            <xsd:element sql:field="IS_LINKABLE" name="IS_LINKABLE" type="xsd:boolean"/>
            <xsd:element sql:field="IS_SQL_ENABLED" name="IS_SQL_ENABLED" type="xsd:boolean"/>
            <xsd:element sql:field="CUBE_CAPTION" name="CUBE_CAPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DIMENSIONS" name="DIMENSIONS" minOccurs="0"/>
            <xsd:element sql:field="SETS" name="SETS" minOccurs="0"/>
            <xsd:element sql:field="MEASURES" name="MEASURES" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <CUBE_TYPE>CUBE</CUBE_TYPE>
        <LAST_SCHEMA_UPDATE>2019-04-10T20:16:40</LAST_SCHEMA_UPDATE>
        <IS_DRILLTHROUGH_ENABLED>true</IS_DRILLTHROUGH_ENABLED>
        <IS_WRITE_ENABLED>false</IS_WRITE_ENABLED>
        <IS_LINKABLE>false</IS_LINKABLE>
        <IS_SQL_ENABLED>false</IS_SQL_ENABLED>
        <CUBE_CAPTION>HR</CUBE_CAPTION>
        <DESCRIPTION>FoodMart Schema - HR Cube</DESCRIPTION>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetMDSchemaDimensions":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_DIMENSIONS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>HR</CUBE_NAME>
          <DIMENSION_NAME>Position</DIMENSION_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>FoodMart</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_NAME" name="DIMENSION_NAME" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_GUID" name="DIMENSION_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="DIMENSION_CAPTION" name="DIMENSION_CAPTION" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_ORDINAL" name="DIMENSION_ORDINAL" type="xsd:unsignedInt"/>
            <xsd:element sql:field="DIMENSION_TYPE" name="DIMENSION_TYPE" type="xsd:short"/>
            <xsd:element sql:field="DIMENSION_CARDINALITY" name="DIMENSION_CARDINALITY" type="xsd:unsignedInt"/>
            <xsd:element sql:field="DEFAULT_HIERARCHY" name="DEFAULT_HIERARCHY" type="xsd:string"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="IS_VIRTUAL" name="IS_VIRTUAL" type="xsd:boolean" minOccurs="0"/>
            <xsd:element sql:field="IS_READWRITE" name="IS_READWRITE" type="xsd:boolean" minOccurs="0"/>
            <xsd:element sql:field="DIMENSION_UNIQUE_SETTINGS" name="DIMENSION_UNIQUE_SETTINGS" type="xsd:int" minOccurs="0"/>
            <xsd:element sql:field="DIMENSION_MASTER_UNIQUE_NAME" name="DIMENSION_MASTER_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DIMENSION_IS_VISIBLE" name="DIMENSION_IS_VISIBLE" type="xsd:boolean" minOccurs="0"/>
            <xsd:element sql:field="HIERARCHIES" name="HIERARCHIES" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_NAME>Position</DIMENSION_NAME>
        <DIMENSION_UNIQUE_NAME>[Position]</DIMENSION_UNIQUE_NAME>
        <DIMENSION_CAPTION>Position</DIMENSION_CAPTION>
        <DIMENSION_ORDINAL>5</DIMENSION_ORDINAL>
        <DIMENSION_TYPE>3</DIMENSION_TYPE>
        <DIMENSION_CARDINALITY>19</DIMENSION_CARDINALITY>
        <DEFAULT_HIERARCHY>[Position]</DEFAULT_HIERARCHY>
        <DESCRIPTION>HR Cube - Position Dimension</DESCRIPTION>
        <IS_VIRTUAL>false</IS_VIRTUAL>
        <IS_READWRITE>false</IS_READWRITE>
        <DIMENSION_UNIQUE_SETTINGS>0</DIMENSION_UNIQUE_SETTINGS>
        <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetMDSchemaFunctions":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_FUNCTIONS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="FUNCTION_NAME" name="FUNCTION_NAME" type="xsd:string"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="PARAMETER_LIST" name="PARAMETER_LIST" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="RETURN_TYPE" name="RETURN_TYPE" type="xsd:int"/>
            <xsd:element sql:field="ORIGIN" name="ORIGIN" type="xsd:int"/>
            <xsd:element sql:field="INTERFACE_NAME" name="INTERFACE_NAME" type="xsd:string"/>
            <xsd:element sql:field="LIBRARY_NAME" name="LIBRARY_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CAPTION" name="CAPTION" type="xsd:string" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <FUNCTION_NAME>*</FUNCTION_NAME>
        <DESCRIPTION>Multiplies two numbers.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>*</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>*</FUNCTION_NAME>
        <DESCRIPTION>Returns the cross product of two sets.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>*</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>*</FUNCTION_NAME>
        <DESCRIPTION>Returns the cross product of two sets.</DESCRIPTION>
        <PARAMETER_LIST>Member, Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>*</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>*</FUNCTION_NAME>
        <DESCRIPTION>Returns the cross product of two sets.</DESCRIPTION>
        <PARAMETER_LIST>Set, Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>*</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>*</FUNCTION_NAME>
        <DESCRIPTION>Returns the cross product of two sets.</DESCRIPTION>
        <PARAMETER_LIST>Member, Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>*</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>+</FUNCTION_NAME>
        <DESCRIPTION>Adds two numbers.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>+</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>-</FUNCTION_NAME>
        <DESCRIPTION>Subtracts two numbers.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>-</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>-</FUNCTION_NAME>
        <DESCRIPTION>Returns the negative of a number.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>-</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>/</FUNCTION_NAME>
        <DESCRIPTION>Divides two numbers.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>/</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>:</FUNCTION_NAME>
        <DESCRIPTION>Infix colon operator returns the set of members between a given pair of members.</DESCRIPTION>
        <PARAMETER_LIST>Member, Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>:</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>&lt;</FUNCTION_NAME>
        <DESCRIPTION>Returns whether an expression is less than another.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>&lt;</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>&lt;</FUNCTION_NAME>
        <DESCRIPTION>Returns whether an expression is less than another.</DESCRIPTION>
        <PARAMETER_LIST>String, String</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>&lt;</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>&lt;=</FUNCTION_NAME>
        <DESCRIPTION>Returns whether an expression is less than or equal to another.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>&lt;=</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>&lt;=</FUNCTION_NAME>
        <DESCRIPTION>Returns whether an expression is less than or equal to another.</DESCRIPTION>
        <PARAMETER_LIST>String, String</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>&lt;=</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>&lt;&gt;</FUNCTION_NAME>
        <DESCRIPTION>Returns whether two expressions are not equal.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>&lt;&gt;</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>&lt;&gt;</FUNCTION_NAME>
        <DESCRIPTION>Returns whether two expressions are not equal.</DESCRIPTION>
        <PARAMETER_LIST>String, String</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>&lt;&gt;</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>=</FUNCTION_NAME>
        <DESCRIPTION>Returns whether two expressions are equal.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>=</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>=</FUNCTION_NAME>
        <DESCRIPTION>Returns whether two expressions are equal.</DESCRIPTION>
        <PARAMETER_LIST>String, String</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>=</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>&gt;</FUNCTION_NAME>
        <DESCRIPTION>Returns whether an expression is greater than another.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>&gt;</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>&gt;</FUNCTION_NAME>
        <DESCRIPTION>Returns whether an expression is greater than another.</DESCRIPTION>
        <PARAMETER_LIST>String, String</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>&gt;</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>&gt;=</FUNCTION_NAME>
        <DESCRIPTION>Returns whether an expression is greater than or equal to another.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>&gt;=</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>&gt;=</FUNCTION_NAME>
        <DESCRIPTION>Returns whether an expression is greater than or equal to another.</DESCRIPTION>
        <PARAMETER_LIST>String, String</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>&gt;=</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>_CaseMatch</FUNCTION_NAME>
        <DESCRIPTION>Evaluates various expressions, and returns the corresponding expression for the first which matches a particular value.</DESCRIPTION>
        <PARAMETER_LIST>(none)</PARAMETER_LIST>
        <RETURN_TYPE>1</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>_CaseMatch</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>_CaseTest</FUNCTION_NAME>
        <DESCRIPTION>Evaluates various conditions, and returns the corresponding expression for the first which evaluates to true.</DESCRIPTION>
        <PARAMETER_LIST>(none)</PARAMETER_LIST>
        <RETURN_TYPE>1</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>_CaseTest</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Abs</FUNCTION_NAME>
        <DESCRIPTION>Returns a value of the same type that is passed to it specifying the absolute value of a number.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Abs</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Acos</FUNCTION_NAME>
        <DESCRIPTION>Returns the arccosine, or inverse cosine, of a number. The arccosine is the angle whose cosine is Arg1. The returned angle is given in radians in the range 0 (zero) to pi.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Acos</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Acosh</FUNCTION_NAME>
        <DESCRIPTION>Returns the inverse hyperbolic cosine of a number. Number must be greater than or equal to 1. The inverse hyperbolic cosine is the value whose hyperbolic cosine is Arg1, so Acosh(Cosh(number)) equals Arg1.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Acosh</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>AddCalculatedMembers</FUNCTION_NAME>
        <DESCRIPTION>Adds calculated members to a set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>AddCalculatedMembers</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Aggregate</FUNCTION_NAME>
        <DESCRIPTION>Returns a calculated value using the appropriate aggregate function, based on the context of the query.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Aggregate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Aggregate</FUNCTION_NAME>
        <DESCRIPTION>Returns a calculated value using the appropriate aggregate function, based on the context of the query.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Aggregate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>AllMembers</FUNCTION_NAME>
        <DESCRIPTION>Returns a set that contains all members, including calculated members, of the specified hierarchy.</DESCRIPTION>
        <PARAMETER_LIST>Hierarchy</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>AllMembers</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>AllMembers</FUNCTION_NAME>
        <DESCRIPTION>Returns a set that contains all members, including calculated members, of the specified level.</DESCRIPTION>
        <PARAMETER_LIST>Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>AllMembers</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Ancestor</FUNCTION_NAME>
        <DESCRIPTION>Returns the ancestor of a member at a specified level.</DESCRIPTION>
        <PARAMETER_LIST>Member, Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Ancestor</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Ancestor</FUNCTION_NAME>
        <DESCRIPTION>Returns the ancestor of a member at a specified level.</DESCRIPTION>
        <PARAMETER_LIST>Member, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Ancestor</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Ancestors</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of all ancestors of a specified member at a specified level or at a specified distance from the member</DESCRIPTION>
        <PARAMETER_LIST>Member, Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Ancestors</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Ancestors</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of all ancestors of a specified member at a specified level or at a specified distance from the member</DESCRIPTION>
        <PARAMETER_LIST>Member, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Ancestors</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>AND</FUNCTION_NAME>
        <DESCRIPTION>Returns the conjunction of two conditions.</DESCRIPTION>
        <PARAMETER_LIST>Logical Expression, Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>AND</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>AS</FUNCTION_NAME>
        <PARAMETER_LIST>(none)</PARAMETER_LIST>
        <RETURN_TYPE>1</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>AS</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Asc</FUNCTION_NAME>
        <DESCRIPTION>Returns an Integer representing the character code corresponding to the first letter in a string.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Asc</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>AscB</FUNCTION_NAME>
        <DESCRIPTION>See Asc.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>AscB</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Ascendants</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of the ascendants of a specified member.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Ascendants</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>AscW</FUNCTION_NAME>
        <DESCRIPTION>See Asc.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>AscW</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Asin</FUNCTION_NAME>
        <DESCRIPTION>Returns the arcsine, or inverse sine, of a number. The arcsine is the angle whose sine is Arg1. The returned angle is given in radians in the range -pi/2 to pi/2.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Asin</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Asinh</FUNCTION_NAME>
        <DESCRIPTION>Returns the inverse hyperbolic sine of a number. The inverse hyperbolic sine is the value whose hyperbolic sine is Arg1, so Asinh(Sinh(number)) equals Arg1.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Asinh</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Atan2</FUNCTION_NAME>
        <DESCRIPTION>Returns the arctangent, or inverse tangent, of the specified x- and y-coordinates. The arctangent is the angle from the x-axis to a line containing the origin (0, 0) and a point with coordinates (x_num, y_num). The angle is given in radians between -pi and pi, excluding -pi.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Atan2</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Atanh</FUNCTION_NAME>
        <DESCRIPTION>Returns the inverse hyperbolic tangent of a number. Number must be between -1 and 1 (excluding -1 and 1).</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Atanh</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Atn</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the arctangent of a number.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Atn</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Avg</FUNCTION_NAME>
        <DESCRIPTION>Returns the average value of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Avg</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Avg</FUNCTION_NAME>
        <DESCRIPTION>Returns the average value of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Avg</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>BottomCount</FUNCTION_NAME>
        <DESCRIPTION>Returns a specified number of items from the bottom of a set, optionally ordering the set first.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>BottomCount</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>BottomCount</FUNCTION_NAME>
        <DESCRIPTION>Returns a specified number of items from the bottom of a set, optionally ordering the set first.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>BottomCount</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>BottomPercent</FUNCTION_NAME>
        <DESCRIPTION>Sorts a set and returns the bottom N elements whose cumulative total is at least a specified percentage.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>BottomPercent</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>BottomSum</FUNCTION_NAME>
        <DESCRIPTION>Sorts a set and returns the bottom N elements whose cumulative total is at least a specified value.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>BottomSum</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Cache</FUNCTION_NAME>
        <DESCRIPTION>Evaluates and returns its sole argument, applying statement-level caching</DESCRIPTION>
        <PARAMETER_LIST>(none)</PARAMETER_LIST>
        <RETURN_TYPE>1</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Cache</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CalculatedChild</FUNCTION_NAME>
        <DESCRIPTION>Returns an existing calculated child member with name &lt;String&gt; from the specified &lt;Member&gt;.</DESCRIPTION>
        <PARAMETER_LIST>Member, String</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CalculatedChild</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Caption</FUNCTION_NAME>
        <DESCRIPTION>Returns the caption of a dimension.</DESCRIPTION>
        <PARAMETER_LIST>Dimension</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Caption</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Caption</FUNCTION_NAME>
        <DESCRIPTION>Returns the caption of a hierarchy.</DESCRIPTION>
        <PARAMETER_LIST>Hierarchy</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Caption</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Caption</FUNCTION_NAME>
        <DESCRIPTION>Returns the caption of a level.</DESCRIPTION>
        <PARAMETER_LIST>Level</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Caption</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Caption</FUNCTION_NAME>
        <DESCRIPTION>Returns the caption of a member.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Caption</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Cast</FUNCTION_NAME>
        <DESCRIPTION>Converts values to another type.</DESCRIPTION>
        <PARAMETER_LIST>(none)</PARAMETER_LIST>
        <RETURN_TYPE>1</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Cast</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CBool</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression that has been converted to a Variant of subtype Boolean.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CBool</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CByte</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression that has been converted to a Variant of subtype Byte.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CByte</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CDate</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression that has been converted to a Variant of subtype Date.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>7</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CDate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CDbl</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression that has been converted to a Variant of subtype Double.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CDbl</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Children</FUNCTION_NAME>
        <DESCRIPTION>Returns the children of a member.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Children</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Chr</FUNCTION_NAME>
        <DESCRIPTION>Returns a String containing the character associated with the specified character code.</DESCRIPTION>
        <PARAMETER_LIST>Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Chr</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ChrB</FUNCTION_NAME>
        <DESCRIPTION>See Chr.</DESCRIPTION>
        <PARAMETER_LIST>Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ChrB</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ChrW</FUNCTION_NAME>
        <DESCRIPTION>See Chr.</DESCRIPTION>
        <PARAMETER_LIST>Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ChrW</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CInt</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression that has been converted to a Variant of subtype Integer.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CInt</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ClosingPeriod</FUNCTION_NAME>
        <DESCRIPTION>Returns the last descendant of a member at a level.</DESCRIPTION>
        <PARAMETER_LIST/>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ClosingPeriod</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ClosingPeriod</FUNCTION_NAME>
        <DESCRIPTION>Returns the last descendant of a member at a level.</DESCRIPTION>
        <PARAMETER_LIST>Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ClosingPeriod</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ClosingPeriod</FUNCTION_NAME>
        <DESCRIPTION>Returns the last descendant of a member at a level.</DESCRIPTION>
        <PARAMETER_LIST>Level, Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ClosingPeriod</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ClosingPeriod</FUNCTION_NAME>
        <DESCRIPTION>Returns the last descendant of a member at a level.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ClosingPeriod</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CoalesceEmpty</FUNCTION_NAME>
        <DESCRIPTION>Coalesces an empty cell value to a different value. All of the expressions must be of the same type (number or string).</DESCRIPTION>
        <PARAMETER_LIST>(none)</PARAMETER_LIST>
        <RETURN_TYPE>1</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CoalesceEmpty</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Correlation</FUNCTION_NAME>
        <DESCRIPTION>Returns the correlation of two series evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Correlation</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Correlation</FUNCTION_NAME>
        <DESCRIPTION>Returns the correlation of two series evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Correlation</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Cos</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the cosine of an angle.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Cos</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Cosh</FUNCTION_NAME>
        <DESCRIPTION>Returns the hyperbolic cosine of a number.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Cosh</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Count</FUNCTION_NAME>
        <DESCRIPTION>Returns the number of tuples in a set, empty cells included unless the optional EXCLUDEEMPTY flag is used.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Count</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Count</FUNCTION_NAME>
        <DESCRIPTION>Returns the number of tuples in a set, empty cells included unless the optional EXCLUDEEMPTY flag is used.</DESCRIPTION>
        <PARAMETER_LIST>Set, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Count</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Count</FUNCTION_NAME>
        <DESCRIPTION>Returns the number of tuples in a set including empty cells.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Count</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Cousin</FUNCTION_NAME>
        <DESCRIPTION>Returns the member with the same relative position under &lt;ancestor member&gt; as the member specified.</DESCRIPTION>
        <PARAMETER_LIST>Member, Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Cousin</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Covariance</FUNCTION_NAME>
        <DESCRIPTION>Returns the covariance of two series evaluated over a set (biased).</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Covariance</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Covariance</FUNCTION_NAME>
        <DESCRIPTION>Returns the covariance of two series evaluated over a set (biased).</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Covariance</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CovarianceN</FUNCTION_NAME>
        <DESCRIPTION>Returns the covariance of two series evaluated over a set (unbiased).</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CovarianceN</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CovarianceN</FUNCTION_NAME>
        <DESCRIPTION>Returns the covariance of two series evaluated over a set (unbiased).</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CovarianceN</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Crossjoin</FUNCTION_NAME>
        <DESCRIPTION>Returns the cross product of two sets.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Crossjoin</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Current</FUNCTION_NAME>
        <DESCRIPTION>Returns the current member or tuple of a named set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Current</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CurrentDateMember</FUNCTION_NAME>
        <PARAMETER_LIST>Hierarchy, String, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CurrentDateMember</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CurrentDateMember</FUNCTION_NAME>
        <PARAMETER_LIST>Hierarchy, String</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CurrentDateMember</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CurrentDateString</FUNCTION_NAME>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CurrentDateString</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CurrentMember</FUNCTION_NAME>
        <DESCRIPTION>Returns the current member along a hierarchy during an iteration.</DESCRIPTION>
        <PARAMETER_LIST>Hierarchy</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CurrentMember</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>CurrentOrdinal</FUNCTION_NAME>
        <DESCRIPTION>Returns the ordinal of the current iteration through a named set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>CurrentOrdinal</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DataMember</FUNCTION_NAME>
        <DESCRIPTION>Returns the system-generated data member that is associated with a nonleaf member of a dimension.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DataMember</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Date</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Date) containing the current system date.</DESCRIPTION>
        <PARAMETER_LIST/>
        <RETURN_TYPE>7</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Date</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DateAdd</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Date) containing a date to which a specified time interval has been added.</DESCRIPTION>
        <PARAMETER_LIST>String, Numeric Expression, DateTime</PARAMETER_LIST>
        <RETURN_TYPE>7</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DateAdd</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DateDiff</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Long) specifying the number of time intervals between two specified dates.</DESCRIPTION>
        <PARAMETER_LIST>String, DateTime, DateTime, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DateDiff</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DateDiff</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Long) specifying the number of time intervals between two specified dates.</DESCRIPTION>
        <PARAMETER_LIST>String, DateTime, DateTime, Integer</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DateDiff</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DateDiff</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Long) specifying the number of time intervals between two specified dates.</DESCRIPTION>
        <PARAMETER_LIST>String, DateTime, DateTime</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DateDiff</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DatePart</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) containing the specified part of a given date.</DESCRIPTION>
        <PARAMETER_LIST>String, DateTime, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DatePart</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DatePart</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) containing the specified part of a given date.</DESCRIPTION>
        <PARAMETER_LIST>String, DateTime, Integer</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DatePart</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DatePart</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) containing the specified part of a given date.</DESCRIPTION>
        <PARAMETER_LIST>String, DateTime</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DatePart</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DateSerial</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Date) for a specified year, month, and day.</DESCRIPTION>
        <PARAMETER_LIST>Integer, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>7</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DateSerial</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DateValue</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Date).</DESCRIPTION>
        <PARAMETER_LIST>DateTime</PARAMETER_LIST>
        <RETURN_TYPE>7</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DateValue</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Day</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) specifying a whole number between 1 and 31, inclusive, representing the day of the month.</DESCRIPTION>
        <PARAMETER_LIST>DateTime</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Day</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DDB</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the depreciation of an asset for a specific time period using the double-declining balance method or some other method you specify.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DDB</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DDB</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the depreciation of an asset for a specific time period using the double-declining balance method or some other method you specify.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DDB</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DefaultMember</FUNCTION_NAME>
        <DESCRIPTION>Returns the default member of a hierarchy.</DESCRIPTION>
        <PARAMETER_LIST>Hierarchy</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DefaultMember</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Degrees</FUNCTION_NAME>
        <DESCRIPTION>Converts radians to degrees.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Degrees</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Descendants</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of descendants of a member at a specified level, optionally including or excluding descendants in other levels.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Descendants</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Descendants</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of descendants of a member at a specified level, optionally including or excluding descendants in other levels.</DESCRIPTION>
        <PARAMETER_LIST>Member, Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Descendants</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Descendants</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of descendants of a member at a specified level, optionally including or excluding descendants in other levels.</DESCRIPTION>
        <PARAMETER_LIST>Member, Level, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Descendants</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Descendants</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of descendants of a member at a specified level, optionally including or excluding descendants in other levels.</DESCRIPTION>
        <PARAMETER_LIST>Member, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Descendants</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Descendants</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of descendants of a member at a specified level, optionally including or excluding descendants in other levels.</DESCRIPTION>
        <PARAMETER_LIST>Member, Numeric Expression, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Descendants</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Descendants</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of descendants of a member at a specified level, optionally including or excluding descendants in other levels.</DESCRIPTION>
        <PARAMETER_LIST>Member, Empty, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Descendants</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Descendants</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of descendants of a set of members at a specified level, optionally including or excluding descendants in other levels.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Descendants</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Descendants</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of descendants of a set of members at a specified level, optionally including or excluding descendants in other levels.</DESCRIPTION>
        <PARAMETER_LIST>Set, Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Descendants</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Descendants</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of descendants of a set of members at a specified level, optionally including or excluding descendants in other levels.</DESCRIPTION>
        <PARAMETER_LIST>Set, Level, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Descendants</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Descendants</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of descendants of a set of members at a specified level, optionally including or excluding descendants in other levels.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Descendants</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Descendants</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of descendants of a set of members at a specified level, optionally including or excluding descendants in other levels.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Descendants</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Descendants</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of descendants of a set of members at a specified level, optionally including or excluding descendants in other levels.</DESCRIPTION>
        <PARAMETER_LIST>Set, Empty, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Descendants</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Dimension</FUNCTION_NAME>
        <DESCRIPTION>Returns the dimension that contains a specified hierarchy.</DESCRIPTION>
        <PARAMETER_LIST>Dimension</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Dimension</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Dimension</FUNCTION_NAME>
        <DESCRIPTION>Returns the dimension that contains a specified hierarchy.</DESCRIPTION>
        <PARAMETER_LIST>Hierarchy</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Dimension</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Dimension</FUNCTION_NAME>
        <DESCRIPTION>Returns the dimension that contains a specified level.</DESCRIPTION>
        <PARAMETER_LIST>Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Dimension</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Dimension</FUNCTION_NAME>
        <DESCRIPTION>Returns the dimension that contains a specified member.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Dimension</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Dimensions</FUNCTION_NAME>
        <DESCRIPTION>Returns the hierarchy whose zero-based position within the cube is specified by a numeric expression.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Dimensions</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Dimensions</FUNCTION_NAME>
        <DESCRIPTION>Returns the hierarchy whose name is specified by a string.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Dimensions</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Distinct</FUNCTION_NAME>
        <DESCRIPTION>Eliminates duplicate tuples from a set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Distinct</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DrilldownLevel</FUNCTION_NAME>
        <DESCRIPTION>Drills down the members of a set, at a specified level, to one level below. Alternatively, drills down on a specified dimension in the set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DrilldownLevel</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DrilldownLevel</FUNCTION_NAME>
        <DESCRIPTION>Drills down the members of a set, at a specified level, to one level below. Alternatively, drills down on a specified dimension in the set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DrilldownLevel</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DrilldownLevel</FUNCTION_NAME>
        <DESCRIPTION>Drills down the members of a set, at a specified level, to one level below. Alternatively, drills down on a specified dimension in the set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Empty, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DrilldownLevel</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DrilldownLevelBottom</FUNCTION_NAME>
        <DESCRIPTION>Drills down the bottommost members of a set, at a specified level, to one level below.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DrilldownLevelBottom</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DrilldownLevelBottom</FUNCTION_NAME>
        <DESCRIPTION>Drills down the bottommost members of a set, at a specified level, to one level below.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DrilldownLevelBottom</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DrilldownLevelBottom</FUNCTION_NAME>
        <DESCRIPTION>Drills down the bottommost members of a set, at a specified level, to one level below.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Level, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DrilldownLevelBottom</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DrilldownLevelBottom</FUNCTION_NAME>
        <DESCRIPTION>Drills down the bottommost members of a set, at a specified level, to one level below.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Empty, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DrilldownLevelBottom</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DrilldownLevelTop</FUNCTION_NAME>
        <DESCRIPTION>Drills down the topmost members of a set, at a specified level, to one level below.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DrilldownLevelTop</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DrilldownLevelTop</FUNCTION_NAME>
        <DESCRIPTION>Drills down the topmost members of a set, at a specified level, to one level below.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DrilldownLevelTop</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DrilldownLevelTop</FUNCTION_NAME>
        <DESCRIPTION>Drills down the topmost members of a set, at a specified level, to one level below.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Level, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DrilldownLevelTop</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DrilldownLevelTop</FUNCTION_NAME>
        <DESCRIPTION>Drills down the topmost members of a set, at a specified level, to one level below.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Empty, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DrilldownLevelTop</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DrilldownMember</FUNCTION_NAME>
        <DESCRIPTION>Drills down the members in a set that are present in a second specified set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DrilldownMember</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>DrilldownMember</FUNCTION_NAME>
        <DESCRIPTION>Drills down the members in a set that are present in a second specified set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>DrilldownMember</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Except</FUNCTION_NAME>
        <DESCRIPTION>Finds the difference between two sets, optionally retaining duplicates.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Except</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Except</FUNCTION_NAME>
        <DESCRIPTION>Finds the difference between two sets, optionally retaining duplicates.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Except</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Existing</FUNCTION_NAME>
        <DESCRIPTION>Forces the set to be evaluated within the current context.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Existing</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Exists</FUNCTION_NAME>
        <DESCRIPTION>Returns the the set of tuples of the first set that exist with one or more tuples of the second set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Exists</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Exp</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying e (the base of natural logarithms) raised to a power.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Exp</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Extract</FUNCTION_NAME>
        <DESCRIPTION>Returns a set of tuples from extracted hierarchy elements. The opposite of Crossjoin.</DESCRIPTION>
        <PARAMETER_LIST>(none)</PARAMETER_LIST>
        <RETURN_TYPE>1</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Extract</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Filter</FUNCTION_NAME>
        <DESCRIPTION>Returns the set resulting from filtering a set based on a search condition.</DESCRIPTION>
        <PARAMETER_LIST>Set, Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Filter</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FirstChild</FUNCTION_NAME>
        <DESCRIPTION>Returns the first child of a member.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FirstChild</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FirstQ</FUNCTION_NAME>
        <DESCRIPTION>Returns the 1st quartile value of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FirstQ</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FirstQ</FUNCTION_NAME>
        <DESCRIPTION>Returns the 1st quartile value of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FirstQ</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FirstSibling</FUNCTION_NAME>
        <DESCRIPTION>Returns the first child of the parent of a member.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FirstSibling</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Fix</FUNCTION_NAME>
        <DESCRIPTION>Returns the integer portion of a number. If negative, returns the negative number greater than or equal to the number.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Fix</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Format</FUNCTION_NAME>
        <DESCRIPTION>Formats a number or date to a string.</DESCRIPTION>
        <PARAMETER_LIST>Member, String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Format</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Format</FUNCTION_NAME>
        <DESCRIPTION>Formats a number or date to a string.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Format</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Format</FUNCTION_NAME>
        <DESCRIPTION>Formats a number or date to a string.</DESCRIPTION>
        <PARAMETER_LIST>DateTime, String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Format</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatCurrency</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a currency value using the currency symbol defined in the system control panel.</DESCRIPTION>
        <PARAMETER_LIST>Value, Integer, Integer, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatCurrency</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatCurrency</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a currency value using the currency symbol defined in the system control panel.</DESCRIPTION>
        <PARAMETER_LIST>Value, Integer, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatCurrency</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatCurrency</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a currency value using the currency symbol defined in the system control panel.</DESCRIPTION>
        <PARAMETER_LIST>Value, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatCurrency</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatCurrency</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a currency value using the currency symbol defined in the system control panel.</DESCRIPTION>
        <PARAMETER_LIST>Value, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatCurrency</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatCurrency</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a currency value using the currency symbol defined in the system control panel.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatCurrency</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatDateTime</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a date or time.</DESCRIPTION>
        <PARAMETER_LIST>DateTime, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatDateTime</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatDateTime</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a date or time.</DESCRIPTION>
        <PARAMETER_LIST>DateTime</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatDateTime</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatNumber</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a number.</DESCRIPTION>
        <PARAMETER_LIST>Value, Integer, Integer, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatNumber</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatNumber</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a number.</DESCRIPTION>
        <PARAMETER_LIST>Value, Integer, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatNumber</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatNumber</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a number.</DESCRIPTION>
        <PARAMETER_LIST>Value, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatNumber</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatNumber</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a number.</DESCRIPTION>
        <PARAMETER_LIST>Value, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatNumber</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatNumber</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a number.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatNumber</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatPercent</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a percentage (multipled by 100) with a trailing % character.</DESCRIPTION>
        <PARAMETER_LIST>Value, Integer, Integer, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatPercent</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatPercent</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a percentage (multipled by 100) with a trailing % character.</DESCRIPTION>
        <PARAMETER_LIST>Value, Integer, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatPercent</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatPercent</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a percentage (multipled by 100) with a trailing % character.</DESCRIPTION>
        <PARAMETER_LIST>Value, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatPercent</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatPercent</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a percentage (multipled by 100) with a trailing % character.</DESCRIPTION>
        <PARAMETER_LIST>Value, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatPercent</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FormatPercent</FUNCTION_NAME>
        <DESCRIPTION>Returns an expression formatted as a percentage (multipled by 100) with a trailing % character.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FormatPercent</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FV</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the future value of an annuity based on periodic, fixed payments and a fixed interest rate.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression, Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FV</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FV</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the future value of an annuity based on periodic, fixed payments and a fixed interest rate.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FV</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>FV</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the future value of an annuity based on periodic, fixed payments and a fixed interest rate.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>FV</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Generate</FUNCTION_NAME>
        <DESCRIPTION>Applies a set to each member of another set and joins the resulting sets by union.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Generate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Generate</FUNCTION_NAME>
        <DESCRIPTION>Applies a set to each member of another set and joins the resulting sets by union.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Generate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Generate</FUNCTION_NAME>
        <DESCRIPTION>Applies a set to a string expression and joins resulting sets by string concatenation.</DESCRIPTION>
        <PARAMETER_LIST>Set, String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Generate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Generate</FUNCTION_NAME>
        <DESCRIPTION>Applies a set to a string expression and joins resulting sets by string concatenation.</DESCRIPTION>
        <PARAMETER_LIST>Set, String, String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Generate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Head</FUNCTION_NAME>
        <DESCRIPTION>Returns the first specified number of elements in a set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Head</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Head</FUNCTION_NAME>
        <DESCRIPTION>Returns the first specified number of elements in a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Head</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Hex</FUNCTION_NAME>
        <DESCRIPTION>Returns a String representing the hexadecimal value of a number.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Hex</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Hierarchize</FUNCTION_NAME>
        <DESCRIPTION>Orders the members of a set in a hierarchy.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Hierarchize</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Hierarchize</FUNCTION_NAME>
        <DESCRIPTION>Orders the members of a set in a hierarchy.</DESCRIPTION>
        <PARAMETER_LIST>Set, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Hierarchize</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Hierarchy</FUNCTION_NAME>
        <DESCRIPTION>Returns a level's hierarchy.</DESCRIPTION>
        <PARAMETER_LIST>Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Hierarchy</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Hierarchy</FUNCTION_NAME>
        <DESCRIPTION>Returns a member's hierarchy.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Hierarchy</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Hour</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) specifying a whole number between 0 and 23, inclusive, representing the hour of the day.</DESCRIPTION>
        <PARAMETER_LIST>DateTime</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Hour</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IIf</FUNCTION_NAME>
        <DESCRIPTION>Returns one of two tuples determined by a logical test.</DESCRIPTION>
        <PARAMETER_LIST>Logical Expression, Tuple, Tuple</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IIf</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IIf</FUNCTION_NAME>
        <DESCRIPTION>Returns one of two dimension values determined by a logical test.</DESCRIPTION>
        <PARAMETER_LIST>Logical Expression, Dimension, Dimension</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IIf</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IIf</FUNCTION_NAME>
        <DESCRIPTION>Returns one of two hierarchy values determined by a logical test.</DESCRIPTION>
        <PARAMETER_LIST>Logical Expression, Hierarchy, Hierarchy</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IIf</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IIf</FUNCTION_NAME>
        <DESCRIPTION>Returns one of two level values determined by a logical test.</DESCRIPTION>
        <PARAMETER_LIST>Logical Expression, Level, Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IIf</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IIf</FUNCTION_NAME>
        <DESCRIPTION>Returns boolean determined by a logical test.</DESCRIPTION>
        <PARAMETER_LIST>Logical Expression, Logical Expression, Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IIf</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IIf</FUNCTION_NAME>
        <DESCRIPTION>Returns one of two member values determined by a logical test.</DESCRIPTION>
        <PARAMETER_LIST>Logical Expression, Member, Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IIf</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IIf</FUNCTION_NAME>
        <DESCRIPTION>Returns one of two numeric values determined by a logical test.</DESCRIPTION>
        <PARAMETER_LIST>Logical Expression, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IIf</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IIf</FUNCTION_NAME>
        <DESCRIPTION>Returns one of two set values determined by a logical test.</DESCRIPTION>
        <PARAMETER_LIST>Logical Expression, Set, Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IIf</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IIf</FUNCTION_NAME>
        <DESCRIPTION>Returns one of two string values determined by a logical test.</DESCRIPTION>
        <PARAMETER_LIST>Logical Expression, String, String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IIf</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IN</FUNCTION_NAME>
        <PARAMETER_LIST>Member, Set</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IN</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>InStr</FUNCTION_NAME>
        <DESCRIPTION>Returns the position of an occurrence of one string within another.</DESCRIPTION>
        <PARAMETER_LIST>Integer, String, String, Integer</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>InStr</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>InStr</FUNCTION_NAME>
        <DESCRIPTION>Returns the position of an occurrence of one string within another.</DESCRIPTION>
        <PARAMETER_LIST>Integer, String, String</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>InStr</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>InStr</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Long) specifying the position of the first occurrence of one string within another.</DESCRIPTION>
        <PARAMETER_LIST>String, String</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>InStr</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>InStrRev</FUNCTION_NAME>
        <DESCRIPTION>Returns the position of an occurrence of one string within another, from the end of string.</DESCRIPTION>
        <PARAMETER_LIST>String, String, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>InStrRev</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>InStrRev</FUNCTION_NAME>
        <DESCRIPTION>Returns the position of an occurrence of one string within another, from the end of string.</DESCRIPTION>
        <PARAMETER_LIST>String, String, Integer</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>InStrRev</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>InStrRev</FUNCTION_NAME>
        <DESCRIPTION>Returns the position of an occurrence of one string within another, from the end of string.</DESCRIPTION>
        <PARAMETER_LIST>String, String</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>InStrRev</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Int</FUNCTION_NAME>
        <DESCRIPTION>Returns the integer portion of a number. If negative, returns the negative number less than or equal to the number.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Int</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Intersect</FUNCTION_NAME>
        <DESCRIPTION>Returns the intersection of two input sets, optionally retaining duplicates.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Intersect</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Intersect</FUNCTION_NAME>
        <DESCRIPTION>Returns the intersection of two input sets, optionally retaining duplicates.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Intersect</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>InverseNormal</FUNCTION_NAME>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>InverseNormal</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IPmt</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the interest payment for a given period of an annuity based on periodic, fixed payments and a fixed interest rate.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression, Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IPmt</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IPmt</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the interest payment for a given period of an annuity based on periodic, fixed payments and a fixed interest rate.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IPmt</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IPmt</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the interest payment for a given period of an annuity based on periodic, fixed payments and a fixed interest rate.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IPmt</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IRR</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the internal rate of return for a series of periodic cash flows (payments and receipts).</DESCRIPTION>
        <PARAMETER_LIST>Array, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IRR</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IRR</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the internal rate of return for a series of periodic cash flows (payments and receipts).</DESCRIPTION>
        <PARAMETER_LIST>Array</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IRR</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IS</FUNCTION_NAME>
        <DESCRIPTION>Returns whether two objects are the same</DESCRIPTION>
        <PARAMETER_LIST>Member, Member</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IS</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IS</FUNCTION_NAME>
        <DESCRIPTION>Returns whether two objects are the same</DESCRIPTION>
        <PARAMETER_LIST>Level, Level</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IS</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IS</FUNCTION_NAME>
        <DESCRIPTION>Returns whether two objects are the same</DESCRIPTION>
        <PARAMETER_LIST>Hierarchy, Hierarchy</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IS</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IS</FUNCTION_NAME>
        <DESCRIPTION>Returns whether two objects are the same</DESCRIPTION>
        <PARAMETER_LIST>Dimension, Dimension</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IS</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IS</FUNCTION_NAME>
        <DESCRIPTION>Returns whether two objects are the same</DESCRIPTION>
        <PARAMETER_LIST>Tuple, Tuple</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IS</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IS EMPTY</FUNCTION_NAME>
        <DESCRIPTION>Determines if an expression evaluates to the empty cell value.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IS EMPTY</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IS EMPTY</FUNCTION_NAME>
        <DESCRIPTION>Determines if an expression evaluates to the empty cell value.</DESCRIPTION>
        <PARAMETER_LIST>Tuple</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IS EMPTY</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IS NULL</FUNCTION_NAME>
        <DESCRIPTION>Returns whether an object is null</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IS NULL</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IS NULL</FUNCTION_NAME>
        <DESCRIPTION>Returns whether an object is null</DESCRIPTION>
        <PARAMETER_LIST>Level</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IS NULL</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IS NULL</FUNCTION_NAME>
        <DESCRIPTION>Returns whether an object is null</DESCRIPTION>
        <PARAMETER_LIST>Hierarchy</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IS NULL</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IS NULL</FUNCTION_NAME>
        <DESCRIPTION>Returns whether an object is null</DESCRIPTION>
        <PARAMETER_LIST>Dimension</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IS NULL</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IsDate</FUNCTION_NAME>
        <DESCRIPTION>Returns a Boolean value indicating whether an expression can be converted to a date.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IsDate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IsEmpty</FUNCTION_NAME>
        <DESCRIPTION>Determines if an expression evaluates to the empty cell value.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IsEmpty</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>IsEmpty</FUNCTION_NAME>
        <DESCRIPTION>Determines if an expression evaluates to the empty cell value.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>IsEmpty</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Item</FUNCTION_NAME>
        <DESCRIPTION>Returns a member from the tuple specified in &lt;Tuple&gt;. The member to be returned is specified by the zero-based position of the member in the set in &lt;Index&gt;.</DESCRIPTION>
        <PARAMETER_LIST>Tuple, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Item</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Item</FUNCTION_NAME>
        <DESCRIPTION>Returns a tuple from the set specified in &lt;Set&gt;. The tuple to be returned is specified by the zero-based position of the tuple in the set in &lt;Index&gt;.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Item</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Item</FUNCTION_NAME>
        <DESCRIPTION>Returns a tuple from the set specified in &lt;Set&gt;. The tuple to be returned is specified by the member name (or names) in &lt;String&gt;.</DESCRIPTION>
        <PARAMETER_LIST>(none)</PARAMETER_LIST>
        <RETURN_TYPE>1</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Item</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Lag</FUNCTION_NAME>
        <DESCRIPTION>Returns a member further along the specified member's dimension.</DESCRIPTION>
        <PARAMETER_LIST>Member, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Lag</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LastChild</FUNCTION_NAME>
        <DESCRIPTION>Returns the last child of a member.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LastChild</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LastNonEmpty</FUNCTION_NAME>
        <PARAMETER_LIST>Set, Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LastNonEmpty</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LastPeriods</FUNCTION_NAME>
        <DESCRIPTION>Returns a set of members prior to and including a specified member.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LastPeriods</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LastPeriods</FUNCTION_NAME>
        <DESCRIPTION>Returns a set of members prior to and including a specified member.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LastPeriods</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LastSibling</FUNCTION_NAME>
        <DESCRIPTION>Returns the last child of the parent of a member.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LastSibling</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LCase</FUNCTION_NAME>
        <DESCRIPTION>Returns a String that has been converted to lowercase.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LCase</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Lead</FUNCTION_NAME>
        <DESCRIPTION>Returns a member further along the specified member's dimension.</DESCRIPTION>
        <PARAMETER_LIST>Member, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Lead</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Left</FUNCTION_NAME>
        <DESCRIPTION>Returns a specified number of characters from the left side of a string.</DESCRIPTION>
        <PARAMETER_LIST>String, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Left</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Len</FUNCTION_NAME>
        <DESCRIPTION>Returns the number of characters in a string</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Len</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Level</FUNCTION_NAME>
        <DESCRIPTION>Returns a member's level.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Level</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Levels</FUNCTION_NAME>
        <DESCRIPTION>Returns the level whose position in a hierarchy is specified by a numeric expression.</DESCRIPTION>
        <PARAMETER_LIST>Hierarchy, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Levels</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Levels</FUNCTION_NAME>
        <DESCRIPTION>Returns the level whose name is specified by a string expression.</DESCRIPTION>
        <PARAMETER_LIST>Hierarchy, String</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Levels</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Levels</FUNCTION_NAME>
        <DESCRIPTION>Returns the level whose name is specified by a string expression.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Levels</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LinRegIntercept</FUNCTION_NAME>
        <DESCRIPTION>Calculates the linear regression of a set and returns the value of b in the regression line y = ax + b.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LinRegIntercept</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LinRegIntercept</FUNCTION_NAME>
        <DESCRIPTION>Calculates the linear regression of a set and returns the value of b in the regression line y = ax + b.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LinRegIntercept</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LinRegPoint</FUNCTION_NAME>
        <DESCRIPTION>Calculates the linear regression of a set and returns the value of y in the regression line y = ax + b.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LinRegPoint</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LinRegPoint</FUNCTION_NAME>
        <DESCRIPTION>Calculates the linear regression of a set and returns the value of y in the regression line y = ax + b.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LinRegPoint</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LinRegR2</FUNCTION_NAME>
        <DESCRIPTION>Calculates the linear regression of a set and returns R2 (the coefficient of determination).</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LinRegR2</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LinRegR2</FUNCTION_NAME>
        <DESCRIPTION>Calculates the linear regression of a set and returns R2 (the coefficient of determination).</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LinRegR2</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LinRegSlope</FUNCTION_NAME>
        <DESCRIPTION>Calculates the linear regression of a set and returns the value of a in the regression line y = ax + b.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LinRegSlope</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LinRegSlope</FUNCTION_NAME>
        <DESCRIPTION>Calculates the linear regression of a set and returns the value of a in the regression line y = ax + b.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LinRegSlope</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LinRegVariance</FUNCTION_NAME>
        <DESCRIPTION>Calculates the linear regression of a set and returns the variance associated with the regression line y = ax + b.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LinRegVariance</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LinRegVariance</FUNCTION_NAME>
        <DESCRIPTION>Calculates the linear regression of a set and returns the variance associated with the regression line y = ax + b.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LinRegVariance</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Log</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the natural logarithm of a number.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Log</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Log10</FUNCTION_NAME>
        <DESCRIPTION>Returns the base-10 logarithm of a number.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Log10</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>LTrim</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (String) containing a copy of a specified string without leading spaces.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>LTrim</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>MATCHES</FUNCTION_NAME>
        <PARAMETER_LIST>String, String</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>MATCHES</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Max</FUNCTION_NAME>
        <DESCRIPTION>Returns the maximum value of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Max</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Max</FUNCTION_NAME>
        <DESCRIPTION>Returns the maximum value of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Max</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Median</FUNCTION_NAME>
        <DESCRIPTION>Returns the median value of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Median</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Median</FUNCTION_NAME>
        <DESCRIPTION>Returns the median value of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Median</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Members</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of members in a hierarchy.</DESCRIPTION>
        <PARAMETER_LIST>Hierarchy</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Members</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Members</FUNCTION_NAME>
        <DESCRIPTION>Returns the set of members in a level.</DESCRIPTION>
        <PARAMETER_LIST>Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Members</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Members</FUNCTION_NAME>
        <DESCRIPTION>Returns the member whose name is specified by a string expression.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Members</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Mid</FUNCTION_NAME>
        <DESCRIPTION>Returns a specified number of characters from a string.</DESCRIPTION>
        <PARAMETER_LIST>String, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Mid</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Mid</FUNCTION_NAME>
        <DESCRIPTION>Returns a specified number of characters from a string.</DESCRIPTION>
        <PARAMETER_LIST>String, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Mid</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Min</FUNCTION_NAME>
        <DESCRIPTION>Returns the minimum value of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Min</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Min</FUNCTION_NAME>
        <DESCRIPTION>Returns the minimum value of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Min</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Minute</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) specifying a whole number between 0 and 59, inclusive, representing the minute of the hour.</DESCRIPTION>
        <PARAMETER_LIST>DateTime</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Minute</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>MIRR</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the modified internal rate of return for a series of periodic cash flows (payments and receipts).</DESCRIPTION>
        <PARAMETER_LIST>Array, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>MIRR</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Mod</FUNCTION_NAME>
        <DESCRIPTION>Returns the remainder of dividing n by d.</DESCRIPTION>
        <PARAMETER_LIST>Value, Value</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Mod</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Month</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) specifying a whole number between 1 and 12, inclusive, representing the month of the year.</DESCRIPTION>
        <PARAMETER_LIST>DateTime</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Month</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>MonthName</FUNCTION_NAME>
        <DESCRIPTION>Returns a string indicating the specified month.</DESCRIPTION>
        <PARAMETER_LIST>Integer, Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>MonthName</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Mtd</FUNCTION_NAME>
        <DESCRIPTION>A shortcut function for the PeriodsToDate function that specifies the level to be Month.</DESCRIPTION>
        <PARAMETER_LIST/>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Mtd</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Mtd</FUNCTION_NAME>
        <DESCRIPTION>A shortcut function for the PeriodsToDate function that specifies the level to be Month.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Mtd</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Name</FUNCTION_NAME>
        <DESCRIPTION>Returns the name of a dimension.</DESCRIPTION>
        <PARAMETER_LIST>Dimension</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Name</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Name</FUNCTION_NAME>
        <DESCRIPTION>Returns the name of a hierarchy.</DESCRIPTION>
        <PARAMETER_LIST>Hierarchy</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Name</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Name</FUNCTION_NAME>
        <DESCRIPTION>Returns the name of a level.</DESCRIPTION>
        <PARAMETER_LIST>Level</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Name</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Name</FUNCTION_NAME>
        <DESCRIPTION>Returns the name of a member.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Name</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>NativizeSet</FUNCTION_NAME>
        <DESCRIPTION>Tries to natively evaluate &lt;Set&gt;.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>NativizeSet</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>NextMember</FUNCTION_NAME>
        <DESCRIPTION>Returns the next member in the level that contains a specified member.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>NextMember</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>NonEmptyCrossJoin</FUNCTION_NAME>
        <DESCRIPTION>Returns the cross product of two sets, excluding empty tuples and tuples without associated fact table data.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>NonEmptyCrossJoin</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>NOT</FUNCTION_NAME>
        <DESCRIPTION>Returns the negation of a condition.</DESCRIPTION>
        <PARAMETER_LIST>Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>NOT</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Now</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Date) specifying the current date and time according your computer's system date and time.</DESCRIPTION>
        <PARAMETER_LIST/>
        <RETURN_TYPE>7</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Now</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>NPer</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the number of periods for an annuity based on periodic, fixed payments and a fixed interest rate.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression, Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>NPer</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>NPV</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the net present value of an investment based on a series of periodic cash flows (payments and receipts) and a discount rate.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Array</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>NPV</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>NullValue</FUNCTION_NAME>
        <PARAMETER_LIST/>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>NullValue</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Oct</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (String) representing the octal value of a number.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Oct</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>OpeningPeriod</FUNCTION_NAME>
        <DESCRIPTION>Returns the first descendant of a member at a level.</DESCRIPTION>
        <PARAMETER_LIST/>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>OpeningPeriod</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>OpeningPeriod</FUNCTION_NAME>
        <DESCRIPTION>Returns the first descendant of a member at a level.</DESCRIPTION>
        <PARAMETER_LIST>Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>OpeningPeriod</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>OpeningPeriod</FUNCTION_NAME>
        <DESCRIPTION>Returns the first descendant of a member at a level.</DESCRIPTION>
        <PARAMETER_LIST>Level, Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>OpeningPeriod</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>OR</FUNCTION_NAME>
        <DESCRIPTION>Returns the disjunction of two conditions.</DESCRIPTION>
        <PARAMETER_LIST>Logical Expression, Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>OR</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Order</FUNCTION_NAME>
        <DESCRIPTION>Arranges members of a set, optionally preserving or breaking the hierarchy.</DESCRIPTION>
        <PARAMETER_LIST>(none)</PARAMETER_LIST>
        <RETURN_TYPE>1</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Order</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>OrderKey</FUNCTION_NAME>
        <DESCRIPTION>Returns the member order key.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>OrderKey</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Ordinal</FUNCTION_NAME>
        <DESCRIPTION>Returns the zero-based ordinal value associated with a level.</DESCRIPTION>
        <PARAMETER_LIST>Level</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Ordinal</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ParallelPeriod</FUNCTION_NAME>
        <DESCRIPTION>Returns a member from a prior period in the same relative position as a specified member.</DESCRIPTION>
        <PARAMETER_LIST/>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ParallelPeriod</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ParallelPeriod</FUNCTION_NAME>
        <DESCRIPTION>Returns a member from a prior period in the same relative position as a specified member.</DESCRIPTION>
        <PARAMETER_LIST>Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ParallelPeriod</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ParallelPeriod</FUNCTION_NAME>
        <DESCRIPTION>Returns a member from a prior period in the same relative position as a specified member.</DESCRIPTION>
        <PARAMETER_LIST>Level, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ParallelPeriod</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ParallelPeriod</FUNCTION_NAME>
        <DESCRIPTION>Returns a member from a prior period in the same relative position as a specified member.</DESCRIPTION>
        <PARAMETER_LIST>Level, Numeric Expression, Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ParallelPeriod</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Parameter</FUNCTION_NAME>
        <DESCRIPTION>Returns default value of parameter.</DESCRIPTION>
        <PARAMETER_LIST>String, Symbol, String, String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Parameter</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Parameter</FUNCTION_NAME>
        <DESCRIPTION>Returns default value of parameter.</DESCRIPTION>
        <PARAMETER_LIST>String, Symbol, String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Parameter</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Parameter</FUNCTION_NAME>
        <DESCRIPTION>Returns default value of parameter.</DESCRIPTION>
        <PARAMETER_LIST>String, Symbol, Numeric Expression, String</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Parameter</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Parameter</FUNCTION_NAME>
        <DESCRIPTION>Returns default value of parameter.</DESCRIPTION>
        <PARAMETER_LIST>String, Symbol, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Parameter</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Parameter</FUNCTION_NAME>
        <DESCRIPTION>Returns default value of parameter.</DESCRIPTION>
        <PARAMETER_LIST>String, Hierarchy, Member, String</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Parameter</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Parameter</FUNCTION_NAME>
        <DESCRIPTION>Returns default value of parameter.</DESCRIPTION>
        <PARAMETER_LIST>String, Hierarchy, Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Parameter</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Parameter</FUNCTION_NAME>
        <DESCRIPTION>Returns default value of parameter.</DESCRIPTION>
        <PARAMETER_LIST>String, Hierarchy, Set, String</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Parameter</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Parameter</FUNCTION_NAME>
        <DESCRIPTION>Returns default value of parameter.</DESCRIPTION>
        <PARAMETER_LIST>String, Hierarchy, Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Parameter</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ParamRef</FUNCTION_NAME>
        <DESCRIPTION>Returns the current value of this parameter. If it is null, returns the default value.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ParamRef</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Parent</FUNCTION_NAME>
        <DESCRIPTION>Returns the parent of a member.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Parent</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Percentile</FUNCTION_NAME>
        <DESCRIPTION>Returns the value of the tuple that is at a given percentile of a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Percentile</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>PeriodsToDate</FUNCTION_NAME>
        <DESCRIPTION>Returns a set of periods (members) from a specified level starting with the first period and ending with a specified member.</DESCRIPTION>
        <PARAMETER_LIST/>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>PeriodsToDate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>PeriodsToDate</FUNCTION_NAME>
        <DESCRIPTION>Returns a set of periods (members) from a specified level starting with the first period and ending with a specified member.</DESCRIPTION>
        <PARAMETER_LIST>Level</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>PeriodsToDate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>PeriodsToDate</FUNCTION_NAME>
        <DESCRIPTION>Returns a set of periods (members) from a specified level starting with the first period and ending with a specified member.</DESCRIPTION>
        <PARAMETER_LIST>Level, Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>PeriodsToDate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Pi</FUNCTION_NAME>
        <DESCRIPTION>Returns the number 3.14159265358979, the mathematical constant pi, accurate to 15 digits.</DESCRIPTION>
        <PARAMETER_LIST/>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Pi</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Pmt</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the payment for an annuity based on periodic, fixed payments and a fixed interest rate.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression, Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Pmt</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Power</FUNCTION_NAME>
        <DESCRIPTION>Returns the result of a number raised to a power.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Power</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>PPmt</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the principal payment for a given period of an annuity based on periodic, fixed payments and a fixed interest rate.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression, Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>PPmt</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>PPmt</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the principal payment for a given period of an annuity based on periodic, fixed payments and a fixed interest rate.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>PPmt</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>PPmt</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the principal payment for a given period of an annuity based on periodic, fixed payments and a fixed interest rate.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>PPmt</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>PrevMember</FUNCTION_NAME>
        <DESCRIPTION>Returns the previous member in the level that contains a specified member.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>PrevMember</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Properties</FUNCTION_NAME>
        <DESCRIPTION>Returns the value of a member property.</DESCRIPTION>
        <PARAMETER_LIST>(none)</PARAMETER_LIST>
        <RETURN_TYPE>1</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Properties</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>PV</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the present value of an annuity based on periodic, fixed payments to be paid in the future and a fixed interest rate.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression, Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>PV</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Qtd</FUNCTION_NAME>
        <DESCRIPTION>A shortcut function for the PeriodsToDate function that specifies the level to be Quarter.</DESCRIPTION>
        <PARAMETER_LIST/>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Qtd</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Qtd</FUNCTION_NAME>
        <DESCRIPTION>A shortcut function for the PeriodsToDate function that specifies the level to be Quarter.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Qtd</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Radians</FUNCTION_NAME>
        <DESCRIPTION>Converts degrees to radians.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Radians</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Rank</FUNCTION_NAME>
        <DESCRIPTION>Returns the one-based rank of a tuple in a set.</DESCRIPTION>
        <PARAMETER_LIST>Tuple, Set</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Rank</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Rank</FUNCTION_NAME>
        <DESCRIPTION>Returns the one-based rank of a tuple in a set.</DESCRIPTION>
        <PARAMETER_LIST>Tuple, Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Rank</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Rank</FUNCTION_NAME>
        <DESCRIPTION>Returns the one-based rank of a tuple in a set.</DESCRIPTION>
        <PARAMETER_LIST>Member, Set</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Rank</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Rank</FUNCTION_NAME>
        <DESCRIPTION>Returns the one-based rank of a tuple in a set.</DESCRIPTION>
        <PARAMETER_LIST>Member, Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Rank</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Rate</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the interest rate per period for an annuity.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression, Logical Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Rate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Rate</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the interest rate per period for an annuity.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression, Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Rate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Rate</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the interest rate per period for an annuity.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Rate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Rate</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the interest rate per period for an annuity.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Rate</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Replace</FUNCTION_NAME>
        <DESCRIPTION>Returns a string in which a specified substring has been replaced with another substring a specified number of times.</DESCRIPTION>
        <PARAMETER_LIST>String, String, String, Integer, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Replace</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Replace</FUNCTION_NAME>
        <DESCRIPTION>Returns a string in which a specified substring has been replaced with another substring a specified number of times.</DESCRIPTION>
        <PARAMETER_LIST>String, String, String, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Replace</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Replace</FUNCTION_NAME>
        <DESCRIPTION>Returns a string in which a specified substring has been replaced with another substring a specified number of times.</DESCRIPTION>
        <PARAMETER_LIST>String, String, String, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Replace</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Replace</FUNCTION_NAME>
        <DESCRIPTION/>
        <PARAMETER_LIST>String, String, String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Replace</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Right</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (String) containing a specified number of characters from the right side of a string.</DESCRIPTION>
        <PARAMETER_LIST>String, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Right</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Round</FUNCTION_NAME>
        <DESCRIPTION>Returns a number rounded to a specified number of decimal places.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Integer</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Round</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Round</FUNCTION_NAME>
        <DESCRIPTION>Returns a number rounded to a specified number of decimal places.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Round</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>RTrim</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (String) containing a copy of a specified string without trailing spaces.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>RTrim</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Second</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) specifying a whole number between 0 and 59, inclusive, representing the second of the minute.</DESCRIPTION>
        <PARAMETER_LIST>DateTime</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Second</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>SetToStr</FUNCTION_NAME>
        <DESCRIPTION>Constructs a string from a set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>SetToStr</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Sgn</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) indicating the sign of a number.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Sgn</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Siblings</FUNCTION_NAME>
        <DESCRIPTION>Returns the siblings of a specified member, including the member itself.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Siblings</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Sin</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the sine of an angle.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Sin</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Sinh</FUNCTION_NAME>
        <DESCRIPTION>Returns the hyperbolic sine of a number.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Sinh</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>SLN</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the straight-line depreciation of an asset for a single period.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>SLN</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Space</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (String) consisting of the specified number of spaces.</DESCRIPTION>
        <PARAMETER_LIST>Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Space</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Sqr</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the square root of a number.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Sqr</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>SqrtPi</FUNCTION_NAME>
        <DESCRIPTION>Returns the square root of (number * pi).</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>SqrtPi</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Stddev</FUNCTION_NAME>
        <DESCRIPTION>Alias for Stdev.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Stddev</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Stddev</FUNCTION_NAME>
        <DESCRIPTION>Alias for Stdev.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Stddev</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>StddevP</FUNCTION_NAME>
        <DESCRIPTION>Alias for StdevP.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>StddevP</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>StddevP</FUNCTION_NAME>
        <DESCRIPTION>Alias for StdevP.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>StddevP</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Stdev</FUNCTION_NAME>
        <DESCRIPTION>Returns the standard deviation of a numeric expression evaluated over a set (unbiased).</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Stdev</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Stdev</FUNCTION_NAME>
        <DESCRIPTION>Returns the standard deviation of a numeric expression evaluated over a set (unbiased).</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Stdev</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>StdevP</FUNCTION_NAME>
        <DESCRIPTION>Returns the standard deviation of a numeric expression evaluated over a set (biased).</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>StdevP</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>StdevP</FUNCTION_NAME>
        <DESCRIPTION>Returns the standard deviation of a numeric expression evaluated over a set (biased).</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>StdevP</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Str</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (String) representation of a number.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Str</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>StrComp</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) indicating the result of a string comparison.</DESCRIPTION>
        <PARAMETER_LIST>String, String, Integer</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>StrComp</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>StrComp</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) indicating the result of a string comparison.</DESCRIPTION>
        <PARAMETER_LIST>String, String</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>StrComp</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>String</FUNCTION_NAME>
        <DESCRIPTION/>
        <PARAMETER_LIST>Integer, String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>String</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>StripCalculatedMembers</FUNCTION_NAME>
        <DESCRIPTION>Removes calculated members from a set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>StripCalculatedMembers</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>StrReverse</FUNCTION_NAME>
        <DESCRIPTION>Returns a string in which the character order of a specified string is reversed.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>StrReverse</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>StrToMember</FUNCTION_NAME>
        <DESCRIPTION>Returns a member from a unique name String in MDX format.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>StrToMember</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>StrToSet</FUNCTION_NAME>
        <DESCRIPTION>Constructs a set from a string expression.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>StrToSet</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>StrToTuple</FUNCTION_NAME>
        <DESCRIPTION>Constructs a tuple from a string.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>StrToTuple</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Subset</FUNCTION_NAME>
        <DESCRIPTION>Returns a subset of elements from a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Subset</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Subset</FUNCTION_NAME>
        <DESCRIPTION>Returns a subset of elements from a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Subset</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Sum</FUNCTION_NAME>
        <DESCRIPTION>Returns the sum of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Sum</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Sum</FUNCTION_NAME>
        <DESCRIPTION>Returns the sum of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Sum</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>SYD</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the sum-of-years' digits depreciation of an asset for a specified period.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression, Numeric Expression, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>SYD</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Tail</FUNCTION_NAME>
        <DESCRIPTION>Returns a subset from the end of a set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Tail</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Tail</FUNCTION_NAME>
        <DESCRIPTION>Returns a subset from the end of a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Tail</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Tan</FUNCTION_NAME>
        <DESCRIPTION>Returns a Double specifying the tangent of an angle.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Tan</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Tanh</FUNCTION_NAME>
        <DESCRIPTION>Returns the hyperbolic tangent of a number.</DESCRIPTION>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Tanh</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ThirdQ</FUNCTION_NAME>
        <DESCRIPTION>Returns the 3rd quartile value of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ThirdQ</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ThirdQ</FUNCTION_NAME>
        <DESCRIPTION>Returns the 3rd quartile value of a numeric expression evaluated over a set.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ThirdQ</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Time</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Date) indicating the current system time.</DESCRIPTION>
        <PARAMETER_LIST/>
        <RETURN_TYPE>7</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Time</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Timer</FUNCTION_NAME>
        <DESCRIPTION>Returns a Single representing the number of seconds elapsed since midnight.</DESCRIPTION>
        <PARAMETER_LIST/>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Timer</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>TimeSerial</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Date) containing the time for a specific hour, minute, and second.</DESCRIPTION>
        <PARAMETER_LIST>Integer, Integer, Integer</PARAMETER_LIST>
        <RETURN_TYPE>7</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>TimeSerial</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>TimeValue</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Date) containing the time.</DESCRIPTION>
        <PARAMETER_LIST>DateTime</PARAMETER_LIST>
        <RETURN_TYPE>7</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>TimeValue</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ToggleDrillState</FUNCTION_NAME>
        <DESCRIPTION>Toggles the drill state of members. This function is a combination of DrillupMember and DrilldownMember.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ToggleDrillState</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ToggleDrillState</FUNCTION_NAME>
        <DESCRIPTION>Toggles the drill state of members. This function is a combination of DrillupMember and DrilldownMember.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ToggleDrillState</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>TopCount</FUNCTION_NAME>
        <DESCRIPTION>Returns a specified number of items from the top of a set, optionally ordering the set first.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>TopCount</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>TopCount</FUNCTION_NAME>
        <DESCRIPTION>Returns a specified number of items from the top of a set, optionally ordering the set first.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>TopCount</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>TopPercent</FUNCTION_NAME>
        <DESCRIPTION>Sorts a set and returns the top N elements whose cumulative total is at least a specified percentage.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>TopPercent</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>TopSum</FUNCTION_NAME>
        <DESCRIPTION>Sorts a set and returns the top N elements whose cumulative total is at least a specified value.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>TopSum</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Trim</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (String) containing a copy of a specified string without leading and trailing spaces.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Trim</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>TupleToStr</FUNCTION_NAME>
        <DESCRIPTION>Constructs a string from a tuple.</DESCRIPTION>
        <PARAMETER_LIST>Tuple</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>TupleToStr</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>TypeName</FUNCTION_NAME>
        <DESCRIPTION>Returns a String that provides information about a variable.</DESCRIPTION>
        <PARAMETER_LIST>Value</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>TypeName</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>UCase</FUNCTION_NAME>
        <DESCRIPTION>Returns a string that has been converted to uppercase</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>UCase</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Union</FUNCTION_NAME>
        <DESCRIPTION>Returns the union of two sets, optionally retaining duplicates.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Union</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Union</FUNCTION_NAME>
        <DESCRIPTION>Returns the union of two sets, optionally retaining duplicates.</DESCRIPTION>
        <PARAMETER_LIST>Set, Set, Symbol</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Union</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>UniqueName</FUNCTION_NAME>
        <DESCRIPTION>Returns the unique name of a dimension.</DESCRIPTION>
        <PARAMETER_LIST>Dimension</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>UniqueName</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>UniqueName</FUNCTION_NAME>
        <DESCRIPTION>Returns the unique name of a hierarchy.</DESCRIPTION>
        <PARAMETER_LIST>Hierarchy</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>UniqueName</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>UniqueName</FUNCTION_NAME>
        <DESCRIPTION>Returns the unique name of a level.</DESCRIPTION>
        <PARAMETER_LIST>Level</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>UniqueName</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>UniqueName</FUNCTION_NAME>
        <DESCRIPTION>Returns the unique name of a member.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>UniqueName</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Unorder</FUNCTION_NAME>
        <DESCRIPTION>Removes any enforced ordering from a specified set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Unorder</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Val</FUNCTION_NAME>
        <PARAMETER_LIST>Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Val</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Val</FUNCTION_NAME>
        <DESCRIPTION>Returns the numbers contained in a string as a numeric value of appropriate type.</DESCRIPTION>
        <PARAMETER_LIST>String</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Val</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>ValidMeasure</FUNCTION_NAME>
        <DESCRIPTION>Returns a valid measure in a virtual cube by forcing inapplicable dimensions to their top level.</DESCRIPTION>
        <PARAMETER_LIST>Tuple</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>ValidMeasure</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Value</FUNCTION_NAME>
        <DESCRIPTION>Returns the value of a measure.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Value</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Var</FUNCTION_NAME>
        <DESCRIPTION>Returns the variance of a numeric expression evaluated over a set (unbiased).</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Var</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Var</FUNCTION_NAME>
        <DESCRIPTION>Returns the variance of a numeric expression evaluated over a set (unbiased).</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Var</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Variance</FUNCTION_NAME>
        <DESCRIPTION>Alias for Var.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Variance</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Variance</FUNCTION_NAME>
        <DESCRIPTION>Alias for Var.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Variance</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>VarianceP</FUNCTION_NAME>
        <DESCRIPTION>Alias for VarP.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>VarianceP</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>VarianceP</FUNCTION_NAME>
        <DESCRIPTION>Alias for VarP.</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>VarianceP</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>VarP</FUNCTION_NAME>
        <DESCRIPTION>Returns the variance of a numeric expression evaluated over a set (biased).</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>VarP</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>VarP</FUNCTION_NAME>
        <DESCRIPTION>Returns the variance of a numeric expression evaluated over a set (biased).</DESCRIPTION>
        <PARAMETER_LIST>Set, Numeric Expression</PARAMETER_LIST>
        <RETURN_TYPE>5</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>VarP</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>VisualTotals</FUNCTION_NAME>
        <DESCRIPTION>Dynamically totals child members specified in a set using a pattern for the total label in the result set.</DESCRIPTION>
        <PARAMETER_LIST>Set</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>VisualTotals</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>VisualTotals</FUNCTION_NAME>
        <DESCRIPTION>Dynamically totals child members specified in a set using a pattern for the total label in the result set.</DESCRIPTION>
        <PARAMETER_LIST>Set, String</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>VisualTotals</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Weekday</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) containing a whole number representing the day of the week.</DESCRIPTION>
        <PARAMETER_LIST>DateTime, Integer</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Weekday</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Weekday</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) containing a whole number representing the day of the week.</DESCRIPTION>
        <PARAMETER_LIST>DateTime</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Weekday</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>WeekdayName</FUNCTION_NAME>
        <DESCRIPTION>Returns a string indicating the specified day of the week.</DESCRIPTION>
        <PARAMETER_LIST>Integer, Logical Expression, Integer</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>WeekdayName</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Wtd</FUNCTION_NAME>
        <DESCRIPTION>A shortcut function for the PeriodsToDate function that specifies the level to be Week.</DESCRIPTION>
        <PARAMETER_LIST/>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Wtd</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Wtd</FUNCTION_NAME>
        <DESCRIPTION>A shortcut function for the PeriodsToDate function that specifies the level to be Week.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Wtd</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>XOR</FUNCTION_NAME>
        <DESCRIPTION>Returns whether two conditions are mutually exclusive.</DESCRIPTION>
        <PARAMETER_LIST>Logical Expression, Logical Expression</PARAMETER_LIST>
        <RETURN_TYPE>11</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>XOR</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Year</FUNCTION_NAME>
        <DESCRIPTION>Returns a Variant (Integer) containing a whole number representing the year.</DESCRIPTION>
        <PARAMETER_LIST>DateTime</PARAMETER_LIST>
        <RETURN_TYPE>2</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Year</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Ytd</FUNCTION_NAME>
        <DESCRIPTION>A shortcut function for the PeriodsToDate function that specifies the level to be Year.</DESCRIPTION>
        <PARAMETER_LIST/>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Ytd</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>Ytd</FUNCTION_NAME>
        <DESCRIPTION>A shortcut function for the PeriodsToDate function that specifies the level to be Year.</DESCRIPTION>
        <PARAMETER_LIST>Member</PARAMETER_LIST>
        <RETURN_TYPE>12</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>Ytd</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>{}</FUNCTION_NAME>
        <DESCRIPTION>Brace operator constructs a set.</DESCRIPTION>
        <PARAMETER_LIST>(none)</PARAMETER_LIST>
        <RETURN_TYPE>1</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>{}</CAPTION>
      </row>
      <row>
        <FUNCTION_NAME>||</FUNCTION_NAME>
        <DESCRIPTION>Concatenates two strings.</DESCRIPTION>
        <PARAMETER_LIST>String, String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>||</CAPTION>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_FUNCTIONS</RequestType>
      <Restrictions>
        <RestrictionList>
          <FUNCTION_NAME>||</FUNCTION_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="FUNCTION_NAME" name="FUNCTION_NAME" type="xsd:string"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="PARAMETER_LIST" name="PARAMETER_LIST" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="RETURN_TYPE" name="RETURN_TYPE" type="xsd:int"/>
            <xsd:element sql:field="ORIGIN" name="ORIGIN" type="xsd:int"/>
            <xsd:element sql:field="INTERFACE_NAME" name="INTERFACE_NAME" type="xsd:string"/>
            <xsd:element sql:field="LIBRARY_NAME" name="LIBRARY_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CAPTION" name="CAPTION" type="xsd:string" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <FUNCTION_NAME>||</FUNCTION_NAME>
        <DESCRIPTION>Concatenates two strings.</DESCRIPTION>
        <PARAMETER_LIST>String, String</PARAMETER_LIST>
        <RETURN_TYPE>8</RETURN_TYPE>
        <ORIGIN>1</ORIGIN>
        <INTERFACE_NAME/>
        <CAPTION>||</CAPTION>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetMDSchemaHierarchies":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_HIERARCHIES</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>HR</CUBE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>FoodMart</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="HIERARCHY_NAME" name="HIERARCHY_NAME" type="xsd:string"/>
            <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="HIERARCHY_GUID" name="HIERARCHY_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="HIERARCHY_CAPTION" name="HIERARCHY_CAPTION" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_TYPE" name="DIMENSION_TYPE" type="xsd:short"/>
            <xsd:element sql:field="HIERARCHY_CARDINALITY" name="HIERARCHY_CARDINALITY" type="xsd:unsignedInt"/>
            <xsd:element sql:field="DEFAULT_MEMBER" name="DEFAULT_MEMBER" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="ALL_MEMBER" name="ALL_MEMBER" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="STRUCTURE" name="STRUCTURE" type="xsd:short"/>
            <xsd:element sql:field="IS_VIRTUAL" name="IS_VIRTUAL" type="xsd:boolean"/>
            <xsd:element sql:field="IS_READWRITE" name="IS_READWRITE" type="xsd:boolean"/>
            <xsd:element sql:field="DIMENSION_UNIQUE_SETTINGS" name="DIMENSION_UNIQUE_SETTINGS" type="xsd:int"/>
            <xsd:element sql:field="DIMENSION_IS_VISIBLE" name="DIMENSION_IS_VISIBLE" type="xsd:boolean"/>
            <xsd:element sql:field="HIERARCHY_IS_VISIBLE" name="HIERARCHY_IS_VISIBLE" type="xsd:boolean"/>
            <xsd:element sql:field="HIERARCHY_ORDINAL" name="HIERARCHY_ORDINAL" type="xsd:unsignedInt"/>
            <xsd:element sql:field="DIMENSION_IS_SHARED" name="DIMENSION_IS_SHARED" type="xsd:boolean"/>
            <xsd:element sql:field="PARENT_CHILD" name="PARENT_CHILD" type="xsd:boolean" minOccurs="0"/>
            <xsd:element sql:field="LEVELS" name="LEVELS" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Department]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_NAME>Department</HIERARCHY_NAME>
        <HIERARCHY_UNIQUE_NAME>[Department]</HIERARCHY_UNIQUE_NAME>
        <HIERARCHY_CAPTION>Department</HIERARCHY_CAPTION>
        <DIMENSION_TYPE>3</DIMENSION_TYPE>
        <HIERARCHY_CARDINALITY>13</HIERARCHY_CARDINALITY>
        <DEFAULT_MEMBER>[Department].[All Departments]</DEFAULT_MEMBER>
        <ALL_MEMBER>[Department].[All Departments]</ALL_MEMBER>
        <DESCRIPTION>HR Cube - Department Hierarchy</DESCRIPTION>
        <STRUCTURE>0</STRUCTURE>
        <IS_VIRTUAL>false</IS_VIRTUAL>
        <IS_READWRITE>false</IS_READWRITE>
        <DIMENSION_UNIQUE_SETTINGS>0</DIMENSION_UNIQUE_SETTINGS>
        <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
        <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
        <HIERARCHY_ORDINAL>6</HIERARCHY_ORDINAL>
        <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
        <PARENT_CHILD>false</PARENT_CHILD>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_NAME>Employees</HIERARCHY_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <HIERARCHY_CAPTION>Employees</HIERARCHY_CAPTION>
        <DIMENSION_TYPE>3</DIMENSION_TYPE>
        <HIERARCHY_CARDINALITY>1156</HIERARCHY_CARDINALITY>
        <DEFAULT_MEMBER>[Employees].[All Employees]</DEFAULT_MEMBER>
        <ALL_MEMBER>[Employees].[All Employees]</ALL_MEMBER>
        <DESCRIPTION>HR Cube - Employees Hierarchy</DESCRIPTION>
        <STRUCTURE>0</STRUCTURE>
        <IS_VIRTUAL>false</IS_VIRTUAL>
        <IS_READWRITE>false</IS_READWRITE>
        <DIMENSION_UNIQUE_SETTINGS>0</DIMENSION_UNIQUE_SETTINGS>
        <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
        <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
        <HIERARCHY_ORDINAL>7</HIERARCHY_ORDINAL>
        <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
        <PARENT_CHILD>true</PARENT_CHILD>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Measures]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_NAME>Measures</HIERARCHY_NAME>
        <HIERARCHY_UNIQUE_NAME>[Measures]</HIERARCHY_UNIQUE_NAME>
        <HIERARCHY_CAPTION>Measures</HIERARCHY_CAPTION>
        <DIMENSION_TYPE>2</DIMENSION_TYPE>
        <HIERARCHY_CARDINALITY>5</HIERARCHY_CARDINALITY>
        <DEFAULT_MEMBER>[Measures].[Org Salary]</DEFAULT_MEMBER>
        <DESCRIPTION>HR Cube - Measures Hierarchy</DESCRIPTION>
        <STRUCTURE>0</STRUCTURE>
        <IS_VIRTUAL>false</IS_VIRTUAL>
        <IS_READWRITE>false</IS_READWRITE>
        <DIMENSION_UNIQUE_SETTINGS>0</DIMENSION_UNIQUE_SETTINGS>
        <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
        <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
        <HIERARCHY_ORDINAL>0</HIERARCHY_ORDINAL>
        <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
        <PARENT_CHILD>false</PARENT_CHILD>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Pay Type]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_NAME>Pay Type</HIERARCHY_NAME>
        <HIERARCHY_UNIQUE_NAME>[Pay Type]</HIERARCHY_UNIQUE_NAME>
        <HIERARCHY_CAPTION>Pay Type</HIERARCHY_CAPTION>
        <DIMENSION_TYPE>3</DIMENSION_TYPE>
        <HIERARCHY_CARDINALITY>3</HIERARCHY_CARDINALITY>
        <DEFAULT_MEMBER>[Pay Type].[All Pay Types]</DEFAULT_MEMBER>
        <ALL_MEMBER>[Pay Type].[All Pay Types]</ALL_MEMBER>
        <DESCRIPTION>HR Cube - Pay Type Hierarchy</DESCRIPTION>
        <STRUCTURE>0</STRUCTURE>
        <IS_VIRTUAL>false</IS_VIRTUAL>
        <IS_READWRITE>false</IS_READWRITE>
        <DIMENSION_UNIQUE_SETTINGS>0</DIMENSION_UNIQUE_SETTINGS>
        <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
        <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
        <HIERARCHY_ORDINAL>3</HIERARCHY_ORDINAL>
        <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
        <PARENT_CHILD>false</PARENT_CHILD>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Position]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_NAME>Position</HIERARCHY_NAME>
        <HIERARCHY_UNIQUE_NAME>[Position]</HIERARCHY_UNIQUE_NAME>
        <HIERARCHY_CAPTION>Position</HIERARCHY_CAPTION>
        <DIMENSION_TYPE>3</DIMENSION_TYPE>
        <HIERARCHY_CARDINALITY>24</HIERARCHY_CARDINALITY>
        <DEFAULT_MEMBER>[Position].[All Position]</DEFAULT_MEMBER>
        <ALL_MEMBER>[Position].[All Position]</ALL_MEMBER>
        <DESCRIPTION>HR Cube - Position Hierarchy</DESCRIPTION>
        <STRUCTURE>0</STRUCTURE>
        <IS_VIRTUAL>false</IS_VIRTUAL>
        <IS_READWRITE>false</IS_READWRITE>
        <DIMENSION_UNIQUE_SETTINGS>0</DIMENSION_UNIQUE_SETTINGS>
        <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
        <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
        <HIERARCHY_ORDINAL>5</HIERARCHY_ORDINAL>
        <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
        <PARENT_CHILD>false</PARENT_CHILD>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Store Type]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_NAME>Store Type</HIERARCHY_NAME>
        <HIERARCHY_UNIQUE_NAME>[Store Type]</HIERARCHY_UNIQUE_NAME>
        <HIERARCHY_CAPTION>Store Type</HIERARCHY_CAPTION>
        <DIMENSION_TYPE>3</DIMENSION_TYPE>
        <HIERARCHY_CARDINALITY>7</HIERARCHY_CARDINALITY>
        <DEFAULT_MEMBER>[Store Type].[All Store Types]</DEFAULT_MEMBER>
        <ALL_MEMBER>[Store Type].[All Store Types]</ALL_MEMBER>
        <DESCRIPTION>HR Cube - Store Type Hierarchy</DESCRIPTION>
        <STRUCTURE>0</STRUCTURE>
        <IS_VIRTUAL>false</IS_VIRTUAL>
        <IS_READWRITE>false</IS_READWRITE>
        <DIMENSION_UNIQUE_SETTINGS>0</DIMENSION_UNIQUE_SETTINGS>
        <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
        <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
        <HIERARCHY_ORDINAL>4</HIERARCHY_ORDINAL>
        <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
        <PARENT_CHILD>false</PARENT_CHILD>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Store]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_NAME>Store</HIERARCHY_NAME>
        <HIERARCHY_UNIQUE_NAME>[Store]</HIERARCHY_UNIQUE_NAME>
        <HIERARCHY_CAPTION>Store</HIERARCHY_CAPTION>
        <DIMENSION_TYPE>3</DIMENSION_TYPE>
        <HIERARCHY_CARDINALITY>63</HIERARCHY_CARDINALITY>
        <DEFAULT_MEMBER>[Store].[All Stores]</DEFAULT_MEMBER>
        <ALL_MEMBER>[Store].[All Stores]</ALL_MEMBER>
        <DESCRIPTION>HR Cube - Store Hierarchy</DESCRIPTION>
        <STRUCTURE>0</STRUCTURE>
        <IS_VIRTUAL>false</IS_VIRTUAL>
        <IS_READWRITE>false</IS_READWRITE>
        <DIMENSION_UNIQUE_SETTINGS>0</DIMENSION_UNIQUE_SETTINGS>
        <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
        <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
        <HIERARCHY_ORDINAL>2</HIERARCHY_ORDINAL>
        <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
        <PARENT_CHILD>false</PARENT_CHILD>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Time]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_NAME>Time</HIERARCHY_NAME>
        <HIERARCHY_UNIQUE_NAME>[Time]</HIERARCHY_UNIQUE_NAME>
        <HIERARCHY_CAPTION>Time</HIERARCHY_CAPTION>
        <DIMENSION_TYPE>1</DIMENSION_TYPE>
        <HIERARCHY_CARDINALITY>34</HIERARCHY_CARDINALITY>
        <DEFAULT_MEMBER>[Time].[1997]</DEFAULT_MEMBER>
        <DESCRIPTION>HR Cube - Time Hierarchy</DESCRIPTION>
        <STRUCTURE>0</STRUCTURE>
        <IS_VIRTUAL>false</IS_VIRTUAL>
        <IS_READWRITE>false</IS_READWRITE>
        <DIMENSION_UNIQUE_SETTINGS>0</DIMENSION_UNIQUE_SETTINGS>
        <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
        <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
        <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
        <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
        <PARENT_CHILD>false</PARENT_CHILD>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_HIERARCHIES</RequestType>
      <Restrictions>
        <RestrictionList>
          <HIERARCHY_NAME>Time</HIERARCHY_NAME>
          <CUBE_NAME>HR</CUBE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>FoodMart</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="HIERARCHY_NAME" name="HIERARCHY_NAME" type="xsd:string"/>
            <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="HIERARCHY_GUID" name="HIERARCHY_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="HIERARCHY_CAPTION" name="HIERARCHY_CAPTION" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_TYPE" name="DIMENSION_TYPE" type="xsd:short"/>
            <xsd:element sql:field="HIERARCHY_CARDINALITY" name="HIERARCHY_CARDINALITY" type="xsd:unsignedInt"/>
            <xsd:element sql:field="DEFAULT_MEMBER" name="DEFAULT_MEMBER" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="ALL_MEMBER" name="ALL_MEMBER" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="STRUCTURE" name="STRUCTURE" type="xsd:short"/>
            <xsd:element sql:field="IS_VIRTUAL" name="IS_VIRTUAL" type="xsd:boolean"/>
            <xsd:element sql:field="IS_READWRITE" name="IS_READWRITE" type="xsd:boolean"/>
            <xsd:element sql:field="DIMENSION_UNIQUE_SETTINGS" name="DIMENSION_UNIQUE_SETTINGS" type="xsd:int"/>
            <xsd:element sql:field="DIMENSION_IS_VISIBLE" name="DIMENSION_IS_VISIBLE" type="xsd:boolean"/>
            <xsd:element sql:field="HIERARCHY_IS_VISIBLE" name="HIERARCHY_IS_VISIBLE" type="xsd:boolean"/>
            <xsd:element sql:field="HIERARCHY_ORDINAL" name="HIERARCHY_ORDINAL" type="xsd:unsignedInt"/>
            <xsd:element sql:field="DIMENSION_IS_SHARED" name="DIMENSION_IS_SHARED" type="xsd:boolean"/>
            <xsd:element sql:field="PARENT_CHILD" name="PARENT_CHILD" type="xsd:boolean" minOccurs="0"/>
            <xsd:element sql:field="LEVELS" name="LEVELS" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Time]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_NAME>Time</HIERARCHY_NAME>
        <HIERARCHY_UNIQUE_NAME>[Time]</HIERARCHY_UNIQUE_NAME>
        <HIERARCHY_CAPTION>Time</HIERARCHY_CAPTION>
        <DIMENSION_TYPE>1</DIMENSION_TYPE>
        <HIERARCHY_CARDINALITY>34</HIERARCHY_CARDINALITY>
        <DEFAULT_MEMBER>[Time].[1997]</DEFAULT_MEMBER>
        <DESCRIPTION>HR Cube - Time Hierarchy</DESCRIPTION>
        <STRUCTURE>0</STRUCTURE>
        <IS_VIRTUAL>false</IS_VIRTUAL>
        <IS_READWRITE>false</IS_READWRITE>
        <DIMENSION_UNIQUE_SETTINGS>0</DIMENSION_UNIQUE_SETTINGS>
        <DIMENSION_IS_VISIBLE>true</DIMENSION_IS_VISIBLE>
        <HIERARCHY_IS_VISIBLE>true</HIERARCHY_IS_VISIBLE>
        <HIERARCHY_ORDINAL>1</HIERARCHY_ORDINAL>
        <DIMENSION_IS_SHARED>true</DIMENSION_IS_SHARED>
        <PARENT_CHILD>false</PARENT_CHILD>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetMDSchemaMeasures":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_MEASURES</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>HR</CUBE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>FoodMart</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="MEASURE_NAME" name="MEASURE_NAME" type="xsd:string"/>
            <xsd:element sql:field="MEASURE_UNIQUE_NAME" name="MEASURE_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="MEASURE_CAPTION" name="MEASURE_CAPTION" type="xsd:string"/>
            <xsd:element sql:field="MEASURE_GUID" name="MEASURE_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="MEASURE_AGGREGATOR" name="MEASURE_AGGREGATOR" type="xsd:int"/>
            <xsd:element sql:field="DATA_TYPE" name="DATA_TYPE" type="xsd:unsignedShort"/>
            <xsd:element sql:field="MEASURE_IS_VISIBLE" name="MEASURE_IS_VISIBLE" type="xsd:boolean"/>
            <xsd:element sql:field="LEVELS_LIST" name="LEVELS_LIST" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DEFAULT_FORMAT_STRING" name="DEFAULT_FORMAT_STRING" type="xsd:string" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <MEASURE_NAME>Avg Salary</MEASURE_NAME>
        <MEASURE_UNIQUE_NAME>[Measures].[Avg Salary]</MEASURE_UNIQUE_NAME>
        <MEASURE_CAPTION>Avg Salary</MEASURE_CAPTION>
        <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
        <DATA_TYPE>130</DATA_TYPE>
        <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
        <DESCRIPTION>HR Cube - Avg Salary Member</DESCRIPTION>
        <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <MEASURE_NAME>Count</MEASURE_NAME>
        <MEASURE_UNIQUE_NAME>[Measures].[Count]</MEASURE_UNIQUE_NAME>
        <MEASURE_CAPTION>Count</MEASURE_CAPTION>
        <MEASURE_AGGREGATOR>2</MEASURE_AGGREGATOR>
        <DATA_TYPE>3</DATA_TYPE>
        <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
        <LEVELS_LIST>[Time].[Month],[Store].[Store Name],[Pay Type].[Pay Type],[Store Type].[Store Type],[Position].[Position Title],[Department].[Department Description],[Employees].[Employee Id]</LEVELS_LIST>
        <DESCRIPTION>HR Cube - Count Member</DESCRIPTION>
        <DEFAULT_FORMAT_STRING>#,#</DEFAULT_FORMAT_STRING>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <MEASURE_NAME>Employee Salary</MEASURE_NAME>
        <MEASURE_UNIQUE_NAME>[Measures].[Employee Salary]</MEASURE_UNIQUE_NAME>
        <MEASURE_CAPTION>Employee Salary</MEASURE_CAPTION>
        <MEASURE_AGGREGATOR>127</MEASURE_AGGREGATOR>
        <DATA_TYPE>130</DATA_TYPE>
        <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
        <DESCRIPTION>HR Cube - Employee Salary Member</DESCRIPTION>
        <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <MEASURE_NAME>Number of Employees</MEASURE_NAME>
        <MEASURE_UNIQUE_NAME>[Measures].[Number of Employees]</MEASURE_UNIQUE_NAME>
        <MEASURE_CAPTION>Number of Employees</MEASURE_CAPTION>
        <MEASURE_AGGREGATOR>0</MEASURE_AGGREGATOR>
        <DATA_TYPE>3</DATA_TYPE>
        <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
        <LEVELS_LIST>[Time].[Month],[Store].[Store Name],[Pay Type].[Pay Type],[Store Type].[Store Type],[Position].[Position Title],[Department].[Department Description],[Employees].[Employee Id]</LEVELS_LIST>
        <DESCRIPTION>HR Cube - Number of Employees Member</DESCRIPTION>
        <DEFAULT_FORMAT_STRING>#,#</DEFAULT_FORMAT_STRING>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <MEASURE_NAME>Org Salary</MEASURE_NAME>
        <MEASURE_UNIQUE_NAME>[Measures].[Org Salary]</MEASURE_UNIQUE_NAME>
        <MEASURE_CAPTION>Org Salary</MEASURE_CAPTION>
        <MEASURE_AGGREGATOR>1</MEASURE_AGGREGATOR>
        <DATA_TYPE>5</DATA_TYPE>
        <MEASURE_IS_VISIBLE>true</MEASURE_IS_VISIBLE>
        <LEVELS_LIST>[Time].[Month],[Store].[Store Name],[Pay Type].[Pay Type],[Store Type].[Store Type],[Position].[Position Title],[Department].[Department Description],[Employees].[Employee Id]</LEVELS_LIST>
        <DESCRIPTION>HR Cube - Org Salary Member</DESCRIPTION>
        <DEFAULT_FORMAT_STRING>Currency</DEFAULT_FORMAT_STRING>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetMDSchemaMembers":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_MEMBERS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>HR</CUBE_NAME>
          <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>FoodMart</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="LEVEL_UNIQUE_NAME" name="LEVEL_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="LEVEL_NUMBER" name="LEVEL_NUMBER" type="xsd:unsignedInt"/>
            <xsd:element sql:field="MEMBER_ORDINAL" name="MEMBER_ORDINAL" type="xsd:unsignedInt"/>
            <xsd:element sql:field="MEMBER_NAME" name="MEMBER_NAME" type="xsd:string"/>
            <xsd:element sql:field="MEMBER_UNIQUE_NAME" name="MEMBER_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="MEMBER_TYPE" name="MEMBER_TYPE" type="xsd:int"/>
            <xsd:element sql:field="MEMBER_GUID" name="MEMBER_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="MEMBER_CAPTION" name="MEMBER_CAPTION" type="xsd:string"/>
            <xsd:element sql:field="CHILDREN_CARDINALITY" name="CHILDREN_CARDINALITY" type="xsd:unsignedInt"/>
            <xsd:element sql:field="PARENT_LEVEL" name="PARENT_LEVEL" type="xsd:unsignedInt"/>
            <xsd:element sql:field="PARENT_UNIQUE_NAME" name="PARENT_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="PARENT_COUNT" name="PARENT_COUNT" type="xsd:unsignedInt"/>
            <xsd:element sql:field="TREE_OP" name="TREE_OP" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DEPTH" name="DEPTH" type="xsd:int" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sheri Nowmer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sheri Nowmer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>7</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[All Employees]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>1</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Derrick Whelply</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Derrick Whelply</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>3</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>2</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael Spence</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael Spence</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>2</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>2</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Maya Gutierrez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Maya Gutierrez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>9</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>2</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Roberta Damstra</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Roberta Damstra]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Roberta Damstra</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>4</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>2</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rebecca Kanagaki</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Rebecca Kanagaki]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rebecca Kanagaki</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>2</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>2</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Darren Stanz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Darren Stanz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>8</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>2</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Donna Arnold</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Donna Arnold]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Donna Arnold</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>2</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>2</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Beverly Baker</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Beverly Baker</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>2</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Pedro Castillo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Pedro Castillo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>4</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Laurie Borges</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Laurie Borges</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>7</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Daniel Wolter</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Daniel Wolter</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dianne Collins</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dianne Collins</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kim Brunner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kim Brunner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brenda Blumberg</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brenda Blumberg</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jonathan Murraiin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jonathan Murraiin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jewel Creek</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jewel Creek]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jewel Creek</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Peggy Medina</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Peggy Medina</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bryan Rutledge</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bryan Rutledge</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Walter Cavestany</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Walter Cavestany</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Peggy Planck</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Peggy Planck</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brenda Marshall</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brenda Marshall</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jennifer Cooper</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Roberta Damstra].[Jennifer Cooper]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jennifer Cooper</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Roberta Damstra]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Peggy Petty</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Roberta Damstra].[Peggy Petty]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Peggy Petty</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Roberta Damstra]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jessica Olguin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Roberta Damstra].[Jessica Olguin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jessica Olguin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Roberta Damstra]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Phyllis Burchett</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Roberta Damstra].[Phyllis Burchett]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Phyllis Burchett</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Roberta Damstra]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Juanita Sharp</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Rebecca Kanagaki].[Juanita Sharp]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Juanita Sharp</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Rebecca Kanagaki]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sandra Brunner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Rebecca Kanagaki].[Sandra Brunner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sandra Brunner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Rebecca Kanagaki]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Donna Carreras</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Donna Carreras</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>9</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Wayne Banack</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Wayne Banack</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ernest Staton</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz].[Ernest Staton]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ernest Staton</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rose Sims</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz].[Rose Sims]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rose Sims</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lauretta De Carlo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz].[Lauretta De Carlo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lauretta De Carlo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Williams</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz].[Mary Williams]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Williams</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Terri Burke</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz].[Terri Burke]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Terri Burke</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Audrey Osborn</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz].[Audrey Osborn]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Audrey Osborn</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brian Binai</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz].[Brian Binai]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brian Binai</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Concepcion Lozada</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz].[Concepcion Lozada]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Concepcion Lozada</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Darren Stanz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Thompson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Thompson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Leda Witte</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jewel Creek].[Leda Witte]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Leda Witte</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>2</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jewel Creek]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Roberta Sturgel</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Roberta Sturgel</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>J. Scott Blauvelt</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>J. Scott Blauvelt</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Monita Heyer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Monita Heyer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>David Johnson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>David Johnson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jeanette Belsey</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jeanette Belsey</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>9</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael John Troyer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael John Troyer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lawrence Hurkett</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lawrence Hurkett</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>9</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shauna Wyro</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Shauna Wyro]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shauna Wyro</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jacqueline Wyllie</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jacqueline Wyllie</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lin Conley</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lin Conley</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jose Bernard</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jose Bernard</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Charles Macaluso</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Charles Macaluso</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lois Wood</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lois Wood</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kevin Armstrong</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Kevin Armstrong]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kevin Armstrong</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cody Goldey</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cody Goldey</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Paula Nickell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Paula Nickell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eric Long</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eric Long</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Solimena</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Solimena</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nathan Muenich</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Nathan Muenich]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nathan Muenich</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ed Young</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ed Young</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>1</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>4</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bunny McCown</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Shauna Wyro].[Bunny McCown]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bunny McCown</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>2</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Shauna Wyro]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ralph Mccoy</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ralph Mccoy</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Paul Tays</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Paul Tays</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Hunt</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Hunt</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Barbara Wallin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Barbara Wallin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dell Gras</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dell Gras</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Danielle Johnson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Kevin Armstrong].[Danielle Johnson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Danielle Johnson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>2</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Kevin Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shanay Steelman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shanay Steelman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kristine Cleary</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kristine Cleary</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Adam Reynolds</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Adam Reynolds</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Matthew Hunter</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Matthew Hunter</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>6</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dick Brummer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Nathan Muenich].[Dick Brummer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dick Brummer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>2</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Nathan Muenich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gregory Whiting</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gregory Whiting</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>9</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Howard Bechard</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Donna Arnold].[Howard Bechard]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Howard Bechard</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Donna Arnold]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Doris Carter</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Donna Arnold].[Doris Carter]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Doris Carter</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Donna Arnold]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>3</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cheryl Thorton</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cheryl Thorton</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>16</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gary Dumin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gary Dumin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>12</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Pat Chin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Pat Chin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>12</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Zach Lovell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Zach Lovell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Zach Lovell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dave Ratcliff</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Dave Ratcliff]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dave Ratcliff</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Elizabeth Moss</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Elizabeth Moss]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Elizabeth Moss</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lori Anderson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Lori Anderson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lori Anderson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael Everson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Michael Everson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael Everson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Borden</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Mary Borden]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Borden</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sue Willson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Sue Willson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sue Willson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Leopoldo Renfro</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Leopoldo Renfro]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Leopoldo Renfro</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Donna Brockett</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Donna Brockett]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Donna Brockett</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Laurie Anderson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Laurie Anderson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Laurie Anderson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Louis Gomez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Louis Gomez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Louis Gomez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Melvin Glass</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Melvin Glass]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Melvin Glass</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kristin Cohen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Kristin Cohen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kristin Cohen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Susan Kharman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Susan Kharman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Susan Kharman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gordon Kirschner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Gordon Kirschner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gordon Kirschner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Geneva Kouba</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Geneva Kouba]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Geneva Kouba</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Tricia Clark</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Tricia Clark]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Tricia Clark</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Debi Munn</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Debi Munn]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Debi Munn</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Patricia Goldberg</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton].[Patricia Goldberg]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Patricia Goldberg</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Cheryl Thorton]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Clayton Harris</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin].[Clayton Harris]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Clayton Harris</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Whitney Contreras</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin].[Whitney Contreras]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Whitney Contreras</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Boyd Pusedu</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin].[Boyd Pusedu]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Boyd Pusedu</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Julie Walker</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin].[Julie Walker]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Julie Walker</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jay Jones</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin].[Jay Jones]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jay Jones</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gayle Winfrey</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin].[Gayle Winfrey]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gayle Winfrey</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>William Burger</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin].[William Burger]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>William Burger</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lana Blau</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin].[Lana Blau]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lana Blau</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Donna Derby</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin].[Donna Derby]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Donna Derby</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Susan Magenheim</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin].[Susan Magenheim]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Susan Magenheim</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nancy Hance</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin].[Nancy Hance]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nancy Hance</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rhonda Mehlert</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin].[Rhonda Mehlert]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rhonda Mehlert</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Gary Dumin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cian Stedman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin].[Cian Stedman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cian Stedman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michele Zocchi</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin].[Michele Zocchi]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michele Zocchi</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jean Walsh</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin].[Jean Walsh]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jean Walsh</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Yasmina Brown</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin].[Yasmina Brown]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Yasmina Brown</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joseph Touchstone</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin].[Joseph Touchstone]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joseph Touchstone</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Bakhtyari</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin].[Mary Bakhtyari]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Bakhtyari</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kathleen Thomson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin].[Kathleen Thomson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kathleen Thomson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gabriel Walton</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin].[Gabriel Walton]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gabriel Walton</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bishop Meastas</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin].[Bishop Meastas]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bishop Meastas</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Paula Duran</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin].[Paula Duran]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Paula Duran</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Margaret Earley</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin].[Margaret Earley]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Margaret Earley</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Elizabeth Horne</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin].[Elizabeth Horne]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Elizabeth Horne</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lin Conley].[Paul Tays].[Pat Chin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Libby Allen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Libby Allen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bonnie Bruno</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bonnie Bruno</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Angela Bowers</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Angela Bowers</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Donald Gonzales</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Donald Gonzales]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Donald Gonzales</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sylvester Valdez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Sylvester Valdez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sylvester Valdez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Stewart</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[John Stewart]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Stewart</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Barney Velasquez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Barney Velasquez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Barney Velasquez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kenneth Dubois</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Kenneth Dubois]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kenneth Dubois</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kate Maestas</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Kate Maestas]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kate Maestas</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Josie Underwood</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Josie Underwood]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Josie Underwood</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Chris Barros</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Chris Barros]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Chris Barros</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Christopher Groome</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Christopher Groome]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Christopher Groome</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Anna Hill</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Anna Hill]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Anna Hill</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ramon Williams</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Ramon Williams]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ramon Williams</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Scott Masters</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Scott Masters]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Scott Masters</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shirley Wilbert</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Shirley Wilbert]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shirley Wilbert</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jeremy Ingram</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Jeremy Ingram]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jeremy Ingram</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sharon Haddix</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Sharon Haddix]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sharon Haddix</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Leland Thomas</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Leland Thomas]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Leland Thomas</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Chad Neuhauser</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Chad Neuhauser]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Chad Neuhauser</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ann Coke</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Ann Coke]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ann Coke</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jon Scarbrough</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Jon Scarbrough]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jon Scarbrough</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lillian Martensen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Lillian Martensen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lillian Martensen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary McCormick</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen].[Mary McCormick]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary McCormick</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Libby Allen]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ramon Strain</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Ramon Strain]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ramon Strain</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Pat Azari</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Pat Azari]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Pat Azari</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bob Dabit</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Bob Dabit]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bob Dabit</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marty Carmona</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Marty Carmona]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marty Carmona</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joseph Brady, Jr.</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Joseph Brady, Jr.]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joseph Brady, Jr.</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ellen Gray</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Ellen Gray]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ellen Gray</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Henry Fielder</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Henry Fielder]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Henry Fielder</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jeanine Finnell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Jeanine Finnell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jeanine Finnell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ian Schuetz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Ian Schuetz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ian Schuetz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Don Wilson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Don Wilson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Don Wilson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Wayne Stovall</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Wayne Stovall]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Wayne Stovall</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Douglas Russell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Douglas Russell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Douglas Russell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Maureen Doose</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Maureen Doose]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Maureen Doose</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Sparacino</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[James Sparacino]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Sparacino</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Racette</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[John Racette]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Racette</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Edwardo Thompson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Edwardo Thompson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Edwardo Thompson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sam Warren</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Sam Warren]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sam Warren</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shelby Chow-Wang</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno].[Shelby Chow-Wang]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shelby Chow-Wang</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Bonnie Bruno]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gina Saxton</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Gina Saxton]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gina Saxton</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Juan McLaughlin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Juan McLaughlin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Juan McLaughlin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carol Eyster</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Carol Eyster]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carol Eyster</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nancy Henry</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Nancy Henry]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nancy Henry</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Richard Runyon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Richard Runyon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Richard Runyon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Linda Potter</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Linda Potter]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Linda Potter</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Smith</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Mary Smith]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Smith</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Barbara Brumagen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Barbara Brumagen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Barbara Brumagen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Thelma Hamilton</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Thelma Hamilton]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Thelma Hamilton</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ann Morreale</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Ann Morreale]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ann Morreale</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sheila Rupert</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Sheila Rupert]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sheila Rupert</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ashley Pierson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Ashley Pierson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ashley Pierson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ivan Nickels</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Ivan Nickels]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ivan Nickels</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nelly Wood</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Nelly Wood]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nelly Wood</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jackie Morgan</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Jackie Morgan]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jackie Morgan</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gavin Boje</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Gavin Boje]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gavin Boje</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marlene Tsujimoto</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[Marlene Tsujimoto]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marlene Tsujimoto</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>RitaIva Bouton</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers].[RitaIva Bouton]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>RitaIva Bouton</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Jose Bernard].[Mary Hunt].[Angela Bowers]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Christopher Solano</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Christopher Solano</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>George Armstrong</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>George Armstrong</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kristine Aldred</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kristine Aldred</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Tom Jorgenson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Tom Jorgenson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Tom Jorgenson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dana Turner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Dana Turner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dana Turner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Terry Zakerski</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Terry Zakerski]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Terry Zakerski</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>David Carlson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[David Carlson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>David Carlson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Linda Symons</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Linda Symons]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Linda Symons</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Louis Reynolds</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Louis Reynolds]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Louis Reynolds</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Maureen Ibsen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Maureen Ibsen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Maureen Ibsen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Vicky Zingarelli</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Vicky Zingarelli]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Vicky Zingarelli</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Helen Valentine</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Helen Valentine]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Helen Valentine</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carol Scheulen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Carol Scheulen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carol Scheulen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Virgie Koon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Virgie Koon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Virgie Koon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sarah Amole</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Sarah Amole]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sarah Amole</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Loni Sosa</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Loni Sosa]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Loni Sosa</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marie Mann</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Marie Mann]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marie Mann</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael Prater</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Michael Prater]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael Prater</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Karen Ansaldo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Karen Ansaldo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Karen Ansaldo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Hall</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Mary Hall]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Hall</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rachel Minarick</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Rachel Minarick]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rachel Minarick</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dorine Los Olmos</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Dorine Los Olmos]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dorine Los Olmos</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dave Garner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Dave Garner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dave Garner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lois Leong</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano].[Lois Leong]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lois Leong</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Christopher Solano]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Virginia Ciochon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Virginia Ciochon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Virginia Ciochon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Steve Berger</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Steve Berger]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Steve Berger</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Bayol</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[James Bayol]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Bayol</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Meredith Thumann</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Meredith Thumann]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Meredith Thumann</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cecil Hill</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Cecil Hill]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cecil Hill</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ruth Tate</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Ruth Tate]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ruth Tate</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Larry Schnurr</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Larry Schnurr]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Larry Schnurr</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jerry Sutton</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Jerry Sutton]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jerry Sutton</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kevin Mlincek</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Kevin Mlincek]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kevin Mlincek</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lance Caijem</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Lance Caijem]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lance Caijem</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Pamela Yates</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Pamela Yates]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Pamela Yates</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Iwona Turner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Iwona Turner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Iwona Turner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Fulcher</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Mary Fulcher]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Fulcher</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Larasa Tate</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Larasa Tate]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Larasa Tate</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>David Watson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[David Watson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>David Watson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Frank</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[James Frank]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Frank</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Alfredo Wood</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Alfredo Wood]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Alfredo Wood</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dorothy Baird</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong].[Dorothy Baird]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dorothy Baird</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[George Armstrong]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Julie Jones</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Julie Jones]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Julie Jones</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Janet Bury</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Janet Bury]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Janet Bury</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Onita Bevan</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Onita Bevan]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Onita Bevan</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Monarco</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Mary Monarco]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Monarco</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Edward Tucker</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Edward Tucker]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Edward Tucker</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kenton Forham</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Kenton Forham]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kenton Forham</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brittany Malik</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Brittany Malik]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brittany Malik</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jeannette Eldridge</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Jeannette Eldridge]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jeannette Eldridge</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Terry Anderson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Terry Anderson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Terry Anderson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Raymond Berg</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Raymond Berg]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Raymond Berg</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ramona Lopez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Ramona Lopez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ramona Lopez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Helen Valdivia</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Helen Valdivia]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Helen Valdivia</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Beverly Cardoza</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Beverly Cardoza]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Beverly Cardoza</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>George Jans</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[George Jans]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>George Jans</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bernadine Garrison</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Bernadine Garrison]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bernadine Garrison</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sam Zeller</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Sam Zeller]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sam Zeller</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dorothy Ace</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Dorothy Ace]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dorothy Ace</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Adria Trujillo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred].[Adria Trujillo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Adria Trujillo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Lois Wood].[Dell Gras].[Kristine Aldred]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nancy Miller</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Shauna Wyro].[Bunny McCown].[Nancy Miller]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nancy Miller</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Shauna Wyro].[Bunny McCown]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Wanda Hollar</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Shauna Wyro].[Bunny McCown].[Wanda Hollar]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Wanda Hollar</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Shauna Wyro].[Bunny McCown]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael Bruha</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael Bruha</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael Suggs</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael Suggs</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kenneth Turner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kenneth Turner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lois Griffin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Lois Griffin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lois Griffin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Robert Guardamondo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Robert Guardamondo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Robert Guardamondo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bryan West</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Bryan West]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bryan West</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Vicki Welsh</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Vicki Welsh]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Vicki Welsh</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Harvey McCollum</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Harvey McCollum]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Harvey McCollum</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Cramer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Mary Cramer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Cramer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Linda Fike</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Linda Fike]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Linda Fike</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Max Lyons</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Max Lyons]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Max Lyons</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Christine Sandy Kurtz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Christine Sandy Kurtz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Christine Sandy Kurtz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rita Santry</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Rita Santry]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rita Santry</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Catherine Quigle</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Catherine Quigle]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Catherine Quigle</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Patricia Christensen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Patricia Christensen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Patricia Christensen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sarah Jimenez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Sarah Jimenez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sarah Jimenez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Darwin Malaby</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Darwin Malaby]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Darwin Malaby</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Pamela Caldwell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Pamela Caldwell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Pamela Caldwell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Roger Tinder</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Roger Tinder]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Roger Tinder</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lee Whitcomb</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Lee Whitcomb]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lee Whitcomb</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brian Turcios</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Brian Turcios]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brian Turcios</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jennifer Confetti</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Jennifer Confetti]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jennifer Confetti</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Geneva Takemura</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Geneva Takemura]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Geneva Takemura</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lynn Campbell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha].[Lynn Campbell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lynn Campbell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Bruha]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sam Adair</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Sam Adair]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sam Adair</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jerry Kolosso</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Jerry Kolosso]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jerry Kolosso</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Todd Carpenter</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Todd Carpenter]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Todd Carpenter</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lisa Watkins</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Lisa Watkins]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lisa Watkins</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Anne Mercurio</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Anne Mercurio]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Anne Mercurio</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Louis McGrath</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Louis McGrath]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Louis McGrath</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rachael Wright</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Rachael Wright]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rachael Wright</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Richard Skuce</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Richard Skuce]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Richard Skuce</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>George Coleman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[George Coleman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>George Coleman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joseph Kropff</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Joseph Kropff]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joseph Kropff</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mimi Worsham</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Mimi Worsham]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mimi Worsham</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ruth Bernal</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Ruth Bernal]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ruth Bernal</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Yolanda Zimmerman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Yolanda Zimmerman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Yolanda Zimmerman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nina Smith</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Nina Smith]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nina Smith</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Darrell Vuong</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Darrell Vuong]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Darrell Vuong</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eric Abbott</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Eric Abbott]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eric Abbott</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Doris Liff</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[Doris Liff]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Doris Liff</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Steinberg</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs].[John Steinberg]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Steinberg</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Michael Suggs]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kevin Barrera</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Kevin Barrera]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kevin Barrera</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Maria Price</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Maria Price]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Maria Price</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Flossie Rosemont</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Flossie Rosemont]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Flossie Rosemont</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Betty McMenama</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Betty McMenama]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Betty McMenama</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lois Barnes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Lois Barnes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lois Barnes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jacky Camille</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Jacky Camille]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jacky Camille</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michelle Allenbach</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Michelle Allenbach]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michelle Allenbach</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Franklin Smith</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Franklin Smith]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Franklin Smith</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Minker</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[John Minker]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Minker</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sandra Evans</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Sandra Evans]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sandra Evans</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Virginia Bowman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Virginia Bowman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Virginia Bowman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Coleman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Mary Coleman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Coleman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kevin Chrisulis</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Kevin Chrisulis]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kevin Chrisulis</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jerry Megel</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Jerry Megel]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jerry Megel</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Styles</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[John Styles]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Styles</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shirley Head</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Shirley Head]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shirley Head</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Story</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[James Story]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Story</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jean Boone</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner].[Jean Boone]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jean Boone</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Pedro Castillo].[Charles Macaluso].[Barbara Wallin].[Kenneth Turner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Anne Tuck</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Anne Tuck</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joy Sincich</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joy Sincich</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bertha Jameson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bertha Jameson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Charles Sanchez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Charles Sanchez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Charles Sanchez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Wanda Parks</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Wanda Parks]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Wanda Parks</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nathan Vij</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Nathan Vij]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nathan Vij</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Corinne Zugschwert</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Corinne Zugschwert]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Corinne Zugschwert</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michelle Adams</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Michelle Adams]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michelle Adams</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Donahue Steen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Donahue Steen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Donahue Steen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Baker</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[John Baker]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Baker</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Keith Pearl</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Keith Pearl]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Keith Pearl</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Pat Chambers</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Pat Chambers]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Pat Chambers</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Stanley Bellifa</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Stanley Bellifa]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Stanley Bellifa</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Samuel Johnson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Samuel Johnson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Samuel Johnson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Janice Vrins</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Janice Vrins]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Janice Vrins</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Christinia Mcdonald</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Christinia Mcdonald]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Christinia Mcdonald</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ole Weldon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Ole Weldon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ole Weldon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ian Yuhasz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Ian Yuhasz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ian Yuhasz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jovita Carmody</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Jovita Carmody]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jovita Carmody</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lynn Gonzales</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Lynn Gonzales]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lynn Gonzales</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Phyllis Allen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Phyllis Allen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Phyllis Allen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Johnny Caprio</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Johnny Caprio]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Johnny Caprio</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Haugh</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[James Haugh]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Haugh</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Paula Moberly</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Paula Moberly]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Paula Moberly</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eric Meyer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Eric Meyer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eric Meyer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gloria Orona</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Gloria Orona]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gloria Orona</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ruth Warmack</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Ruth Warmack]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ruth Warmack</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joanna Wall</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck].[Joanna Wall]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joanna Wall</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Anne Tuck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sarah Roundtree</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Sarah Roundtree]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sarah Roundtree</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lawrence Bollin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Lawrence Bollin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lawrence Bollin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Fred Hopkins</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Fred Hopkins]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Fred Hopkins</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Caroline Vicknair</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Caroline Vicknair]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Caroline Vicknair</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nancy McPhearson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Nancy McPhearson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nancy McPhearson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ruth Choin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Ruth Choin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ruth Choin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sharon Crow</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Sharon Crow]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sharon Crow</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Robert Avalos</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Robert Avalos]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Robert Avalos</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eric Jacobsen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Eric Jacobsen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eric Jacobsen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Pamela Castro</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Pamela Castro]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Pamela Castro</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sylvia Caldwell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Sylvia Caldwell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sylvia Caldwell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lanna Slaven</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Lanna Slaven]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lanna Slaven</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Fred Ortiz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Fred Ortiz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Fred Ortiz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Beaver</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[John Beaver]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Beaver</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Albert Rhodes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Albert Rhodes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Albert Rhodes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Scott Kaffer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Scott Kaffer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Scott Kaffer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sabria Appelbaum</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Sabria Appelbaum]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sabria Appelbaum</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jeffrey Kung</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Jeffrey Kung]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jeffrey Kung</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gloria Wilson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Gloria Wilson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gloria Wilson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Phyllis Tuffield</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Phyllis Tuffield]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Phyllis Tuffield</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Patricia Ping</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[Patricia Ping]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Patricia Ping</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>David Shepard</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich].[David Shepard]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>David Shepard</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Joy Sincich]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Anna Albright</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Anna Albright]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Anna Albright</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Phyllis Thomas</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Phyllis Thomas]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Phyllis Thomas</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Tina Perko</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Tina Perko]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Tina Perko</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jane McCarty</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Jane McCarty]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jane McCarty</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Scot Bent</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Scot Bent]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Scot Bent</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Russell Reed</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Russell Reed]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Russell Reed</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Victor Kelley</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Victor Kelley]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Victor Kelley</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Damon Taylor</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Damon Taylor]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Damon Taylor</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rebecca Robinson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Rebecca Robinson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rebecca Robinson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Andrea Thomsen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Andrea Thomsen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Andrea Thomsen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Douglas Baldwin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Douglas Baldwin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Douglas Baldwin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jennifer Bales</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Jennifer Bales]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jennifer Bales</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Louis Stotka</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Louis Stotka]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Louis Stotka</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sandra Maynard</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Sandra Maynard]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sandra Maynard</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gracia Tuell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Gracia Tuell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gracia Tuell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Timothy Burnett</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Timothy Burnett]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Timothy Burnett</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Bailey</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[James Bailey]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Bailey</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Susan Chestnut</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Susan Chestnut]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Susan Chestnut</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Delia Toone</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Delia Toone]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Delia Toone</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Thomas Armstrong</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Thomas Armstrong]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Thomas Armstrong</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Billstrom</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Mary Billstrom]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Billstrom</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Robert Stotka</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson].[Robert Stotka]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Robert Stotka</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Beverly Baker].[Jacqueline Wyllie].[Ralph Mccoy].[Bertha Jameson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bonnie Lepro</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Kevin Armstrong].[Danielle Johnson].[Bonnie Lepro]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bonnie Lepro</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Kevin Armstrong].[Danielle Johnson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carol Elliott</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Kevin Armstrong].[Danielle Johnson].[Carol Elliott]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carol Elliott</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Kevin Armstrong].[Danielle Johnson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Frances Adams</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Frances Adams</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Alma Poorbaugh</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Alma Poorbaugh</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Neal Hasty</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Neal Hasty</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Steven Betsekas</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Steven Betsekas]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Steven Betsekas</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Arvid Ziegler</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Arvid Ziegler]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Arvid Ziegler</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ann Weyerhaeuser</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Ann Weyerhaeuser]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ann Weyerhaeuser</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dorothy Robinson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[Dorothy Robinson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dorothy Robinson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>June Brunner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[June Brunner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>June Brunner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Judith Frazier</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[Judith Frazier]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Judith Frazier</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michelle Rector</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[Michelle Rector]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michelle Rector</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Alice Kesterson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[Alice Kesterson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Alice Kesterson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>J. Phillip Alexander</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[J. Phillip Alexander]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>J. Phillip Alexander</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>R. Morgan Mendoza</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[R. Morgan Mendoza]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>R. Morgan Mendoza</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Pam Herrick</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[Pam Herrick]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Pam Herrick</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James McCoy</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[James McCoy]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James McCoy</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Barbara Sipsy</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[Barbara Sipsy]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Barbara Sipsy</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dorothy Weimer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[Dorothy Weimer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dorothy Weimer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Richard Irwin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[Richard Irwin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Richard Irwin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Alma Son</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[Alma Son]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Alma Son</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>David Givens</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[David Givens]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>David Givens</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Glenna Beanston</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[Glenna Beanston]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Glenna Beanston</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dirk Bruno</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[Dirk Bruno]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dirk Bruno</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Alexander Berger</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[Alexander Berger]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Alexander Berger</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marcia Sultan</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams].[Marcia Sultan]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marcia Sultan</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Frances Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mari Caldwell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Mari Caldwell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mari Caldwell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Linda Gonzales</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Linda Gonzales]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Linda Gonzales</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Alan Monitor</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Alan Monitor]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Alan Monitor</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Elsie Lewin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Elsie Lewin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Elsie Lewin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rossane Thoreson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Rossane Thoreson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rossane Thoreson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Victoria Snowden</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Victoria Snowden]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Victoria Snowden</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Donald Blanton</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Donald Blanton]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Donald Blanton</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cornett Gibbens</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Cornett Gibbens]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cornett Gibbens</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Paul Alcorn</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Paul Alcorn]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Paul Alcorn</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cornelius Brandon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Cornelius Brandon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cornelius Brandon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Monica Quintana</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Monica Quintana]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Monica Quintana</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Colon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[John Colon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Colon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brenda Barlow</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Brenda Barlow]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brenda Barlow</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Martin Svoboda</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Martin Svoboda]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Martin Svoboda</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Tullao</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Mary Tullao]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Tullao</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Irene Hernandez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Irene Hernandez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Irene Hernandez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jay Saxema Wilkie</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Jay Saxema Wilkie]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jay Saxema Wilkie</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sean Lunt</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh].[Sean Lunt]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sean Lunt</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Alma Poorbaugh]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bev Desalvo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Bev Desalvo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bev Desalvo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Oscar Alpuerto</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Oscar Alpuerto]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Oscar Alpuerto</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cecelia Marshall</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Cecelia Marshall]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cecelia Marshall</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gabriel Bockenkamp</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Gabriel Bockenkamp]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gabriel Bockenkamp</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Virginia Miller</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Virginia Miller]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Virginia Miller</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Henry Campen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Henry Campen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Henry Campen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Connie Coffman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Connie Coffman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Connie Coffman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jared Bustamante</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Jared Bustamante]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jared Bustamante</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carla Eldridge</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Carla Eldridge]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carla Eldridge</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ronald Adina</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Ronald Adina]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ronald Adina</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael Bohling</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Michael Bohling]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael Bohling</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sam Wheeler</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Sam Wheeler]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sam Wheeler</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Abraham Swearengin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Abraham Swearengin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Abraham Swearengin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Paul Fulton</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Paul Fulton]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Paul Fulton</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rudolph Dillon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Rudolph Dillon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rudolph Dillon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Matthew Miller</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Matthew Miller]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Matthew Miller</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Vassar Stern</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Vassar Stern]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Vassar Stern</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ruth Suffin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty].[Ruth Suffin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ruth Suffin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Cody Goldey].[Shanay Steelman].[Neal Hasty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jaunita Homax</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jaunita Homax</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Margaret Adams</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Margaret Adams</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carla Zubaty</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carla Zubaty</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Tammy Khan</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Tammy Khan]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Tammy Khan</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>David Brinkd</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[David Brinkd]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>David Brinkd</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Clark</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[James Clark]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Clark</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Helen Dennis</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Helen Dennis]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Helen Dennis</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eric Brumfield</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Eric Brumfield]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eric Brumfield</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Madalena Sanchez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Madalena Sanchez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Madalena Sanchez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gary Suess</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Gary Suess]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gary Suess</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>David Byrnes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[David Byrnes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>David Byrnes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Justine Ryan</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Justine Ryan]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Justine Ryan</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Forrest Chand</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Forrest Chand]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Forrest Chand</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Margaret Vanderkamp</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Margaret Vanderkamp]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Margaret Vanderkamp</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rosmarie Carroll</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Rosmarie Carroll]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rosmarie Carroll</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ethel Porter</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Ethel Porter]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ethel Porter</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gloria Lesko</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Gloria Lesko]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gloria Lesko</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael Worland</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Michael Worland]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael Worland</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Alvin Torre</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Alvin Torre]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Alvin Torre</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Doris Traube</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Doris Traube]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Doris Traube</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cathy Sloan</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Cathy Sloan]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cathy Sloan</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Homer Villa</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Homer Villa]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Homer Villa</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Deena Herman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Deena Herman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Deena Herman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Leota Roberts</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax].[Leota Roberts]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Leota Roberts</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Jaunita Homax]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Glenn Trach</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Glenn Trach]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Glenn Trach</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cynthia White</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Cynthia White]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cynthia White</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Walter Brian</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Walter Brian]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Walter Brian</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Christie Trujillo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Christie Trujillo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Christie Trujillo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dorothy Contreras</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Dorothy Contreras]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dorothy Contreras</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joseph Cantoni</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Joseph Cantoni]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joseph Cantoni</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Celine Reed</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Celine Reed]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Celine Reed</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Glin Peterson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Glin Peterson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Glin Peterson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Stephen Osborn</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Stephen Osborn]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Stephen Osborn</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Susan Ramos</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Susan Ramos]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Susan Ramos</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jill Christie</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Jill Christie]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jill Christie</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Juanita Zocchi</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Juanita Zocchi]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Juanita Zocchi</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sandra Altamirano</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Sandra Altamirano]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sandra Altamirano</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Mc Clane</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[John Mc Clane]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Mc Clane</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jennifer Maxham</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Jennifer Maxham]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jennifer Maxham</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Elizabeth Sullivan</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Elizabeth Sullivan]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Elizabeth Sullivan</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Irene Watada</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Irene Watada]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Irene Watada</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Constance Rhiger</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams].[Constance Rhiger]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Constance Rhiger</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Margaret Adams]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lili Alameda</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Lili Alameda]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lili Alameda</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dorothy Fox</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Dorothy Fox]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dorothy Fox</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Aldeen Gallagher</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Aldeen Gallagher]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Aldeen Gallagher</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dorothy Myer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Dorothy Myer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dorothy Myer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lowell Graham.</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Lowell Graham.]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lowell Graham.</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jamie Shaddy</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Jamie Shaddy]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jamie Shaddy</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Hattie Haemon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Hattie Haemon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Hattie Haemon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jame Krow</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Jame Krow]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jame Krow</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shane Belli</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Shane Belli]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shane Belli</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Edna Benson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Edna Benson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Edna Benson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Alexander Deborde</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Alexander Deborde]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Alexander Deborde</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Barbara Calone</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Barbara Calone]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Barbara Calone</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cheryl Pompa</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Cheryl Pompa]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cheryl Pompa</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rhoda Finley</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Rhoda Finley]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rhoda Finley</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kathleen Winter</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Kathleen Winter]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kathleen Winter</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carla Adams</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Carla Adams]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carla Adams</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Vanessa Tench</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Vanessa Tench]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Vanessa Tench</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carol Brink</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty].[Carol Brink]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carol Brink</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Paula Nickell].[Kristine Cleary].[Carla Zubaty]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Constance Posner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Constance Posner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>William Hapke</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>William Hapke</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joshua Huff</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joshua Huff</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carolee Brown</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Carolee Brown]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carolee Brown</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Frances Giglio</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Frances Giglio]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Frances Giglio</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Irma Sherwood</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Irma Sherwood]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Irma Sherwood</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Benjamin Becker</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Benjamin Becker]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Benjamin Becker</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Chad Tedford</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Chad Tedford]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Chad Tedford</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Luke Roy</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Luke Roy]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Luke Roy</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jean Holloway</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Jean Holloway]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jean Holloway</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Charlene Wojcik</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Charlene Wojcik]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Charlene Wojcik</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eunice Wolf</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Eunice Wolf]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eunice Wolf</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kelly Whitworth</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Kelly Whitworth]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kelly Whitworth</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Judy Thames</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Judy Thames]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Judy Thames</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Pearlie Rusek</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Pearlie Rusek]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Pearlie Rusek</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lee Chapla</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Lee Chapla]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lee Chapla</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>DeeDee Cameron</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[DeeDee Cameron]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>DeeDee Cameron</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jo Zgeirmann</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Jo Zgeirmann]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jo Zgeirmann</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>William Mondragon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[William Mondragon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>William Mondragon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael Lee</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Michael Lee]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael Lee</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Walter Maes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Walter Maes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Walter Maes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ramona Antrim</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Ramona Antrim]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ramona Antrim</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Liam Friedland</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Liam Friedland]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Liam Friedland</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Charles Strange</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner].[Charles Strange]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Charles Strange</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Constance Posner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Olga Trau</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Olga Trau]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Olga Trau</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Steve Carnes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Steve Carnes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Steve Carnes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Betty Potts</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Betty Potts]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Betty Potts</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Edward Kozlowski</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Edward Kozlowski]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Edward Kozlowski</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Peggy Justice</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Peggy Justice]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Peggy Justice</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>William Conner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[William Conner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>William Conner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ciro Bauer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Ciro Bauer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ciro Bauer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Takiko Collins</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Takiko Collins]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Takiko Collins</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Leonard Smith</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Leonard Smith]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Leonard Smith</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cecil Allison</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Cecil Allison]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cecil Allison</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nieves Vargas</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Nieves Vargas]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nieves Vargas</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Helen Vlass</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Helen Vlass]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Helen Vlass</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Abigail Gonzalez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Abigail Gonzalez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Abigail Gonzalez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>William Richter</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[William Richter]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>William Richter</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Maxwell Amland</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Maxwell Amland]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Maxwell Amland</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Z . T.  Milton Albury</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Z . T.  Milton Albury]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Z . T.  Milton Albury</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marie Richmeier</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Marie Richmeier]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marie Richmeier</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jodan Jacobson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke].[Jodan Jacobson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jodan Jacobson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[William Hapke]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sharon Looney</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Sharon Looney]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sharon Looney</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Patrick Magenheimer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Patrick Magenheimer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Patrick Magenheimer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sue Hofsetz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Sue Hofsetz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sue Hofsetz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Janet Gilliat</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Janet Gilliat]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Janet Gilliat</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lenore Yasi</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Lenore Yasi]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lenore Yasi</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lester Bowman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Lester Bowman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lester Bowman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Barbara Germanson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Barbara Germanson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Barbara Germanson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Smith</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Mary Smith]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Smith</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Alice Serventi</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Alice Serventi]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Alice Serventi</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Denean Ison</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Denean Ison]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Denean Ison</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Billy Trent</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Billy Trent]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Billy Trent</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Vaca</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Mary Vaca]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Vaca</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kyley Arbelaez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Kyley Arbelaez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kyley Arbelaez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>David Bartness</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[David Bartness]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>David Bartness</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Teanna Cobb</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Teanna Cobb]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Teanna Cobb</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>M. E. Joseph Lique</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[M. E. Joseph Lique]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>M. E. Joseph Lique</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Robert Bernacchi</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Robert Bernacchi]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Robert Bernacchi</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Patricia Zubaty</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff].[Patricia Zubaty]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Patricia Zubaty</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Eric Long].[Adam Reynolds].[Joshua Huff]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Florence Vonholt</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Florence Vonholt</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eddie Holmes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eddie Holmes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gerald Drury</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gerald Drury</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kristin Watts</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Kristin Watts]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kristin Watts</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carlos Short</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Carlos Short]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carlos Short</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Robin Mc Guigan</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Robin Mc Guigan]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Robin Mc Guigan</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dorothy Wollesen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Dorothy Wollesen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dorothy Wollesen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marjorie Lee</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Marjorie Lee]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marjorie Lee</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Gimmi</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Mary Gimmi]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Gimmi</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Milton Pugh</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Milton Pugh]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Milton Pugh</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Bennetts</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[John Bennetts]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Bennetts</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Charles Christensen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Charles Christensen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Charles Christensen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Darrell Banks</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Darrell Banks]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Darrell Banks</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carlton Carlisle</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Carlton Carlisle]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carlton Carlisle</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Abe Tramel</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Abe Tramel]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Abe Tramel</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jose Curry</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Jose Curry]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jose Curry</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Betty Haines</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Betty Haines]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Betty Haines</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rose Vandenouer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Rose Vandenouer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rose Vandenouer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eric Vincenzi</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Eric Vincenzi]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eric Vincenzi</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cheryl Herring</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Cheryl Herring]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cheryl Herring</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kathleen Garza</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Kathleen Garza]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kathleen Garza</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gail Westover</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Gail Westover]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gail Westover</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Pamala Kotc</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Pamala Kotc]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Pamala Kotc</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marlin Coriell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Marlin Coriell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marlin Coriell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Clay Warthen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Clay Warthen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Clay Warthen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Greg Johnson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Greg Johnson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Greg Johnson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>George Huckaby</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[George Huckaby]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>George Huckaby</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Faith Gustafson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt].[Faith Gustafson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Faith Gustafson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Florence Vonholt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Caroline Woodard</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Caroline Woodard]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Caroline Woodard</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Tomas Manzanares</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Tomas Manzanares]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Tomas Manzanares</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kayla Stotler</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Kayla Stotler]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kayla Stotler</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Elizabeth Peoples</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Elizabeth Peoples]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Elizabeth Peoples</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mike Choi</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Mike Choi]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mike Choi</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Deborah Campbell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Deborah Campbell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Deborah Campbell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Catherine Whitney</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Catherine Whitney]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Catherine Whitney</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Neva Mitchell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Neva Mitchell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Neva Mitchell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cindy Dodd</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Cindy Dodd]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cindy Dodd</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Stacey Cereghino</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Stacey Cereghino]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Stacey Cereghino</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Helen Meyer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Helen Meyer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Helen Meyer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Matthew Hagemann</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Matthew Hagemann]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Matthew Hagemann</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Patricia Vasquez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Patricia Vasquez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Patricia Vasquez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lola McCarthy</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Lola McCarthy]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lola McCarthy</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Phillip Bacalzo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Phillip Bacalzo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Phillip Bacalzo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marian Berch</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Marian Berch]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marian Berch</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Donald Thompson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Donald Thompson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Donald Thompson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Valentina Hendricks</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Valentina Hendricks]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Valentina Hendricks</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mae Black</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Mae Black]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mae Black</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carlos Vansant</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Carlos Vansant]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carlos Vansant</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Richard Bentley</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Richard Bentley]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Richard Bentley</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Thomas Ritacco</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes].[Thomas Ritacco]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Thomas Ritacco</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Eddie Holmes]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Lou Quintana</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Mary Lou Quintana]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Lou Quintana</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Christopher Bright</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Christopher Bright]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Christopher Bright</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Scott Rodgers</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Scott Rodgers]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Scott Rodgers</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Janet Gates</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Janet Gates]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Janet Gates</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Darren Watkins</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Darren Watkins]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Darren Watkins</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Olga Stevens</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Olga Stevens]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Olga Stevens</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joan Campbell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Joan Campbell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joan Campbell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Silvia Walker</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Silvia Walker]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Silvia Walker</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mosha Pasumansky</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Mosha Pasumansky]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mosha Pasumansky</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shawn Whitney</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Shawn Whitney]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shawn Whitney</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lloyd Saunders</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Lloyd Saunders]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lloyd Saunders</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mike Taylor</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Mike Taylor]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mike Taylor</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Vivian Whipple</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Vivian Whipple]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Vivian Whipple</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cecilia Laursen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Cecilia Laursen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cecilia Laursen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lee Olguin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Lee Olguin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lee Olguin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Stephen Ayers</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Stephen Ayers]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Stephen Ayers</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Karen Theisen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Karen Theisen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Karen Theisen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Berger</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[John Berger]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Berger</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joy Koski</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Joy Koski]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joy Koski</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Duane Fitzgerald</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Duane Fitzgerald]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Duane Fitzgerald</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lindsey Camacho</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Lindsey Camacho]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lindsey Camacho</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Selena Alvarado</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury].[Selena Alvarado]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Selena Alvarado</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Mary Solimena].[Matthew Hunter].[Gerald Drury]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Pat Pinkston</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Nathan Muenich].[Dick Brummer].[Pat Pinkston]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Pat Pinkston</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Nathan Muenich].[Dick Brummer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kristin Spivey</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Nathan Muenich].[Dick Brummer].[Kristin Spivey]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kristin Spivey</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Nathan Muenich].[Dick Brummer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Martha Espinoza</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Martha Espinoza</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>8</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>David Robinett</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[David Robinett]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>David Robinett</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Judy Lundahl</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Judy Lundahl]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Judy Lundahl</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kathy Marcovecchio</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Kathy Marcovecchio]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kathy Marcovecchio</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Twanna Evans</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Twanna Evans]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Twanna Evans</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Deanna Buskirk</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Deanna Buskirk]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Deanna Buskirk</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Kesslep</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Mary Kesslep]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Kesslep</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Merrill Steel</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Merrill Steel]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Merrill Steel</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Melissa Marple</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Melissa Marple]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Melissa Marple</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shawn Demicell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza].[Shawn Demicell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shawn Demicell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Linda Rousey</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza].[Linda Rousey]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Linda Rousey</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Judy Storjohann</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza].[Judy Storjohann]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Judy Storjohann</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Denise Maccietto</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza].[Denise Maccietto]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Denise Maccietto</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Barbara Schultz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza].[Barbara Schultz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Barbara Schultz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kris Bergin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza].[Kris Bergin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kris Bergin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ann Evans</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza].[Ann Evans]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ann Evans</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shirley Bruner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza].[Shirley Bruner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shirley Bruner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Derrick Whelply].[Laurie Borges].[Ed Young].[Gregory Whiting].[Martha Espinoza]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>7</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Sandidge</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Sandidge</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Monk Skonnard</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Monk Skonnard</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Christopher Beck</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Christopher Beck</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Catherine Abel</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Catherine Abel]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Catherine Abel</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Emilo Miller</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Emilo Miller]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Emilo Miller</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Hazel Walker</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Hazel Walker]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Hazel Walker</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Brooks</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[John Brooks]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Brooks</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Todd Logan</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Todd Logan]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Todd Logan</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joshua Several</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Joshua Several]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joshua Several</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Thomas</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[James Thomas]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Thomas</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Robert Vessa</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Robert Vessa]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Robert Vessa</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bronson Jacobs</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Bronson Jacobs]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bronson Jacobs</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rebecca Barley</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Rebecca Barley]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rebecca Barley</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Emilio Alvaro</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Emilio Alvaro]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Emilio Alvaro</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Becky Waters</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Becky Waters]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Becky Waters</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>A. Joyce Jarvis</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[A. Joyce Jarvis]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>A. Joyce Jarvis</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ruby Sue Styles</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Ruby Sue Styles]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ruby Sue Styles</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lisa Roy</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Lisa Roy]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lisa Roy</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ingrid Burkhardt</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Ingrid Burkhardt]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ingrid Burkhardt</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Todd Whitney</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Todd Whitney]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Todd Whitney</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Barbara Wisnewski</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Barbara Wisnewski]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Barbara Wisnewski</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Karren Burkhardt</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Karren Burkhardt]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Karren Burkhardt</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Long</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[John Long]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Long</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Edwin Olenzek</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Edwin Olenzek]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Edwin Olenzek</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jessie Valerio</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Jessie Valerio]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jessie Valerio</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Robert Ahlering</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Robert Ahlering]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Robert Ahlering</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Megan Burke</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Megan Burke]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Megan Burke</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Karel Bates</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge].[Karel Bates]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Karel Bates</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Mary Sandidge]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Tran</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[James Tran]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Tran</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shelley Crow</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Shelley Crow]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shelley Crow</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Anne Sims</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Anne Sims]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Anne Sims</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Clarence Tatman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Clarence Tatman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Clarence Tatman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jan Nelsen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Jan Nelsen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jan Nelsen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jeanie Glenn</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Jeanie Glenn]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jeanie Glenn</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Peggy Smith</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Peggy Smith]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Peggy Smith</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Tish Duff</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Tish Duff]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Tish Duff</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Anita Lucero</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Anita Lucero]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Anita Lucero</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Stephen Burton</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Stephen Burton]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Stephen Burton</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Amy Consentino</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Amy Consentino]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Amy Consentino</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Stacie Mcanich</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Stacie Mcanich]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Stacie Mcanich</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Browning</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Mary Browning]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Browning</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Alexandra Wellington</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Alexandra Wellington]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Alexandra Wellington</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cory Bacugalupi</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Cory Bacugalupi]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cory Bacugalupi</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Stacy Rizzi</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Stacy Rizzi]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Stacy Rizzi</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mike White</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Mike White]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mike White</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marty Simpson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Marty Simpson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marty Simpson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Robert Jones</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Robert Jones]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Robert Jones</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Raul Casts</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Raul Casts]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Raul Casts</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bridget Browqett</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Bridget Browqett]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bridget Browqett</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kay Kartz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard].[Kay Kartz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kay Kartz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Monk Skonnard]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jeanette Cole</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Jeanette Cole]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jeanette Cole</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Phyllis Huntsman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Phyllis Huntsman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Phyllis Huntsman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Hannah Arakawa</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Hannah Arakawa]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Hannah Arakawa</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Wathalee Steuber</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Wathalee Steuber]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Wathalee Steuber</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Pamela Cox</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Pamela Cox]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Pamela Cox</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Helen Lutes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Helen Lutes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Helen Lutes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Linda Ecoffey</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Linda Ecoffey]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Linda Ecoffey</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Katherine Swint</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Katherine Swint]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Katherine Swint</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dianne Slattengren</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Dianne Slattengren]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dianne Slattengren</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ronald Heymsfield</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Ronald Heymsfield]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ronald Heymsfield</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Steven Whitehead</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Steven Whitehead]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Steven Whitehead</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>William Sotelo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[William Sotelo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>William Sotelo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Beth Stanley</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Beth Stanley]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Beth Stanley</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jill Markwood</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Jill Markwood]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jill Markwood</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mildred Valentine</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Mildred Valentine]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mildred Valentine</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Suzann Reams</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Suzann Reams]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Suzann Reams</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Audrey Wold</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Audrey Wold]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Audrey Wold</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Susan French</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Susan French]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Susan French</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Trish Pederson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Trish Pederson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Trish Pederson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eric Renn</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Eric Renn]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eric Renn</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Elizabeth Catalano</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Elizabeth Catalano]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Elizabeth Catalano</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eric Coleman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck].[Eric Coleman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eric Coleman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Daniel Wolter].[Michael John Troyer].[Christopher Beck]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sara Pettengill</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sara Pettengill</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>8</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jauna Elson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Jauna Elson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jauna Elson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nancy Hirota</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Nancy Hirota]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nancy Hirota</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marie Moya</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Marie Moya]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marie Moya</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nicky Chesnut</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Nicky Chesnut]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nicky Chesnut</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Karen Hall</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Karen Hall]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Karen Hall</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Greg Narberes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Greg Narberes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Greg Narberes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Anna Townsend</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Anna Townsend]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Anna Townsend</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carol Ann Rockne</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Carol Ann Rockne]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carol Ann Rockne</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Linda Blasingame</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill].[Linda Blasingame]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Linda Blasingame</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jackie Blackwell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill].[Jackie Blackwell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jackie Blackwell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Ortiz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill].[John Ortiz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Ortiz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Stacey Tearpak</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill].[Stacey Tearpak]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Stacey Tearpak</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Fannye Weber</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill].[Fannye Weber]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Fannye Weber</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Diane Kabbes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill].[Diane Kabbes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Diane Kabbes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brenda Heaney</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill].[Brenda Heaney]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brenda Heaney</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Judith Karavites</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill].[Judith Karavites]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Judith Karavites</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Michael Spence].[Dianne Collins].[Lawrence Hurkett].[Sara Pettengill]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gladys Mendiola</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gladys Mendiola</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>8</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>David Trolen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[David Trolen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>David Trolen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Wanda Vernon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Wanda Vernon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Wanda Vernon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Alberto Baltazar</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Alberto Baltazar]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Alberto Baltazar</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Onetha Higgs</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Onetha Higgs]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Onetha Higgs</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Hillaine Montera</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Hillaine Montera]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Hillaine Montera</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gina Ciochon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gina Ciochon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gina Ciochon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Chris Bidelman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Chris Bidelman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Chris Bidelman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Orlando Gee</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Orlando Gee]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Orlando Gee</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sharon Lynn</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola].[Sharon Lynn]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sharon Lynn</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brigid Cavendish</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola].[Brigid Cavendish]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brigid Cavendish</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Della Demott Jr</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola].[Della Demott Jr]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Della Demott Jr</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jane Carmichael</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola].[Jane Carmichael]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jane Carmichael</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mae Anderson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola].[Mae Anderson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mae Anderson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marvin Allen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola].[Marvin Allen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marvin Allen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sara Breer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola].[Sara Breer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sara Breer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Norma Barrera</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola].[Norma Barrera]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Norma Barrera</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Kim Brunner].[Donna Carreras].[Gladys Mendiola]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jacob Dean</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jacob Dean</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kendra Thompson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kendra Thompson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Liza Marie Stevens</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Liza Marie Stevens</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Megan Davis</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Megan Davis]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Megan Davis</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kerry Westgaard</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kerry Westgaard]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kerry Westgaard</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Samuel Agcaoili</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Samuel Agcaoili]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Samuel Agcaoili</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Deanna Sabella</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Deanna Sabella]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Deanna Sabella</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kara Vanderlinden</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Kara Vanderlinden]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kara Vanderlinden</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Keith Virden</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Keith Virden]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Keith Virden</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sylvia Spencer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Sylvia Spencer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sylvia Spencer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joseph Castellucio</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Joseph Castellucio]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joseph Castellucio</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Curtis Howard</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Curtis Howard]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Curtis Howard</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shannon Elliott</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Shannon Elliott]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shannon Elliott</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Andrew Kobylinski</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Andrew Kobylinski]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Andrew Kobylinski</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dora Verdad</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Dora Verdad]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dora Verdad</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dave Browning</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Dave Browning]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dave Browning</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Robert Lyeba</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Robert Lyeba]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Robert Lyeba</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Vincent White</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Vincent White]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Vincent White</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sandra Kahl</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Sandra Kahl]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sandra Kahl</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Aguilar</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[James Aguilar]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Aguilar</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gregory Vanderbout</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Gregory Vanderbout]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gregory Vanderbout</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Filomena Visser</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Filomena Visser]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Filomena Visser</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shelly Wilson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Shelly Wilson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shelly Wilson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sean Leri</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Sean Leri]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sean Leri</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mike Carr</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Mike Carr]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mike Carr</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Steven Zobairi</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Steven Zobairi]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Steven Zobairi</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Aaron Zimmerman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[Aaron Zimmerman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Aaron Zimmerman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Sherfy</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean].[John Sherfy]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Sherfy</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Jacob Dean]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Judy Zugelder</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Judy Zugelder]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Judy Zugelder</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kimberly Malmendier</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Kimberly Malmendier]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kimberly Malmendier</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Geri Farrell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Geri Farrell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Geri Farrell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Ault</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[John Ault]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Ault</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Fran Highfill</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Fran Highfill]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Fran Highfill</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jean Handley</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Jean Handley]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jean Handley</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gary Meyerhoff</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Gary Meyerhoff]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gary Meyerhoff</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shane Vigil</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Shane Vigil]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shane Vigil</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dominic Gash</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Dominic Gash]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dominic Gash</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jane Greer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Jane Greer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jane Greer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Payton Benson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Payton Benson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Payton Benson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Thomas Sanchez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Thomas Sanchez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Thomas Sanchez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Geraldine Spicer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Geraldine Spicer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Geraldine Spicer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nellie Medina</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Nellie Medina]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nellie Medina</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Richard Young</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Richard Young]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Richard Young</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Margaret Krupka</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Margaret Krupka]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Margaret Krupka</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Albert Behnke</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Albert Behnke]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Albert Behnke</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Taylor Tu</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Taylor Tu]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Taylor Tu</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>W. Harris</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[W. Harris]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>W. Harris</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cheryl Faubert</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Cheryl Faubert]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cheryl Faubert</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Margurite Bonilla</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Margurite Bonilla]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Margurite Bonilla</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Hirschboeck</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson].[Mary Hirschboeck]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Hirschboeck</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Kendra Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Julie Waggoner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Julie Waggoner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Julie Waggoner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Julie Estes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Julie Estes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Julie Estes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Vivian Jarmillo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Vivian Jarmillo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Vivian Jarmillo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joan Steele</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Joan Steele]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joan Steele</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Daniel Thompson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Daniel Thompson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Daniel Thompson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joseph Mitzner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Joseph Mitzner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joseph Mitzner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Willie Brooks</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Willie Brooks]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Willie Brooks</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ann Hass</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Ann Hass]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ann Hass</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Amir Netz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Amir Netz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Amir Netz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Geneva Hill</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Geneva Hill]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Geneva Hill</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gary Drury</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Gary Drury]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gary Drury</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Edward Buensalido</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Edward Buensalido]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Edward Buensalido</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Donovan</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[John Donovan]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Donovan</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Roberto Smith</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Roberto Smith]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Roberto Smith</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Josef Gentile</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Josef Gentile]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Josef Gentile</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sarah Tancredy</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Sarah Tancredy]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sarah Tancredy</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jason VanHarn</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Jason VanHarn]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jason VanHarn</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joyce Steffen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Joyce Steffen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joyce Steffen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carol Flynn</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Carol Flynn]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carol Flynn</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ellis Richardson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Ellis Richardson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ellis Richardson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Brew</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[James Brew]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Brew</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nadine Cook</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens].[Nadine Cook]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nadine Cook</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Blumberg].[Wayne Banack].[Liza Marie Stevens]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rodney Gentry</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rodney Gentry</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lillian Heckman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lillian Heckman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Donald Reasoner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Donald Reasoner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Melissa Wheeler</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Melissa Wheeler]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Melissa Wheeler</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Samantha Weller</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Samantha Weller]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Samantha Weller</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ian Bloomberg</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Ian Bloomberg]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ian Bloomberg</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Merav Netz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Merav Netz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Merav Netz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Maria Green</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Maria Green]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Maria Green</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Virginia Bobbitt</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Virginia Bobbitt]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Virginia Bobbitt</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Stanley Boston</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Stanley Boston]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Stanley Boston</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Josh Mullins</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Josh Mullins]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Josh Mullins</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Catherine Maes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Catherine Maes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Catherine Maes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Renee Trujillo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Renee Trujillo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Renee Trujillo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Isabel Barrington</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Isabel Barrington]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Isabel Barrington</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Donna Zuluaga</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Donna Zuluaga]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Donna Zuluaga</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Maria Marsden</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Maria Marsden]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Maria Marsden</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jeffrey Campbell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Jeffrey Campbell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jeffrey Campbell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Leonardo Roberts</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Leonardo Roberts]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Leonardo Roberts</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kathy Larkin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Kathy Larkin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kathy Larkin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Dephillipo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[John Dephillipo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Dephillipo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nellie Orando</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Nellie Orando]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nellie Orando</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Norman Troxell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Norman Troxell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Norman Troxell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Patrick Gabbard</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Patrick Gabbard]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Patrick Gabbard</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ted Lebaron</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry].[Ted Lebaron]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ted Lebaron</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Rodney Gentry]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Matthew Barry</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Matthew Barry]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Matthew Barry</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Scott Chang</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Scott Chang]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Scott Chang</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Melvin Carreras</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Melvin Carreras]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Melvin Carreras</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Karlyn Burtis</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Karlyn Burtis]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Karlyn Burtis</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Parker Abo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Parker Abo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Parker Abo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jacob Azzolino</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Jacob Azzolino]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jacob Azzolino</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Grant Archuleta</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Grant Archuleta]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Grant Archuleta</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Melvin Campos</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Melvin Campos]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Melvin Campos</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gary Unfried</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Gary Unfried]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gary Unfried</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joan Bitler</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Joan Bitler]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joan Bitler</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jim Allen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Jim Allen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jim Allen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ella Worth</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Ella Worth]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ella Worth</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ivan Mauro</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Ivan Mauro]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ivan Mauro</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Medra Hill</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Medra Hill]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Medra Hill</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael Butcher</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Michael Butcher]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael Butcher</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Amy Taurman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Amy Taurman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Amy Taurman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lillie Rachak</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Lillie Rachak]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lillie Rachak</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Loy Caro</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman].[Loy Caro]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Loy Caro</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Lillian Heckman]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Daniel Sanders</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Daniel Sanders]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Daniel Sanders</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Concetta Steinberg</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Concetta Steinberg]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Concetta Steinberg</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>William Viellieux</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[William Viellieux]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>William Viellieux</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ted Baugh</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Ted Baugh]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ted Baugh</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Roberta Bozeman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Roberta Bozeman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Roberta Bozeman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jeremy Kassab</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Jeremy Kassab]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jeremy Kassab</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Phyllis Enlow</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Phyllis Enlow]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Phyllis Enlow</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gene Lee</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Gene Lee]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gene Lee</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Linda Skapinok</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Linda Skapinok]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Linda Skapinok</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sharon Stroh</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Sharon Stroh]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sharon Stroh</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Karen Theriault</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Karen Theriault]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Karen Theriault</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Julia Ketterman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Julia Ketterman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Julia Ketterman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rose Beavers</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Rose Beavers]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rose Beavers</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Beverly Robertson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Beverly Robertson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Beverly Robertson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Margaret Potter</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Margaret Potter]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Margaret Potter</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Maya Holmes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Maya Holmes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Maya Holmes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ryan Crouch</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Ryan Crouch]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ryan Crouch</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jason Henderson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner].[Jason Henderson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jason Henderson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jonathan Murraiin].[James Thompson].[Donald Reasoner]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Harold Bauer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jewel Creek].[Leda Witte].[Harold Bauer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Harold Bauer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jewel Creek].[Leda Witte]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joseph Thompson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jewel Creek].[Leda Witte].[Joseph Thompson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joseph Thompson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Jewel Creek].[Leda Witte]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Norman Gambao</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Norman Gambao</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dorothy Snow</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dorothy Snow</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Julia Vaughn</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Julia Vaughn</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>18</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jack Baccus</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Jack Baccus]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jack Baccus</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Christopher Smith</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Christopher Smith]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Christopher Smith</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Josephine Joanne A Potter</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Josephine Joanne A Potter]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Josephine Joanne A Potter</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lisa Gerber</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Lisa Gerber]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lisa Gerber</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Deanne Vanderslice</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Deanne Vanderslice]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Deanne Vanderslice</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kathy Wood</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Kathy Wood]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kathy Wood</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Howard Bostwick</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Howard Bostwick]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Howard Bostwick</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eddie Gillmore</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Eddie Gillmore]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eddie Gillmore</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Hazel Mixon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Hazel Mixon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Hazel Mixon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Tommerup</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[John Tommerup]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Tommerup</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Emilio Martinez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Emilio Martinez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Emilio Martinez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael Glancy</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Michael Glancy]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael Glancy</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dorothy Chrisman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Dorothy Chrisman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dorothy Chrisman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Walter Taryle</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Walter Taryle]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Walter Taryle</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Herve Spencer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Herve Spencer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Herve Spencer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Christopher Tribble</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Christopher Tribble]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Christopher Tribble</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Susan Mc Nair</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Susan Mc Nair]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Susan Mc Nair</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Wilfred Ceballos</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Wilfred Ceballos]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Wilfred Ceballos</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Georgia Landrum</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Georgia Landrum]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Georgia Landrum</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Niki Netz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Niki Netz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Niki Netz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carol Amyotte</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao].[Carol Amyotte]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carol Amyotte</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Norman Gambao]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lavona Corcoran</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Lavona Corcoran]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lavona Corcoran</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dixie Good</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Dixie Good]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dixie Good</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Andrew Grosvenor</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Andrew Grosvenor]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Andrew Grosvenor</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nancy Smrha</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Nancy Smrha]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nancy Smrha</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>M. Cappa</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[M. Cappa]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>M. Cappa</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jonathan Netz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Jonathan Netz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jonathan Netz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Teresa Blanc</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Teresa Blanc]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Teresa Blanc</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>William Collins</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[William Collins]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>William Collins</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lou Scroggins</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Lou Scroggins]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lou Scroggins</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nick Skapinok</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Nick Skapinok]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nick Skapinok</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Janice Belleci</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Janice Belleci]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Janice Belleci</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ila Armstrong</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Ila Armstrong]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ila Armstrong</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Millard Koeber</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Millard Koeber]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Millard Koeber</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brian Watson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Brian Watson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brian Watson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Waddle</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Mary Waddle]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Waddle</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Alice Shintani</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Alice Shintani]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Alice Shintani</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Prudence Chavez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[Prudence Chavez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Prudence Chavez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Wilson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow].[John Wilson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Wilson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Dorothy Snow]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Robert Wright</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Robert Wright]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Robert Wright</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kenneth Kalman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Kenneth Kalman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kenneth Kalman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Greg Ponce</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Greg Ponce]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Greg Ponce</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Chad Borrelli</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Chad Borrelli]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Chad Borrelli</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Hazel Marsh</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Hazel Marsh]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Hazel Marsh</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mildred Robinson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Mildred Robinson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mildred Robinson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Susan Cox</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Susan Cox]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Susan Cox</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Janine Clare</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Janine Clare]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Janine Clare</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Barnurn</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[James Barnurn]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Barnurn</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jacquelyn Wagner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Jacquelyn Wagner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jacquelyn Wagner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rosalina Noice</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Rosalina Noice]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rosalina Noice</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sharon Lindall</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Sharon Lindall]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sharon Lindall</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Charles Noakes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Charles Noakes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Charles Noakes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>William Gill</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[William Gill]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>William Gill</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Beverly Smallwood</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Beverly Smallwood]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Beverly Smallwood</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>David Chavez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[David Chavez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>David Chavez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Deborah Blackburn</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Deborah Blackburn]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Deborah Blackburn</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Donald Abston</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn].[Donald Abston]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Donald Abston</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Medina].[Roberta Sturgel].[Julia Vaughn]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Curtis Wardley</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Curtis Wardley</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Matthew Durocher</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Matthew Durocher</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Hazel Terbush</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Hazel Terbush</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Arturo Poisson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Arturo Poisson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Arturo Poisson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shaharia Cosby</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Shaharia Cosby]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shaharia Cosby</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Amir Oss</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Amir Oss]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Amir Oss</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Smith</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[John Smith]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Smith</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Christel Christensen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Christel Christensen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Christel Christensen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Valerie Pectol</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Valerie Pectol]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Valerie Pectol</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Cornelius Baker</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Cornelius Baker]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Cornelius Baker</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Fay Finke</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Fay Finke]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Fay Finke</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Pete Fisher</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Pete Fisher]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Pete Fisher</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ida Dabit</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Ida Dabit]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ida Dabit</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shawn Turner</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Shawn Turner]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shawn Turner</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mike Clark</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Mike Clark]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mike Clark</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Arlene Schimanski</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Arlene Schimanski]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Arlene Schimanski</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carolyn Alumbaugh</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Carolyn Alumbaugh]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carolyn Alumbaugh</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Maeve Wall</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Maeve Wall]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Maeve Wall</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Margaret Clendenen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Margaret Clendenen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Margaret Clendenen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brian Willeford</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Brian Willeford]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brian Willeford</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dominick Nutter</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Dominick Nutter]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dominick Nutter</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Stacey Case</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Stacey Case]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Stacey Case</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joan Carol</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Joan Carol]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joan Carol</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ida Holmes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Ida Holmes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ida Holmes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lillian Chandler</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Lillian Chandler]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lillian Chandler</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marylou Burkett</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Marylou Burkett]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marylou Burkett</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Melvin Drake</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Melvin Drake]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Melvin Drake</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Natalie Barber</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley].[Natalie Barber]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Natalie Barber</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Curtis Wardley]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Allison Beutel</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Allison Beutel]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Allison Beutel</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ann Duvalle</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Ann Duvalle]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ann Duvalle</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kari Sloper</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Kari Sloper]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kari Sloper</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Patricia Weinzimmer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Patricia Weinzimmer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Patricia Weinzimmer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Raven Moore</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Raven Moore]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Raven Moore</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael Benson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Michael Benson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael Benson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ted Rusch</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Ted Rusch]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ted Rusch</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>David Cocadiz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[David Cocadiz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>David Cocadiz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lorraine Mcgough</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Lorraine Mcgough]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lorraine Mcgough</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bennie King</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Bennie King]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bennie King</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Melissa Smith</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Melissa Smith]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Melissa Smith</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Maria Terry</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Maria Terry]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Maria Terry</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Claudette Cabrera</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Claudette Cabrera]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Claudette Cabrera</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ethan Bunosky</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Ethan Bunosky]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ethan Bunosky</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Richard Burke</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Richard Burke]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Richard Burke</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carol Lindsay</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Carol Lindsay]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carol Lindsay</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eunice Richendollar</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Eunice Richendollar]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eunice Richendollar</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Judy Caravello</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Judy Caravello]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Judy Caravello</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marilyn Paulson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Marilyn Paulson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marilyn Paulson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Trujillo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[James Trujillo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Trujillo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>M. Barajas</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[M. Barajas]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>M. Barajas</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kara Ealey</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher].[Kara Ealey]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kara Ealey</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Matthew Durocher]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Susan Chaw</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Susan Chaw]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Susan Chaw</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Steve Reitzel</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Steve Reitzel]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Steve Reitzel</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Edie Horbach</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Edie Horbach]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Edie Horbach</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lois Knobel</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Lois Knobel]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lois Knobel</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rachel Hope</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Rachel Hope]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rachel Hope</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>M. Patricia Campbell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[M. Patricia Campbell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>M. Patricia Campbell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Selene Watson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Selene Watson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Selene Watson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Linda Anderson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Linda Anderson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Linda Anderson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Elisabeth Duncan</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Elisabeth Duncan]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Elisabeth Duncan</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>French Wilson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[French Wilson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>French Wilson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mildred Morrow</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Mildred Morrow]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mildred Morrow</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>William Murphy</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[William Murphy]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>William Murphy</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Sweet</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[John Sweet]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Sweet</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Elizabeth Jantzer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Elizabeth Jantzer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Elizabeth Jantzer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Beverly Dittmar</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Beverly Dittmar]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Beverly Dittmar</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Miggs Gutirrez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Miggs Gutirrez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Miggs Gutirrez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Frederick Pigman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Frederick Pigman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Frederick Pigman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ruth Minniear</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Ruth Minniear]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ruth Minniear</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Macario Robinson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Macario Robinson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Macario Robinson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Corrie Steger</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Corrie Steger]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Corrie Steger</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rebecca Lindsey</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Rebecca Lindsey]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rebecca Lindsey</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Dennis Larson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush].[Dennis Larson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Dennis Larson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Bryan Rutledge].[J. Scott Blauvelt].[Hazel Terbush]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kim Clifford</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kim Clifford</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>16</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lucille Smith</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lucille Smith</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>12</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Atallah Todd</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Atallah Todd</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>12</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Chris Batouche</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Chris Batouche]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Chris Batouche</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Martha Marple</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Martha Marple]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Martha Marple</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Blanche Griffin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Blanche Griffin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Blanche Griffin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Beverly Carrington</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Beverly Carrington]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Beverly Carrington</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kathy Vigil</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Kathy Vigil]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kathy Vigil</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gary Gonzales</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Gary Gonzales]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gary Gonzales</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Catherine Starr</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Catherine Starr]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Catherine Starr</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Clara Morris</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Clara Morris]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Clara Morris</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kerry Price</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Kerry Price]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kerry Price</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joyce Marez</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Joyce Marez]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joyce Marez</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eleanor Wachterman</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Eleanor Wachterman]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eleanor Wachterman</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mabel Powers</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Mabel Powers]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mabel Powers</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gregory Amburgey</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Gregory Amburgey]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gregory Amburgey</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brian Johnston</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Brian Johnston]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brian Johnston</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rama Hager</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Rama Hager]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rama Hager</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Thomas Kamas</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Thomas Kamas]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Thomas Kamas</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Anthony Barr</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Anthony Barr]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Anthony Barr</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Amy Petranoff</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Amy Petranoff]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Amy Petranoff</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marcia ONeill</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford].[Marcia ONeill]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marcia ONeill</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Kim Clifford]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Steven Murphy</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith].[Steven Murphy]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Steven Murphy</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Harold Rinks</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith].[Harold Rinks]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Harold Rinks</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>William Kroes</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith].[William Kroes]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>William Kroes</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jason Usnick</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith].[Jason Usnick]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jason Usnick</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mike Brown</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith].[Mike Brown]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mike Brown</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ronald Galich</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith].[Ronald Galich]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ronald Galich</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Daniel Posey</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith].[Daniel Posey]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Daniel Posey</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ruth Dimon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith].[Ruth Dimon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ruth Dimon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ryan Williams</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith].[Ryan Williams]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ryan Williams</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marilyn McDonald</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith].[Marilyn McDonald]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marilyn McDonald</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Verla Walter</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith].[Verla Walter]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Verla Walter</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jean McGuin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith].[Jean McGuin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jean McGuin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Lucille Smith]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Andrea Shafer</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd].[Andrea Shafer]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Andrea Shafer</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Garrett Price</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd].[Garrett Price]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Garrett Price</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Betty Driscoll</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd].[Betty Driscoll]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Betty Driscoll</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gayle Watson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd].[Gayle Watson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gayle Watson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Phyllis Ardell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd].[Phyllis Ardell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Phyllis Ardell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brian Nakauchi</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd].[Brian Nakauchi]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brian Nakauchi</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kiyo Fien</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd].[Kiyo Fien]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kiyo Fien</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brenda Stalker</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd].[Brenda Stalker]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brenda Stalker</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Wei Fan</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd].[Wei Fan]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Wei Fan</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gilbert Amper</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd].[Gilbert Amper]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gilbert Amper</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Frances Hansen</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd].[Frances Hansen]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Frances Hansen</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Virginia Craycraft</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd].[Virginia Craycraft]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Virginia Craycraft</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Walter Cavestany].[Monita Heyer].[Atallah Todd]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marjorie Marlowe</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marjorie Marlowe</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Edward Ortiz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Edward Ortiz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael Michaels</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael Michaels</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>22</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Barbara Obaugh</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Barbara Obaugh]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Barbara Obaugh</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Brett Hammons</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Brett Hammons]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Brett Hammons</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Donald Curl</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Donald Curl]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Donald Curl</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joyce Heth</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Joyce Heth]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joyce Heth</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Alice Salazar</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Alice Salazar]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Alice Salazar</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marcus Reardon</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Marcus Reardon]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marcus Reardon</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Glenn Chenault</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Glenn Chenault]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Glenn Chenault</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sandra Edwards</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Sandra Edwards]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sandra Edwards</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Williamson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[John Williamson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Williamson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Eugene Goodwater</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Eugene Goodwater]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Eugene Goodwater</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Paula Tomlinson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Paula Tomlinson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Paula Tomlinson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shauneen Springate</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Shauneen Springate]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shauneen Springate</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Delhay</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[James Delhay]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Delhay</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Linda Petrick</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Linda Petrick]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Linda Petrick</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marcella Isaacs</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Marcella Isaacs]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marcella Isaacs</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Charlotte Yonce</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Charlotte Yonce]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Charlotte Yonce</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Benjamin Foster</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Benjamin Foster]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Benjamin Foster</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>John Reed</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[John Reed]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>John Reed</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lynn Kwiatkowski</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Lynn Kwiatkowski]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lynn Kwiatkowski</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Luther Flanigan</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Luther Flanigan]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Luther Flanigan</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Oleta Shanklin</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Oleta Shanklin]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Oleta Shanklin</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Margaret Lewis</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Margaret Lewis]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Margaret Lewis</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Chris King</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Chris King]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Chris King</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Anna Frongillo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Anna Frongillo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Anna Frongillo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sheila Stallings</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe].[Sheila Stallings]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sheila Stallings</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Marjorie Marlowe]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Beulah Sowards</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Beulah Sowards]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Beulah Sowards</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Konie James</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Konie James]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Konie James</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Hazel Coy</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Hazel Coy]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Hazel Coy</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Merced Putinas</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Merced Putinas]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Merced Putinas</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marilyn Jasper</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Marilyn Jasper]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marilyn Jasper</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bernard Maestas</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Bernard Maestas]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bernard Maestas</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Thomas Balchuck</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Thomas Balchuck]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Thomas Balchuck</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Valerie Waller</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Valerie Waller]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Valerie Waller</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Beatrice Barney</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Beatrice Barney]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Beatrice Barney</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Emily Gerber</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Emily Gerber]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Emily Gerber</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Darlyn Grayson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Darlyn Grayson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Darlyn Grayson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Donald Vann</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Donald Vann]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Donald Vann</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>William Smith</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[William Smith]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>William Smith</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Amy Hensley</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Amy Hensley]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Amy Hensley</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Judy Owens</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Judy Owens]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Judy Owens</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Frederick Castillo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Frederick Castillo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Frederick Castillo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Richard Yoshimura</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Richard Yoshimura]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Richard Yoshimura</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Stacey Rowland</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Stacey Rowland]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Stacey Rowland</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Daniel Balleo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Daniel Balleo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Daniel Balleo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Myrtle Maggard</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Myrtle Maggard]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Myrtle Maggard</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Marin Bezic</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Marin Bezic]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Marin Bezic</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joan Staley</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz].[Joan Staley]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joan Staley</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Edward Ortiz]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Carl Morris</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Carl Morris]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Carl Morris</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Merceades Laudenslager</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Merceades Laudenslager]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Merceades Laudenslager</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Robin Dominica</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Robin Dominica]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Robin Dominica</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jade Brandberry</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Jade Brandberry]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jade Brandberry</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kathleen Henderson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Kathleen Henderson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kathleen Henderson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Rachel Purcell</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Rachel Purcell]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Rachel Purcell</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Steve Eurich</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Steve Eurich]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Steve Eurich</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mary Pierson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Mary Pierson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mary Pierson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Leo Jones</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Leo Jones]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Leo Jones</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Nancy Beatty</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Nancy Beatty]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Nancy Beatty</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Clara McNight</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Clara McNight]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Clara McNight</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Phil Munoz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Phil Munoz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Phil Munoz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Lori Lightfoot</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Lori Lightfoot]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Lori Lightfoot</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Joyce Simmons</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Joyce Simmons]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Joyce Simmons</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Hays</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[James Hays]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Hays</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Elizabeth Auintana</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Elizabeth Auintana]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Elizabeth Auintana</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Troy Lipford</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Troy Lipford]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Troy Lipford</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Johann Winternitz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Johann Winternitz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Johann Winternitz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ruben Burns</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Ruben Burns]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ruben Burns</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sepideh Cruz</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Sepideh Cruz]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sepideh Cruz</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Heather Geiermann</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[Heather Geiermann]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Heather Geiermann</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Eichorn</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels].[James Eichorn]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Eichorn</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Peggy Planck].[David Johnson].[Michael Michaels]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Mona Jaramillo</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Mona Jaramillo</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>8</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>James Compagno</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[James Compagno]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>James Compagno</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Hazel Souza</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Hazel Souza]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Hazel Souza</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Michael Swartwood</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Michael Swartwood]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Michael Swartwood</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Elizabeth Anderson</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Elizabeth Anderson]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Elizabeth Anderson</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Bertha Ciruli</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Bertha Ciruli]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Bertha Ciruli</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Foster Detwiler</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Foster Detwiler]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Foster Detwiler</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Gail Pirnie</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Gail Pirnie]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Gail Pirnie</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Judy Doolittle</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Judy Doolittle]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Judy Doolittle</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>5</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Ana Quick</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo].[Ana Quick]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Ana Quick</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Shirley Curtsinger</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo].[Shirley Curtsinger]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Shirley Curtsinger</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Jacqueline Cutwright</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo].[Jacqueline Cutwright]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Jacqueline Cutwright</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Sharon Bishop</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo].[Sharon Bishop]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Sharon Bishop</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Burnis Biltoft</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo].[Burnis Biltoft]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Burnis Biltoft</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Barbara Younce</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo].[Barbara Younce]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Barbara Younce</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Vivian Burnham</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo].[Vivian Burnham]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Vivian Burnham</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <MEMBER_ORDINAL>-1</MEMBER_ORDINAL>
        <MEMBER_NAME>Kris Stand</MEMBER_NAME>
        <MEMBER_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo].[Kris Stand]</MEMBER_UNIQUE_NAME>
        <MEMBER_TYPE>1</MEMBER_TYPE>
        <MEMBER_CAPTION>Kris Stand</MEMBER_CAPTION>
        <CHILDREN_CARDINALITY>0</CHILDREN_CARDINALITY>
        <PARENT_LEVEL>0</PARENT_LEVEL>
        <PARENT_UNIQUE_NAME>[Employees].[Sheri Nowmer].[Maya Gutierrez].[Brenda Marshall].[Jeanette Belsey].[Mona Jaramillo]</PARENT_UNIQUE_NAME>
        <PARENT_COUNT>1</PARENT_COUNT>
        <DEPTH>6</DEPTH>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetMDSchemaProperties":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_PROPERTIES</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>HR</CUBE_NAME>
          <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>FoodMart</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="LEVEL_UNIQUE_NAME" name="LEVEL_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="MEMBER_UNIQUE_NAME" name="MEMBER_UNIQUE_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="PROPERTY_NAME" name="PROPERTY_NAME" type="xsd:string"/>
            <xsd:element sql:field="PROPERTY_CAPTION" name="PROPERTY_CAPTION" type="xsd:string"/>
            <xsd:element sql:field="PROPERTY_TYPE" name="PROPERTY_TYPE" type="xsd:short"/>
            <xsd:element sql:field="DATA_TYPE" name="DATA_TYPE" type="xsd:unsignedShort"/>
            <xsd:element sql:field="PROPERTY_CONTENT_TYPE" name="PROPERTY_CONTENT_TYPE" type="xsd:short" minOccurs="0"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <PROPERTY_NAME>Marital Status</PROPERTY_NAME>
        <PROPERTY_CAPTION>Marital Status</PROPERTY_CAPTION>
        <PROPERTY_TYPE>1</PROPERTY_TYPE>
        <DATA_TYPE>130</DATA_TYPE>
        <PROPERTY_CONTENT_TYPE>0</PROPERTY_CONTENT_TYPE>
        <DESCRIPTION>HR Cube - Employees Hierarchy - Employee Id Level - Marital Status Property</DESCRIPTION>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <PROPERTY_NAME>Position Title</PROPERTY_NAME>
        <PROPERTY_CAPTION>Position Title</PROPERTY_CAPTION>
        <PROPERTY_TYPE>1</PROPERTY_TYPE>
        <DATA_TYPE>130</DATA_TYPE>
        <PROPERTY_CONTENT_TYPE>0</PROPERTY_CONTENT_TYPE>
        <DESCRIPTION>HR Cube - Employees Hierarchy - Employee Id Level - Position Title Property</DESCRIPTION>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <PROPERTY_NAME>Gender</PROPERTY_NAME>
        <PROPERTY_CAPTION>Gender</PROPERTY_CAPTION>
        <PROPERTY_TYPE>1</PROPERTY_TYPE>
        <DATA_TYPE>130</DATA_TYPE>
        <PROPERTY_CONTENT_TYPE>0</PROPERTY_CONTENT_TYPE>
        <DESCRIPTION>HR Cube - Employees Hierarchy - Employee Id Level - Gender Property</DESCRIPTION>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <PROPERTY_NAME>Salary</PROPERTY_NAME>
        <PROPERTY_CAPTION>Salary</PROPERTY_CAPTION>
        <PROPERTY_TYPE>1</PROPERTY_TYPE>
        <DATA_TYPE>130</DATA_TYPE>
        <PROPERTY_CONTENT_TYPE>0</PROPERTY_CONTENT_TYPE>
        <DESCRIPTION>HR Cube - Employees Hierarchy - Employee Id Level - Salary Property</DESCRIPTION>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <PROPERTY_NAME>Education Level</PROPERTY_NAME>
        <PROPERTY_CAPTION>Education Level</PROPERTY_CAPTION>
        <PROPERTY_TYPE>1</PROPERTY_TYPE>
        <DATA_TYPE>130</DATA_TYPE>
        <PROPERTY_CONTENT_TYPE>0</PROPERTY_CONTENT_TYPE>
        <DESCRIPTION>HR Cube - Employees Hierarchy - Employee Id Level - Education Level Property</DESCRIPTION>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Employees]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Employees]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_UNIQUE_NAME>[Employees].[Employee Id]</LEVEL_UNIQUE_NAME>
        <PROPERTY_NAME>Management Role</PROPERTY_NAME>
        <PROPERTY_CAPTION>Management Role</PROPERTY_CAPTION>
        <PROPERTY_TYPE>1</PROPERTY_TYPE>
        <DATA_TYPE>130</DATA_TYPE>
        <PROPERTY_CONTENT_TYPE>0</PROPERTY_CONTENT_TYPE>
        <DESCRIPTION>HR Cube - Employees Hierarchy - Employee Id Level - Management Role Property</DESCRIPTION>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetMDSchemaSets":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_SETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="SET_NAME" name="SET_NAME" type="xsd:string"/>
            <xsd:element sql:field="SCOPE" name="SCOPE" type="xsd:int"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>Warehouse</CUBE_NAME>
        <SET_NAME>[Top Sellers]</SET_NAME>
        <SCOPE>1</SCOPE>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetProperties":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_PROPERTIES</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="PropertyName" name="PropertyName" type="xsd:string"/>
            <xsd:element sql:field="PropertyDescription" name="PropertyDescription" type="xsd:string"/>
            <xsd:element sql:field="PropertyType" name="PropertyType" type="xsd:string"/>
            <xsd:element sql:field="PropertyAccessType" name="PropertyAccessType" type="xsd:string"/>
            <xsd:element sql:field="IsRequired" name="IsRequired" type="xsd:boolean"/>
            <xsd:element sql:field="Value" name="Value" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <PropertyName>AxisFormat</PropertyName>
        <PropertyDescription>Determines the format used within an MDDataSet result set to describe the axes of the multidimensional dataset. This property can have the values listed in the following table: TupleFormat (default), ClusterFormat, CustomFormat.</PropertyDescription>
        <PropertyType>Enumeration</PropertyType>
        <PropertyAccessType>Write</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value/>
      </row>
      <row>
        <PropertyName>BeginRange</PropertyName>
        <PropertyDescription>Contains a zero-based integer value corresponding to a CellOrdinal attribute value. (The CellOrdinal attribute is part of the Cell element in the CellData section of MDDataSet.) Used together with the EndRange property, the client application can use this property to restrict an OLAP dataset returned by a command to a specific range of cells. If -1 is specified, all cells up to the cell specified in the EndRange property are returned. The default value for this property is -1.</PropertyDescription>
        <PropertyType>Integer</PropertyType>
        <PropertyAccessType>Write</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value>-1</Value>
      </row>
      <row>
        <PropertyName>Catalog</PropertyName>
        <PropertyDescription>When establishing a session with an Analysis Services instance to send an XMLA command, this property is equivalent to the OLE DB property, DBPROP_INIT_CATALOG. When you set this property during a session to change the current database for the session, this property is equivalent to the OLE DB property, DBPROP_CURRENTCATALOG. The default value for this property is an empty string.</PropertyDescription>
        <PropertyType>string</PropertyType>
        <PropertyAccessType>ReadWrite</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value/>
      </row>
      <row>
        <PropertyName>Content</PropertyName>
        <PropertyDescription>An enumerator that specifies what type of data is returned in the result set. None: Allows the structure of the command to be verified, but not executed. Analogous to using Prepare to check syntax, and so on. Schema: Contains the XML schema (which indicates column information, and so on) that relates to the requested query. Data: Contains only the data that was requested. SchemaData: Returns both the schema information as well as the data.</PropertyDescription>
        <PropertyType>EnumString</PropertyType>
        <PropertyAccessType>Write</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value>SchemaData</Value>
      </row>
      <row>
        <PropertyName>Cube</PropertyName>
        <PropertyDescription>The cube context for the Command parameter. If the command contains a cube name (such as an MDX FROM clause) the setting of this property is ignored.</PropertyDescription>
        <PropertyType>string</PropertyType>
        <PropertyAccessType>ReadWrite</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value/>
      </row>
      <row>
        <PropertyName>DataSourceInfo</PropertyName>
        <PropertyDescription>A string containing provider specific information, required to access the data source.</PropertyDescription>
        <PropertyType>string</PropertyType>
        <PropertyAccessType>ReadWrite</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value/>
      </row>
      <row>
        <PropertyName>Deep</PropertyName>
        <PropertyDescription>In an MDSCHEMA_CUBES request, whether to include sub-elements (dimensions, hierarchies, levels, measures, named sets) of each cube.</PropertyDescription>
        <PropertyType>Boolean</PropertyType>
        <PropertyAccessType>ReadWrite</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value/>
      </row>
      <row>
        <PropertyName>EmitInvisibleMembers</PropertyName>
        <PropertyDescription>Whether to include members whose VISIBLE property is false, or measures whose MEASURE_IS_VISIBLE property is false.</PropertyDescription>
        <PropertyType>Boolean</PropertyType>
        <PropertyAccessType>ReadWrite</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value/>
      </row>
      <row>
        <PropertyName>EndRange</PropertyName>
        <PropertyDescription>An integer value corresponding to a CellOrdinal used to restrict an MDDataSet returned by a command to a specific range of cells. Used in conjunction with the BeginRange property. If unspecified, all cells are returned in the rowset. The value -1 means unspecified.</PropertyDescription>
        <PropertyType>Integer</PropertyType>
        <PropertyAccessType>Write</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value>-1</Value>
      </row>
      <row>
        <PropertyName>Format</PropertyName>
        <PropertyDescription>Enumerator that determines the format of the returned result set. Values include: Tabular: a flat or hierarchical rowset. Similar to the XML RAW format in SQL. The Format property should be set to Tabular for OLE DB for Data Mining commands. Multidimensional: Indicates that the result set will use the MDDataSet format (Execute method only). Native: The client does not request a specific format, so the provider may return the format  appropriate to the query. (The actual result type is identified by namespace of the result.)</PropertyDescription>
        <PropertyType>EnumString</PropertyType>
        <PropertyAccessType>Write</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value>Native</Value>
      </row>
      <row>
        <PropertyName>LocaleIdentifier</PropertyName>
        <PropertyDescription>Use this to read or set the numeric locale identifier for this request. The default is provider-specific. For the complete hexadecimal list of language identifiers, search on "Language Identifiers" in the MSDN Library at http://www.msdn.microsoft.com. As an extension to the XMLA standard, Mondrian also allows locale codes as specified by ISO-639 and ISO-3166 and as used by Java; for example 'en-US'. </PropertyDescription>
        <PropertyType>UnsignedInteger</PropertyType>
        <PropertyAccessType>ReadWrite</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value>None</Value>
      </row>
      <row>
        <PropertyName>MDXSupport</PropertyName>
        <PropertyDescription>Enumeration that describes the degree of MDX support. At initial release Core is the only value in the enumeration. In future releases, other values will be defined for this enumeration.</PropertyDescription>
        <PropertyType>EnumString</PropertyType>
        <PropertyAccessType>Read</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value>Core</Value>
      </row>
      <row>
        <PropertyName>Password</PropertyName>
        <PropertyDescription>This property is deprecated in XMLA 1.1. To support legacy applications, the provider accepts but ignores the Password property setting when it is used with the Discover and Execute method</PropertyDescription>
        <PropertyType>string</PropertyType>
        <PropertyAccessType>Read</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value/>
      </row>
      <row>
        <PropertyName>ProviderName</PropertyName>
        <PropertyDescription>The XML for Analysis Provider name.</PropertyDescription>
        <PropertyType>string</PropertyType>
        <PropertyAccessType>Read</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value>Mondrian XML for Analysis Provider</Value>
      </row>
      <row>
        <PropertyName>ProviderVersion</PropertyName>
        <PropertyDescription>The version of the Mondrian XMLA Provider</PropertyDescription>
        <PropertyType>string</PropertyType>
        <PropertyAccessType>Read</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value>3.130</Value>
      </row>
      <row>
        <PropertyName>ResponseMimeType</PropertyName>
        <PropertyDescription>Accepted mime type for RPC response; accepted are 'text/xml' (default), 'application/xml' (equivalent to 'text/xml'), or 'application/json'. If not specified, value in the 'Accept' header of the HTTP request is used.</PropertyDescription>
        <PropertyType>string</PropertyType>
        <PropertyAccessType>ReadWrite</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value>None</Value>
      </row>
      <row>
        <PropertyName>StateSupport</PropertyName>
        <PropertyDescription>Property that specifies the degree of support in the provider for state. For information about state in XML for Analysis, see "Support for Statefulness in XML for Analysis." Minimum enumeration values are as follows: None - No support for sessions or stateful operations. Sessions - Provider supports sessions.</PropertyDescription>
        <PropertyType>EnumString</PropertyType>
        <PropertyAccessType>Read</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value>None</Value>
      </row>
      <row>
        <PropertyName>Timeout</PropertyName>
        <PropertyDescription>A numeric time-out specifying in seconds the amount of time to wait for a request to be successful.</PropertyDescription>
        <PropertyType>UnsignedInteger</PropertyType>
        <PropertyAccessType>ReadWrite</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value>Undefined</Value>
      </row>
      <row>
        <PropertyName>UserName</PropertyName>
        <PropertyDescription>Returns the UserName the server associates with the command. This property is deprecated as writeable in XMLA 1.1. To support legacy applications, servers accept but ignore the password setting when it is used with the Execute method.</PropertyDescription>
        <PropertyType>string</PropertyType>
        <PropertyAccessType>Read</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value/>
      </row>
      <row>
        <PropertyName>VisualMode</PropertyName>
        <PropertyDescription>This property is equivalent to the OLE DB property, MDPROP_VISUALMODE. The default value for this property is zero (0), equivalent to DBPROPVAL_VISUAL_MODE_DEFAULT.</PropertyDescription>
        <PropertyType>Enumeration</PropertyType>
        <PropertyAccessType>Write</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value>1</Value>
      </row>
      <row>
        <PropertyName>TableFields</PropertyName>
        <PropertyDescription>List of fields to return for drill-through. The default value of this property is the empty string,in which case, all fields are returned.</PropertyDescription>
        <PropertyType>string</PropertyType>
        <PropertyAccessType>Read</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value/>
      </row>
      <row>
        <PropertyName>AdvancedFlag</PropertyName>
        <PropertyDescription/>
        <PropertyType>Boolean</PropertyType>
        <PropertyAccessType>Read</PropertyAccessType>
        <IsRequired>false</IsRequired>
        <Value>false</Value>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetSchemaLevels":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>MDSCHEMA_LEVELS</RequestType>
      <Restrictions>
        <RestrictionList>
          <CUBE_NAME>HR</CUBE_NAME>
          <HIERARCHY_UNIQUE_NAME>[Time]</HIERARCHY_UNIQUE_NAME>
        </RestrictionList>
      </Restrictions>
      <Properties>
        <PropertyList>
          <Catalog>FoodMart</Catalog>
        </PropertyList>
      </Properties>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="CATALOG_NAME" name="CATALOG_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="SCHEMA_NAME" name="SCHEMA_NAME" type="xsd:string" minOccurs="0"/>
            <xsd:element sql:field="CUBE_NAME" name="CUBE_NAME" type="xsd:string"/>
            <xsd:element sql:field="DIMENSION_UNIQUE_NAME" name="DIMENSION_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="HIERARCHY_UNIQUE_NAME" name="HIERARCHY_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="LEVEL_NAME" name="LEVEL_NAME" type="xsd:string"/>
            <xsd:element sql:field="LEVEL_UNIQUE_NAME" name="LEVEL_UNIQUE_NAME" type="xsd:string"/>
            <xsd:element sql:field="LEVEL_GUID" name="LEVEL_GUID" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="LEVEL_CAPTION" name="LEVEL_CAPTION" type="xsd:string"/>
            <xsd:element sql:field="LEVEL_NUMBER" name="LEVEL_NUMBER" type="xsd:unsignedInt"/>
            <xsd:element sql:field="LEVEL_CARDINALITY" name="LEVEL_CARDINALITY" type="xsd:unsignedInt"/>
            <xsd:element sql:field="LEVEL_TYPE" name="LEVEL_TYPE" type="xsd:int"/>
            <xsd:element sql:field="CUSTOM_ROLLUP_SETTINGS" name="CUSTOM_ROLLUP_SETTINGS" type="xsd:int"/>
            <xsd:element sql:field="LEVEL_UNIQUE_SETTINGS" name="LEVEL_UNIQUE_SETTINGS" type="xsd:int"/>
            <xsd:element sql:field="LEVEL_IS_VISIBLE" name="LEVEL_IS_VISIBLE" type="xsd:boolean"/>
            <xsd:element sql:field="DESCRIPTION" name="DESCRIPTION" type="xsd:string" minOccurs="0"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Time]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Time]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_NAME>Year</LEVEL_NAME>
        <LEVEL_UNIQUE_NAME>[Time].[Year]</LEVEL_UNIQUE_NAME>
        <LEVEL_CAPTION>Year</LEVEL_CAPTION>
        <LEVEL_NUMBER>0</LEVEL_NUMBER>
        <LEVEL_CARDINALITY>2</LEVEL_CARDINALITY>
        <LEVEL_TYPE>20</LEVEL_TYPE>
        <CUSTOM_ROLLUP_SETTINGS>0</CUSTOM_ROLLUP_SETTINGS>
        <LEVEL_UNIQUE_SETTINGS>1</LEVEL_UNIQUE_SETTINGS>
        <LEVEL_IS_VISIBLE>true</LEVEL_IS_VISIBLE>
        <DESCRIPTION>HR Cube - Time Hierarchy - Year Level</DESCRIPTION>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Time]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Time]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_NAME>Quarter</LEVEL_NAME>
        <LEVEL_UNIQUE_NAME>[Time].[Quarter]</LEVEL_UNIQUE_NAME>
        <LEVEL_CAPTION>Quarter</LEVEL_CAPTION>
        <LEVEL_NUMBER>1</LEVEL_NUMBER>
        <LEVEL_CARDINALITY>8</LEVEL_CARDINALITY>
        <LEVEL_TYPE>68</LEVEL_TYPE>
        <CUSTOM_ROLLUP_SETTINGS>0</CUSTOM_ROLLUP_SETTINGS>
        <LEVEL_UNIQUE_SETTINGS>0</LEVEL_UNIQUE_SETTINGS>
        <LEVEL_IS_VISIBLE>true</LEVEL_IS_VISIBLE>
        <DESCRIPTION>HR Cube - Time Hierarchy - Quarter Level</DESCRIPTION>
      </row>
      <row>
        <CATALOG_NAME>FoodMart</CATALOG_NAME>
        <SCHEMA_NAME>FoodMart</SCHEMA_NAME>
        <CUBE_NAME>HR</CUBE_NAME>
        <DIMENSION_UNIQUE_NAME>[Time]</DIMENSION_UNIQUE_NAME>
        <HIERARCHY_UNIQUE_NAME>[Time]</HIERARCHY_UNIQUE_NAME>
        <LEVEL_NAME>Month</LEVEL_NAME>
        <LEVEL_UNIQUE_NAME>[Time].[Month]</LEVEL_UNIQUE_NAME>
        <LEVEL_CAPTION>Month</LEVEL_CAPTION>
        <LEVEL_NUMBER>2</LEVEL_NUMBER>
        <LEVEL_CARDINALITY>24</LEVEL_CARDINALITY>
        <LEVEL_TYPE>132</LEVEL_TYPE>
        <CUSTOM_ROLLUP_SETTINGS>0</CUSTOM_ROLLUP_SETTINGS>
        <LEVEL_UNIQUE_SETTINGS>0</LEVEL_UNIQUE_SETTINGS>
        <LEVEL_IS_VISIBLE>true</LEVEL_IS_VISIBLE>
        <DESCRIPTION>HR Cube - Time Hierarchy - Month Level</DESCRIPTION>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
    "testGetSchemaRowsets":[
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
        ("request", """<soap-env:Envelope xmlns:soap-env="http://schemas.xmlsoap.org/soap/envelope/" xmlns="urn:schemas-microsoft-com:xml-analysis">
  <soap-env:Body>
    <Discover>
      <RequestType>DISCOVER_SCHEMA_ROWSETS</RequestType>
      <Restrictions xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
      <Properties xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"/>
    </Discover>
  </soap-env:Body>
</soap-env:Envelope>
"""),
        ("response", """<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Header>
</SOAP-ENV:Header>
<SOAP-ENV:Body>
<cxmla:DiscoverResponse xmlns:cxmla="urn:schemas-microsoft-com:xml-analysis">
  <cxmla:return>
    <root xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:EX="urn:schemas-microsoft-com:xml-analysis:exception">
      <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns="urn:schemas-microsoft-com:xml-analysis:rowset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sql="urn:schemas-microsoft-com:xml-sql" targetNamespace="urn:schemas-microsoft-com:xml-analysis:rowset" elementFormDefault="qualified">
        <xsd:element name="root">
          <xsd:complexType>
            <xsd:sequence>
              <xsd:element name="row" type="row" minOccurs="0" maxOccurs="unbounded"/>
            </xsd:sequence>
          </xsd:complexType>
        </xsd:element>
        <xsd:simpleType name="uuid">
          <xsd:restriction base="xsd:string">
            <xsd:pattern value="[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"/>
          </xsd:restriction>
        </xsd:simpleType>
        <xsd:complexType name="row">
          <xsd:sequence>
            <xsd:element sql:field="SchemaName" name="SchemaName" type="xsd:string"/>
            <xsd:element sql:field="SchemaGuid" name="SchemaGuid" type="uuid" minOccurs="0"/>
            <xsd:element sql:field="Restrictions" name="Restrictions" minOccurs="0" maxOccurs="unbounded">
              <xsd:complexType>
                <xsd:sequence>
                  <xsd:element name="Name" type="xsd:string" sql:field="Name"/>
                  <xsd:element name="Type" type="xsd:string" sql:field="Type"/>
                </xsd:sequence>
              </xsd:complexType>
            </xsd:element>
            <xsd:element sql:field="Description" name="Description" type="xsd:string"/>
          </xsd:sequence>
        </xsd:complexType>
      </xsd:schema>
      <row>
        <SchemaName>DBSCHEMA_CATALOGS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Identifies the physical attributes associated with catalogs accessible from the provider.</Description>
      </row>
      <row>
        <SchemaName>DBSCHEMA_COLUMNS</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COLUMN_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_PROVIDER_TYPES</SchemaName>
        <Restrictions>
          <Name>DATA_TYPE</Name>
          <Type>xsd:unsignedShort</Type>
        </Restrictions>
        <Restrictions>
          <Name>BEST_MATCH</Name>
          <Type>xsd:boolean</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_SCHEMATA</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_OWNER</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DBSCHEMA_TABLES_INFO</SchemaName>
        <Restrictions>
          <Name>TABLE_CATALOG</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_SCHEMA</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TABLE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>DISCOVER_DATASOURCES</SchemaName>
        <Restrictions>
          <Name>DataSourceName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>URL</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ProviderType</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>AuthenticationMode</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of XML for Analysis data sources available on the server or Web Service.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_ENUMERATORS</SchemaName>
        <Restrictions>
          <Name>EnumName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of names, data types, and enumeration values for enumerators supported by the provider of a specific data source.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_KEYWORDS</SchemaName>
        <Restrictions>
          <Name>Keyword</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns an XML list of keywords reserved by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_LITERALS</SchemaName>
        <Restrictions>
          <Name>LiteralName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns information about literals supported by the provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>PropertyName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns a list of information and values about the requested properties that are supported by the specified data source provider.</Description>
      </row>
      <row>
        <SchemaName>DISCOVER_SCHEMA_ROWSETS</SchemaName>
        <Restrictions>
          <Name>SchemaName</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description>Returns the names, values, and other information of all supported RequestType enumeration values.</Description>
      </row>
      <row>
        <SchemaName>MDSCHEMA_ACTIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ACTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>COORDINATE_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_CUBES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_TYPE</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_DIMENSIONS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_FUNCTIONS</SchemaName>
        <Restrictions>
          <Name>FUNCTION_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>ORIGIN</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>INTERFACE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LIBRARY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_HIERARCHIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_LEVELS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEASURES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEASURE_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_MEMBERS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_NUMBER</Name>
          <Type>xsd:unsignedInt</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_TYPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_CAPTION</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>TREE_OP</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_PROPERTIES</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>DIMENSION_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>HIERARCHY_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>LEVEL_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>MEMBER_UNIQUE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Restrictions>
          <Name>PROPERTY_CONTENT_TYPE</Name>
          <Type>xsd:short</Type>
        </Restrictions>
        <Description/>
      </row>
      <row>
        <SchemaName>MDSCHEMA_SETS</SchemaName>
        <Restrictions>
          <Name>CATALOG_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCHEMA_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>CUBE_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SET_NAME</Name>
          <Type>xsd:string</Type>
        </Restrictions>
        <Restrictions>
          <Name>SCOPE</Name>
          <Type>xsd:int</Type>
        </Restrictions>
        <Description/>
      </row>
    </root>
  </cxmla:return>
</cxmla:DiscoverResponse>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""),
    ],
}